# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: otg.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='otg.proto',
  package='otg',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\totg.proto\x12\x03otg\x1a google/protobuf/descriptor.proto\x1a\x1bgoogle/protobuf/empty.proto\"\x91\x02\n\x06\x43onfig\x12\x18\n\x05ports\x18\x01 \x03(\x0b\x32\t.otg.Port\x12\x16\n\x04lags\x18\x02 \x03(\x0b\x32\x08.otg.Lag\x12\x1b\n\x06layer1\x18\x03 \x03(\x0b\x32\x0b.otg.Layer1\x12\x1e\n\x08\x63\x61ptures\x18\x04 \x03(\x0b\x32\x0c.otg.Capture\x12\x1c\n\x07\x64\x65vices\x18\x05 \x03(\x0b\x32\x0b.otg.Device\x12\x18\n\x05\x66lows\x18\x06 \x03(\x0b\x32\t.otg.Flow\x12\x1f\n\x06\x65vents\x18\x07 \x01(\x0b\x32\n.otg.EventH\x00\x88\x01\x01\x12(\n\x07options\x18\x08 \x01(\x0b\x32\x12.otg.ConfigOptionsH\x01\x88\x01\x01\x42\t\n\x07_eventsB\n\n\x08_options\"M\n\rConfigOptions\x12+\n\x0cport_options\x18\x01 \x01(\x0b\x32\x10.otg.PortOptionsH\x00\x88\x01\x01\x42\x0f\n\r_port_options\"8\n\x04Port\x12\x15\n\x08location\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x0c\n\x04name\x18\x02 \x01(\tB\x0b\n\t_location\"G\n\x0bPortOptions\x12 \n\x13location_preemption\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\x16\n\x14_location_preemption\"0\n\x03Lag\x12\x1b\n\x05ports\x18\x01 \x03(\x0b\x32\x0c.otg.LagPort\x12\x0c\n\x04name\x18\x02 \x01(\t\"k\n\x07LagPort\x12\x11\n\tport_name\x18\x01 \x01(\t\x12\"\n\x08protocol\x18\x02 \x01(\x0b\x32\x10.otg.LagProtocol\x12)\n\x08\x65thernet\x18\x03 \x01(\x0b\x32\x17.otg.DeviceEthernetBase\"\xde\x01\n\x0bLagProtocol\x12\x31\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1c.otg.LagProtocol.Choice.EnumH\x00\x88\x01\x01\x12\x1f\n\x04lacp\x18\x02 \x01(\x0b\x32\x0c.otg.LagLacpH\x01\x88\x01\x01\x12#\n\x06static\x18\x03 \x01(\x0b\x32\x0e.otg.LagStaticH\x02\x88\x01\x01\x1a\x37\n\x06\x43hoice\"-\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04lacp\x10\x01\x12\n\n\x06static\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_lacpB\t\n\x07_static\"+\n\tLagStatic\x12\x13\n\x06lag_id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x42\t\n\x07_lag_id\"\xa1\x04\n\x07LagLacp\x12\x16\n\tactor_key\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x1e\n\x11\x61\x63tor_port_number\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12 \n\x13\x61\x63tor_port_priority\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x1c\n\x0f\x61\x63tor_system_id\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\"\n\x15\x61\x63tor_system_priority\x18\x05 \x01(\x05H\x04\x88\x01\x01\x12*\n\x1dlacpdu_periodic_time_interval\x18\x06 \x01(\x05H\x05\x88\x01\x01\x12\x1b\n\x0elacpdu_timeout\x18\x07 \x01(\x05H\x06\x88\x01\x01\x12<\n\x0e\x61\x63tor_activity\x18\x08 \x01(\x0e\x32\x1f.otg.LagLacp.ActorActivity.EnumH\x07\x88\x01\x01\x1a\x41\n\rActorActivity\"0\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07passive\x10\x01\x12\n\n\x06\x61\x63tive\x10\x02\x42\x0c\n\n_actor_keyB\x14\n\x12_actor_port_numberB\x16\n\x14_actor_port_priorityB\x12\n\x10_actor_system_idB\x18\n\x16_actor_system_priorityB \n\x1e_lacpdu_periodic_time_intervalB\x11\n\x0f_lacpdu_timeoutB\x11\n\x0f_actor_activity\"i\n\x12\x44\x65viceEthernetBase\x12\x0b\n\x03mac\x18\x01 \x01(\t\x12\x10\n\x03mtu\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x1e\n\x05vlans\x18\x03 \x03(\x0b\x32\x0f.otg.DeviceVlan\x12\x0c\n\x04name\x18\x04 \x01(\tB\x06\n\x04_mtu\"\xca\x01\n\x0e\x44\x65viceEthernet\x12\x11\n\tport_name\x18\x01 \x01(\t\x12\'\n\x0eipv4_addresses\x18\x02 \x03(\x0b\x32\x0f.otg.DeviceIpv4\x12\'\n\x0eipv6_addresses\x18\x03 \x03(\x0b\x32\x0f.otg.DeviceIpv6\x12\x0b\n\x03mac\x18\x04 \x01(\t\x12\x10\n\x03mtu\x18\x05 \x01(\x05H\x00\x88\x01\x01\x12\x1e\n\x05vlans\x18\x06 \x03(\x0b\x32\x0f.otg.DeviceVlan\x12\x0c\n\x04name\x18\x07 \x01(\tB\x06\n\x04_mtu\"\xe5\x01\n\nDeviceVlan\x12,\n\x04tpid\x18\x01 \x01(\x0e\x32\x19.otg.DeviceVlan.Tpid.EnumH\x00\x88\x01\x01\x12\x15\n\x08priority\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0f\n\x02id\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x0c\n\x04name\x18\x04 \x01(\t\x1aV\n\x04Tpid\"N\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05x8100\x10\x01\x12\t\n\x05x88a8\x10\x02\x12\t\n\x05x9100\x10\x03\x12\t\n\x05x9200\x10\x04\x12\t\n\x05x9300\x10\x05\x42\x07\n\x05_tpidB\x0b\n\t_priorityB\x05\n\x03_id\"\\\n\nDeviceIpv4\x12\x0f\n\x07gateway\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x13\n\x06prefix\x18\x03 \x01(\x05H\x00\x88\x01\x01\x12\x0c\n\x04name\x18\x04 \x01(\tB\t\n\x07_prefix\"V\n\x12\x44\x65viceIpv4Loopback\x12\x10\n\x08\x65th_name\x18\x01 \x01(\t\x12\x14\n\x07\x61\x64\x64ress\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x0c\n\x04name\x18\x03 \x01(\tB\n\n\x08_address\"\\\n\nDeviceIpv6\x12\x0f\n\x07gateway\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x13\n\x06prefix\x18\x03 \x01(\x05H\x00\x88\x01\x01\x12\x0c\n\x04name\x18\x04 \x01(\tB\t\n\x07_prefix\"V\n\x12\x44\x65viceIpv6Loopback\x12\x10\n\x08\x65th_name\x18\x01 \x01(\t\x12\x14\n\x07\x61\x64\x64ress\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x0c\n\x04name\x18\x03 \x01(\tB\n\n\x08_address\"\xb4\x06\n\x06Layer1\x12\x12\n\nport_names\x18\x01 \x03(\t\x12*\n\x05speed\x18\x02 \x01(\x0e\x32\x16.otg.Layer1.Speed.EnumH\x00\x88\x01\x01\x12*\n\x05media\x18\x03 \x01(\x0e\x32\x16.otg.Layer1.Media.EnumH\x01\x88\x01\x01\x12\x18\n\x0bpromiscuous\x18\x04 \x01(\x08H\x02\x88\x01\x01\x12\x10\n\x03mtu\x18\x05 \x01(\x05H\x03\x88\x01\x01\x12 \n\x13ieee_media_defaults\x18\x06 \x01(\x08H\x04\x88\x01\x01\x12\x1b\n\x0e\x61uto_negotiate\x18\x07 \x01(\x08H\x05\x88\x01\x01\x12\x39\n\x10\x61uto_negotiation\x18\x08 \x01(\x0b\x32\x1a.otg.Layer1AutoNegotiationH\x06\x88\x01\x01\x12\x31\n\x0c\x66low_control\x18\t \x01(\x0b\x32\x16.otg.Layer1FlowControlH\x07\x88\x01\x01\x12\x0c\n\x04name\x18\n \x01(\t\x1a\x95\x02\n\x05Speed\"\x8b\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x14\n\x10speed_10_fd_mbps\x10\x01\x12\x14\n\x10speed_10_hd_mbps\x10\x02\x12\x15\n\x11speed_100_fd_mbps\x10\x03\x12\x15\n\x11speed_100_hd_mbps\x10\x04\x12\x10\n\x0cspeed_1_gbps\x10\x05\x12\x11\n\rspeed_10_gbps\x10\x06\x12\x11\n\rspeed_25_gbps\x10\x07\x12\x11\n\rspeed_40_gbps\x10\x08\x12\x11\n\rspeed_50_gbps\x10\t\x12\x12\n\x0espeed_100_gbps\x10\n\x12\x12\n\x0espeed_200_gbps\x10\x0b\x12\x12\n\x0espeed_400_gbps\x10\x0c\x1a\x42\n\x05Media\"9\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06\x63opper\x10\x01\x12\t\n\x05\x66iber\x10\x02\x12\t\n\x05sgmii\x10\x03\x42\x08\n\x06_speedB\x08\n\x06_mediaB\x0e\n\x0c_promiscuousB\x06\n\x04_mtuB\x16\n\x14_ieee_media_defaultsB\x11\n\x0f_auto_negotiateB\x13\n\x11_auto_negotiationB\x0f\n\r_flow_control\"\x93\x03\n\x15Layer1AutoNegotiation\x12 \n\x13\x61\x64vertise_1000_mbps\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\"\n\x15\x61\x64vertise_100_fd_mbps\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\"\n\x15\x61\x64vertise_100_hd_mbps\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12!\n\x14\x61\x64vertise_10_fd_mbps\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12!\n\x14\x61\x64vertise_10_hd_mbps\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x1a\n\rlink_training\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x13\n\x06rs_fec\x18\x07 \x01(\x08H\x06\x88\x01\x01\x42\x16\n\x14_advertise_1000_mbpsB\x18\n\x16_advertise_100_fd_mbpsB\x18\n\x16_advertise_100_hd_mbpsB\x17\n\x15_advertise_10_fd_mbpsB\x17\n\x15_advertise_10_hd_mbpsB\x10\n\x0e_link_trainingB\t\n\x07_rs_fec\"\xd8\x02\n\x11Layer1FlowControl\x12\x1d\n\x10\x64irected_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x37\n\x06\x63hoice\x18\x02 \x01(\x0e\x32\".otg.Layer1FlowControl.Choice.EnumH\x01\x88\x01\x01\x12\x32\n\rieee_802_1qbb\x18\x03 \x01(\x0b\x32\x16.otg.Layer1Ieee8021qbbH\x02\x88\x01\x01\x12.\n\x0bieee_802_3x\x18\x04 \x01(\x0b\x32\x14.otg.Layer1Ieee8023xH\x03\x88\x01\x01\x1a\x45\n\x06\x43hoice\";\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rieee_802_1qbb\x10\x01\x12\x0f\n\x0bieee_802_3x\x10\x02\x42\x13\n\x11_directed_addressB\t\n\x07_choiceB\x10\n\x0e_ieee_802_1qbbB\x0e\n\x0c_ieee_802_3x\"\x11\n\x0fLayer1Ieee8023x\"\x89\x03\n\x11Layer1Ieee8021qbb\x12\x16\n\tpfc_delay\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x18\n\x0bpfc_class_0\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x18\n\x0bpfc_class_1\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x18\n\x0bpfc_class_2\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12\x18\n\x0bpfc_class_3\x18\x05 \x01(\x05H\x04\x88\x01\x01\x12\x18\n\x0bpfc_class_4\x18\x06 \x01(\x05H\x05\x88\x01\x01\x12\x18\n\x0bpfc_class_5\x18\x07 \x01(\x05H\x06\x88\x01\x01\x12\x18\n\x0bpfc_class_6\x18\x08 \x01(\x05H\x07\x88\x01\x01\x12\x18\n\x0bpfc_class_7\x18\t \x01(\x05H\x08\x88\x01\x01\x42\x0c\n\n_pfc_delayB\x0e\n\x0c_pfc_class_0B\x0e\n\x0c_pfc_class_1B\x0e\n\x0c_pfc_class_2B\x0e\n\x0c_pfc_class_3B\x0e\n\x0c_pfc_class_4B\x0e\n\x0c_pfc_class_5B\x0e\n\x0c_pfc_class_6B\x0e\n\x0c_pfc_class_7\"\x93\x02\n\x07\x43\x61pture\x12\x12\n\nport_names\x18\x01 \x03(\t\x12#\n\x07\x66ilters\x18\x02 \x03(\x0b\x32\x12.otg.CaptureFilter\x12\x16\n\toverwrite\x18\x03 \x01(\x08H\x00\x88\x01\x01\x12\x18\n\x0bpacket_size\x18\x04 \x01(\x05H\x01\x88\x01\x01\x12-\n\x06\x66ormat\x18\x05 \x01(\x0e\x32\x18.otg.Capture.Format.EnumH\x02\x88\x01\x01\x12\x0c\n\x04name\x18\x06 \x01(\t\x1a\x37\n\x06\x46ormat\"-\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04pcap\x10\x01\x12\n\n\x06pcapng\x10\x02\x42\x0c\n\n_overwriteB\x0e\n\x0c_packet_sizeB\t\n\x07_format\"\xa2\x03\n\rCaptureFilter\x12\x33\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1e.otg.CaptureFilter.Choice.EnumH\x00\x88\x01\x01\x12\'\n\x06\x63ustom\x18\x02 \x01(\x0b\x32\x12.otg.CaptureCustomH\x01\x88\x01\x01\x12+\n\x08\x65thernet\x18\x03 \x01(\x0b\x32\x14.otg.CaptureEthernetH\x02\x88\x01\x01\x12#\n\x04vlan\x18\x04 \x01(\x0b\x32\x10.otg.CaptureVlanH\x03\x88\x01\x01\x12#\n\x04ipv4\x18\x05 \x01(\x0b\x32\x10.otg.CaptureIpv4H\x04\x88\x01\x01\x12#\n\x04ipv6\x18\x06 \x01(\x0b\x32\x10.otg.CaptureIpv6H\x05\x88\x01\x01\x1aY\n\x06\x43hoice\"O\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06\x63ustom\x10\x01\x12\x0c\n\x08\x65thernet\x10\x02\x12\x08\n\x04vlan\x10\x03\x12\x08\n\x04ipv4\x10\x04\x12\x08\n\x04ipv6\x10\x05\x42\t\n\x07_choiceB\t\n\x07_customB\x0b\n\t_ethernetB\x07\n\x05_vlanB\x07\n\x05_ipv4B\x07\n\x05_ipv6\"\xb1\x01\n\rCaptureCustom\x12\x13\n\x06offset\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x17\n\nbit_length\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x11\n\x04mask\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x13\n\x06negate\x18\x05 \x01(\x08H\x04\x88\x01\x01\x42\t\n\x07_offsetB\r\n\x0b_bit_lengthB\x08\n\x06_valueB\x07\n\x05_maskB\t\n\x07_negate\"h\n\x0c\x43\x61ptureField\x12\x12\n\x05value\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04mask\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06negate\x18\x03 \x01(\x08H\x02\x88\x01\x01\x42\x08\n\x06_valueB\x07\n\x05_maskB\t\n\x07_negate\"\xdf\x01\n\x0f\x43\x61ptureEthernet\x12#\n\x03src\x18\x01 \x01(\x0b\x32\x11.otg.CaptureFieldH\x00\x88\x01\x01\x12#\n\x03\x64st\x18\x02 \x01(\x0b\x32\x11.otg.CaptureFieldH\x01\x88\x01\x01\x12*\n\nether_type\x18\x03 \x01(\x0b\x32\x11.otg.CaptureFieldH\x02\x88\x01\x01\x12)\n\tpfc_queue\x18\x04 \x01(\x0b\x32\x11.otg.CaptureFieldH\x03\x88\x01\x01\x42\x06\n\x04_srcB\x06\n\x04_dstB\r\n\x0b_ether_typeB\x0c\n\n_pfc_queue\"\xd3\x01\n\x0b\x43\x61ptureVlan\x12(\n\x08priority\x18\x01 \x01(\x0b\x32\x11.otg.CaptureFieldH\x00\x88\x01\x01\x12#\n\x03\x63\x66i\x18\x02 \x01(\x0b\x32\x11.otg.CaptureFieldH\x01\x88\x01\x01\x12\"\n\x02id\x18\x03 \x01(\x0b\x32\x11.otg.CaptureFieldH\x02\x88\x01\x01\x12(\n\x08protocol\x18\x04 \x01(\x0b\x32\x11.otg.CaptureFieldH\x03\x88\x01\x01\x42\x0b\n\t_priorityB\x06\n\x04_cfiB\x05\n\x03_idB\x0b\n\t_protocol\"\xd1\x06\n\x0b\x43\x61ptureIpv4\x12\'\n\x07version\x18\x01 \x01(\x0b\x32\x11.otg.CaptureFieldH\x00\x88\x01\x01\x12-\n\rheader_length\x18\x02 \x01(\x0b\x32\x11.otg.CaptureFieldH\x01\x88\x01\x01\x12(\n\x08priority\x18\x03 \x01(\x0b\x32\x11.otg.CaptureFieldH\x02\x88\x01\x01\x12,\n\x0ctotal_length\x18\x04 \x01(\x0b\x32\x11.otg.CaptureFieldH\x03\x88\x01\x01\x12.\n\x0eidentification\x18\x05 \x01(\x0b\x32\x11.otg.CaptureFieldH\x04\x88\x01\x01\x12(\n\x08reserved\x18\x06 \x01(\x0b\x32\x11.otg.CaptureFieldH\x05\x88\x01\x01\x12-\n\rdont_fragment\x18\x07 \x01(\x0b\x32\x11.otg.CaptureFieldH\x06\x88\x01\x01\x12.\n\x0emore_fragments\x18\x08 \x01(\x0b\x32\x11.otg.CaptureFieldH\x07\x88\x01\x01\x12/\n\x0f\x66ragment_offset\x18\t \x01(\x0b\x32\x11.otg.CaptureFieldH\x08\x88\x01\x01\x12,\n\x0ctime_to_live\x18\n \x01(\x0b\x32\x11.otg.CaptureFieldH\t\x88\x01\x01\x12(\n\x08protocol\x18\x0b \x01(\x0b\x32\x11.otg.CaptureFieldH\n\x88\x01\x01\x12/\n\x0fheader_checksum\x18\x0c \x01(\x0b\x32\x11.otg.CaptureFieldH\x0b\x88\x01\x01\x12#\n\x03src\x18\r \x01(\x0b\x32\x11.otg.CaptureFieldH\x0c\x88\x01\x01\x12#\n\x03\x64st\x18\x0e \x01(\x0b\x32\x11.otg.CaptureFieldH\r\x88\x01\x01\x42\n\n\x08_versionB\x10\n\x0e_header_lengthB\x0b\n\t_priorityB\x0f\n\r_total_lengthB\x11\n\x0f_identificationB\x0b\n\t_reservedB\x10\n\x0e_dont_fragmentB\x11\n\x0f_more_fragmentsB\x12\n\x10_fragment_offsetB\x0f\n\r_time_to_liveB\x0b\n\t_protocolB\x12\n\x10_header_checksumB\x06\n\x04_srcB\x06\n\x04_dst\"\xd1\x03\n\x0b\x43\x61ptureIpv6\x12\'\n\x07version\x18\x01 \x01(\x0b\x32\x11.otg.CaptureFieldH\x00\x88\x01\x01\x12-\n\rtraffic_class\x18\x02 \x01(\x0b\x32\x11.otg.CaptureFieldH\x01\x88\x01\x01\x12*\n\nflow_label\x18\x03 \x01(\x0b\x32\x11.otg.CaptureFieldH\x02\x88\x01\x01\x12.\n\x0epayload_length\x18\x04 \x01(\x0b\x32\x11.otg.CaptureFieldH\x03\x88\x01\x01\x12+\n\x0bnext_header\x18\x05 \x01(\x0b\x32\x11.otg.CaptureFieldH\x04\x88\x01\x01\x12)\n\thop_limit\x18\x06 \x01(\x0b\x32\x11.otg.CaptureFieldH\x05\x88\x01\x01\x12#\n\x03src\x18\x07 \x01(\x0b\x32\x11.otg.CaptureFieldH\x06\x88\x01\x01\x12#\n\x03\x64st\x18\x08 \x01(\x0b\x32\x11.otg.CaptureFieldH\x07\x88\x01\x01\x42\n\n\x08_versionB\x10\n\x0e_traffic_classB\r\n\x0b_flow_labelB\x11\n\x0f_payload_lengthB\x0e\n\x0c_next_headerB\x0c\n\n_hop_limitB\x06\n\x04_srcB\x06\n\x04_dst\"\x83\x02\n\x06\x44\x65vice\x12&\n\tethernets\x18\x01 \x03(\x0b\x32\x13.otg.DeviceEthernet\x12/\n\x0eipv4_loopbacks\x18\x02 \x03(\x0b\x32\x17.otg.DeviceIpv4Loopback\x12/\n\x0eipv6_loopbacks\x18\x03 \x03(\x0b\x32\x17.otg.DeviceIpv6Loopback\x12(\n\x04isis\x18\x04 \x01(\x0b\x32\x15.otg.DeviceIsisRouterH\x00\x88\x01\x01\x12&\n\x03\x62gp\x18\x05 \x01(\x0b\x32\x14.otg.DeviceBgpRouterH\x01\x88\x01\x01\x12\x0c\n\x04name\x18\x06 \x01(\tB\x07\n\x05_isisB\x06\n\x04_bgp\"\x99\x03\n\x10\x44\x65viceIsisRouter\x12\x33\n\x08instance\x18\x01 \x01(\x0b\x32\x1c.otg.DeviceIsisMultiInstanceH\x00\x88\x01\x01\x12\x11\n\tsystem_id\x18\x02 \x01(\t\x12&\n\ninterfaces\x18\x03 \x03(\x0b\x32\x12.otg.IsisInterface\x12\"\n\x05\x62\x61sic\x18\x04 \x01(\x0b\x32\x0e.otg.IsisBasicH\x01\x88\x01\x01\x12(\n\x08\x61\x64vanced\x18\x05 \x01(\x0b\x32\x11.otg.IsisAdvancedH\x02\x88\x01\x01\x12\x31\n\x0brouter_auth\x18\x06 \x01(\x0b\x32\x17.otg.IsisAuthenticationH\x03\x88\x01\x01\x12(\n\tv4_routes\x18\x07 \x03(\x0b\x32\x15.otg.IsisV4RouteRange\x12(\n\tv6_routes\x18\x08 \x03(\x0b\x32\x15.otg.IsisV6RouteRange\x12\x0c\n\x04name\x18\t \x01(\tB\x0b\n\t_instanceB\x08\n\x06_basicB\x0b\n\t_advancedB\x0e\n\x0c_router_auth\"B\n\x17\x44\x65viceIsisMultiInstance\x12\x10\n\x03iid\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\r\n\x05itids\x18\x02 \x03(\x05\x42\x06\n\x04_iid\"\xde\x06\n\rIsisInterface\x12\x10\n\x08\x65th_name\x18\x01 \x01(\t\x12\x13\n\x06metric\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12>\n\x0cnetwork_type\x18\x03 \x01(\x0e\x32#.otg.IsisInterface.NetworkType.EnumH\x01\x88\x01\x01\x12:\n\nlevel_type\x18\x04 \x01(\x0e\x32!.otg.IsisInterface.LevelType.EnumH\x02\x88\x01\x01\x12\x31\n\x0bl1_settings\x18\x05 \x01(\x0b\x32\x17.otg.IsisInterfaceLevelH\x03\x88\x01\x01\x12\x31\n\x0bl2_settings\x18\x06 \x01(\x0b\x32\x17.otg.IsisInterfaceLevelH\x04\x88\x01\x01\x12\'\n\x12multi_topology_ids\x18\x07 \x03(\x0b\x32\x0b.otg.IsisMT\x12-\n\x13traffic_engineering\x18\x08 \x03(\x0b\x32\x10.otg.LinkStateTE\x12=\n\x0e\x61uthentication\x18\t \x01(\x0b\x32 .otg.IsisInterfaceAuthenticationH\x05\x88\x01\x01\x12\x31\n\x08\x61\x64vanced\x18\n \x01(\x0b\x32\x1a.otg.IsisInterfaceAdvancedH\x06\x88\x01\x01\x12>\n\x0flink_protection\x18\x0b \x01(\x0b\x32 .otg.IsisInterfaceLinkProtectionH\x07\x88\x01\x01\x12\x13\n\x0bsrlg_values\x18\x0c \x03(\x05\x12\x0c\n\x04name\x18\r \x01(\t\x1aI\n\x0bNetworkType\":\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tbroadcast\x10\x01\x12\x12\n\x0epoint_to_point\x10\x02\x1aM\n\tLevelType\"@\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07level_1\x10\x01\x12\x0b\n\x07level_2\x10\x02\x12\r\n\tlevel_1_2\x10\x03\x42\t\n\x07_metricB\x0f\n\r_network_typeB\r\n\x0b_level_typeB\x0e\n\x0c_l1_settingsB\x0e\n\x0c_l2_settingsB\x11\n\x0f_authenticationB\x0b\n\t_advancedB\x12\n\x10_link_protection\"\x96\x01\n\x12IsisInterfaceLevel\x12\x15\n\x08priority\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x1b\n\x0ehello_interval\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x1a\n\rdead_interval\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x0b\n\t_priorityB\x11\n\x0f_hello_intervalB\x10\n\x0e_dead_interval\"P\n\x06IsisMT\x12\x12\n\x05mt_id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x18\n\x0blink_metric\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x08\n\x06_mt_idB\x0e\n\x0c_link_metric\"\xc1\x02\n\x0bLinkStateTE\x12!\n\x14\x61\x64ministrative_group\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0cmetric_level\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x19\n\x0cmax_bandwith\x18\x03 \x01(\x03H\x02\x88\x01\x01\x12%\n\x18max_reservable_bandwidth\x18\x04 \x01(\x03H\x03\x88\x01\x01\x12\x42\n\x13priority_bandwidths\x18\x05 \x01(\x0b\x32 .otg.LinkStatepriorityBandwidthsH\x04\x88\x01\x01\x42\x17\n\x15_administrative_groupB\x0f\n\r_metric_levelB\x0f\n\r_max_bandwithB\x1b\n\x19_max_reservable_bandwidthB\x16\n\x14_priority_bandwidths\"\xed\x01\n\x1bLinkStatepriorityBandwidths\x12\x10\n\x03pb0\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12\x10\n\x03pb1\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x10\n\x03pb2\x18\x03 \x01(\x03H\x02\x88\x01\x01\x12\x10\n\x03pb3\x18\x04 \x01(\x03H\x03\x88\x01\x01\x12\x10\n\x03pb4\x18\x05 \x01(\x03H\x04\x88\x01\x01\x12\x10\n\x03pb5\x18\x06 \x01(\x03H\x05\x88\x01\x01\x12\x10\n\x03pb6\x18\x07 \x01(\x03H\x06\x88\x01\x01\x12\x10\n\x03pb7\x18\x08 \x01(\x03H\x07\x88\x01\x01\x42\x06\n\x04_pb0B\x06\n\x04_pb1B\x06\n\x04_pb2B\x06\n\x04_pb3B\x06\n\x04_pb4B\x06\n\x04_pb5B\x06\n\x04_pb6B\x06\n\x04_pb7\"\xda\x01\n\x1bIsisInterfaceAuthentication\x12\x41\n\tauth_type\x18\x01 \x01(\x0e\x32..otg.IsisInterfaceAuthentication.AuthType.Enum\x12\x10\n\x03md5\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08password\x18\x03 \x01(\tH\x01\x88\x01\x01\x1a:\n\x08\x41uthType\".\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03md5\x10\x01\x12\x0c\n\x08password\x10\x02\x42\x06\n\x04_md5B\x0b\n\t_password\"\x8d\x02\n\x15IsisInterfaceAdvanced\x12\x1c\n\x0f\x61uto_adjust_mtu\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x1d\n\x10\x61uto_adjust_area\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12,\n\x1f\x61uto_adjust_supported_protocols\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\"\n\x15\x65nable_3way_handshake\x18\x04 \x01(\x08H\x03\x88\x01\x01\x42\x12\n\x10_auto_adjust_mtuB\x13\n\x11_auto_adjust_areaB\"\n _auto_adjust_supported_protocolsB\x18\n\x16_enable_3way_handshake\"\xf9\x02\n\x1bIsisInterfaceLinkProtection\x12\x1a\n\rextra_traffic\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x18\n\x0bunprotected\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x13\n\x06shared\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x1d\n\x10\x64\x65\x64icated_1_to_1\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x1f\n\x12\x64\x65\x64icated_1_plus_1\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x15\n\x08\x65nhanced\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x18\n\x0breserved_40\x18\x07 \x01(\x08H\x06\x88\x01\x01\x12\x18\n\x0breserved_80\x18\x08 \x01(\x08H\x07\x88\x01\x01\x42\x10\n\x0e_extra_trafficB\x0e\n\x0c_unprotectedB\t\n\x07_sharedB\x13\n\x11_dedicated_1_to_1B\x15\n\x13_dedicated_1_plus_1B\x0b\n\t_enhancedB\x0e\n\x0c_reserved_40B\x0e\n\x0c_reserved_80\"\x9d\x01\n\tIsisBasic\x12\x1e\n\x11ipv4_te_router_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08hostname\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1f\n\x12\x65nable_wide_metric\x18\x03 \x01(\x08H\x02\x88\x01\x01\x42\x14\n\x12_ipv4_te_router_idB\x0b\n\t_hostnameB\x15\n\x13_enable_wide_metric\"\x8a\x04\n\x0cIsisAdvanced\x12!\n\x14\x65nable_hello_padding\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x1f\n\x12max_area_addresses\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x16\n\x0e\x61rea_addresses\x18\x03 \x03(\t\x12\x1d\n\x10lsp_refresh_rate\x18\x04 \x01(\x05H\x02\x88\x01\x01\x12\x19\n\x0clsp_lifetime\x18\x05 \x01(\x05H\x03\x88\x01\x01\x12\x1a\n\rpsnp_interval\x18\x06 \x01(\x05H\x04\x88\x01\x01\x12\x1a\n\rcsnp_interval\x18\x07 \x01(\x05H\x05\x88\x01\x01\x12\x19\n\x0cmax_lsp_size\x18\x08 \x01(\x05H\x06\x88\x01\x01\x12*\n\x1dlsp_mgroup_min_trans_interval\x18\t \x01(\x05H\x07\x88\x01\x01\x12 \n\x13\x65nable_attached_bit\x18\n \x01(\x08H\x08\x88\x01\x01\x42\x17\n\x15_enable_hello_paddingB\x15\n\x13_max_area_addressesB\x13\n\x11_lsp_refresh_rateB\x0f\n\r_lsp_lifetimeB\x10\n\x0e_psnp_intervalB\x10\n\x0e_csnp_intervalB\x0f\n\r_max_lsp_sizeB \n\x1e_lsp_mgroup_min_trans_intervalB\x16\n\x14_enable_attached_bit\"\xd6\x01\n\x12IsisAuthentication\x12\x1f\n\x12ignore_receive_md5\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x33\n\tarea_auth\x18\x02 \x01(\x0b\x32\x1b.otg.IsisAuthenticationBaseH\x01\x88\x01\x01\x12\x35\n\x0b\x64omain_auth\x18\x03 \x01(\x0b\x32\x1b.otg.IsisAuthenticationBaseH\x02\x88\x01\x01\x42\x15\n\x13_ignore_receive_md5B\x0c\n\n_area_authB\x0e\n\x0c_domain_auth\"\xd0\x01\n\x16IsisAuthenticationBase\x12<\n\tauth_type\x18\x01 \x01(\x0e\x32).otg.IsisAuthenticationBase.AuthType.Enum\x12\x10\n\x03md5\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08password\x18\x03 \x01(\tH\x01\x88\x01\x01\x1a:\n\x08\x41uthType\".\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03md5\x10\x01\x12\x0c\n\x08password\x10\x02\x42\x06\n\x04_md5B\x0b\n\t_password\"\xca\x04\n\x10IsisV4RouteRange\x12&\n\taddresses\x18\x01 \x03(\x0b\x32\x13.otg.V4RouteAddress\x12\x18\n\x0blink_metric\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12?\n\x0borigin_type\x18\x03 \x01(\x0e\x32%.otg.IsisV4RouteRange.OriginType.EnumH\x01\x88\x01\x01\x12O\n\x13redistribution_type\x18\x04 \x01(\x0e\x32-.otg.IsisV4RouteRange.RedistributionType.EnumH\x02\x88\x01\x01\x12\x0c\n\x04name\x18\x05 \x01(\t\x12 \n\x13prefix_attr_enabled\x18\x06 \x01(\x08H\x03\x88\x01\x01\x12\x13\n\x06x_flag\x18\x07 \x01(\x08H\x04\x88\x01\x01\x12\x13\n\x06r_flag\x18\x08 \x01(\x08H\x05\x88\x01\x01\x12\x13\n\x06n_flag\x18\t \x01(\x08H\x06\x88\x01\x01\x1a\x41\n\nOriginType\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08internal\x10\x01\x12\x0c\n\x08\x65xternal\x10\x02\x1a?\n\x12RedistributionType\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x0e\n\x0c_link_metricB\x0e\n\x0c_origin_typeB\x16\n\x14_redistribution_typeB\x16\n\x14_prefix_attr_enabledB\t\n\x07_x_flagB\t\n\x07_r_flagB\t\n\x07_n_flag\"{\n\x0eV4RouteAddress\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x13\n\x06prefix\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x01\x88\x01\x01\x12\x11\n\x04step\x18\x04 \x01(\x05H\x02\x88\x01\x01\x42\t\n\x07_prefixB\x08\n\x06_countB\x07\n\x05_step\"{\n\x0eV6RouteAddress\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x13\n\x06prefix\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x01\x88\x01\x01\x12\x11\n\x04step\x18\x04 \x01(\x05H\x02\x88\x01\x01\x42\t\n\x07_prefixB\x08\n\x06_countB\x07\n\x05_step\"\xca\x04\n\x10IsisV6RouteRange\x12&\n\taddresses\x18\x01 \x03(\x0b\x32\x13.otg.V6RouteAddress\x12\x18\n\x0blink_metric\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12?\n\x0borigin_type\x18\x03 \x01(\x0e\x32%.otg.IsisV6RouteRange.OriginType.EnumH\x01\x88\x01\x01\x12O\n\x13redistribution_type\x18\x04 \x01(\x0e\x32-.otg.IsisV6RouteRange.RedistributionType.EnumH\x02\x88\x01\x01\x12\x0c\n\x04name\x18\x05 \x01(\t\x12 \n\x13prefix_attr_enabled\x18\x06 \x01(\x08H\x03\x88\x01\x01\x12\x13\n\x06x_flag\x18\x07 \x01(\x08H\x04\x88\x01\x01\x12\x13\n\x06r_flag\x18\x08 \x01(\x08H\x05\x88\x01\x01\x12\x13\n\x06n_flag\x18\t \x01(\x08H\x06\x88\x01\x01\x1a\x41\n\nOriginType\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08internal\x10\x01\x12\x0c\n\x08\x65xternal\x10\x02\x1a?\n\x12RedistributionType\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x0e\n\x0c_link_metricB\x0e\n\x0c_origin_typeB\x16\n\x14_redistribution_typeB\x16\n\x14_prefix_attr_enabledB\t\n\x07_x_flagB\t\n\x07_r_flagB\t\n\x07_n_flag\"\x80\x01\n\x0f\x44\x65viceBgpRouter\x12\x11\n\trouter_id\x18\x01 \x01(\t\x12,\n\x0fipv4_interfaces\x18\x02 \x03(\x0b\x32\x13.otg.BgpV4Interface\x12,\n\x0fipv6_interfaces\x18\x03 \x03(\x0b\x32\x13.otg.BgpV6Interface\"\xdc\x04\n\tBgpV4Peer\x12\x14\n\x0cpeer_address\x18\x01 \x01(\t\x12+\n\x07\x61s_type\x18\x02 \x01(\x0e\x32\x1a.otg.BgpV4Peer.AsType.Enum\x12\x11\n\tas_number\x18\x03 \x01(\x05\x12?\n\x0f\x61s_number_width\x18\x04 \x01(\x0e\x32!.otg.BgpV4Peer.AsNumberWidth.EnumH\x00\x88\x01\x01\x12\'\n\x08\x61\x64vanced\x18\x05 \x01(\x0b\x32\x10.otg.BgpAdvancedH\x01\x88\x01\x01\x12+\n\ncapability\x18\x06 \x01(\x0b\x32\x12.otg.BgpCapabilityH\x02\x88\x01\x01\x12\'\n\tv4_routes\x18\x07 \x03(\x0b\x32\x14.otg.BgpV4RouteRange\x12\'\n\tv6_routes\x18\x08 \x03(\x0b\x32\x14.otg.BgpV6RouteRange\x12.\n\x10v4_srte_policies\x18\t \x03(\x0b\x32\x14.otg.BgpSrteV4Policy\x12.\n\x10v6_srte_policies\x18\n \x03(\x0b\x32\x14.otg.BgpSrteV6Policy\x12\x0c\n\x04name\x18\x0b \x01(\t\x1a\x35\n\x06\x41sType\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ibgp\x10\x01\x12\x08\n\x04\x65\x62gp\x10\x02\x1a;\n\rAsNumberWidth\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03two\x10\x01\x12\x08\n\x04\x66our\x10\x02\x42\x12\n\x10_as_number_widthB\x0b\n\t_advancedB\r\n\x0b_capability\"B\n\x0e\x42gpV4Interface\x12\x11\n\tipv4_name\x18\x01 \x01(\t\x12\x1d\n\x05peers\x18\x02 \x03(\x0b\x32\x0e.otg.BgpV4Peer\"\xff\x01\n\x0b\x42gpAdvanced\x12\x1f\n\x12hold_time_interval\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12 \n\x13keep_alive_interval\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x1c\n\x0fupdate_interval\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x19\n\x0ctime_to_live\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12\x14\n\x07md5_key\x18\x05 \x01(\tH\x04\x88\x01\x01\x42\x15\n\x13_hold_time_intervalB\x16\n\x14_keep_alive_intervalB\x12\n\x10_update_intervalB\x0f\n\r_time_to_liveB\n\n\x08_md5_key\"\x91\n\n\rBgpCapability\x12\x19\n\x0cipv4_unicast\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x1b\n\x0eipv4_multicast\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x19\n\x0cipv6_unicast\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x1b\n\x0eipv6_multicast\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x11\n\x04vpls\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x1a\n\rroute_refresh\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x1d\n\x10route_constraint\x18\x07 \x01(\x08H\x06\x88\x01\x01\x12\x1f\n\x12link_state_non_vpn\x18\x08 \x01(\x08H\x07\x88\x01\x01\x12\x1b\n\x0elink_state_vpn\x18\t \x01(\x08H\x08\x88\x01\x01\x12\x11\n\x04\x65vpn\x18\n \x01(\x08H\t\x88\x01\x01\x12\'\n\x1a\x65xtended_next_hop_encoding\x18\x0b \x01(\x08H\n\x88\x01\x01\x12\x1f\n\x12ipv4_multicast_vpn\x18\x0c \x01(\x08H\x0b\x88\x01\x01\x12\x1a\n\ripv4_mpls_vpn\x18\r \x01(\x08H\x0c\x88\x01\x01\x12\x15\n\x08ipv4_mdt\x18\x0e \x01(\x08H\r\x88\x01\x01\x12$\n\x17ipv4_multicast_mpls_vpn\x18\x0f \x01(\x08H\x0e\x88\x01\x01\x12#\n\x16ipv4_unicast_flow_spec\x18\x10 \x01(\x08H\x0f\x88\x01\x01\x12\x1e\n\x11ipv4_sr_te_policy\x18\x11 \x01(\x08H\x10\x88\x01\x01\x12\"\n\x15ipv4_unicast_add_path\x18\x12 \x01(\x08H\x11\x88\x01\x01\x12\x1f\n\x12ipv6_multicast_vpn\x18\x13 \x01(\x08H\x12\x88\x01\x01\x12\x1a\n\ripv6_mpls_vpn\x18\x14 \x01(\x08H\x13\x88\x01\x01\x12\x15\n\x08ipv6_mdt\x18\x15 \x01(\x08H\x14\x88\x01\x01\x12$\n\x17ipv6_multicast_mpls_vpn\x18\x16 \x01(\x08H\x15\x88\x01\x01\x12#\n\x16ipv6_unicast_flow_spec\x18\x17 \x01(\x08H\x16\x88\x01\x01\x12\x1e\n\x11ipv6_sr_te_policy\x18\x18 \x01(\x08H\x17\x88\x01\x01\x12\"\n\x15ipv6_unicast_add_path\x18\x19 \x01(\x08H\x18\x88\x01\x01\x42\x0f\n\r_ipv4_unicastB\x11\n\x0f_ipv4_multicastB\x0f\n\r_ipv6_unicastB\x11\n\x0f_ipv6_multicastB\x07\n\x05_vplsB\x10\n\x0e_route_refreshB\x13\n\x11_route_constraintB\x15\n\x13_link_state_non_vpnB\x11\n\x0f_link_state_vpnB\x07\n\x05_evpnB\x1d\n\x1b_extended_next_hop_encodingB\x15\n\x13_ipv4_multicast_vpnB\x10\n\x0e_ipv4_mpls_vpnB\x0b\n\t_ipv4_mdtB\x1a\n\x18_ipv4_multicast_mpls_vpnB\x19\n\x17_ipv4_unicast_flow_specB\x14\n\x12_ipv4_sr_te_policyB\x18\n\x16_ipv4_unicast_add_pathB\x15\n\x13_ipv6_multicast_vpnB\x10\n\x0e_ipv6_mpls_vpnB\x0b\n\t_ipv6_mdtB\x1a\n\x18_ipv6_multicast_mpls_vpnB\x19\n\x17_ipv6_unicast_flow_specB\x14\n\x12_ipv6_sr_te_policyB\x18\n\x16_ipv6_unicast_add_path\"\xd3\x05\n\x0f\x42gpV4RouteRange\x12&\n\taddresses\x18\x01 \x03(\x0b\x32\x13.otg.V4RouteAddress\x12\x41\n\rnext_hop_mode\x18\x02 \x01(\x0e\x32%.otg.BgpV4RouteRange.NextHopMode.EnumH\x00\x88\x01\x01\x12P\n\x15next_hop_address_type\x18\x03 \x01(\x0e\x32,.otg.BgpV4RouteRange.NextHopAddressType.EnumH\x01\x88\x01\x01\x12\"\n\x15next_hop_ipv4_address\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\"\n\x15next_hop_ipv6_address\x18\x05 \x01(\tH\x03\x88\x01\x01\x12,\n\x08\x61\x64vanced\x18\x06 \x01(\x0b\x32\x15.otg.BgpRouteAdvancedH\x04\x88\x01\x01\x12&\n\x0b\x63ommunities\x18\x07 \x03(\x0b\x32\x11.otg.BgpCommunity\x12$\n\x07\x61s_path\x18\x08 \x01(\x0b\x32\x0e.otg.BgpAsPathH\x05\x88\x01\x01\x12&\n\x08\x61\x64\x64_path\x18\t \x01(\x0b\x32\x0f.otg.BgpAddPathH\x06\x88\x01\x01\x12\x0c\n\x04name\x18\n \x01(\t\x1a@\n\x0bNextHopMode\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08local_ip\x10\x01\x12\n\n\x06manual\x10\x02\x1a\x41\n\x12NextHopAddressType\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x42\x10\n\x0e_next_hop_modeB\x18\n\x16_next_hop_address_typeB\x18\n\x16_next_hop_ipv4_addressB\x18\n\x16_next_hop_ipv6_addressB\x0b\n\t_advancedB\n\n\x08_as_pathB\x0b\n\t_add_path\"\xce\x01\n\x10\x42gpRouteAdvanced\x12%\n\x18multi_exit_discriminator\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x36\n\x06origin\x18\x02 \x01(\x0e\x32!.otg.BgpRouteAdvanced.Origin.EnumH\x01\x88\x01\x01\x1a\x33\n\x06Origin\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03igp\x10\x01\x12\x07\n\x03\x65gp\x10\x02\x42\x1b\n\x19_multi_exit_discriminatorB\t\n\x07_origin\"\xa4\x02\n\x0c\x42gpCommunity\x12.\n\x04type\x18\x01 \x01(\x0e\x32\x1b.otg.BgpCommunity.Type.EnumH\x00\x88\x01\x01\x12\x16\n\tas_number\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x16\n\tas_custom\x18\x03 \x01(\x05H\x02\x88\x01\x01\x1a\x8e\x01\n\x04Type\"\x85\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x14\n\x10manual_as_number\x10\x01\x12\r\n\tno_export\x10\x02\x12\x11\n\rno_advertised\x10\x03\x12\x17\n\x13no_export_subconfed\x10\x04\x12\x0e\n\nllgr_stale\x10\x05\x12\x0b\n\x07no_llgr\x10\x06\x42\x07\n\x05_typeB\x0c\n\n_as_numberB\x0c\n\n_as_custom\"\xbe\x02\n\tBgpAsPath\x12\x37\n\x0b\x61s_set_mode\x18\x01 \x01(\x0e\x32\x1d.otg.BgpAsPath.AsSetMode.EnumH\x00\x88\x01\x01\x12\'\n\x08segments\x18\x02 \x03(\x0b\x32\x15.otg.BgpAsPathSegment\x1a\xbe\x01\n\tAsSetMode\"\xb0\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x1b\n\x17\x64o_not_include_local_as\x10\x01\x12\x12\n\x0einclude_as_seq\x10\x02\x12\x12\n\x0einclude_as_set\x10\x03\x12\x19\n\x15include_as_confed_seq\x10\x04\x12\x19\n\x15include_as_confed_set\x10\x05\x12\x1c\n\x18prepend_to_first_segment\x10\x06\x42\x0e\n\x0c_as_set_mode\"\xc2\x01\n\x10\x42gpAsPathSegment\x12\x32\n\x04type\x18\x01 \x01(\x0e\x32\x1f.otg.BgpAsPathSegment.Type.EnumH\x00\x88\x01\x01\x12\x12\n\nas_numbers\x18\x02 \x03(\x03\x1a]\n\x04Type\"U\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06\x61s_seq\x10\x01\x12\n\n\x06\x61s_set\x10\x02\x12\x11\n\ras_confed_seq\x10\x03\x12\x11\n\ras_confed_set\x10\x04\x42\x07\n\x05_type\".\n\nBgpAddPath\x12\x14\n\x07path_id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x42\n\n\x08_path_id\"\xd3\x05\n\x0f\x42gpV6RouteRange\x12&\n\taddresses\x18\x01 \x03(\x0b\x32\x13.otg.V6RouteAddress\x12\x41\n\rnext_hop_mode\x18\x02 \x01(\x0e\x32%.otg.BgpV6RouteRange.NextHopMode.EnumH\x00\x88\x01\x01\x12P\n\x15next_hop_address_type\x18\x03 \x01(\x0e\x32,.otg.BgpV6RouteRange.NextHopAddressType.EnumH\x01\x88\x01\x01\x12\"\n\x15next_hop_ipv4_address\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\"\n\x15next_hop_ipv6_address\x18\x05 \x01(\tH\x03\x88\x01\x01\x12,\n\x08\x61\x64vanced\x18\x06 \x01(\x0b\x32\x15.otg.BgpRouteAdvancedH\x04\x88\x01\x01\x12&\n\x0b\x63ommunities\x18\x07 \x03(\x0b\x32\x11.otg.BgpCommunity\x12$\n\x07\x61s_path\x18\x08 \x01(\x0b\x32\x0e.otg.BgpAsPathH\x05\x88\x01\x01\x12&\n\x08\x61\x64\x64_path\x18\t \x01(\x0b\x32\x0f.otg.BgpAddPathH\x06\x88\x01\x01\x12\x0c\n\x04name\x18\n \x01(\t\x1a@\n\x0bNextHopMode\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08local_ip\x10\x01\x12\n\n\x06manual\x10\x02\x1a\x41\n\x12NextHopAddressType\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x42\x10\n\x0e_next_hop_modeB\x18\n\x16_next_hop_address_typeB\x18\n\x16_next_hop_ipv4_addressB\x18\n\x16_next_hop_ipv6_addressB\x0b\n\t_advancedB\n\n\x08_as_pathB\x0b\n\t_add_path\"\x8b\x07\n\x0f\x42gpSrteV4Policy\x12\x1a\n\rdistinguisher\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12\x12\n\x05\x63olor\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x15\n\ripv4_endpoint\x18\x03 \x01(\t\x12\x41\n\rnext_hop_mode\x18\x04 \x01(\x0e\x32%.otg.BgpSrteV4Policy.NextHopMode.EnumH\x02\x88\x01\x01\x12P\n\x15next_hop_address_type\x18\x05 \x01(\x0e\x32,.otg.BgpSrteV4Policy.NextHopAddressType.EnumH\x03\x88\x01\x01\x12\"\n\x15next_hop_ipv4_address\x18\x06 \x01(\tH\x04\x88\x01\x01\x12\"\n\x15next_hop_ipv6_address\x18\x07 \x01(\tH\x05\x88\x01\x01\x12,\n\x08\x61\x64vanced\x18\x08 \x01(\x0b\x32\x15.otg.BgpRouteAdvancedH\x06\x88\x01\x01\x12&\n\x08\x61\x64\x64_path\x18\t \x01(\x0b\x32\x0f.otg.BgpAddPathH\x07\x88\x01\x01\x12$\n\x07\x61s_path\x18\n \x01(\x0b\x32\x0e.otg.BgpAsPathH\x08\x88\x01\x01\x12&\n\x0b\x63ommunities\x18\x0b \x03(\x0b\x32\x11.otg.BgpCommunity\x12-\n\x0f\x65xt_communities\x18\x0c \x03(\x0b\x32\x14.otg.BgpExtCommunity\x12,\n\x0btunnel_tlvs\x18\r \x03(\x0b\x32\x17.otg.BgpSrteV4TunnelTlv\x12\x0c\n\x04name\x18\x0e \x01(\t\x12\x13\n\x06\x61\x63tive\x18\x0f \x01(\x08H\t\x88\x01\x01\x1a@\n\x0bNextHopMode\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08local_ip\x10\x01\x12\n\n\x06manual\x10\x02\x1a\x41\n\x12NextHopAddressType\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x42\x10\n\x0e_distinguisherB\x08\n\x06_colorB\x10\n\x0e_next_hop_modeB\x18\n\x16_next_hop_address_typeB\x18\n\x16_next_hop_ipv4_addressB\x18\n\x16_next_hop_ipv6_addressB\x0b\n\t_advancedB\x0b\n\t_add_pathB\n\n\x08_as_pathB\t\n\x07_active\"\xf9\x03\n\x0f\x42gpExtCommunity\x12\x31\n\x04type\x18\x01 \x01(\x0e\x32\x1e.otg.BgpExtCommunity.Type.EnumH\x00\x88\x01\x01\x12\x37\n\x07subtype\x18\x02 \x01(\x0e\x32!.otg.BgpExtCommunity.Subtype.EnumH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\tH\x02\x88\x01\x01\x1a\xbc\x01\n\x04Type\"\xb3\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x1b\n\x17\x61\x64ministrator_as_2octet\x10\x01\x12\x1e\n\x1a\x61\x64ministrator_ipv4_address\x10\x02\x12\x1b\n\x17\x61\x64ministrator_as_4octet\x10\x03\x12\n\n\x06opaque\x10\x04\x12\x08\n\x04\x65vpn\x10\x05\x12*\n&administrator_as_2octet_link_bandwidth\x10\x06\x1a\x87\x01\n\x07Subtype\"|\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0croute_target\x10\x01\x12\n\n\x06origin\x10\x02\x12\x16\n\x12\x65xtended_bandwidth\x10\x03\x12\t\n\x05\x63olor\x10\x04\x12\x11\n\rencapsulation\x10\x05\x12\x0f\n\x0bmac_address\x10\x06\x42\x07\n\x05_typeB\n\n\x08_subtypeB\x08\n\x06_value\"\xff\x05\n\x12\x42gpSrteV4TunnelTlv\x12\x46\n\x17remote_endpoint_sub_tlv\x18\x01 \x01(\x0b\x32 .otg.BgpSrteRemoteEndpointSubTlvH\x00\x88\x01\x01\x12\x33\n\rcolor_sub_tlv\x18\x02 \x01(\x0b\x32\x17.otg.BgpSrteColorSubTlvH\x01\x88\x01\x01\x12\x37\n\x0f\x62inding_sub_tlv\x18\x03 \x01(\x0b\x32\x19.otg.BgpSrteBindingSubTlvH\x02\x88\x01\x01\x12=\n\x12preference_sub_tlv\x18\x04 \x01(\x0b\x32\x1c.otg.BgpSrtePreferenceSubTlvH\x03\x88\x01\x01\x12\x46\n\x17policy_priority_sub_tlv\x18\x05 \x01(\x0b\x32 .otg.BgpSrtePolicyPrioritySubTlvH\x04\x88\x01\x01\x12>\n\x13policy_name_sub_tlv\x18\x06 \x01(\x0b\x32\x1c.otg.BgpSrtePolicyNameSubTlvH\x05\x88\x01\x01\x12Z\n\"explicit_null_label_policy_sub_tlv\x18\x07 \x01(\x0b\x32).otg.BgpSrteExplicitNullLabelPolicySubTlvH\x06\x88\x01\x01\x12.\n\rsegment_lists\x18\x08 \x03(\x0b\x32\x17.otg.BgpSrteSegmentList\x12\x0c\n\x04name\x18\t \x01(\t\x12\x13\n\x06\x61\x63tive\x18\n \x01(\x08H\x07\x88\x01\x01\x42\x1a\n\x18_remote_endpoint_sub_tlvB\x10\n\x0e_color_sub_tlvB\x12\n\x10_binding_sub_tlvB\x15\n\x13_preference_sub_tlvB\x1a\n\x18_policy_priority_sub_tlvB\x16\n\x14_policy_name_sub_tlvB%\n#_explicit_null_label_policy_sub_tlvB\t\n\x07_active\"\xbe\x02\n\x1b\x42gpSrteRemoteEndpointSubTlv\x12\x16\n\tas_number\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12P\n\x0e\x61\x64\x64ress_family\x18\x02 \x01(\x0e\x32\x33.otg.BgpSrteRemoteEndpointSubTlv.AddressFamily.EnumH\x01\x88\x01\x01\x12\x19\n\x0cipv4_address\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x19\n\x0cipv6_address\x18\x04 \x01(\tH\x03\x88\x01\x01\x1a<\n\rAddressFamily\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x42\x0c\n\n_as_numberB\x11\n\x0f_address_familyB\x0f\n\r_ipv4_addressB\x0f\n\r_ipv6_address\"2\n\x12\x42gpSrteColorSubTlv\x12\x12\n\x05\x63olor\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x08\n\x06_color\"\xea\x02\n\x14\x42gpSrteBindingSubTlv\x12L\n\x10\x62inding_sid_type\x18\x01 \x01(\x0e\x32-.otg.BgpSrteBindingSubTlv.BindingSidType.EnumH\x00\x88\x01\x01\x12\x1b\n\x0e\x66our_octet_sid\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x15\n\x08ipv6_sid\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x13\n\x06s_flag\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x13\n\x06i_flag\x18\x05 \x01(\x08H\x04\x88\x01\x01\x1a[\n\x0e\x42indingSidType\"I\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\nno_binding\x10\x01\x12\x12\n\x0e\x66our_octet_sid\x10\x02\x12\x0c\n\x08ipv6_sid\x10\x03\x42\x13\n\x11_binding_sid_typeB\x11\n\x0f_four_octet_sidB\x0b\n\t_ipv6_sidB\t\n\x07_s_flagB\t\n\x07_i_flag\"A\n\x17\x42gpSrtePreferenceSubTlv\x12\x17\n\npreference\x18\x01 \x01(\x03H\x00\x88\x01\x01\x42\r\n\x0b_preference\"O\n\x1b\x42gpSrtePolicyPrioritySubTlv\x12\x1c\n\x0fpolicy_priority\x18\x01 \x01(\x05H\x00\x88\x01\x01\x42\x12\n\x10_policy_priority\"C\n\x17\x42gpSrtePolicyNameSubTlv\x12\x18\n\x0bpolicy_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x0e\n\x0c_policy_name\"\xd6\x02\n$BgpSrteExplicitNullLabelPolicySubTlv\x12o\n\x1a\x65xplicit_null_label_policy\x18\x01 \x01(\x0e\x32\x46.otg.BgpSrteExplicitNullLabelPolicySubTlv.ExplicitNullLabelPolicy.EnumH\x00\x88\x01\x01\x1a\x9d\x01\n\x17\x45xplicitNullLabelPolicy\"\x81\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rreserved_enlp\x10\x01\x12\x12\n\x0epush_ipv4_enlp\x10\x02\x12\x12\n\x0epush_ipv6_enlp\x10\x03\x12\x17\n\x13push_ipv4_ipv6_enlp\x10\x04\x12\x14\n\x10\x64o_not_push_enlp\x10\x05\x42\x1d\n\x1b_explicit_null_label_policy\"\x89\x01\n\x12\x42gpSrteSegmentList\x12\x13\n\x06weight\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12%\n\x08segments\x18\x02 \x03(\x0b\x32\x13.otg.BgpSrteSegment\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x06\x61\x63tive\x18\x04 \x01(\x08H\x01\x88\x01\x01\x42\t\n\x07_weightB\t\n\x07_active\"\xe8\x07\n\x0e\x42gpSrteSegment\x12:\n\x0csegment_type\x18\x01 \x01(\x0e\x32$.otg.BgpSrteSegment.SegmentType.Enum\x12\x33\n\x06type_a\x18\x02 \x01(\x0b\x32\x1e.otg.BgpSrteSegmentATypeSubTlvH\x00\x88\x01\x01\x12\x33\n\x06type_b\x18\x03 \x01(\x0b\x32\x1e.otg.BgpSrteSegmentBTypeSubTlvH\x01\x88\x01\x01\x12\x33\n\x06type_c\x18\x04 \x01(\x0b\x32\x1e.otg.BgpSrteSegmentCTypeSubTlvH\x02\x88\x01\x01\x12\x33\n\x06type_d\x18\x05 \x01(\x0b\x32\x1e.otg.BgpSrteSegmentDTypeSubTlvH\x03\x88\x01\x01\x12\x33\n\x06type_e\x18\x06 \x01(\x0b\x32\x1e.otg.BgpSrteSegmentETypeSubTlvH\x04\x88\x01\x01\x12\x33\n\x06type_f\x18\x07 \x01(\x0b\x32\x1e.otg.BgpSrteSegmentFTypeSubTlvH\x05\x88\x01\x01\x12\x33\n\x06type_g\x18\x08 \x01(\x0b\x32\x1e.otg.BgpSrteSegmentGTypeSubTlvH\x06\x88\x01\x01\x12\x33\n\x06type_h\x18\t \x01(\x0b\x32\x1e.otg.BgpSrteSegmentHTypeSubTlvH\x07\x88\x01\x01\x12\x33\n\x06type_i\x18\n \x01(\x0b\x32\x1e.otg.BgpSrteSegmentITypeSubTlvH\x08\x88\x01\x01\x12\x33\n\x06type_j\x18\x0b \x01(\x0b\x32\x1e.otg.BgpSrteSegmentJTypeSubTlvH\t\x88\x01\x01\x12\x33\n\x06type_k\x18\x0c \x01(\x0b\x32\x1e.otg.BgpSrteSegmentKTypeSubTlvH\n\x88\x01\x01\x12\x0c\n\x04name\x18\r \x01(\t\x12\x13\n\x06\x61\x63tive\x18\x0e \x01(\x08H\x0b\x88\x01\x01\x1a\xab\x01\n\x0bSegmentType\"\x9b\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06type_a\x10\x01\x12\n\n\x06type_b\x10\x02\x12\n\n\x06type_c\x10\x03\x12\n\n\x06type_d\x10\x04\x12\n\n\x06type_e\x10\x05\x12\n\n\x06type_f\x10\x06\x12\n\n\x06type_g\x10\x07\x12\n\n\x06type_h\x10\x08\x12\n\n\x06type_i\x10\t\x12\n\n\x06type_j\x10\n\x12\n\n\x06type_k\x10\x0b\x42\t\n\x07_type_aB\t\n\x07_type_bB\t\n\x07_type_cB\t\n\x07_type_dB\t\n\x07_type_eB\t\n\x07_type_fB\t\n\x07_type_gB\t\n\x07_type_hB\t\n\x07_type_iB\t\n\x07_type_jB\t\n\x07_type_kB\t\n\x07_active\"\x80\x01\n\x10\x42gpSrteSrMplsSid\x12\x12\n\x05label\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x0f\n\x02tc\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05s_bit\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x10\n\x03ttl\x18\x04 \x01(\x05H\x03\x88\x01\x01\x42\x08\n\x06_labelB\x05\n\x03_tcB\x08\n\x06_s_bitB\x06\n\x04_ttl\"\xca\x01\n*BgpSrteSRv6SIDEndpointBehaviorAndStructure\x12\x16\n\tlb_length\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x16\n\tln_length\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x18\n\x0b\x66unc_length\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x17\n\narg_length\x18\x04 \x01(\x05H\x03\x88\x01\x01\x42\x0c\n\n_lb_lengthB\x0c\n\n_ln_lengthB\x0e\n\x0c_func_lengthB\r\n\x0b_arg_length\"\xa7\x01\n\x19\x42gpSrteSegmentATypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05label\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0f\n\x02tc\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x12\n\x05s_bit\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x10\n\x03ttl\x18\x05 \x01(\x05H\x04\x88\x01\x01\x42\x08\n\x06_flagsB\x08\n\x06_labelB\x05\n\x03_tcB\x08\n\x06_s_bitB\x06\n\x04_ttl\"\xc4\x01\n\x19\x42gpSrteSegmentBTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x10\n\x08srv6_sid\x18\x02 \x01(\t\x12X\n\x1asrv6_sid_endpoint_behavior\x18\x03 \x01(\x0b\x32/.otg.BgpSrteSRv6SIDEndpointBehaviorAndStructureH\x01\x88\x01\x01\x42\x08\n\x06_flagsB\x1d\n\x1b_srv6_sid_endpoint_behavior\"\xc1\x01\n\x19\x42gpSrteSegmentCTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0csr_algorithm\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x19\n\x11ipv4_node_address\x18\x03 \x01(\t\x12/\n\x0bsr_mpls_sid\x18\x04 \x01(\x0b\x32\x15.otg.BgpSrteSrMplsSidH\x02\x88\x01\x01\x42\x08\n\x06_flagsB\x0f\n\r_sr_algorithmB\x0e\n\x0c_sr_mpls_sid\"\xc1\x01\n\x19\x42gpSrteSegmentDTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0csr_algorithm\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x19\n\x11ipv6_node_address\x18\x03 \x01(\t\x12/\n\x0bsr_mpls_sid\x18\x04 \x01(\x0b\x32\x15.otg.BgpSrteSrMplsSidH\x02\x88\x01\x01\x42\x08\n\x06_flagsB\x0f\n\r_sr_algorithmB\x0e\n\x0c_sr_mpls_sid\"\xcd\x01\n\x19\x42gpSrteSegmentETypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1f\n\x12local_interface_id\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x19\n\x11ipv4_node_address\x18\x03 \x01(\t\x12/\n\x0bsr_mpls_sid\x18\x04 \x01(\x0b\x32\x15.otg.BgpSrteSrMplsSidH\x02\x88\x01\x01\x42\x08\n\x06_flagsB\x15\n\x13_local_interface_idB\x0e\n\x0c_sr_mpls_sid\"\xb3\x01\n\x19\x42gpSrteSegmentFTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\x12local_ipv4_address\x18\x02 \x01(\t\x12\x1b\n\x13remote_ipv4_address\x18\x03 \x01(\t\x12/\n\x0bsr_mpls_sid\x18\x04 \x01(\x0b\x32\x15.otg.BgpSrteSrMplsSidH\x01\x88\x01\x01\x42\x08\n\x06_flagsB\x0e\n\x0c_sr_mpls_sid\"\xaf\x02\n\x19\x42gpSrteSegmentGTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1f\n\x12local_interface_id\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x1f\n\x17local_ipv6_node_address\x18\x03 \x01(\t\x12 \n\x13remote_interface_id\x18\x04 \x01(\x05H\x02\x88\x01\x01\x12 \n\x18remote_ipv6_node_address\x18\x05 \x01(\t\x12/\n\x0bsr_mpls_sid\x18\x06 \x01(\x0b\x32\x15.otg.BgpSrteSrMplsSidH\x03\x88\x01\x01\x42\x08\n\x06_flagsB\x15\n\x13_local_interface_idB\x16\n\x14_remote_interface_idB\x0e\n\x0c_sr_mpls_sid\"\xb3\x01\n\x19\x42gpSrteSegmentHTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\x12local_ipv6_address\x18\x02 \x01(\t\x12\x1b\n\x13remote_ipv6_address\x18\x03 \x01(\t\x12/\n\x0bsr_mpls_sid\x18\x04 \x01(\x0b\x32\x15.otg.BgpSrteSrMplsSidH\x01\x88\x01\x01\x42\x08\n\x06_flagsB\x0e\n\x0c_sr_mpls_sid\"\xf1\x01\n\x19\x42gpSrteSegmentITypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x11ipv6_node_address\x18\x02 \x01(\t\x12\x15\n\x08srv6_sid\x18\x03 \x01(\tH\x01\x88\x01\x01\x12X\n\x1asrv6_sid_endpoint_behavior\x18\x04 \x01(\x0b\x32/.otg.BgpSrteSRv6SIDEndpointBehaviorAndStructureH\x02\x88\x01\x01\x42\x08\n\x06_flagsB\x0b\n\t_srv6_sidB\x1d\n\x1b_srv6_sid_endpoint_behavior\"\xb7\x03\n\x19\x42gpSrteSegmentJTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0csr_algorithm\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x1f\n\x12local_interface_id\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x1f\n\x17local_ipv6_node_address\x18\x04 \x01(\t\x12 \n\x13remote_interface_id\x18\x05 \x01(\x05H\x03\x88\x01\x01\x12 \n\x18remote_ipv6_node_address\x18\x06 \x01(\t\x12\x15\n\x08srv6_sid\x18\x07 \x01(\tH\x04\x88\x01\x01\x12X\n\x1asrv6_sid_endpoint_behavior\x18\x08 \x01(\x0b\x32/.otg.BgpSrteSRv6SIDEndpointBehaviorAndStructureH\x05\x88\x01\x01\x42\x08\n\x06_flagsB\x0f\n\r_sr_algorithmB\x15\n\x13_local_interface_idB\x16\n\x14_remote_interface_idB\x0b\n\t_srv6_sidB\x1d\n\x1b_srv6_sid_endpoint_behavior\"\xbb\x02\n\x19\x42gpSrteSegmentKTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0csr_algorithm\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x1a\n\x12local_ipv6_address\x18\x03 \x01(\t\x12\x1b\n\x13remote_ipv6_address\x18\x04 \x01(\t\x12\x15\n\x08srv6_sid\x18\x05 \x01(\tH\x02\x88\x01\x01\x12X\n\x1asrv6_sid_endpoint_behavior\x18\x06 \x01(\x0b\x32/.otg.BgpSrteSRv6SIDEndpointBehaviorAndStructureH\x03\x88\x01\x01\x42\x08\n\x06_flagsB\x0f\n\r_sr_algorithmB\x0b\n\t_srv6_sidB\x1d\n\x1b_srv6_sid_endpoint_behavior\"\x8a\x07\n\x0f\x42gpSrteV6Policy\x12\x1a\n\rdistinguisher\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12\x12\n\x05\x63olor\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x15\n\ripv6_endpoint\x18\x03 \x01(\t\x12\x41\n\rnext_hop_mode\x18\x04 \x01(\x0e\x32%.otg.BgpSrteV6Policy.NextHopMode.EnumH\x02\x88\x01\x01\x12P\n\x15next_hop_address_type\x18\x05 \x01(\x0e\x32,.otg.BgpSrteV6Policy.NextHopAddressType.EnumH\x03\x88\x01\x01\x12\"\n\x15next_hop_ipv4_address\x18\x06 \x01(\tH\x04\x88\x01\x01\x12\"\n\x15next_hop_ipv6_address\x18\x07 \x01(\tH\x05\x88\x01\x01\x12,\n\x08\x61\x64vanced\x18\x08 \x01(\x0b\x32\x15.otg.BgpRouteAdvancedH\x06\x88\x01\x01\x12&\n\x08\x61\x64\x64_path\x18\t \x01(\x0b\x32\x0f.otg.BgpAddPathH\x07\x88\x01\x01\x12$\n\x07\x61s_path\x18\n \x01(\x0b\x32\x0e.otg.BgpAsPathH\x08\x88\x01\x01\x12&\n\x0b\x63ommunities\x18\x0b \x03(\x0b\x32\x11.otg.BgpCommunity\x12,\n\x0e\x65xtcommunities\x18\x0c \x03(\x0b\x32\x14.otg.BgpExtCommunity\x12,\n\x0btunnel_tlvs\x18\r \x03(\x0b\x32\x17.otg.BgpSrteV6TunnelTlv\x12\x0c\n\x04name\x18\x0e \x01(\t\x12\x13\n\x06\x61\x63tive\x18\x0f \x01(\x08H\t\x88\x01\x01\x1a@\n\x0bNextHopMode\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08local_ip\x10\x01\x12\n\n\x06manual\x10\x02\x1a\x41\n\x12NextHopAddressType\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x42\x10\n\x0e_distinguisherB\x08\n\x06_colorB\x10\n\x0e_next_hop_modeB\x18\n\x16_next_hop_address_typeB\x18\n\x16_next_hop_ipv4_addressB\x18\n\x16_next_hop_ipv6_addressB\x0b\n\t_advancedB\x0b\n\t_add_pathB\n\n\x08_as_pathB\t\n\x07_active\"\xff\x05\n\x12\x42gpSrteV6TunnelTlv\x12\x46\n\x17remote_endpoint_sub_tlv\x18\x01 \x01(\x0b\x32 .otg.BgpSrteRemoteEndpointSubTlvH\x00\x88\x01\x01\x12\x33\n\rcolor_sub_tlv\x18\x02 \x01(\x0b\x32\x17.otg.BgpSrteColorSubTlvH\x01\x88\x01\x01\x12\x37\n\x0f\x62inding_sub_tlv\x18\x03 \x01(\x0b\x32\x19.otg.BgpSrteBindingSubTlvH\x02\x88\x01\x01\x12=\n\x12preference_sub_tlv\x18\x04 \x01(\x0b\x32\x1c.otg.BgpSrtePreferenceSubTlvH\x03\x88\x01\x01\x12\x46\n\x17policy_priority_sub_tlv\x18\x05 \x01(\x0b\x32 .otg.BgpSrtePolicyPrioritySubTlvH\x04\x88\x01\x01\x12>\n\x13policy_name_sub_tlv\x18\x06 \x01(\x0b\x32\x1c.otg.BgpSrtePolicyNameSubTlvH\x05\x88\x01\x01\x12Z\n\"explicit_null_label_policy_sub_tlv\x18\x07 \x01(\x0b\x32).otg.BgpSrteExplicitNullLabelPolicySubTlvH\x06\x88\x01\x01\x12.\n\rsegment_lists\x18\x08 \x03(\x0b\x32\x17.otg.BgpSrteSegmentList\x12\x0c\n\x04name\x18\t \x01(\t\x12\x13\n\x06\x61\x63tive\x18\n \x01(\x08H\x07\x88\x01\x01\x42\x1a\n\x18_remote_endpoint_sub_tlvB\x10\n\x0e_color_sub_tlvB\x12\n\x10_binding_sub_tlvB\x15\n\x13_preference_sub_tlvB\x1a\n\x18_policy_priority_sub_tlvB\x16\n\x14_policy_name_sub_tlvB%\n#_explicit_null_label_policy_sub_tlvB\t\n\x07_active\"\xa8\x05\n\tBgpV6Peer\x12\x14\n\x0cpeer_address\x18\x01 \x01(\t\x12\x36\n\x0fsegment_routing\x18\x02 \x01(\x0b\x32\x18.otg.BgpV6SegmentRoutingH\x00\x88\x01\x01\x12+\n\x07\x61s_type\x18\x03 \x01(\x0e\x32\x1a.otg.BgpV6Peer.AsType.Enum\x12\x11\n\tas_number\x18\x04 \x01(\x05\x12?\n\x0f\x61s_number_width\x18\x05 \x01(\x0e\x32!.otg.BgpV6Peer.AsNumberWidth.EnumH\x01\x88\x01\x01\x12\'\n\x08\x61\x64vanced\x18\x06 \x01(\x0b\x32\x10.otg.BgpAdvancedH\x02\x88\x01\x01\x12+\n\ncapability\x18\x07 \x01(\x0b\x32\x12.otg.BgpCapabilityH\x03\x88\x01\x01\x12\'\n\tv4_routes\x18\x08 \x03(\x0b\x32\x14.otg.BgpV4RouteRange\x12\'\n\tv6_routes\x18\t \x03(\x0b\x32\x14.otg.BgpV6RouteRange\x12.\n\x10v4_srte_policies\x18\n \x03(\x0b\x32\x14.otg.BgpSrteV4Policy\x12.\n\x10v6_srte_policies\x18\x0b \x03(\x0b\x32\x14.otg.BgpSrteV6Policy\x12\x0c\n\x04name\x18\x0c \x01(\t\x1a\x35\n\x06\x41sType\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ibgp\x10\x01\x12\x08\n\x04\x65\x62gp\x10\x02\x1a;\n\rAsNumberWidth\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03two\x10\x01\x12\x08\n\x04\x66our\x10\x02\x42\x12\n\x10_segment_routingB\x12\n\x10_as_number_widthB\x0b\n\t_advancedB\r\n\x0b_capability\"B\n\x0e\x42gpV6Interface\x12\x11\n\tipv6_name\x18\x01 \x01(\t\x12\x1d\n\x05peers\x18\x02 \x03(\x0b\x32\x0e.otg.BgpV6Peer\"\xf1\x03\n\x13\x42gpV6SegmentRouting\x12!\n\x14ingress_supports_vpn\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\"\n\x15reduced_encapsulation\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x1e\n\x11\x63opy_time_to_live\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x19\n\x0ctime_to_live\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12\x1d\n\x10max_sids_per_srh\x18\x05 \x01(\x05H\x04\x88\x01\x01\x12-\n auto_generate_segment_left_value\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x1f\n\x12segment_left_value\x18\x07 \x01(\x05H\x06\x88\x01\x01\x12#\n\x16\x61\x64vertise_sr_te_policy\x18\x08 \x01(\x08H\x07\x88\x01\x01\x42\x17\n\x15_ingress_supports_vpnB\x18\n\x16_reduced_encapsulationB\x14\n\x12_copy_time_to_liveB\x0f\n\r_time_to_liveB\x13\n\x11_max_sids_per_srhB#\n!_auto_generate_segment_left_valueB\x15\n\x13_segment_left_valueB\x19\n\x17_advertise_sr_te_policy\"\x94\x02\n\x04\x46low\x12\x1c\n\x05tx_rx\x18\x01 \x01(\x0b\x32\r.otg.FlowTxRx\x12\x1f\n\x06packet\x18\x02 \x03(\x0b\x32\x0f.otg.FlowHeader\x12 \n\x04size\x18\x03 \x01(\x0b\x32\r.otg.FlowSizeH\x00\x88\x01\x01\x12 \n\x04rate\x18\x04 \x01(\x0b\x32\r.otg.FlowRateH\x01\x88\x01\x01\x12(\n\x08\x64uration\x18\x05 \x01(\x0b\x32\x11.otg.FlowDurationH\x02\x88\x01\x01\x12&\n\x07metrics\x18\x06 \x01(\x0b\x32\x10.otg.FlowMetricsH\x03\x88\x01\x01\x12\x0c\n\x04name\x18\x07 \x01(\tB\x07\n\x05_sizeB\x07\n\x05_rateB\x0b\n\t_durationB\n\n\x08_metrics\"\xda\x01\n\x08\x46lowTxRx\x12.\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x19.otg.FlowTxRx.Choice.EnumH\x00\x88\x01\x01\x12 \n\x04port\x18\x02 \x01(\x0b\x32\r.otg.FlowPortH\x01\x88\x01\x01\x12$\n\x06\x64\x65vice\x18\x03 \x01(\x0b\x32\x0f.otg.FlowRouterH\x02\x88\x01\x01\x1a\x37\n\x06\x43hoice\"-\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04port\x10\x01\x12\n\n\x06\x64\x65vice\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_portB\t\n\x07_device\"=\n\x08\x46lowPort\x12\x0f\n\x07tx_name\x18\x01 \x01(\t\x12\x14\n\x07rx_name\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\n\n\x08_rx_name\"\xa2\x01\n\nFlowRouter\x12,\n\x04mode\x18\x01 \x01(\x0e\x32\x19.otg.FlowRouter.Mode.EnumH\x00\x88\x01\x01\x12\x10\n\x08tx_names\x18\x02 \x03(\t\x12\x10\n\x08rx_names\x18\x03 \x03(\t\x1a\x39\n\x04Mode\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04mesh\x10\x01\x12\x0e\n\none_to_one\x10\x02\x42\x07\n\x05_mode\"\xfc\x08\n\nFlowHeader\x12\x30\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1b.otg.FlowHeader.Choice.EnumH\x00\x88\x01\x01\x12$\n\x06\x63ustom\x18\x02 \x01(\x0b\x32\x0f.otg.FlowCustomH\x01\x88\x01\x01\x12(\n\x08\x65thernet\x18\x03 \x01(\x0b\x32\x11.otg.FlowEthernetH\x02\x88\x01\x01\x12 \n\x04vlan\x18\x04 \x01(\x0b\x32\r.otg.FlowVlanH\x03\x88\x01\x01\x12\"\n\x05vxlan\x18\x05 \x01(\x0b\x32\x0e.otg.FlowVxlanH\x04\x88\x01\x01\x12 \n\x04ipv4\x18\x06 \x01(\x0b\x32\r.otg.FlowIpv4H\x05\x88\x01\x01\x12 \n\x04ipv6\x18\x07 \x01(\x0b\x32\r.otg.FlowIpv6H\x06\x88\x01\x01\x12(\n\x08pfcpause\x18\x08 \x01(\x0b\x32\x11.otg.FlowPfcPauseH\x07\x88\x01\x01\x12\x32\n\rethernetpause\x18\t \x01(\x0b\x32\x16.otg.FlowEthernetPauseH\x08\x88\x01\x01\x12\x1e\n\x03tcp\x18\n \x01(\x0b\x32\x0c.otg.FlowTcpH\t\x88\x01\x01\x12\x1e\n\x03udp\x18\x0b \x01(\x0b\x32\x0c.otg.FlowUdpH\n\x88\x01\x01\x12\x1e\n\x03gre\x18\x0c \x01(\x0b\x32\x0c.otg.FlowGreH\x0b\x88\x01\x01\x12\"\n\x05gtpv1\x18\r \x01(\x0b\x32\x0e.otg.FlowGtpv1H\x0c\x88\x01\x01\x12\"\n\x05gtpv2\x18\x0e \x01(\x0b\x32\x0e.otg.FlowGtpv2H\r\x88\x01\x01\x12\x1e\n\x03\x61rp\x18\x0f \x01(\x0b\x32\x0c.otg.FlowArpH\x0e\x88\x01\x01\x12 \n\x04icmp\x18\x10 \x01(\x0b\x32\r.otg.FlowIcmpH\x0f\x88\x01\x01\x12$\n\x06icmpv6\x18\x11 \x01(\x0b\x32\x0f.otg.FlowIcmpv6H\x10\x88\x01\x01\x12\x1e\n\x03ppp\x18\x12 \x01(\x0b\x32\x0c.otg.FlowPppH\x11\x88\x01\x01\x12$\n\x06igmpv1\x18\x13 \x01(\x0b\x32\x0f.otg.FlowIgmpv1H\x12\x88\x01\x01\x1a\xeb\x01\n\x06\x43hoice\"\xe0\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06\x63ustom\x10\x01\x12\x0c\n\x08\x65thernet\x10\x02\x12\x08\n\x04vlan\x10\x03\x12\t\n\x05vxlan\x10\x04\x12\x08\n\x04ipv4\x10\x05\x12\x08\n\x04ipv6\x10\x06\x12\x0c\n\x08pfcpause\x10\x07\x12\x11\n\rethernetpause\x10\x08\x12\x07\n\x03tcp\x10\t\x12\x07\n\x03udp\x10\n\x12\x07\n\x03gre\x10\x0b\x12\t\n\x05gtpv1\x10\x0c\x12\t\n\x05gtpv2\x10\r\x12\x07\n\x03\x61rp\x10\x0e\x12\x08\n\x04icmp\x10\x0f\x12\n\n\x06icmpv6\x10\x10\x12\x07\n\x03ppp\x10\x11\x12\n\n\x06igmpv1\x10\x12\x42\t\n\x07_choiceB\t\n\x07_customB\x0b\n\t_ethernetB\x07\n\x05_vlanB\x08\n\x06_vxlanB\x07\n\x05_ipv4B\x07\n\x05_ipv6B\x0b\n\t_pfcpauseB\x10\n\x0e_ethernetpauseB\x06\n\x04_tcpB\x06\n\x04_udpB\x06\n\x04_greB\x08\n\x06_gtpv1B\x08\n\x06_gtpv2B\x06\n\x04_arpB\x07\n\x05_icmpB\t\n\x07_icmpv6B\x06\n\x04_pppB\t\n\x07_igmpv1\"\x1b\n\nFlowCustom\x12\r\n\x05\x62ytes\x18\x01 \x01(\t\"\x8f\x02\n\x0c\x46lowEthernet\x12-\n\x03\x64st\x18\x01 \x01(\x0b\x32\x1b.otg.PatternFlowEthernetDstH\x00\x88\x01\x01\x12-\n\x03src\x18\x02 \x01(\x0b\x32\x1b.otg.PatternFlowEthernetSrcH\x01\x88\x01\x01\x12:\n\nether_type\x18\x03 \x01(\x0b\x32!.otg.PatternFlowEthernetEtherTypeH\x02\x88\x01\x01\x12\x38\n\tpfc_queue\x18\x04 \x01(\x0b\x32 .otg.PatternFlowEthernetPfcQueueH\x03\x88\x01\x01\x42\x06\n\x04_dstB\x06\n\x04_srcB\r\n\x0b_ether_typeB\x0c\n\n_pfc_queue\"\xe5\x01\n\x08\x46lowVlan\x12\x33\n\x08priority\x18\x01 \x01(\x0b\x32\x1c.otg.PatternFlowVlanPriorityH\x00\x88\x01\x01\x12)\n\x03\x63\x66i\x18\x02 \x01(\x0b\x32\x17.otg.PatternFlowVlanCfiH\x01\x88\x01\x01\x12\'\n\x02id\x18\x03 \x01(\x0b\x32\x16.otg.PatternFlowVlanIdH\x02\x88\x01\x01\x12+\n\x04tpid\x18\x04 \x01(\x0b\x32\x18.otg.PatternFlowVlanTpidH\x03\x88\x01\x01\x42\x0b\n\t_priorityB\x06\n\x04_cfiB\x05\n\x03_idB\x07\n\x05_tpid\"\x85\x02\n\tFlowVxlan\x12.\n\x05\x66lags\x18\x01 \x01(\x0b\x32\x1a.otg.PatternFlowVxlanFlagsH\x00\x88\x01\x01\x12\x36\n\treserved0\x18\x02 \x01(\x0b\x32\x1e.otg.PatternFlowVxlanReserved0H\x01\x88\x01\x01\x12*\n\x03vni\x18\x03 \x01(\x0b\x32\x18.otg.PatternFlowVxlanVniH\x02\x88\x01\x01\x12\x36\n\treserved1\x18\x04 \x01(\x0b\x32\x1e.otg.PatternFlowVxlanReserved1H\x03\x88\x01\x01\x42\x08\n\x06_flagsB\x0c\n\n_reserved0B\x06\n\x04_vniB\x0c\n\n_reserved1\"\xfa\x07\n\x08\x46lowIpv4\x12\x31\n\x07version\x18\x01 \x01(\x0b\x32\x1b.otg.PatternFlowIpv4VersionH\x00\x88\x01\x01\x12<\n\rheader_length\x18\x02 \x01(\x0b\x32 .otg.PatternFlowIpv4HeaderLengthH\x01\x88\x01\x01\x12,\n\x08priority\x18\x03 \x01(\x0b\x32\x15.otg.FlowIpv4PriorityH\x02\x88\x01\x01\x12:\n\x0ctotal_length\x18\x04 \x01(\x0b\x32\x1f.otg.PatternFlowIpv4TotalLengthH\x03\x88\x01\x01\x12?\n\x0eidentification\x18\x05 \x01(\x0b\x32\".otg.PatternFlowIpv4IdentificationH\x04\x88\x01\x01\x12\x33\n\x08reserved\x18\x06 \x01(\x0b\x32\x1c.otg.PatternFlowIpv4ReservedH\x05\x88\x01\x01\x12<\n\rdont_fragment\x18\x07 \x01(\x0b\x32 .otg.PatternFlowIpv4DontFragmentH\x06\x88\x01\x01\x12>\n\x0emore_fragments\x18\x08 \x01(\x0b\x32!.otg.PatternFlowIpv4MoreFragmentsH\x07\x88\x01\x01\x12@\n\x0f\x66ragment_offset\x18\t \x01(\x0b\x32\".otg.PatternFlowIpv4FragmentOffsetH\x08\x88\x01\x01\x12\x39\n\x0ctime_to_live\x18\n \x01(\x0b\x32\x1e.otg.PatternFlowIpv4TimeToLiveH\t\x88\x01\x01\x12\x33\n\x08protocol\x18\x0b \x01(\x0b\x32\x1c.otg.PatternFlowIpv4ProtocolH\n\x88\x01\x01\x12@\n\x0fheader_checksum\x18\x0c \x01(\x0b\x32\".otg.PatternFlowIpv4HeaderChecksumH\x0b\x88\x01\x01\x12)\n\x03src\x18\r \x01(\x0b\x32\x17.otg.PatternFlowIpv4SrcH\x0c\x88\x01\x01\x12)\n\x03\x64st\x18\x0e \x01(\x0b\x32\x17.otg.PatternFlowIpv4DstH\r\x88\x01\x01\x42\n\n\x08_versionB\x10\n\x0e_header_lengthB\x0b\n\t_priorityB\x0f\n\r_total_lengthB\x11\n\x0f_identificationB\x0b\n\t_reservedB\x10\n\x0e_dont_fragmentB\x11\n\x0f_more_fragmentsB\x12\n\x10_fragment_offsetB\x0f\n\r_time_to_liveB\x0b\n\t_protocolB\x12\n\x10_header_checksumB\x06\n\x04_srcB\x06\n\x04_dst\"\xaa\x02\n\x10\x46lowIpv4Priority\x12\x36\n\x06\x63hoice\x18\x01 \x01(\x0e\x32!.otg.FlowIpv4Priority.Choice.EnumH\x00\x88\x01\x01\x12\x31\n\x03raw\x18\x02 \x01(\x0b\x32\x1f.otg.PatternFlowIpv4PriorityRawH\x01\x88\x01\x01\x12\"\n\x03tos\x18\x03 \x01(\x0b\x32\x10.otg.FlowIpv4TosH\x02\x88\x01\x01\x12$\n\x04\x64scp\x18\x04 \x01(\x0b\x32\x11.otg.FlowIpv4DscpH\x03\x88\x01\x01\x1a=\n\x06\x43hoice\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03raw\x10\x01\x12\x07\n\x03tos\x10\x02\x12\x08\n\x04\x64scp\x10\x03\x42\t\n\x07_choiceB\x06\n\x04_rawB\x06\n\x04_tosB\x07\n\x05_dscp\"|\n\x0c\x46lowIpv4Dscp\x12-\n\x03phb\x18\x01 \x01(\x0b\x32\x1b.otg.PatternFlowIpv4DscpPhbH\x00\x88\x01\x01\x12-\n\x03\x65\x63n\x18\x02 \x01(\x0b\x32\x1b.otg.PatternFlowIpv4DscpEcnH\x01\x88\x01\x01\x42\x06\n\x04_phbB\x06\n\x04_ecn\"\xb1\x03\n\x0b\x46lowIpv4Tos\x12:\n\nprecedence\x18\x01 \x01(\x0b\x32!.otg.PatternFlowIpv4TosPrecedenceH\x00\x88\x01\x01\x12\x30\n\x05\x64\x65lay\x18\x02 \x01(\x0b\x32\x1c.otg.PatternFlowIpv4TosDelayH\x01\x88\x01\x01\x12:\n\nthroughput\x18\x03 \x01(\x0b\x32!.otg.PatternFlowIpv4TosThroughputH\x02\x88\x01\x01\x12<\n\x0breliability\x18\x04 \x01(\x0b\x32\".otg.PatternFlowIpv4TosReliabilityH\x03\x88\x01\x01\x12\x36\n\x08monetary\x18\x05 \x01(\x0b\x32\x1f.otg.PatternFlowIpv4TosMonetaryH\x04\x88\x01\x01\x12\x32\n\x06unused\x18\x06 \x01(\x0b\x32\x1d.otg.PatternFlowIpv4TosUnusedH\x05\x88\x01\x01\x42\r\n\x0b_precedenceB\x08\n\x06_delayB\r\n\x0b_throughputB\x0e\n\x0c_reliabilityB\x0b\n\t_monetaryB\t\n\x07_unused\"\xa7\x04\n\x08\x46lowIpv6\x12\x31\n\x07version\x18\x01 \x01(\x0b\x32\x1b.otg.PatternFlowIpv6VersionH\x00\x88\x01\x01\x12<\n\rtraffic_class\x18\x02 \x01(\x0b\x32 .otg.PatternFlowIpv6TrafficClassH\x01\x88\x01\x01\x12\x36\n\nflow_label\x18\x03 \x01(\x0b\x32\x1d.otg.PatternFlowIpv6FlowLabelH\x02\x88\x01\x01\x12>\n\x0epayload_length\x18\x04 \x01(\x0b\x32!.otg.PatternFlowIpv6PayloadLengthH\x03\x88\x01\x01\x12\x38\n\x0bnext_header\x18\x05 \x01(\x0b\x32\x1e.otg.PatternFlowIpv6NextHeaderH\x04\x88\x01\x01\x12\x34\n\thop_limit\x18\x06 \x01(\x0b\x32\x1c.otg.PatternFlowIpv6HopLimitH\x05\x88\x01\x01\x12)\n\x03src\x18\x07 \x01(\x0b\x32\x17.otg.PatternFlowIpv6SrcH\x06\x88\x01\x01\x12)\n\x03\x64st\x18\x08 \x01(\x0b\x32\x17.otg.PatternFlowIpv6DstH\x07\x88\x01\x01\x42\n\n\x08_versionB\x10\n\x0e_traffic_classB\r\n\x0b_flow_labelB\x11\n\x0f_payload_lengthB\x0e\n\x0c_next_headerB\x0c\n\n_hop_limitB\x06\n\x04_srcB\x06\n\x04_dst\"\x9d\x08\n\x0c\x46lowPfcPause\x12-\n\x03\x64st\x18\x01 \x01(\x0b\x32\x1b.otg.PatternFlowPfcPauseDstH\x00\x88\x01\x01\x12-\n\x03src\x18\x02 \x01(\x0b\x32\x1b.otg.PatternFlowPfcPauseSrcH\x01\x88\x01\x01\x12:\n\nether_type\x18\x03 \x01(\x0b\x32!.otg.PatternFlowPfcPauseEtherTypeH\x02\x88\x01\x01\x12\x43\n\x0f\x63ontrol_op_code\x18\x04 \x01(\x0b\x32%.otg.PatternFlowPfcPauseControlOpCodeH\x03\x88\x01\x01\x12K\n\x13\x63lass_enable_vector\x18\x05 \x01(\x0b\x32).otg.PatternFlowPfcPauseClassEnableVectorH\x04\x88\x01\x01\x12?\n\rpause_class_0\x18\x06 \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass0H\x05\x88\x01\x01\x12?\n\rpause_class_1\x18\x07 \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass1H\x06\x88\x01\x01\x12?\n\rpause_class_2\x18\x08 \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass2H\x07\x88\x01\x01\x12?\n\rpause_class_3\x18\t \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass3H\x08\x88\x01\x01\x12?\n\rpause_class_4\x18\n \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass4H\t\x88\x01\x01\x12?\n\rpause_class_5\x18\x0b \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass5H\n\x88\x01\x01\x12?\n\rpause_class_6\x18\x0c \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass6H\x0b\x88\x01\x01\x12?\n\rpause_class_7\x18\r \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass7H\x0c\x88\x01\x01\x42\x06\n\x04_dstB\x06\n\x04_srcB\r\n\x0b_ether_typeB\x12\n\x10_control_op_codeB\x16\n\x14_class_enable_vectorB\x10\n\x0e_pause_class_0B\x10\n\x0e_pause_class_1B\x10\n\x0e_pause_class_2B\x10\n\x0e_pause_class_3B\x10\n\x0e_pause_class_4B\x10\n\x0e_pause_class_5B\x10\n\x0e_pause_class_6B\x10\n\x0e_pause_class_7\"\xf8\x02\n\x11\x46lowEthernetPause\x12\x32\n\x03\x64st\x18\x01 \x01(\x0b\x32 .otg.PatternFlowEthernetPauseDstH\x00\x88\x01\x01\x12\x32\n\x03src\x18\x02 \x01(\x0b\x32 .otg.PatternFlowEthernetPauseSrcH\x01\x88\x01\x01\x12?\n\nether_type\x18\x03 \x01(\x0b\x32&.otg.PatternFlowEthernetPauseEtherTypeH\x02\x88\x01\x01\x12H\n\x0f\x63ontrol_op_code\x18\x04 \x01(\x0b\x32*.otg.PatternFlowEthernetPauseControlOpCodeH\x03\x88\x01\x01\x12\x34\n\x04time\x18\x05 \x01(\x0b\x32!.otg.PatternFlowEthernetPauseTimeH\x04\x88\x01\x01\x42\x06\n\x04_dstB\x06\n\x04_srcB\r\n\x0b_ether_typeB\x12\n\x10_control_op_codeB\x07\n\x05_time\"\xac\x07\n\x07\x46lowTcp\x12\x31\n\x08src_port\x18\x01 \x01(\x0b\x32\x1a.otg.PatternFlowTcpSrcPortH\x00\x88\x01\x01\x12\x31\n\x08\x64st_port\x18\x02 \x01(\x0b\x32\x1a.otg.PatternFlowTcpDstPortH\x01\x88\x01\x01\x12/\n\x07seq_num\x18\x03 \x01(\x0b\x32\x19.otg.PatternFlowTcpSeqNumH\x02\x88\x01\x01\x12/\n\x07\x61\x63k_num\x18\x04 \x01(\x0b\x32\x19.otg.PatternFlowTcpAckNumH\x03\x88\x01\x01\x12\x37\n\x0b\x64\x61ta_offset\x18\x05 \x01(\x0b\x32\x1d.otg.PatternFlowTcpDataOffsetH\x04\x88\x01\x01\x12-\n\x06\x65\x63n_ns\x18\x06 \x01(\x0b\x32\x18.otg.PatternFlowTcpEcnNsH\x05\x88\x01\x01\x12/\n\x07\x65\x63n_cwr\x18\x07 \x01(\x0b\x32\x19.otg.PatternFlowTcpEcnCwrH\x06\x88\x01\x01\x12\x31\n\x08\x65\x63n_echo\x18\x08 \x01(\x0b\x32\x1a.otg.PatternFlowTcpEcnEchoH\x07\x88\x01\x01\x12/\n\x07\x63tl_urg\x18\t \x01(\x0b\x32\x19.otg.PatternFlowTcpCtlUrgH\x08\x88\x01\x01\x12/\n\x07\x63tl_ack\x18\n \x01(\x0b\x32\x19.otg.PatternFlowTcpCtlAckH\t\x88\x01\x01\x12/\n\x07\x63tl_psh\x18\x0b \x01(\x0b\x32\x19.otg.PatternFlowTcpCtlPshH\n\x88\x01\x01\x12/\n\x07\x63tl_rst\x18\x0c \x01(\x0b\x32\x19.otg.PatternFlowTcpCtlRstH\x0b\x88\x01\x01\x12/\n\x07\x63tl_syn\x18\r \x01(\x0b\x32\x19.otg.PatternFlowTcpCtlSynH\x0c\x88\x01\x01\x12/\n\x07\x63tl_fin\x18\x0e \x01(\x0b\x32\x19.otg.PatternFlowTcpCtlFinH\r\x88\x01\x01\x12.\n\x06window\x18\x0f \x01(\x0b\x32\x19.otg.PatternFlowTcpWindowH\x0e\x88\x01\x01\x42\x0b\n\t_src_portB\x0b\n\t_dst_portB\n\n\x08_seq_numB\n\n\x08_ack_numB\x0e\n\x0c_data_offsetB\t\n\x07_ecn_nsB\n\n\x08_ecn_cwrB\x0b\n\t_ecn_echoB\n\n\x08_ctl_urgB\n\n\x08_ctl_ackB\n\n\x08_ctl_pshB\n\n\x08_ctl_rstB\n\n\x08_ctl_synB\n\n\x08_ctl_finB\t\n\x07_window\"\x85\x02\n\x07\x46lowUdp\x12\x31\n\x08src_port\x18\x01 \x01(\x0b\x32\x1a.otg.PatternFlowUdpSrcPortH\x00\x88\x01\x01\x12\x31\n\x08\x64st_port\x18\x02 \x01(\x0b\x32\x1a.otg.PatternFlowUdpDstPortH\x01\x88\x01\x01\x12.\n\x06length\x18\x03 \x01(\x0b\x32\x19.otg.PatternFlowUdpLengthH\x02\x88\x01\x01\x12\x32\n\x08\x63hecksum\x18\x04 \x01(\x0b\x32\x1b.otg.PatternFlowUdpChecksumH\x03\x88\x01\x01\x42\x0b\n\t_src_portB\x0b\n\t_dst_portB\t\n\x07_lengthB\x0b\n\t_checksum\"\xa9\x03\n\x07\x46lowGre\x12\x41\n\x10\x63hecksum_present\x18\x01 \x01(\x0b\x32\".otg.PatternFlowGreChecksumPresentH\x00\x88\x01\x01\x12\x34\n\treserved0\x18\x02 \x01(\x0b\x32\x1c.otg.PatternFlowGreReserved0H\x01\x88\x01\x01\x12\x30\n\x07version\x18\x03 \x01(\x0b\x32\x1a.otg.PatternFlowGreVersionH\x02\x88\x01\x01\x12\x32\n\x08protocol\x18\x04 \x01(\x0b\x32\x1b.otg.PatternFlowGreProtocolH\x03\x88\x01\x01\x12\x32\n\x08\x63hecksum\x18\x05 \x01(\x0b\x32\x1b.otg.PatternFlowGreChecksumH\x04\x88\x01\x01\x12\x34\n\treserved1\x18\x06 \x01(\x0b\x32\x1c.otg.PatternFlowGreReserved1H\x05\x88\x01\x01\x42\x13\n\x11_checksum_presentB\x0c\n\n_reserved0B\n\n\x08_versionB\x0b\n\t_protocolB\x0b\n\t_checksumB\x0c\n\n_reserved1\"\xb8\x07\n\tFlowGtpv1\x12\x32\n\x07version\x18\x01 \x01(\x0b\x32\x1c.otg.PatternFlowGtpv1VersionH\x00\x88\x01\x01\x12=\n\rprotocol_type\x18\x02 \x01(\x0b\x32!.otg.PatternFlowGtpv1ProtocolTypeH\x01\x88\x01\x01\x12\x34\n\x08reserved\x18\x03 \x01(\x0b\x32\x1d.otg.PatternFlowGtpv1ReservedH\x02\x88\x01\x01\x12/\n\x06\x65_flag\x18\x04 \x01(\x0b\x32\x1a.otg.PatternFlowGtpv1EFlagH\x03\x88\x01\x01\x12/\n\x06s_flag\x18\x05 \x01(\x0b\x32\x1a.otg.PatternFlowGtpv1SFlagH\x04\x88\x01\x01\x12\x31\n\x07pn_flag\x18\x06 \x01(\x0b\x32\x1b.otg.PatternFlowGtpv1PnFlagH\x05\x88\x01\x01\x12;\n\x0cmessage_type\x18\x07 \x01(\x0b\x32 .otg.PatternFlowGtpv1MessageTypeH\x06\x88\x01\x01\x12?\n\x0emessage_length\x18\x08 \x01(\x0b\x32\".otg.PatternFlowGtpv1MessageLengthH\x07\x88\x01\x01\x12,\n\x04teid\x18\t \x01(\x0b\x32\x19.otg.PatternFlowGtpv1TeidH\x08\x88\x01\x01\x12?\n\x0esquence_number\x18\n \x01(\x0b\x32\".otg.PatternFlowGtpv1SquenceNumberH\t\x88\x01\x01\x12:\n\x0cn_pdu_number\x18\x0b \x01(\x0b\x32\x1f.otg.PatternFlowGtpv1NPduNumberH\n\x88\x01\x01\x12U\n\x1anext_extension_header_type\x18\x0c \x01(\x0b\x32,.otg.PatternFlowGtpv1NextExtensionHeaderTypeH\x0b\x88\x01\x01\x12\x30\n\x11\x65xtension_headers\x18\r \x03(\x0b\x32\x15.otg.FlowGtpExtensionB\n\n\x08_versionB\x10\n\x0e_protocol_typeB\x0b\n\t_reservedB\t\n\x07_e_flagB\t\n\x07_s_flagB\n\n\x08_pn_flagB\x0f\n\r_message_typeB\x11\n\x0f_message_lengthB\x07\n\x05_teidB\x11\n\x0f_squence_numberB\x0f\n\r_n_pdu_numberB\x1d\n\x1b_next_extension_header_type\"\xac\x02\n\x10\x46lowGtpExtension\x12J\n\x10\x65xtension_length\x18\x01 \x01(\x0b\x32+.otg.PatternFlowGtpExtensionExtensionLengthH\x00\x88\x01\x01\x12;\n\x08\x63ontents\x18\x02 \x01(\x0b\x32$.otg.PatternFlowGtpExtensionContentsH\x01\x88\x01\x01\x12S\n\x15next_extension_header\x18\x03 \x01(\x0b\x32/.otg.PatternFlowGtpExtensionNextExtensionHeaderH\x02\x88\x01\x01\x42\x13\n\x11_extension_lengthB\x0b\n\t_contentsB\x18\n\x16_next_extension_header\"\x97\x05\n\tFlowGtpv2\x12\x32\n\x07version\x18\x01 \x01(\x0b\x32\x1c.otg.PatternFlowGtpv2VersionH\x00\x88\x01\x01\x12\x45\n\x11piggybacking_flag\x18\x02 \x01(\x0b\x32%.otg.PatternFlowGtpv2PiggybackingFlagH\x01\x88\x01\x01\x12\x35\n\tteid_flag\x18\x03 \x01(\x0b\x32\x1d.otg.PatternFlowGtpv2TeidFlagH\x02\x88\x01\x01\x12\x30\n\x06spare1\x18\x04 \x01(\x0b\x32\x1b.otg.PatternFlowGtpv2Spare1H\x03\x88\x01\x01\x12;\n\x0cmessage_type\x18\x05 \x01(\x0b\x32 .otg.PatternFlowGtpv2MessageTypeH\x04\x88\x01\x01\x12?\n\x0emessage_length\x18\x06 \x01(\x0b\x32\".otg.PatternFlowGtpv2MessageLengthH\x05\x88\x01\x01\x12,\n\x04teid\x18\x07 \x01(\x0b\x32\x19.otg.PatternFlowGtpv2TeidH\x06\x88\x01\x01\x12\x41\n\x0fsequence_number\x18\x08 \x01(\x0b\x32#.otg.PatternFlowGtpv2SequenceNumberH\x07\x88\x01\x01\x12\x30\n\x06spare2\x18\t \x01(\x0b\x32\x1b.otg.PatternFlowGtpv2Spare2H\x08\x88\x01\x01\x42\n\n\x08_versionB\x14\n\x12_piggybacking_flagB\x0c\n\n_teid_flagB\t\n\x07_spare1B\x0f\n\r_message_typeB\x11\n\x0f_message_lengthB\x07\n\x05_teidB\x12\n\x10_sequence_numberB\t\n\x07_spare2\"\xa1\x06\n\x07\x46lowArp\x12;\n\rhardware_type\x18\x01 \x01(\x0b\x32\x1f.otg.PatternFlowArpHardwareTypeH\x00\x88\x01\x01\x12;\n\rprotocol_type\x18\x02 \x01(\x0b\x32\x1f.otg.PatternFlowArpProtocolTypeH\x01\x88\x01\x01\x12?\n\x0fhardware_length\x18\x03 \x01(\x0b\x32!.otg.PatternFlowArpHardwareLengthH\x02\x88\x01\x01\x12?\n\x0fprotocol_length\x18\x04 \x01(\x0b\x32!.otg.PatternFlowArpProtocolLengthH\x03\x88\x01\x01\x12\x34\n\toperation\x18\x05 \x01(\x0b\x32\x1c.otg.PatternFlowArpOperationH\x04\x88\x01\x01\x12H\n\x14sender_hardware_addr\x18\x06 \x01(\x0b\x32%.otg.PatternFlowArpSenderHardwareAddrH\x05\x88\x01\x01\x12H\n\x14sender_protocol_addr\x18\x07 \x01(\x0b\x32%.otg.PatternFlowArpSenderProtocolAddrH\x06\x88\x01\x01\x12H\n\x14target_hardware_addr\x18\x08 \x01(\x0b\x32%.otg.PatternFlowArpTargetHardwareAddrH\x07\x88\x01\x01\x12H\n\x14target_protocol_addr\x18\t \x01(\x0b\x32%.otg.PatternFlowArpTargetProtocolAddrH\x08\x88\x01\x01\x42\x10\n\x0e_hardware_typeB\x10\n\x0e_protocol_typeB\x12\n\x10_hardware_lengthB\x12\n\x10_protocol_lengthB\x0c\n\n_operationB\x17\n\x15_sender_hardware_addrB\x17\n\x15_sender_protocol_addrB\x17\n\x15_target_hardware_addrB\x17\n\x15_target_protocol_addr\"\xa1\x01\n\x08\x46lowIcmp\x12.\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x19.otg.FlowIcmp.Choice.EnumH\x00\x88\x01\x01\x12$\n\x04\x65\x63ho\x18\x02 \x01(\x0b\x32\x11.otg.FlowIcmpEchoH\x01\x88\x01\x01\x1a+\n\x06\x43hoice\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x65\x63ho\x10\x01\x42\t\n\x07_choiceB\x07\n\x05_echo\"\xee\x02\n\x0c\x46lowIcmpEcho\x12/\n\x04type\x18\x01 \x01(\x0b\x32\x1c.otg.PatternFlowIcmpEchoTypeH\x00\x88\x01\x01\x12/\n\x04\x63ode\x18\x02 \x01(\x0b\x32\x1c.otg.PatternFlowIcmpEchoCodeH\x01\x88\x01\x01\x12\x37\n\x08\x63hecksum\x18\x03 \x01(\x0b\x32 .otg.PatternFlowIcmpEchoChecksumH\x02\x88\x01\x01\x12;\n\nidentifier\x18\x04 \x01(\x0b\x32\".otg.PatternFlowIcmpEchoIdentifierH\x03\x88\x01\x01\x12\x44\n\x0fsequence_number\x18\x05 \x01(\x0b\x32&.otg.PatternFlowIcmpEchoSequenceNumberH\x04\x88\x01\x01\x42\x07\n\x05_typeB\x07\n\x05_codeB\x0b\n\t_checksumB\r\n\x0b_identifierB\x12\n\x10_sequence_number\"\xa7\x01\n\nFlowIcmpv6\x12\x30\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1b.otg.FlowIcmpv6.Choice.EnumH\x00\x88\x01\x01\x12&\n\x04\x65\x63ho\x18\x02 \x01(\x0b\x32\x13.otg.FlowIcmpv6EchoH\x01\x88\x01\x01\x1a+\n\x06\x43hoice\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x65\x63ho\x10\x01\x42\t\n\x07_choiceB\x07\n\x05_echo\"\xfa\x02\n\x0e\x46lowIcmpv6Echo\x12\x31\n\x04type\x18\x01 \x01(\x0b\x32\x1e.otg.PatternFlowIcmpv6EchoTypeH\x00\x88\x01\x01\x12\x31\n\x04\x63ode\x18\x02 \x01(\x0b\x32\x1e.otg.PatternFlowIcmpv6EchoCodeH\x01\x88\x01\x01\x12=\n\nidentifier\x18\x03 \x01(\x0b\x32$.otg.PatternFlowIcmpv6EchoIdentifierH\x02\x88\x01\x01\x12\x46\n\x0fsequence_number\x18\x04 \x01(\x0b\x32(.otg.PatternFlowIcmpv6EchoSequenceNumberH\x03\x88\x01\x01\x12\x39\n\x08\x63hecksum\x18\x05 \x01(\x0b\x32\".otg.PatternFlowIcmpv6EchoChecksumH\x04\x88\x01\x01\x42\x07\n\x05_typeB\x07\n\x05_codeB\r\n\x0b_identifierB\x12\n\x10_sequence_numberB\x0b\n\t_checksum\"\xd4\x01\n\x07\x46lowPpp\x12\x30\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1a.otg.PatternFlowPppAddressH\x00\x88\x01\x01\x12\x30\n\x07\x63ontrol\x18\x02 \x01(\x0b\x32\x1a.otg.PatternFlowPppControlH\x01\x88\x01\x01\x12;\n\rprotocol_type\x18\x03 \x01(\x0b\x32\x1f.otg.PatternFlowPppProtocolTypeH\x02\x88\x01\x01\x42\n\n\x08_addressB\n\n\x08_controlB\x10\n\x0e_protocol_type\"\xd9\x02\n\nFlowIgmpv1\x12\x33\n\x07version\x18\x01 \x01(\x0b\x32\x1d.otg.PatternFlowIgmpv1VersionH\x00\x88\x01\x01\x12-\n\x04type\x18\x02 \x01(\x0b\x32\x1a.otg.PatternFlowIgmpv1TypeH\x01\x88\x01\x01\x12\x31\n\x06unused\x18\x03 \x01(\x0b\x32\x1c.otg.PatternFlowIgmpv1UnusedH\x02\x88\x01\x01\x12\x35\n\x08\x63hecksum\x18\x04 \x01(\x0b\x32\x1e.otg.PatternFlowIgmpv1ChecksumH\x03\x88\x01\x01\x12>\n\rgroup_address\x18\x05 \x01(\x0b\x32\".otg.PatternFlowIgmpv1GroupAddressH\x04\x88\x01\x01\x42\n\n\x08_versionB\x07\n\x05_typeB\t\n\x07_unusedB\x0b\n\t_checksumB\x10\n\x0e_group_address\"\x9f\x02\n\x08\x46lowSize\x12.\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x19.otg.FlowSize.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05\x66ixed\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12.\n\tincrement\x18\x03 \x01(\x0b\x32\x16.otg.FlowSizeIncrementH\x02\x88\x01\x01\x12(\n\x06random\x18\x04 \x01(\x0b\x32\x13.otg.FlowSizeRandomH\x03\x88\x01\x01\x1aG\n\x06\x43hoice\"=\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05\x66ixed\x10\x01\x12\r\n\tincrement\x10\x02\x12\n\n\x06random\x10\x03\x42\t\n\x07_choiceB\x08\n\x06_fixedB\x0c\n\n_incrementB\t\n\x07_random\"g\n\x11\x46lowSizeIncrement\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x10\n\x03\x65nd\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x11\n\x04step\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x06\n\x04_endB\x07\n\x05_step\"D\n\x0e\x46lowSizeRandom\x12\x10\n\x03min\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x10\n\x03max\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x06\n\x04_minB\x06\n\x04_max\"\xd8\x02\n\x08\x46lowRate\x12.\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x19.otg.FlowRate.Choice.EnumH\x00\x88\x01\x01\x12\x10\n\x03pps\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x10\n\x03\x62ps\x18\x03 \x01(\x03H\x02\x88\x01\x01\x12\x11\n\x04kbps\x18\x04 \x01(\x03H\x03\x88\x01\x01\x12\x11\n\x04mbps\x18\x05 \x01(\x03H\x04\x88\x01\x01\x12\x11\n\x04gbps\x18\x06 \x01(\x05H\x05\x88\x01\x01\x12\x17\n\npercentage\x18\x07 \x01(\x02H\x06\x88\x01\x01\x1a\x61\n\x06\x43hoice\"W\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03pps\x10\x01\x12\x07\n\x03\x62ps\x10\x02\x12\x08\n\x04kbps\x10\x03\x12\x08\n\x04mbps\x10\x04\x12\x08\n\x04gbps\x10\x05\x12\x0e\n\npercentage\x10\x06\x42\t\n\x07_choiceB\x06\n\x04_ppsB\x06\n\x04_bpsB\x07\n\x05_kbpsB\x07\n\x05_mbpsB\x07\n\x05_gbpsB\r\n\x0b_percentage\"\xa6\x03\n\x0c\x46lowDuration\x12\x32\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1d.otg.FlowDuration.Choice.EnumH\x00\x88\x01\x01\x12\x31\n\rfixed_packets\x18\x02 \x01(\x0b\x32\x15.otg.FlowFixedPacketsH\x01\x88\x01\x01\x12\x31\n\rfixed_seconds\x18\x03 \x01(\x0b\x32\x15.otg.FlowFixedSecondsH\x02\x88\x01\x01\x12\"\n\x05\x62urst\x18\x04 \x01(\x0b\x32\x0e.otg.FlowBurstH\x03\x88\x01\x01\x12,\n\ncontinuous\x18\x05 \x01(\x0b\x32\x13.otg.FlowContinuousH\x04\x88\x01\x01\x1a\x62\n\x06\x43hoice\"X\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rfixed_packets\x10\x01\x12\x11\n\rfixed_seconds\x10\x02\x12\t\n\x05\x62urst\x10\x03\x12\x0e\n\ncontinuous\x10\x04\x42\t\n\x07_choiceB\x10\n\x0e_fixed_packetsB\x10\n\x0e_fixed_secondsB\x08\n\x06_burstB\r\n\x0b_continuous\"X\n\x0e\x46lowContinuous\x12\x10\n\x03gap\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\"\n\x05\x64\x65lay\x18\x02 \x01(\x0b\x32\x0e.otg.FlowDelayH\x01\x88\x01\x01\x42\x06\n\x04_gapB\x08\n\x06_delay\"\x8c\x02\n\tFlowDelay\x12/\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1a.otg.FlowDelay.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05\x62ytes\x18\x02 \x01(\x02H\x01\x88\x01\x01\x12\x18\n\x0bnanoseconds\x18\x03 \x01(\x02H\x02\x88\x01\x01\x12\x19\n\x0cmicroseconds\x18\x04 \x01(\x02H\x03\x88\x01\x01\x1aO\n\x06\x43hoice\"E\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05\x62ytes\x10\x01\x12\x0f\n\x0bnanoseconds\x10\x02\x12\x10\n\x0cmicroseconds\x10\x03\x42\t\n\x07_choiceB\x08\n\x06_bytesB\x0e\n\x0c_nanosecondsB\x0f\n\r_microseconds\"|\n\x10\x46lowFixedPackets\x12\x14\n\x07packets\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x10\n\x03gap\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\"\n\x05\x64\x65lay\x18\x03 \x01(\x0b\x32\x0e.otg.FlowDelayH\x02\x88\x01\x01\x42\n\n\x08_packetsB\x06\n\x04_gapB\x08\n\x06_delay\"|\n\x10\x46lowFixedSeconds\x12\x14\n\x07seconds\x18\x01 \x01(\x02H\x00\x88\x01\x01\x12\x10\n\x03gap\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\"\n\x05\x64\x65lay\x18\x03 \x01(\x0b\x32\x0e.otg.FlowDelayH\x02\x88\x01\x01\x42\n\n\x08_secondsB\x06\n\x04_gapB\x08\n\x06_delay\"\xb9\x01\n\tFlowBurst\x12\x13\n\x06\x62ursts\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x14\n\x07packets\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x10\n\x03gap\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12<\n\x0finter_burst_gap\x18\x04 \x01(\x0b\x32\x1e.otg.FlowDurationInterBurstGapH\x03\x88\x01\x01\x42\t\n\x07_burstsB\n\n\x08_packetsB\x06\n\x04_gapB\x12\n\x10_inter_burst_gap\"\xac\x02\n\x19\x46lowDurationInterBurstGap\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.FlowDurationInterBurstGap.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05\x62ytes\x18\x02 \x01(\x01H\x01\x88\x01\x01\x12\x18\n\x0bnanoseconds\x18\x03 \x01(\x01H\x02\x88\x01\x01\x12\x19\n\x0cmicroseconds\x18\x04 \x01(\x01H\x03\x88\x01\x01\x1aO\n\x06\x43hoice\"E\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05\x62ytes\x10\x01\x12\x0f\n\x0bnanoseconds\x10\x02\x12\x10\n\x0cmicroseconds\x10\x03\x42\t\n\x07_choiceB\x08\n\x06_bytesB\x0e\n\x0c_nanosecondsB\x0f\n\r_microseconds\"\xac\x01\n\x0b\x46lowMetrics\x12\x13\n\x06\x65nable\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x11\n\x04loss\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x17\n\ntimestamps\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12-\n\x07latency\x18\x04 \x01(\x0b\x32\x17.otg.FlowLatencyMetricsH\x03\x88\x01\x01\x42\t\n\x07_enableB\x07\n\x05_lossB\r\n\x0b_timestampsB\n\n\x08_latency\"\xb8\x01\n\x12\x46lowLatencyMetrics\x12\x13\n\x06\x65nable\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x34\n\x04mode\x18\x02 \x01(\x0e\x32!.otg.FlowLatencyMetrics.Mode.EnumH\x01\x88\x01\x01\x1a\x43\n\x04Mode\";\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rstore_forward\x10\x01\x12\x0f\n\x0b\x63ut_through\x10\x02\x42\t\n\x07_enableB\x07\n\x05_mode\"\x8a\x02\n\x05\x45vent\x12\x13\n\x06\x65nable\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12!\n\x04link\x18\x02 \x01(\x0b\x32\x0e.otg.EventLinkH\x01\x88\x01\x01\x12\x39\n\x11rx_rate_threshold\x18\x03 \x01(\x0b\x32\x19.otg.EventRxRateThresholdH\x02\x88\x01\x01\x12G\n\x18route_advertise_withdraw\x18\x04 \x01(\x0b\x32 .otg.EventRouteAdvertiseWithdrawH\x03\x88\x01\x01\x42\t\n\x07_enableB\x07\n\x05_linkB\x14\n\x12_rx_rate_thresholdB\x1b\n\x19_route_advertise_withdraw\"\\\n\x14\x45ventRxRateThreshold\x12\x13\n\x06\x65nable\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x16\n\tthreshold\x18\x02 \x01(\x02H\x01\x88\x01\x01\x42\t\n\x07_enableB\x0c\n\n_threshold\"+\n\tEventLink\x12\x13\n\x06\x65nable\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\t\n\x07_enable\"=\n\x1b\x45ventRouteAdvertiseWithdraw\x12\x13\n\x06\x65nable\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\t\n\x07_enable\"\xf5\x01\n\x0c\x45ventRequest\x12)\n\x04type\x18\x01 \x03(\x0e\x32\x1b.otg.EventRequest.Type.Enum\x12\x0e\n\x06source\x18\x02 \x03(\t\x1a\xa9\x01\n\x04Type\"\xa0\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tlink_down\x10\x01\x12\x0b\n\x07link_up\x10\x02\x12\x12\n\x0eroute_withdraw\x10\x03\x12\x13\n\x0froute_advertise\x10\x04\x12 \n\x1c\x66low_rx_rate_above_threshold\x10\x05\x12 \n\x1c\x66low_rx_rate_below_threshold\x10\x06\"p\n\x11\x45ventSubscription\x12&\n\x06\x65vents\x18\x01 \x01(\x0b\x32\x11.otg.EventRequestH\x00\x88\x01\x01\x12\x18\n\x0b\x63\x61llbackurl\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\t\n\x07_eventsB\x0e\n\x0c_callbackurl\"\x1f\n\rResponseError\x12\x0e\n\x06\x65rrors\x18\x01 \x03(\t\"#\n\x0fResponseWarning\x12\x10\n\x08warnings\x18\x01 \x03(\t\"}\n\tLinkState\x12\x12\n\nport_names\x18\x01 \x03(\t\x12(\n\x05state\x18\x02 \x01(\x0e\x32\x19.otg.LinkState.State.Enum\x1a\x32\n\x05State\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\"\x93\x01\n\rTransmitState\x12\x12\n\nflow_names\x18\x01 \x03(\t\x12,\n\x05state\x18\x02 \x01(\x0e\x32\x1d.otg.TransmitState.State.Enum\x1a@\n\x05State\"7\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05start\x10\x01\x12\x08\n\x04stop\x10\x02\x12\t\n\x05pause\x10\x03\"\x86\x01\n\x0c\x43\x61ptureState\x12\x12\n\nport_names\x18\x01 \x03(\t\x12+\n\x05state\x18\x02 \x01(\x0e\x32\x1c.otg.CaptureState.State.Enum\x1a\x35\n\x05State\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05start\x10\x01\x12\x08\n\x04stop\x10\x02\"\xa2\x01\n\x0b\x46lowsUpdate\x12;\n\x0eproperty_names\x18\x01 \x03(\x0e\x32#.otg.FlowsUpdate.PropertyNames.Enum\x12\x18\n\x05\x66lows\x18\x02 \x03(\x0b\x32\t.otg.Flow\x1a<\n\rPropertyNames\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04rate\x10\x01\x12\x08\n\x04size\x10\x02\"\x85\x01\n\nRouteState\x12\r\n\x05names\x18\x01 \x03(\t\x12)\n\x05state\x18\x02 \x01(\x0e\x32\x1a.otg.RouteState.State.Enum\x1a=\n\x05State\"4\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08withdraw\x10\x01\x12\r\n\tadvertise\x10\x02\"+\n\x0bPingRequest\x12\x1c\n\tendpoints\x18\x01 \x03(\x0b\x32\t.otg.Ping\"t\n\rProtocolState\x12,\n\x05state\x18\x01 \x01(\x0e\x32\x1d.otg.ProtocolState.State.Enum\x1a\x35\n\x05State\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05start\x10\x01\x12\x08\n\x04stop\x10\x02\"\xca\x01\n\x04Ping\x12*\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x15.otg.Ping.Choice.EnumH\x00\x88\x01\x01\x12 \n\x04ipv4\x18\x02 \x01(\x0b\x32\r.otg.PingIpv4H\x01\x88\x01\x01\x12 \n\x04ipv6\x18\x03 \x01(\x0b\x32\r.otg.PingIpv6H\x02\x88\x01\x01\x1a\x35\n\x06\x43hoice\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_ipv4B\x07\n\x05_ipv6\"N\n\x08PingIpv4\x12\x15\n\x08src_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06\x64st_ip\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x0b\n\t_src_nameB\t\n\x07_dst_ip\"N\n\x08PingIpv6\x12\x15\n\x08src_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06\x64st_ip\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x0b\n\t_src_nameB\t\n\x07_dst_ip\"0\n\x0cPingResponse\x12 \n\tresponses\x18\x01 \x03(\x0b\x32\r.otg.Response\"\xc6\x01\n\x08Response\x12\x15\n\x08src_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06\x64st_ip\x18\x02 \x01(\tH\x01\x88\x01\x01\x12.\n\x06result\x18\x03 \x01(\x0e\x32\x19.otg.Response.Result.EnumH\x02\x88\x01\x01\x1a;\n\x06Result\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07success\x10\x01\x12\x0b\n\x07\x66\x61ilure\x10\x02\x42\x0b\n\t_src_nameB\t\n\x07_dst_ipB\t\n\x07_result\"\xb7\x03\n\x0eMetricsRequest\x12\x34\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1f.otg.MetricsRequest.Choice.EnumH\x00\x88\x01\x01\x12*\n\x04port\x18\x02 \x01(\x0b\x32\x17.otg.PortMetricsRequestH\x01\x88\x01\x01\x12*\n\x04\x66low\x18\x03 \x01(\x0b\x32\x17.otg.FlowMetricsRequestH\x02\x88\x01\x01\x12,\n\x05\x62gpv4\x18\x04 \x01(\x0b\x32\x18.otg.Bgpv4MetricsRequestH\x03\x88\x01\x01\x12,\n\x05\x62gpv6\x18\x05 \x01(\x0b\x32\x18.otg.Bgpv6MetricsRequestH\x04\x88\x01\x01\x12*\n\x04isis\x18\x06 \x01(\x0b\x32\x17.otg.IsisMetricsRequestH\x05\x88\x01\x01\x1aU\n\x06\x43hoice\"K\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04port\x10\x01\x12\x08\n\x04\x66low\x10\x02\x12\t\n\x05\x62gpv4\x10\x03\x12\t\n\x05\x62gpv6\x10\x04\x12\x08\n\x04isis\x10\x05\x42\t\n\x07_choiceB\x07\n\x05_portB\x07\n\x05_flowB\x08\n\x06_bgpv4B\x08\n\x06_bgpv6B\x07\n\x05_isis\"\x99\x03\n\x0fMetricsResponse\x12\x35\n\x06\x63hoice\x18\x01 \x01(\x0e\x32 .otg.MetricsResponse.Choice.EnumH\x00\x88\x01\x01\x12%\n\x0cport_metrics\x18\x02 \x03(\x0b\x32\x0f.otg.PortMetric\x12%\n\x0c\x66low_metrics\x18\x03 \x03(\x0b\x32\x0f.otg.FlowMetric\x12\'\n\rbgpv4_metrics\x18\x04 \x03(\x0b\x32\x10.otg.Bgpv4Metric\x12\'\n\rbgpv6_metrics\x18\x05 \x03(\x0b\x32\x10.otg.Bgpv6Metric\x12%\n\x0cisis_metrics\x18\x06 \x03(\x0b\x32\x0f.otg.IsisMetric\x1a}\n\x06\x43hoice\"s\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0c\x66low_metrics\x10\x01\x12\x10\n\x0cport_metrics\x10\x02\x12\x11\n\rbgpv4_metrics\x10\x03\x12\x11\n\rbgpv6_metrics\x10\x04\x12\x10\n\x0cisis_metrics\x10\x05\x42\t\n\x07_choice\"\xcd\x02\n\x12PortMetricsRequest\x12\x12\n\nport_names\x18\x01 \x03(\t\x12>\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32(.otg.PortMetricsRequest.ColumnNames.Enum\x1a\xe2\x01\n\x0b\x43olumnNames\"\xd2\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08transmit\x10\x01\x12\x0c\n\x08location\x10\x02\x12\x08\n\x04link\x10\x03\x12\x0b\n\x07\x63\x61pture\x10\x04\x12\r\n\tframes_tx\x10\x05\x12\r\n\tframes_rx\x10\x06\x12\x0c\n\x08\x62ytes_tx\x10\x07\x12\x0c\n\x08\x62ytes_rx\x10\x08\x12\x12\n\x0e\x66rames_tx_rate\x10\t\x12\x12\n\x0e\x66rames_rx_rate\x10\n\x12\x11\n\rbytes_tx_rate\x10\x0b\x12\x11\n\rbytes_rx_rate\x10\x0c\"\x84\x05\n\nPortMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08location\x18\x02 \x01(\tH\x01\x88\x01\x01\x12,\n\x04link\x18\x03 \x01(\x0e\x32\x19.otg.PortMetric.Link.EnumH\x02\x88\x01\x01\x12\x32\n\x07\x63\x61pture\x18\x04 \x01(\x0e\x32\x1c.otg.PortMetric.Capture.EnumH\x03\x88\x01\x01\x12\x16\n\tframes_tx\x18\x05 \x01(\x03H\x04\x88\x01\x01\x12\x16\n\tframes_rx\x18\x06 \x01(\x03H\x05\x88\x01\x01\x12\x15\n\x08\x62ytes_tx\x18\x07 \x01(\x03H\x06\x88\x01\x01\x12\x15\n\x08\x62ytes_rx\x18\x08 \x01(\x03H\x07\x88\x01\x01\x12\x1b\n\x0e\x66rames_tx_rate\x18\t \x01(\x02H\x08\x88\x01\x01\x12\x1b\n\x0e\x66rames_rx_rate\x18\n \x01(\x02H\t\x88\x01\x01\x12\x1a\n\rbytes_tx_rate\x18\x0b \x01(\x02H\n\x88\x01\x01\x12\x1a\n\rbytes_rx_rate\x18\x0c \x01(\x02H\x0b\x88\x01\x01\x1a\x31\n\x04Link\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x1a<\n\x07\x43\x61pture\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07started\x10\x01\x12\x0b\n\x07stopped\x10\x02\x42\x07\n\x05_nameB\x0b\n\t_locationB\x07\n\x05_linkB\n\n\x08_captureB\x0c\n\n_frames_txB\x0c\n\n_frames_rxB\x0b\n\t_bytes_txB\x0b\n\t_bytes_rxB\x11\n\x0f_frames_tx_rateB\x11\n\x0f_frames_rx_rateB\x10\n\x0e_bytes_tx_rateB\x10\n\x0e_bytes_rx_rate\"\xcd\x02\n\x12\x46lowMetricsRequest\x12\x12\n\nflow_names\x18\x01 \x03(\t\x12\x37\n\rmetric_groups\x18\x02 \x01(\x0b\x32\x1b.otg.FlowMetricGroupRequestH\x00\x88\x01\x01\x12>\n\x0cmetric_names\x18\x03 \x03(\x0e\x32(.otg.FlowMetricsRequest.MetricNames.Enum\x1a\x97\x01\n\x0bMetricNames\"\x87\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08transmit\x10\x01\x12\r\n\tframes_tx\x10\x02\x12\r\n\tframes_rx\x10\x03\x12\x0c\n\x08\x62ytes_tx\x10\x04\x12\x0c\n\x08\x62ytes_rx\x10\x05\x12\x12\n\x0e\x66rames_tx_rate\x10\x06\x12\x12\n\x0e\x66rames_rx_rate\x10\x07\x42\x10\n\x0e_metric_groups\"\xbe\x01\n\x16\x46lowMetricGroupRequest\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.FlowMetricGroupRequest.Choice.EnumH\x00\x88\x01\x01\x12\x0f\n\x07ingress\x18\x02 \x03(\t\x12\x0e\n\x06\x65gress\x18\x03 \x03(\t\x1a:\n\x06\x43hoice\"0\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07ingress\x10\x01\x12\n\n\x06\x65gress\x10\x02\x42\t\n\x07_choice\"\xab\x05\n\nFlowMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07port_tx\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x14\n\x07port_rx\x18\x03 \x01(\tH\x02\x88\x01\x01\x12+\n\rmetric_groups\x18\x04 \x03(\x0b\x32\x14.otg.FlowMetricGroup\x12\x34\n\x08transmit\x18\x05 \x01(\x0e\x32\x1d.otg.FlowMetric.Transmit.EnumH\x03\x88\x01\x01\x12\x16\n\tframes_tx\x18\x06 \x01(\x03H\x04\x88\x01\x01\x12\x16\n\tframes_rx\x18\x07 \x01(\x03H\x05\x88\x01\x01\x12\x15\n\x08\x62ytes_tx\x18\x08 \x01(\x03H\x06\x88\x01\x01\x12\x15\n\x08\x62ytes_rx\x18\t \x01(\x03H\x07\x88\x01\x01\x12\x1b\n\x0e\x66rames_tx_rate\x18\n \x01(\x02H\x08\x88\x01\x01\x12\x1b\n\x0e\x66rames_rx_rate\x18\x0b \x01(\x02H\t\x88\x01\x01\x12\x11\n\x04loss\x18\x0c \x01(\x02H\n\x88\x01\x01\x12-\n\ntimestamps\x18\r \x01(\x0b\x32\x14.otg.MetricTimestampH\x0b\x88\x01\x01\x12(\n\x07latency\x18\x0e \x01(\x0b\x32\x12.otg.MetricLatencyH\x0c\x88\x01\x01\x1aI\n\x08Transmit\"=\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07started\x10\x01\x12\x0b\n\x07stopped\x10\x02\x12\n\n\x06paused\x10\x03\x42\x07\n\x05_nameB\n\n\x08_port_txB\n\n\x08_port_rxB\x0b\n\t_transmitB\x0c\n\n_frames_txB\x0c\n\n_frames_rxB\x0b\n\t_bytes_txB\x0b\n\t_bytes_rxB\x11\n\x0f_frames_tx_rateB\x11\n\x0f_frames_rx_rateB\x07\n\x05_lossB\r\n\x0b_timestampsB\n\n\x08_latency\"K\n\x0f\x46lowMetricGroup\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_nameB\x08\n\x06_value\"\x7f\n\x0fMetricTimestamp\x12\x1f\n\x12\x66irst_timestamp_ns\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x1e\n\x11last_timestamp_ns\x18\x02 \x01(\x01H\x01\x88\x01\x01\x42\x15\n\x13_first_timestamp_nsB\x14\n\x12_last_timestamp_ns\"\x87\x01\n\rMetricLatency\x12\x17\n\nminimum_ns\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x17\n\nmaximum_ns\x18\x02 \x01(\x01H\x01\x88\x01\x01\x12\x17\n\naverage_ns\x18\x03 \x01(\x01H\x02\x88\x01\x01\x42\r\n\x0b_minimum_nsB\r\n\x0b_maximum_nsB\r\n\x0b_average_ns\"\xd1\x03\n\x13\x42gpv4MetricsRequest\x12\x12\n\npeer_names\x18\x01 \x03(\t\x12?\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32).otg.Bgpv4MetricsRequest.ColumnNames.Enum\x1a\xe4\x02\n\x0b\x43olumnNames\"\xd4\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rsession_state\x10\x01\x12\x16\n\x12session_flap_count\x10\x02\x12\x15\n\x11routes_advertised\x10\x03\x12\x13\n\x0froutes_received\x10\x04\x12\x18\n\x14route_withdraws_sent\x10\x05\x12\x1c\n\x18route_withdraws_received\x10\x06\x12\x10\n\x0cupdates_sent\x10\x07\x12\x14\n\x10updates_received\x10\x08\x12\x0e\n\nopens_sent\x10\t\x12\x12\n\x0eopens_received\x10\n\x12\x13\n\x0fkeepalives_sent\x10\x0b\x12\x17\n\x13keepalives_received\x10\x0c\x12\x16\n\x12notifications_sent\x10\r\x12\x1a\n\x16notifications_received\x10\x0e\"\xf2\x06\n\x0b\x42gpv4Metric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12>\n\rsession_state\x18\x02 \x01(\x0e\x32\".otg.Bgpv4Metric.SessionState.EnumH\x01\x88\x01\x01\x12\x1f\n\x12session_flap_count\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x1e\n\x11routes_advertised\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12\x1c\n\x0froutes_received\x18\x05 \x01(\x05H\x04\x88\x01\x01\x12!\n\x14route_withdraws_sent\x18\x06 \x01(\x05H\x05\x88\x01\x01\x12%\n\x18route_withdraws_received\x18\x07 \x01(\x05H\x06\x88\x01\x01\x12\x19\n\x0cupdates_sent\x18\x08 \x01(\x05H\x07\x88\x01\x01\x12\x1d\n\x10updates_received\x18\t \x01(\x05H\x08\x88\x01\x01\x12\x17\n\nopens_sent\x18\n \x01(\x05H\t\x88\x01\x01\x12\x1b\n\x0eopens_received\x18\x0b \x01(\x05H\n\x88\x01\x01\x12\x1c\n\x0fkeepalives_sent\x18\x0c \x01(\x05H\x0b\x88\x01\x01\x12 \n\x13keepalives_received\x18\r \x01(\x05H\x0c\x88\x01\x01\x12\x1f\n\x12notifications_sent\x18\x0e \x01(\x05H\r\x88\x01\x01\x12#\n\x16notifications_received\x18\x0f \x01(\x05H\x0e\x88\x01\x01\x1a\x39\n\x0cSessionState\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x07\n\x05_nameB\x10\n\x0e_session_stateB\x15\n\x13_session_flap_countB\x14\n\x12_routes_advertisedB\x12\n\x10_routes_receivedB\x17\n\x15_route_withdraws_sentB\x1b\n\x19_route_withdraws_receivedB\x0f\n\r_updates_sentB\x13\n\x11_updates_receivedB\r\n\x0b_opens_sentB\x11\n\x0f_opens_receivedB\x12\n\x10_keepalives_sentB\x16\n\x14_keepalives_receivedB\x15\n\x13_notifications_sentB\x19\n\x17_notifications_received\"\xd1\x03\n\x13\x42gpv6MetricsRequest\x12\x12\n\npeer_names\x18\x01 \x03(\t\x12?\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32).otg.Bgpv6MetricsRequest.ColumnNames.Enum\x1a\xe4\x02\n\x0b\x43olumnNames\"\xd4\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rsession_state\x10\x01\x12\x16\n\x12session_flap_count\x10\x02\x12\x15\n\x11routes_advertised\x10\x03\x12\x13\n\x0froutes_received\x10\x04\x12\x18\n\x14route_withdraws_sent\x10\x05\x12\x1c\n\x18route_withdraws_received\x10\x06\x12\x10\n\x0cupdates_sent\x10\x07\x12\x14\n\x10updates_received\x10\x08\x12\x0e\n\nopens_sent\x10\t\x12\x12\n\x0eopens_received\x10\n\x12\x13\n\x0fkeepalives_sent\x10\x0b\x12\x17\n\x13keepalives_received\x10\x0c\x12\x16\n\x12notifications_sent\x10\r\x12\x1a\n\x16notifications_received\x10\x0e\"\xf2\x06\n\x0b\x42gpv6Metric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12>\n\rsession_state\x18\x02 \x01(\x0e\x32\".otg.Bgpv6Metric.SessionState.EnumH\x01\x88\x01\x01\x12\x1f\n\x12session_flap_count\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x1e\n\x11routes_advertised\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12\x1c\n\x0froutes_received\x18\x05 \x01(\x05H\x04\x88\x01\x01\x12!\n\x14route_withdraws_sent\x18\x06 \x01(\x05H\x05\x88\x01\x01\x12%\n\x18route_withdraws_received\x18\x07 \x01(\x05H\x06\x88\x01\x01\x12\x19\n\x0cupdates_sent\x18\x08 \x01(\x05H\x07\x88\x01\x01\x12\x1d\n\x10updates_received\x18\t \x01(\x05H\x08\x88\x01\x01\x12\x17\n\nopens_sent\x18\n \x01(\x05H\t\x88\x01\x01\x12\x1b\n\x0eopens_received\x18\x0b \x01(\x05H\n\x88\x01\x01\x12\x1c\n\x0fkeepalives_sent\x18\x0c \x01(\x05H\x0b\x88\x01\x01\x12 \n\x13keepalives_received\x18\r \x01(\x05H\x0c\x88\x01\x01\x12\x1f\n\x12notifications_sent\x18\x0e \x01(\x05H\r\x88\x01\x01\x12#\n\x16notifications_received\x18\x0f \x01(\x05H\x0e\x88\x01\x01\x1a\x39\n\x0cSessionState\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x07\n\x05_nameB\x10\n\x0e_session_stateB\x15\n\x13_session_flap_countB\x14\n\x12_routes_advertisedB\x12\n\x10_routes_receivedB\x17\n\x15_route_withdraws_sentB\x1b\n\x19_route_withdraws_receivedB\x0f\n\r_updates_sentB\x13\n\x11_updates_receivedB\r\n\x0b_opens_sentB\x11\n\x0f_opens_receivedB\x12\n\x10_keepalives_sentB\x16\n\x14_keepalives_receivedB\x15\n\x13_notifications_sentB\x19\n\x17_notifications_received\"\x92\x06\n\x12IsisMetricsRequest\x12\x14\n\x0crouter_names\x18\x01 \x03(\t\x12>\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32(.otg.IsisMetricsRequest.ColumnNames.Enum\x1a\xa5\x05\n\x0b\x43olumnNames\"\x95\x05\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x12\n\x0el1_sessions_up\x10\x01\x12\x13\n\x0fl1_session_flap\x10\x02\x12\x14\n\x10l1_database_size\x10\x03\x12\x1c\n\x18l1_broadcast_hellos_sent\x10\x04\x12 \n\x1cl1_broadcast_hellos_received\x10\x05\x12!\n\x1dl1_point_to_point_hellos_sent\x10\x06\x12%\n!l1_point_to_point_hellos_received\x10\x07\x12\x10\n\x0cl1_psnp_sent\x10\x08\x12\x14\n\x10l1_psnp_received\x10\t\x12\x10\n\x0cl1_csnp_sent\x10\n\x12\x14\n\x10l1_csnp_received\x10\x0b\x12\x0f\n\x0bl1_lsp_sent\x10\x0c\x12\x13\n\x0fl1_lsp_received\x10\r\x12\x12\n\x0el2_sessions_up\x10\x0e\x12\x13\n\x0fl2_session_flap\x10\x0f\x12\x14\n\x10l2_database_size\x10\x10\x12\x1c\n\x18l2_broadcast_hellos_sent\x10\x11\x12 \n\x1cl2_broadcast_hellos_received\x10\x12\x12!\n\x1dl2_point_to_point_hellos_sent\x10\x13\x12%\n!l2_point_to_point_hellos_received\x10\x14\x12\x10\n\x0cl2_psnp_sent\x10\x15\x12\x14\n\x10l2_psnp_received\x10\x16\x12\x10\n\x0cl2_csnp_sent\x10\x17\x12\x14\n\x10l2_csnp_received\x10\x18\x12\x0f\n\x0bl2_lsp_sent\x10\x19\x12\x13\n\x0fl2_lsp_received\x10\x1a\"\xf4\x0b\n\nIsisMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1b\n\x0el1_sessions_up\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x1c\n\x0fl1_session_flap\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12%\n\x18l1_broadcast_hellos_sent\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12)\n\x1cl1_broadcast_hellos_received\x18\x05 \x01(\x05H\x04\x88\x01\x01\x12*\n\x1dl1_point_to_point_hellos_sent\x18\x06 \x01(\x05H\x05\x88\x01\x01\x12.\n!l1_point_to_point_hellos_received\x18\x07 \x01(\x05H\x06\x88\x01\x01\x12\x1d\n\x10l1_database_size\x18\x08 \x01(\x05H\x07\x88\x01\x01\x12\x19\n\x0cl1_psnp_sent\x18\t \x01(\x05H\x08\x88\x01\x01\x12\x1d\n\x10l1_psnp_received\x18\n \x01(\x05H\t\x88\x01\x01\x12\x19\n\x0cl1_csnp_sent\x18\x0b \x01(\x05H\n\x88\x01\x01\x12\x1d\n\x10l1_csnp_received\x18\x0c \x01(\x05H\x0b\x88\x01\x01\x12\x18\n\x0bl1_lsp_sent\x18\r \x01(\x05H\x0c\x88\x01\x01\x12\x1c\n\x0fl1_lsp_received\x18\x0e \x01(\x05H\r\x88\x01\x01\x12\x1b\n\x0el2_sessions_up\x18\x0f \x01(\x05H\x0e\x88\x01\x01\x12\x1c\n\x0fl2_session_flap\x18\x10 \x01(\x05H\x0f\x88\x01\x01\x12%\n\x18l2_broadcast_hellos_sent\x18\x11 \x01(\x05H\x10\x88\x01\x01\x12)\n\x1cl2_broadcast_hellos_received\x18\x12 \x01(\x05H\x11\x88\x01\x01\x12*\n\x1dl2_point_to_point_hellos_sent\x18\x13 \x01(\x05H\x12\x88\x01\x01\x12.\n!l2_point_to_point_hellos_received\x18\x14 \x01(\x05H\x13\x88\x01\x01\x12\x1d\n\x10l2_database_size\x18\x15 \x01(\x05H\x14\x88\x01\x01\x12\x19\n\x0cl2_psnp_sent\x18\x16 \x01(\x05H\x15\x88\x01\x01\x12\x1d\n\x10l2_psnp_received\x18\x17 \x01(\x05H\x16\x88\x01\x01\x12\x19\n\x0cl2_csnp_sent\x18\x18 \x01(\x05H\x17\x88\x01\x01\x12\x1d\n\x10l2_csnp_received\x18\x19 \x01(\x05H\x18\x88\x01\x01\x12\x18\n\x0bl2_lsp_sent\x18\x1a \x01(\x05H\x19\x88\x01\x01\x12\x1c\n\x0fl2_lsp_received\x18\x1b \x01(\x05H\x1a\x88\x01\x01\x42\x07\n\x05_nameB\x11\n\x0f_l1_sessions_upB\x12\n\x10_l1_session_flapB\x1b\n\x19_l1_broadcast_hellos_sentB\x1f\n\x1d_l1_broadcast_hellos_receivedB \n\x1e_l1_point_to_point_hellos_sentB$\n\"_l1_point_to_point_hellos_receivedB\x13\n\x11_l1_database_sizeB\x0f\n\r_l1_psnp_sentB\x13\n\x11_l1_psnp_receivedB\x0f\n\r_l1_csnp_sentB\x13\n\x11_l1_csnp_receivedB\x0e\n\x0c_l1_lsp_sentB\x12\n\x10_l1_lsp_receivedB\x11\n\x0f_l2_sessions_upB\x12\n\x10_l2_session_flapB\x1b\n\x19_l2_broadcast_hellos_sentB\x1f\n\x1d_l2_broadcast_hellos_receivedB \n\x1e_l2_point_to_point_hellos_sentB$\n\"_l2_point_to_point_hellos_receivedB\x13\n\x11_l2_database_sizeB\x0f\n\r_l2_psnp_sentB\x13\n\x11_l2_psnp_receivedB\x0f\n\r_l2_csnp_sentB\x13\n\x11_l2_csnp_receivedB\x0e\n\x0c_l2_lsp_sentB\x12\n\x10_l2_lsp_received\"\xb8\x02\n\rStatesRequest\x12\x33\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1e.otg.StatesRequest.Choice.EnumH\x00\x88\x01\x01\x12:\n\x0eipv4_neighbors\x18\x02 \x01(\x0b\x32\x1d.otg.Neighborsv4StatesRequestH\x01\x88\x01\x01\x12:\n\x0eipv6_neighbors\x18\x03 \x01(\x0b\x32\x1d.otg.Neighborsv6StatesRequestH\x02\x88\x01\x01\x1aI\n\x06\x43hoice\"?\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x12\n\x0eipv4_neighbors\x10\x01\x12\x12\n\x0eipv6_neighbors\x10\x02\x42\t\n\x07_choiceB\x11\n\x0f_ipv4_neighborsB\x11\n\x0f_ipv6_neighbors\"\xfa\x01\n\x0eStatesResponse\x12\x34\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1f.otg.StatesResponse.Choice.EnumH\x00\x88\x01\x01\x12-\n\x0eipv4_neighbors\x18\x02 \x03(\x0b\x32\x15.otg.Neighborsv4State\x12-\n\x0eipv6_neighbors\x18\x03 \x03(\x0b\x32\x15.otg.Neighborsv6State\x1aI\n\x06\x43hoice\"?\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x12\n\x0eipv4_neighbors\x10\x01\x12\x12\n\x0eipv6_neighbors\x10\x02\x42\t\n\x07_choice\"2\n\x18Neighborsv4StatesRequest\x12\x16\n\x0e\x65thernet_names\x18\x01 \x03(\t\"w\n\x10Neighborsv4State\x12\x15\n\rethernet_name\x18\x01 \x01(\t\x12\x14\n\x0cipv4_address\x18\x02 \x01(\t\x12\x1f\n\x12link_layer_address\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x15\n\x13_link_layer_address\"2\n\x18Neighborsv6StatesRequest\x12\x16\n\x0e\x65thernet_names\x18\x01 \x03(\t\"w\n\x10Neighborsv6State\x12\x15\n\rethernet_name\x18\x01 \x01(\t\x12\x14\n\x0cipv6_address\x18\x02 \x01(\t\x12\x1f\n\x12link_layer_address\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x15\n\x13_link_layer_address\"#\n\x0e\x43\x61ptureRequest\x12\x11\n\tport_name\x18\x01 \x01(\t\"w\n\x1dPatternFlowEthernetDstCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa7\x03\n\x16PatternFlowEthernetDst\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowEthernetDst.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowEthernetDstCounterH\x03\x88\x01\x01\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowEthernetDstCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"w\n\x1dPatternFlowEthernetSrcCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa7\x03\n\x16PatternFlowEthernetSrc\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowEthernetSrc.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowEthernetSrcCounterH\x03\x88\x01\x01\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowEthernetSrcCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"}\n#PatternFlowEthernetEtherTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xbd\x04\n\x1cPatternFlowEthernetEtherType\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowEthernetEtherType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12>\n\x04\x61uto\x18\x04 \x01(\x0e\x32+.otg.PatternFlowEthernetEtherType.Auto.EnumH\x02\x88\x01\x01\x12\x19\n\x0cmetric_group\x18\x05 \x01(\tH\x03\x88\x01\x01\x12@\n\tincrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowEthernetEtherTypeCounterH\x04\x88\x01\x01\x12@\n\tdecrement\x18\x07 \x01(\x0b\x32(.otg.PatternFlowEthernetEtherTypeCounterH\x05\x88\x01\x01\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\x08\n\x04\x61uto\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x1a)\n\x04\x41uto\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_autoB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"|\n\"PatternFlowEthernetPfcQueueCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xbb\x03\n\x1bPatternFlowEthernetPfcQueue\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowEthernetPfcQueue.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12?\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowEthernetPfcQueueCounterH\x03\x88\x01\x01\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowEthernetPfcQueueCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"x\n\x1ePatternFlowVlanPriorityCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xab\x03\n\x17PatternFlowVlanPriority\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowVlanPriority.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12;\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowVlanPriorityCounterH\x03\x88\x01\x01\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowVlanPriorityCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"s\n\x19PatternFlowVlanCfiCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x97\x03\n\x12PatternFlowVlanCfi\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.PatternFlowVlanCfi.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32\x1e.otg.PatternFlowVlanCfiCounterH\x03\x88\x01\x01\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32\x1e.otg.PatternFlowVlanCfiCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"r\n\x18PatternFlowVlanIdCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x93\x03\n\x11PatternFlowVlanId\x12\x37\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\".otg.PatternFlowVlanId.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x35\n\tincrement\x18\x05 \x01(\x0b\x32\x1d.otg.PatternFlowVlanIdCounterH\x03\x88\x01\x01\x12\x35\n\tdecrement\x18\x06 \x01(\x0b\x32\x1d.otg.PatternFlowVlanIdCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"t\n\x1aPatternFlowVlanTpidCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x9b\x03\n\x13PatternFlowVlanTpid\x12\x39\n\x06\x63hoice\x18\x01 \x01(\x0e\x32$.otg.PatternFlowVlanTpid.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x37\n\tincrement\x18\x05 \x01(\x0b\x32\x1f.otg.PatternFlowVlanTpidCounterH\x03\x88\x01\x01\x12\x37\n\tdecrement\x18\x06 \x01(\x0b\x32\x1f.otg.PatternFlowVlanTpidCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"v\n\x1cPatternFlowVxlanFlagsCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa3\x03\n\x15PatternFlowVxlanFlags\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowVxlanFlags.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowVxlanFlagsCounterH\x03\x88\x01\x01\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowVxlanFlagsCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"z\n PatternFlowVxlanReserved0Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xb3\x03\n\x19PatternFlowVxlanReserved0\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowVxlanReserved0.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12=\n\tincrement\x18\x05 \x01(\x0b\x32%.otg.PatternFlowVxlanReserved0CounterH\x03\x88\x01\x01\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowVxlanReserved0CounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"t\n\x1aPatternFlowVxlanVniCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x9b\x03\n\x13PatternFlowVxlanVni\x12\x39\n\x06\x63hoice\x18\x01 \x01(\x0e\x32$.otg.PatternFlowVxlanVni.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x37\n\tincrement\x18\x05 \x01(\x0b\x32\x1f.otg.PatternFlowVxlanVniCounterH\x03\x88\x01\x01\x12\x37\n\tdecrement\x18\x06 \x01(\x0b\x32\x1f.otg.PatternFlowVxlanVniCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"z\n PatternFlowVxlanReserved1Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xb3\x03\n\x19PatternFlowVxlanReserved1\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowVxlanReserved1.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12=\n\tincrement\x18\x05 \x01(\x0b\x32%.otg.PatternFlowVxlanReserved1CounterH\x03\x88\x01\x01\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowVxlanReserved1CounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"w\n\x1dPatternFlowIpv4VersionCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa7\x03\n\x16PatternFlowIpv4Version\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowIpv4Version.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowIpv4VersionCounterH\x03\x88\x01\x01\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowIpv4VersionCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"|\n\"PatternFlowIpv4HeaderLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xb8\x04\n\x1bPatternFlowIpv4HeaderLength\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowIpv4HeaderLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12=\n\x04\x61uto\x18\x04 \x01(\x0e\x32*.otg.PatternFlowIpv4HeaderLength.Auto.EnumH\x02\x88\x01\x01\x12\x19\n\x0cmetric_group\x18\x05 \x01(\tH\x03\x88\x01\x01\x12?\n\tincrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowIpv4HeaderLengthCounterH\x04\x88\x01\x01\x12?\n\tdecrement\x18\x07 \x01(\x0b\x32\'.otg.PatternFlowIpv4HeaderLengthCounterH\x05\x88\x01\x01\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\x08\n\x04\x61uto\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x1a)\n\x04\x41uto\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_autoB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"{\n!PatternFlowIpv4TotalLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xb3\x04\n\x1aPatternFlowIpv4TotalLength\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.PatternFlowIpv4TotalLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12<\n\x04\x61uto\x18\x04 \x01(\x0e\x32).otg.PatternFlowIpv4TotalLength.Auto.EnumH\x02\x88\x01\x01\x12\x19\n\x0cmetric_group\x18\x05 \x01(\tH\x03\x88\x01\x01\x12>\n\tincrement\x18\x06 \x01(\x0b\x32&.otg.PatternFlowIpv4TotalLengthCounterH\x04\x88\x01\x01\x12>\n\tdecrement\x18\x07 \x01(\x0b\x32&.otg.PatternFlowIpv4TotalLengthCounterH\x05\x88\x01\x01\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\x08\n\x04\x61uto\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x1a)\n\x04\x41uto\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_autoB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"~\n$PatternFlowIpv4IdentificationCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc3\x03\n\x1dPatternFlowIpv4Identification\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIpv4Identification.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x41\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowIpv4IdentificationCounterH\x03\x88\x01\x01\x12\x41\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowIpv4IdentificationCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"x\n\x1ePatternFlowIpv4ReservedCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xab\x03\n\x17PatternFlowIpv4Reserved\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowIpv4Reserved.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12;\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowIpv4ReservedCounterH\x03\x88\x01\x01\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowIpv4ReservedCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"|\n\"PatternFlowIpv4DontFragmentCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xbb\x03\n\x1bPatternFlowIpv4DontFragment\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowIpv4DontFragment.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12?\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowIpv4DontFragmentCounterH\x03\x88\x01\x01\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowIpv4DontFragmentCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"}\n#PatternFlowIpv4MoreFragmentsCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xbf\x03\n\x1cPatternFlowIpv4MoreFragments\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowIpv4MoreFragments.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12@\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowIpv4MoreFragmentsCounterH\x03\x88\x01\x01\x12@\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowIpv4MoreFragmentsCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"~\n$PatternFlowIpv4FragmentOffsetCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc3\x03\n\x1dPatternFlowIpv4FragmentOffset\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIpv4FragmentOffset.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x41\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowIpv4FragmentOffsetCounterH\x03\x88\x01\x01\x12\x41\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowIpv4FragmentOffsetCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"z\n PatternFlowIpv4TimeToLiveCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xb3\x03\n\x19PatternFlowIpv4TimeToLive\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowIpv4TimeToLive.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12=\n\tincrement\x18\x05 \x01(\x0b\x32%.otg.PatternFlowIpv4TimeToLiveCounterH\x03\x88\x01\x01\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowIpv4TimeToLiveCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"x\n\x1ePatternFlowIpv4ProtocolCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa4\x04\n\x17PatternFlowIpv4Protocol\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowIpv4Protocol.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x39\n\x04\x61uto\x18\x04 \x01(\x0e\x32&.otg.PatternFlowIpv4Protocol.Auto.EnumH\x02\x88\x01\x01\x12\x19\n\x0cmetric_group\x18\x05 \x01(\tH\x03\x88\x01\x01\x12;\n\tincrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowIpv4ProtocolCounterH\x04\x88\x01\x01\x12;\n\tdecrement\x18\x07 \x01(\x0b\x32#.otg.PatternFlowIpv4ProtocolCounterH\x05\x88\x01\x01\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\x08\n\x04\x61uto\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x1a)\n\x04\x41uto\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_autoB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\xdf\x02\n\x1dPatternFlowIpv4HeaderChecksum\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIpv4HeaderChecksum.Choice.EnumH\x00\x88\x01\x01\x12I\n\tgenerated\x18\x02 \x01(\x0e\x32\x31.otg.PatternFlowIpv4HeaderChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\x05H\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"s\n\x19PatternFlowIpv4SrcCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x97\x03\n\x12PatternFlowIpv4Src\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.PatternFlowIpv4Src.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32\x1e.otg.PatternFlowIpv4SrcCounterH\x03\x88\x01\x01\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32\x1e.otg.PatternFlowIpv4SrcCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"s\n\x19PatternFlowIpv4DstCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x97\x03\n\x12PatternFlowIpv4Dst\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.PatternFlowIpv4Dst.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32\x1e.otg.PatternFlowIpv4DstCounterH\x03\x88\x01\x01\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32\x1e.otg.PatternFlowIpv4DstCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"{\n!PatternFlowIpv4PriorityRawCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xb7\x03\n\x1aPatternFlowIpv4PriorityRaw\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.PatternFlowIpv4PriorityRaw.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12>\n\tincrement\x18\x05 \x01(\x0b\x32&.otg.PatternFlowIpv4PriorityRawCounterH\x03\x88\x01\x01\x12>\n\tdecrement\x18\x06 \x01(\x0b\x32&.otg.PatternFlowIpv4PriorityRawCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"w\n\x1dPatternFlowIpv4DscpPhbCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa7\x03\n\x16PatternFlowIpv4DscpPhb\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowIpv4DscpPhb.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowIpv4DscpPhbCounterH\x03\x88\x01\x01\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowIpv4DscpPhbCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"w\n\x1dPatternFlowIpv4DscpEcnCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa7\x03\n\x16PatternFlowIpv4DscpEcn\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowIpv4DscpEcn.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowIpv4DscpEcnCounterH\x03\x88\x01\x01\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowIpv4DscpEcnCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"}\n#PatternFlowIpv4TosPrecedenceCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xbf\x03\n\x1cPatternFlowIpv4TosPrecedence\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowIpv4TosPrecedence.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12@\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowIpv4TosPrecedenceCounterH\x03\x88\x01\x01\x12@\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowIpv4TosPrecedenceCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"x\n\x1ePatternFlowIpv4TosDelayCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xab\x03\n\x17PatternFlowIpv4TosDelay\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowIpv4TosDelay.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12;\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowIpv4TosDelayCounterH\x03\x88\x01\x01\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowIpv4TosDelayCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"}\n#PatternFlowIpv4TosThroughputCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xbf\x03\n\x1cPatternFlowIpv4TosThroughput\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowIpv4TosThroughput.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12@\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowIpv4TosThroughputCounterH\x03\x88\x01\x01\x12@\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowIpv4TosThroughputCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"~\n$PatternFlowIpv4TosReliabilityCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc3\x03\n\x1dPatternFlowIpv4TosReliability\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIpv4TosReliability.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x41\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowIpv4TosReliabilityCounterH\x03\x88\x01\x01\x12\x41\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowIpv4TosReliabilityCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"{\n!PatternFlowIpv4TosMonetaryCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xb7\x03\n\x1aPatternFlowIpv4TosMonetary\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.PatternFlowIpv4TosMonetary.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12>\n\tincrement\x18\x05 \x01(\x0b\x32&.otg.PatternFlowIpv4TosMonetaryCounterH\x03\x88\x01\x01\x12>\n\tdecrement\x18\x06 \x01(\x0b\x32&.otg.PatternFlowIpv4TosMonetaryCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"y\n\x1fPatternFlowIpv4TosUnusedCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xaf\x03\n\x18PatternFlowIpv4TosUnused\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.PatternFlowIpv4TosUnused.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12<\n\tincrement\x18\x05 \x01(\x0b\x32$.otg.PatternFlowIpv4TosUnusedCounterH\x03\x88\x01\x01\x12<\n\tdecrement\x18\x06 \x01(\x0b\x32$.otg.PatternFlowIpv4TosUnusedCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"w\n\x1dPatternFlowIpv6VersionCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa7\x03\n\x16PatternFlowIpv6Version\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowIpv6Version.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowIpv6VersionCounterH\x03\x88\x01\x01\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowIpv6VersionCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"|\n\"PatternFlowIpv6TrafficClassCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xbb\x03\n\x1bPatternFlowIpv6TrafficClass\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowIpv6TrafficClass.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12?\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowIpv6TrafficClassCounterH\x03\x88\x01\x01\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowIpv6TrafficClassCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"y\n\x1fPatternFlowIpv6FlowLabelCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xaf\x03\n\x18PatternFlowIpv6FlowLabel\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.PatternFlowIpv6FlowLabel.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12<\n\tincrement\x18\x05 \x01(\x0b\x32$.otg.PatternFlowIpv6FlowLabelCounterH\x03\x88\x01\x01\x12<\n\tdecrement\x18\x06 \x01(\x0b\x32$.otg.PatternFlowIpv6FlowLabelCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"}\n#PatternFlowIpv6PayloadLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xbd\x04\n\x1cPatternFlowIpv6PayloadLength\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowIpv6PayloadLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12>\n\x04\x61uto\x18\x04 \x01(\x0e\x32+.otg.PatternFlowIpv6PayloadLength.Auto.EnumH\x02\x88\x01\x01\x12\x19\n\x0cmetric_group\x18\x05 \x01(\tH\x03\x88\x01\x01\x12@\n\tincrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowIpv6PayloadLengthCounterH\x04\x88\x01\x01\x12@\n\tdecrement\x18\x07 \x01(\x0b\x32(.otg.PatternFlowIpv6PayloadLengthCounterH\x05\x88\x01\x01\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\x08\n\x04\x61uto\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x1a)\n\x04\x41uto\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_autoB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"z\n PatternFlowIpv6NextHeaderCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xb3\x03\n\x19PatternFlowIpv6NextHeader\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowIpv6NextHeader.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12=\n\tincrement\x18\x05 \x01(\x0b\x32%.otg.PatternFlowIpv6NextHeaderCounterH\x03\x88\x01\x01\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowIpv6NextHeaderCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"x\n\x1ePatternFlowIpv6HopLimitCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xab\x03\n\x17PatternFlowIpv6HopLimit\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowIpv6HopLimit.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12;\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowIpv6HopLimitCounterH\x03\x88\x01\x01\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowIpv6HopLimitCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"s\n\x19PatternFlowIpv6SrcCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x97\x03\n\x12PatternFlowIpv6Src\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.PatternFlowIpv6Src.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32\x1e.otg.PatternFlowIpv6SrcCounterH\x03\x88\x01\x01\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32\x1e.otg.PatternFlowIpv6SrcCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"s\n\x19PatternFlowIpv6DstCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x97\x03\n\x12PatternFlowIpv6Dst\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.PatternFlowIpv6Dst.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32\x1e.otg.PatternFlowIpv6DstCounterH\x03\x88\x01\x01\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32\x1e.otg.PatternFlowIpv6DstCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"w\n\x1dPatternFlowPfcPauseDstCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa7\x03\n\x16PatternFlowPfcPauseDst\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowPfcPauseDst.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowPfcPauseDstCounterH\x03\x88\x01\x01\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowPfcPauseDstCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"w\n\x1dPatternFlowPfcPauseSrcCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa7\x03\n\x16PatternFlowPfcPauseSrc\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowPfcPauseSrc.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowPfcPauseSrcCounterH\x03\x88\x01\x01\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowPfcPauseSrcCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"}\n#PatternFlowPfcPauseEtherTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xbf\x03\n\x1cPatternFlowPfcPauseEtherType\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowPfcPauseEtherType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12@\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowPfcPauseEtherTypeCounterH\x03\x88\x01\x01\x12@\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowPfcPauseEtherTypeCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x81\x01\n\'PatternFlowPfcPauseControlOpCodeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xcf\x03\n PatternFlowPfcPauseControlOpCode\x12\x46\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x31.otg.PatternFlowPfcPauseControlOpCode.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x44\n\tincrement\x18\x05 \x01(\x0b\x32,.otg.PatternFlowPfcPauseControlOpCodeCounterH\x03\x88\x01\x01\x12\x44\n\tdecrement\x18\x06 \x01(\x0b\x32,.otg.PatternFlowPfcPauseControlOpCodeCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x85\x01\n+PatternFlowPfcPauseClassEnableVectorCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xdf\x03\n$PatternFlowPfcPauseClassEnableVector\x12J\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x35.otg.PatternFlowPfcPauseClassEnableVector.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12H\n\tincrement\x18\x05 \x01(\x0b\x32\x30.otg.PatternFlowPfcPauseClassEnableVectorCounterH\x03\x88\x01\x01\x12H\n\tdecrement\x18\x06 \x01(\x0b\x32\x30.otg.PatternFlowPfcPauseClassEnableVectorCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x7f\n%PatternFlowPfcPausePauseClass0Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc7\x03\n\x1ePatternFlowPfcPausePauseClass0\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass0.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x42\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass0CounterH\x03\x88\x01\x01\x12\x42\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass0CounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x7f\n%PatternFlowPfcPausePauseClass1Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc7\x03\n\x1ePatternFlowPfcPausePauseClass1\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass1.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x42\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass1CounterH\x03\x88\x01\x01\x12\x42\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass1CounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x7f\n%PatternFlowPfcPausePauseClass2Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc7\x03\n\x1ePatternFlowPfcPausePauseClass2\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass2.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x42\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass2CounterH\x03\x88\x01\x01\x12\x42\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass2CounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x7f\n%PatternFlowPfcPausePauseClass3Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc7\x03\n\x1ePatternFlowPfcPausePauseClass3\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass3.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x42\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass3CounterH\x03\x88\x01\x01\x12\x42\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass3CounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x7f\n%PatternFlowPfcPausePauseClass4Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc7\x03\n\x1ePatternFlowPfcPausePauseClass4\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass4.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x42\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass4CounterH\x03\x88\x01\x01\x12\x42\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass4CounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x7f\n%PatternFlowPfcPausePauseClass5Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc7\x03\n\x1ePatternFlowPfcPausePauseClass5\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass5.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x42\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass5CounterH\x03\x88\x01\x01\x12\x42\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass5CounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x7f\n%PatternFlowPfcPausePauseClass6Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc7\x03\n\x1ePatternFlowPfcPausePauseClass6\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass6.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x42\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass6CounterH\x03\x88\x01\x01\x12\x42\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass6CounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x7f\n%PatternFlowPfcPausePauseClass7Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc7\x03\n\x1ePatternFlowPfcPausePauseClass7\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass7.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x42\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass7CounterH\x03\x88\x01\x01\x12\x42\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass7CounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"|\n\"PatternFlowEthernetPauseDstCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xbb\x03\n\x1bPatternFlowEthernetPauseDst\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowEthernetPauseDst.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12?\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowEthernetPauseDstCounterH\x03\x88\x01\x01\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowEthernetPauseDstCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"|\n\"PatternFlowEthernetPauseSrcCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xbb\x03\n\x1bPatternFlowEthernetPauseSrc\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowEthernetPauseSrc.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12?\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowEthernetPauseSrcCounterH\x03\x88\x01\x01\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowEthernetPauseSrcCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x82\x01\n(PatternFlowEthernetPauseEtherTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xd3\x03\n!PatternFlowEthernetPauseEtherType\x12G\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x32.otg.PatternFlowEthernetPauseEtherType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x45\n\tincrement\x18\x05 \x01(\x0b\x32-.otg.PatternFlowEthernetPauseEtherTypeCounterH\x03\x88\x01\x01\x12\x45\n\tdecrement\x18\x06 \x01(\x0b\x32-.otg.PatternFlowEthernetPauseEtherTypeCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x86\x01\n,PatternFlowEthernetPauseControlOpCodeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xe3\x03\n%PatternFlowEthernetPauseControlOpCode\x12K\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x36.otg.PatternFlowEthernetPauseControlOpCode.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12I\n\tincrement\x18\x05 \x01(\x0b\x32\x31.otg.PatternFlowEthernetPauseControlOpCodeCounterH\x03\x88\x01\x01\x12I\n\tdecrement\x18\x06 \x01(\x0b\x32\x31.otg.PatternFlowEthernetPauseControlOpCodeCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"}\n#PatternFlowEthernetPauseTimeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xbf\x03\n\x1cPatternFlowEthernetPauseTime\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowEthernetPauseTime.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12@\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowEthernetPauseTimeCounterH\x03\x88\x01\x01\x12@\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowEthernetPauseTimeCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"v\n\x1cPatternFlowTcpSrcPortCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa3\x03\n\x15PatternFlowTcpSrcPort\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowTcpSrcPort.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowTcpSrcPortCounterH\x03\x88\x01\x01\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowTcpSrcPortCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"v\n\x1cPatternFlowTcpDstPortCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa3\x03\n\x15PatternFlowTcpDstPort\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowTcpDstPort.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowTcpDstPortCounterH\x03\x88\x01\x01\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowTcpDstPortCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowTcpSeqNumCounter\x12\x12\n\x05start\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x9f\x03\n\x14PatternFlowTcpSeqNum\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpSeqNum.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x03\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpSeqNumCounterH\x03\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpSeqNumCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowTcpAckNumCounter\x12\x12\n\x05start\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x9f\x03\n\x14PatternFlowTcpAckNum\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpAckNum.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x03\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpAckNumCounterH\x03\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpAckNumCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"y\n\x1fPatternFlowTcpDataOffsetCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xaf\x03\n\x18PatternFlowTcpDataOffset\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.PatternFlowTcpDataOffset.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12<\n\tincrement\x18\x05 \x01(\x0b\x32$.otg.PatternFlowTcpDataOffsetCounterH\x03\x88\x01\x01\x12<\n\tdecrement\x18\x06 \x01(\x0b\x32$.otg.PatternFlowTcpDataOffsetCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"t\n\x1aPatternFlowTcpEcnNsCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x9b\x03\n\x13PatternFlowTcpEcnNs\x12\x39\n\x06\x63hoice\x18\x01 \x01(\x0e\x32$.otg.PatternFlowTcpEcnNs.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x37\n\tincrement\x18\x05 \x01(\x0b\x32\x1f.otg.PatternFlowTcpEcnNsCounterH\x03\x88\x01\x01\x12\x37\n\tdecrement\x18\x06 \x01(\x0b\x32\x1f.otg.PatternFlowTcpEcnNsCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowTcpEcnCwrCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x9f\x03\n\x14PatternFlowTcpEcnCwr\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpEcnCwr.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpEcnCwrCounterH\x03\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpEcnCwrCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"v\n\x1cPatternFlowTcpEcnEchoCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa3\x03\n\x15PatternFlowTcpEcnEcho\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowTcpEcnEcho.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowTcpEcnEchoCounterH\x03\x88\x01\x01\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowTcpEcnEchoCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowTcpCtlUrgCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x9f\x03\n\x14PatternFlowTcpCtlUrg\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpCtlUrg.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpCtlUrgCounterH\x03\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpCtlUrgCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowTcpCtlAckCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x9f\x03\n\x14PatternFlowTcpCtlAck\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpCtlAck.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpCtlAckCounterH\x03\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpCtlAckCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowTcpCtlPshCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x9f\x03\n\x14PatternFlowTcpCtlPsh\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpCtlPsh.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpCtlPshCounterH\x03\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpCtlPshCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowTcpCtlRstCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x9f\x03\n\x14PatternFlowTcpCtlRst\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpCtlRst.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpCtlRstCounterH\x03\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpCtlRstCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowTcpCtlSynCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x9f\x03\n\x14PatternFlowTcpCtlSyn\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpCtlSyn.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpCtlSynCounterH\x03\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpCtlSynCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowTcpCtlFinCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x9f\x03\n\x14PatternFlowTcpCtlFin\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpCtlFin.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpCtlFinCounterH\x03\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpCtlFinCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowTcpWindowCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x9f\x03\n\x14PatternFlowTcpWindow\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpWindow.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpWindowCounterH\x03\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpWindowCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"v\n\x1cPatternFlowUdpSrcPortCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa3\x03\n\x15PatternFlowUdpSrcPort\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowUdpSrcPort.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowUdpSrcPortCounterH\x03\x88\x01\x01\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowUdpSrcPortCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"v\n\x1cPatternFlowUdpDstPortCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa3\x03\n\x15PatternFlowUdpDstPort\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowUdpDstPort.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowUdpDstPortCounterH\x03\x88\x01\x01\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowUdpDstPortCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowUdpLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x9f\x03\n\x14PatternFlowUdpLength\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowUdpLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowUdpLengthCounterH\x03\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowUdpLengthCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\xca\x02\n\x16PatternFlowUdpChecksum\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowUdpChecksum.Choice.EnumH\x00\x88\x01\x01\x12\x42\n\tgenerated\x18\x02 \x01(\x0e\x32*.otg.PatternFlowUdpChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\x05H\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"~\n$PatternFlowGreChecksumPresentCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc3\x03\n\x1dPatternFlowGreChecksumPresent\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowGreChecksumPresent.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x41\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowGreChecksumPresentCounterH\x03\x88\x01\x01\x12\x41\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowGreChecksumPresentCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"x\n\x1ePatternFlowGreReserved0Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xab\x03\n\x17PatternFlowGreReserved0\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowGreReserved0.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12;\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowGreReserved0CounterH\x03\x88\x01\x01\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowGreReserved0CounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"v\n\x1cPatternFlowGreVersionCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa3\x03\n\x15PatternFlowGreVersion\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowGreVersion.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowGreVersionCounterH\x03\x88\x01\x01\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowGreVersionCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"w\n\x1dPatternFlowGreProtocolCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa7\x03\n\x16PatternFlowGreProtocol\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowGreProtocol.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowGreProtocolCounterH\x03\x88\x01\x01\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowGreProtocolCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\xca\x02\n\x16PatternFlowGreChecksum\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowGreChecksum.Choice.EnumH\x00\x88\x01\x01\x12\x42\n\tgenerated\x18\x02 \x01(\x0e\x32*.otg.PatternFlowGreChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\x05H\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"x\n\x1ePatternFlowGreReserved1Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xab\x03\n\x17PatternFlowGreReserved1\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowGreReserved1.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12;\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowGreReserved1CounterH\x03\x88\x01\x01\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowGreReserved1CounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"x\n\x1ePatternFlowGtpv1VersionCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xab\x03\n\x17PatternFlowGtpv1Version\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowGtpv1Version.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12;\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowGtpv1VersionCounterH\x03\x88\x01\x01\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowGtpv1VersionCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"}\n#PatternFlowGtpv1ProtocolTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xbf\x03\n\x1cPatternFlowGtpv1ProtocolType\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowGtpv1ProtocolType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12@\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowGtpv1ProtocolTypeCounterH\x03\x88\x01\x01\x12@\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowGtpv1ProtocolTypeCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"y\n\x1fPatternFlowGtpv1ReservedCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xaf\x03\n\x18PatternFlowGtpv1Reserved\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.PatternFlowGtpv1Reserved.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12<\n\tincrement\x18\x05 \x01(\x0b\x32$.otg.PatternFlowGtpv1ReservedCounterH\x03\x88\x01\x01\x12<\n\tdecrement\x18\x06 \x01(\x0b\x32$.otg.PatternFlowGtpv1ReservedCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"v\n\x1cPatternFlowGtpv1EFlagCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa3\x03\n\x15PatternFlowGtpv1EFlag\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowGtpv1EFlag.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowGtpv1EFlagCounterH\x03\x88\x01\x01\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowGtpv1EFlagCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"v\n\x1cPatternFlowGtpv1SFlagCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa3\x03\n\x15PatternFlowGtpv1SFlag\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowGtpv1SFlag.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowGtpv1SFlagCounterH\x03\x88\x01\x01\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowGtpv1SFlagCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"w\n\x1dPatternFlowGtpv1PnFlagCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa7\x03\n\x16PatternFlowGtpv1PnFlag\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowGtpv1PnFlag.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowGtpv1PnFlagCounterH\x03\x88\x01\x01\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowGtpv1PnFlagCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"|\n\"PatternFlowGtpv1MessageTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xbb\x03\n\x1bPatternFlowGtpv1MessageType\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowGtpv1MessageType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12?\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowGtpv1MessageTypeCounterH\x03\x88\x01\x01\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowGtpv1MessageTypeCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"~\n$PatternFlowGtpv1MessageLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc3\x03\n\x1dPatternFlowGtpv1MessageLength\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowGtpv1MessageLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x41\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowGtpv1MessageLengthCounterH\x03\x88\x01\x01\x12\x41\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowGtpv1MessageLengthCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowGtpv1TeidCounter\x12\x12\n\x05start\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x9f\x03\n\x14PatternFlowGtpv1Teid\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowGtpv1Teid.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x03\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowGtpv1TeidCounterH\x03\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowGtpv1TeidCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"~\n$PatternFlowGtpv1SquenceNumberCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc3\x03\n\x1dPatternFlowGtpv1SquenceNumber\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowGtpv1SquenceNumber.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x41\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowGtpv1SquenceNumberCounterH\x03\x88\x01\x01\x12\x41\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowGtpv1SquenceNumberCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"{\n!PatternFlowGtpv1NPduNumberCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xb7\x03\n\x1aPatternFlowGtpv1NPduNumber\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.PatternFlowGtpv1NPduNumber.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12>\n\tincrement\x18\x05 \x01(\x0b\x32&.otg.PatternFlowGtpv1NPduNumberCounterH\x03\x88\x01\x01\x12>\n\tdecrement\x18\x06 \x01(\x0b\x32&.otg.PatternFlowGtpv1NPduNumberCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x88\x01\n.PatternFlowGtpv1NextExtensionHeaderTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xeb\x03\n\'PatternFlowGtpv1NextExtensionHeaderType\x12M\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x38.otg.PatternFlowGtpv1NextExtensionHeaderType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12K\n\tincrement\x18\x05 \x01(\x0b\x32\x33.otg.PatternFlowGtpv1NextExtensionHeaderTypeCounterH\x03\x88\x01\x01\x12K\n\tdecrement\x18\x06 \x01(\x0b\x32\x33.otg.PatternFlowGtpv1NextExtensionHeaderTypeCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x87\x01\n-PatternFlowGtpExtensionExtensionLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xe7\x03\n&PatternFlowGtpExtensionExtensionLength\x12L\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x37.otg.PatternFlowGtpExtensionExtensionLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12J\n\tincrement\x18\x05 \x01(\x0b\x32\x32.otg.PatternFlowGtpExtensionExtensionLengthCounterH\x03\x88\x01\x01\x12J\n\tdecrement\x18\x06 \x01(\x0b\x32\x32.otg.PatternFlowGtpExtensionExtensionLengthCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x80\x01\n&PatternFlowGtpExtensionContentsCounter\x12\x12\n\x05start\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xcb\x03\n\x1fPatternFlowGtpExtensionContents\x12\x45\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x30.otg.PatternFlowGtpExtensionContents.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x03\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x43\n\tincrement\x18\x05 \x01(\x0b\x32+.otg.PatternFlowGtpExtensionContentsCounterH\x03\x88\x01\x01\x12\x43\n\tdecrement\x18\x06 \x01(\x0b\x32+.otg.PatternFlowGtpExtensionContentsCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x8b\x01\n1PatternFlowGtpExtensionNextExtensionHeaderCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xf7\x03\n*PatternFlowGtpExtensionNextExtensionHeader\x12P\n\x06\x63hoice\x18\x01 \x01(\x0e\x32;.otg.PatternFlowGtpExtensionNextExtensionHeader.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12N\n\tincrement\x18\x05 \x01(\x0b\x32\x36.otg.PatternFlowGtpExtensionNextExtensionHeaderCounterH\x03\x88\x01\x01\x12N\n\tdecrement\x18\x06 \x01(\x0b\x32\x36.otg.PatternFlowGtpExtensionNextExtensionHeaderCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"x\n\x1ePatternFlowGtpv2VersionCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xab\x03\n\x17PatternFlowGtpv2Version\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowGtpv2Version.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12;\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowGtpv2VersionCounterH\x03\x88\x01\x01\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowGtpv2VersionCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x81\x01\n\'PatternFlowGtpv2PiggybackingFlagCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xcf\x03\n PatternFlowGtpv2PiggybackingFlag\x12\x46\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x31.otg.PatternFlowGtpv2PiggybackingFlag.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x44\n\tincrement\x18\x05 \x01(\x0b\x32,.otg.PatternFlowGtpv2PiggybackingFlagCounterH\x03\x88\x01\x01\x12\x44\n\tdecrement\x18\x06 \x01(\x0b\x32,.otg.PatternFlowGtpv2PiggybackingFlagCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"y\n\x1fPatternFlowGtpv2TeidFlagCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xaf\x03\n\x18PatternFlowGtpv2TeidFlag\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.PatternFlowGtpv2TeidFlag.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12<\n\tincrement\x18\x05 \x01(\x0b\x32$.otg.PatternFlowGtpv2TeidFlagCounterH\x03\x88\x01\x01\x12<\n\tdecrement\x18\x06 \x01(\x0b\x32$.otg.PatternFlowGtpv2TeidFlagCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"w\n\x1dPatternFlowGtpv2Spare1Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa7\x03\n\x16PatternFlowGtpv2Spare1\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowGtpv2Spare1.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowGtpv2Spare1CounterH\x03\x88\x01\x01\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowGtpv2Spare1CounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"|\n\"PatternFlowGtpv2MessageTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xbb\x03\n\x1bPatternFlowGtpv2MessageType\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowGtpv2MessageType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12?\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowGtpv2MessageTypeCounterH\x03\x88\x01\x01\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowGtpv2MessageTypeCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"~\n$PatternFlowGtpv2MessageLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc3\x03\n\x1dPatternFlowGtpv2MessageLength\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowGtpv2MessageLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x41\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowGtpv2MessageLengthCounterH\x03\x88\x01\x01\x12\x41\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowGtpv2MessageLengthCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowGtpv2TeidCounter\x12\x12\n\x05start\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x9f\x03\n\x14PatternFlowGtpv2Teid\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowGtpv2Teid.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x03\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowGtpv2TeidCounterH\x03\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowGtpv2TeidCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x7f\n%PatternFlowGtpv2SequenceNumberCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc7\x03\n\x1ePatternFlowGtpv2SequenceNumber\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowGtpv2SequenceNumber.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x42\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowGtpv2SequenceNumberCounterH\x03\x88\x01\x01\x12\x42\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowGtpv2SequenceNumberCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"w\n\x1dPatternFlowGtpv2Spare2Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa7\x03\n\x16PatternFlowGtpv2Spare2\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowGtpv2Spare2.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowGtpv2Spare2CounterH\x03\x88\x01\x01\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowGtpv2Spare2CounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"{\n!PatternFlowArpHardwareTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xb7\x03\n\x1aPatternFlowArpHardwareType\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.PatternFlowArpHardwareType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12>\n\tincrement\x18\x05 \x01(\x0b\x32&.otg.PatternFlowArpHardwareTypeCounterH\x03\x88\x01\x01\x12>\n\tdecrement\x18\x06 \x01(\x0b\x32&.otg.PatternFlowArpHardwareTypeCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"{\n!PatternFlowArpProtocolTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xb7\x03\n\x1aPatternFlowArpProtocolType\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.PatternFlowArpProtocolType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12>\n\tincrement\x18\x05 \x01(\x0b\x32&.otg.PatternFlowArpProtocolTypeCounterH\x03\x88\x01\x01\x12>\n\tdecrement\x18\x06 \x01(\x0b\x32&.otg.PatternFlowArpProtocolTypeCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"}\n#PatternFlowArpHardwareLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xbf\x03\n\x1cPatternFlowArpHardwareLength\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowArpHardwareLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12@\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowArpHardwareLengthCounterH\x03\x88\x01\x01\x12@\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowArpHardwareLengthCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"}\n#PatternFlowArpProtocolLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xbf\x03\n\x1cPatternFlowArpProtocolLength\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowArpProtocolLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12@\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowArpProtocolLengthCounterH\x03\x88\x01\x01\x12@\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowArpProtocolLengthCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"x\n\x1ePatternFlowArpOperationCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xab\x03\n\x17PatternFlowArpOperation\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowArpOperation.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12;\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowArpOperationCounterH\x03\x88\x01\x01\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowArpOperationCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x81\x01\n\'PatternFlowArpSenderHardwareAddrCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xcf\x03\n PatternFlowArpSenderHardwareAddr\x12\x46\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x31.otg.PatternFlowArpSenderHardwareAddr.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x44\n\tincrement\x18\x05 \x01(\x0b\x32,.otg.PatternFlowArpSenderHardwareAddrCounterH\x03\x88\x01\x01\x12\x44\n\tdecrement\x18\x06 \x01(\x0b\x32,.otg.PatternFlowArpSenderHardwareAddrCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x81\x01\n\'PatternFlowArpSenderProtocolAddrCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xcf\x03\n PatternFlowArpSenderProtocolAddr\x12\x46\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x31.otg.PatternFlowArpSenderProtocolAddr.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x44\n\tincrement\x18\x05 \x01(\x0b\x32,.otg.PatternFlowArpSenderProtocolAddrCounterH\x03\x88\x01\x01\x12\x44\n\tdecrement\x18\x06 \x01(\x0b\x32,.otg.PatternFlowArpSenderProtocolAddrCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x81\x01\n\'PatternFlowArpTargetHardwareAddrCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xcf\x03\n PatternFlowArpTargetHardwareAddr\x12\x46\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x31.otg.PatternFlowArpTargetHardwareAddr.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x44\n\tincrement\x18\x05 \x01(\x0b\x32,.otg.PatternFlowArpTargetHardwareAddrCounterH\x03\x88\x01\x01\x12\x44\n\tdecrement\x18\x06 \x01(\x0b\x32,.otg.PatternFlowArpTargetHardwareAddrCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x81\x01\n\'PatternFlowArpTargetProtocolAddrCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xcf\x03\n PatternFlowArpTargetProtocolAddr\x12\x46\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x31.otg.PatternFlowArpTargetProtocolAddr.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x44\n\tincrement\x18\x05 \x01(\x0b\x32,.otg.PatternFlowArpTargetProtocolAddrCounterH\x03\x88\x01\x01\x12\x44\n\tdecrement\x18\x06 \x01(\x0b\x32,.otg.PatternFlowArpTargetProtocolAddrCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"x\n\x1ePatternFlowIcmpEchoTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xab\x03\n\x17PatternFlowIcmpEchoType\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowIcmpEchoType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12;\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowIcmpEchoTypeCounterH\x03\x88\x01\x01\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowIcmpEchoTypeCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"x\n\x1ePatternFlowIcmpEchoCodeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xab\x03\n\x17PatternFlowIcmpEchoCode\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowIcmpEchoCode.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12;\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowIcmpEchoCodeCounterH\x03\x88\x01\x01\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowIcmpEchoCodeCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\xd9\x02\n\x1bPatternFlowIcmpEchoChecksum\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowIcmpEchoChecksum.Choice.EnumH\x00\x88\x01\x01\x12G\n\tgenerated\x18\x02 \x01(\x0e\x32/.otg.PatternFlowIcmpEchoChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\x05H\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"~\n$PatternFlowIcmpEchoIdentifierCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc3\x03\n\x1dPatternFlowIcmpEchoIdentifier\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIcmpEchoIdentifier.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x41\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowIcmpEchoIdentifierCounterH\x03\x88\x01\x01\x12\x41\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowIcmpEchoIdentifierCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x82\x01\n(PatternFlowIcmpEchoSequenceNumberCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xd3\x03\n!PatternFlowIcmpEchoSequenceNumber\x12G\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x32.otg.PatternFlowIcmpEchoSequenceNumber.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x45\n\tincrement\x18\x05 \x01(\x0b\x32-.otg.PatternFlowIcmpEchoSequenceNumberCounterH\x03\x88\x01\x01\x12\x45\n\tdecrement\x18\x06 \x01(\x0b\x32-.otg.PatternFlowIcmpEchoSequenceNumberCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\xdf\x02\n\x1dPatternFlowIcmpCommonChecksum\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIcmpCommonChecksum.Choice.EnumH\x00\x88\x01\x01\x12I\n\tgenerated\x18\x02 \x01(\x0e\x32\x31.otg.PatternFlowIcmpCommonChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\x05H\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"\x84\x01\n*PatternFlowIcmpNextFieldsIdentifierCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xdb\x03\n#PatternFlowIcmpNextFieldsIdentifier\x12I\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x34.otg.PatternFlowIcmpNextFieldsIdentifier.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12G\n\tincrement\x18\x05 \x01(\x0b\x32/.otg.PatternFlowIcmpNextFieldsIdentifierCounterH\x03\x88\x01\x01\x12G\n\tdecrement\x18\x06 \x01(\x0b\x32/.otg.PatternFlowIcmpNextFieldsIdentifierCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x88\x01\n.PatternFlowIcmpNextFieldsSequenceNumberCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xeb\x03\n\'PatternFlowIcmpNextFieldsSequenceNumber\x12M\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x38.otg.PatternFlowIcmpNextFieldsSequenceNumber.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12K\n\tincrement\x18\x05 \x01(\x0b\x32\x33.otg.PatternFlowIcmpNextFieldsSequenceNumberCounterH\x03\x88\x01\x01\x12K\n\tdecrement\x18\x06 \x01(\x0b\x32\x33.otg.PatternFlowIcmpNextFieldsSequenceNumberCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"z\n PatternFlowIcmpv6EchoTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xb3\x03\n\x19PatternFlowIcmpv6EchoType\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowIcmpv6EchoType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12=\n\tincrement\x18\x05 \x01(\x0b\x32%.otg.PatternFlowIcmpv6EchoTypeCounterH\x03\x88\x01\x01\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowIcmpv6EchoTypeCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"z\n PatternFlowIcmpv6EchoCodeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xb3\x03\n\x19PatternFlowIcmpv6EchoCode\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowIcmpv6EchoCode.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12=\n\tincrement\x18\x05 \x01(\x0b\x32%.otg.PatternFlowIcmpv6EchoCodeCounterH\x03\x88\x01\x01\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowIcmpv6EchoCodeCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x80\x01\n&PatternFlowIcmpv6EchoIdentifierCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xcb\x03\n\x1fPatternFlowIcmpv6EchoIdentifier\x12\x45\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x30.otg.PatternFlowIcmpv6EchoIdentifier.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x43\n\tincrement\x18\x05 \x01(\x0b\x32+.otg.PatternFlowIcmpv6EchoIdentifierCounterH\x03\x88\x01\x01\x12\x43\n\tdecrement\x18\x06 \x01(\x0b\x32+.otg.PatternFlowIcmpv6EchoIdentifierCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x84\x01\n*PatternFlowIcmpv6EchoSequenceNumberCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xdb\x03\n#PatternFlowIcmpv6EchoSequenceNumber\x12I\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x34.otg.PatternFlowIcmpv6EchoSequenceNumber.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12G\n\tincrement\x18\x05 \x01(\x0b\x32/.otg.PatternFlowIcmpv6EchoSequenceNumberCounterH\x03\x88\x01\x01\x12G\n\tdecrement\x18\x06 \x01(\x0b\x32/.otg.PatternFlowIcmpv6EchoSequenceNumberCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\xdf\x02\n\x1dPatternFlowIcmpv6EchoChecksum\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIcmpv6EchoChecksum.Choice.EnumH\x00\x88\x01\x01\x12I\n\tgenerated\x18\x02 \x01(\x0e\x32\x31.otg.PatternFlowIcmpv6EchoChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\x05H\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"\xe5\x02\n\x1fPatternFlowIcmpv6CommonChecksum\x12\x45\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x30.otg.PatternFlowIcmpv6CommonChecksum.Choice.EnumH\x00\x88\x01\x01\x12K\n\tgenerated\x18\x02 \x01(\x0e\x32\x33.otg.PatternFlowIcmpv6CommonChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\x05H\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"v\n\x1cPatternFlowPppAddressCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa3\x03\n\x15PatternFlowPppAddress\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowPppAddress.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowPppAddressCounterH\x03\x88\x01\x01\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowPppAddressCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"v\n\x1cPatternFlowPppControlCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa3\x03\n\x15PatternFlowPppControl\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowPppControl.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowPppControlCounterH\x03\x88\x01\x01\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowPppControlCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"{\n!PatternFlowPppProtocolTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xb3\x04\n\x1aPatternFlowPppProtocolType\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.PatternFlowPppProtocolType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12<\n\x04\x61uto\x18\x04 \x01(\x0e\x32).otg.PatternFlowPppProtocolType.Auto.EnumH\x02\x88\x01\x01\x12\x19\n\x0cmetric_group\x18\x05 \x01(\tH\x03\x88\x01\x01\x12>\n\tincrement\x18\x06 \x01(\x0b\x32&.otg.PatternFlowPppProtocolTypeCounterH\x04\x88\x01\x01\x12>\n\tdecrement\x18\x07 \x01(\x0b\x32&.otg.PatternFlowPppProtocolTypeCounterH\x05\x88\x01\x01\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\x08\n\x04\x61uto\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x1a)\n\x04\x41uto\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_autoB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"y\n\x1fPatternFlowIgmpv1VersionCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xaf\x03\n\x18PatternFlowIgmpv1Version\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.PatternFlowIgmpv1Version.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12<\n\tincrement\x18\x05 \x01(\x0b\x32$.otg.PatternFlowIgmpv1VersionCounterH\x03\x88\x01\x01\x12<\n\tdecrement\x18\x06 \x01(\x0b\x32$.otg.PatternFlowIgmpv1VersionCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"v\n\x1cPatternFlowIgmpv1TypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa3\x03\n\x15PatternFlowIgmpv1Type\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowIgmpv1Type.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowIgmpv1TypeCounterH\x03\x88\x01\x01\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowIgmpv1TypeCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"x\n\x1ePatternFlowIgmpv1UnusedCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xab\x03\n\x17PatternFlowIgmpv1Unused\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowIgmpv1Unused.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12;\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowIgmpv1UnusedCounterH\x03\x88\x01\x01\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowIgmpv1UnusedCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\xd3\x02\n\x19PatternFlowIgmpv1Checksum\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowIgmpv1Checksum.Choice.EnumH\x00\x88\x01\x01\x12\x45\n\tgenerated\x18\x02 \x01(\x0e\x32-.otg.PatternFlowIgmpv1Checksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\x05H\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"~\n$PatternFlowIgmpv1GroupAddressCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc3\x03\n\x1dPatternFlowIgmpv1GroupAddress\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIgmpv1GroupAddress.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x41\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowIgmpv1GroupAddressCounterH\x03\x88\x01\x01\x12\x41\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowIgmpv1GroupAddressCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"9\n\x07Success\x12.\n\x10response_warning\x18\x01 \x01(\x0b\x32\x14.otg.ResponseWarning\"8\n\nBadRequest\x12*\n\x0eresponse_error\x18\x01 \x01(\x0b\x32\x12.otg.ResponseError\"A\n\x13InternalServerError\x12*\n\x0eresponse_error\x18\x01 \x01(\x0b\x32\x12.otg.ResponseError\"/\n\x10SetConfigRequest\x12\x1b\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x0b.otg.Config\"\xe7\x01\n\x11SetConfigResponse\x12\x32\n\x0fstatus_code_200\x18\x01 \x01(\x0b\x32\x14.otg.ResponseWarningH\x00\x88\x01\x01\x12\x30\n\x0fstatus_code_400\x18\x02 \x01(\x0b\x32\x12.otg.ResponseErrorH\x01\x88\x01\x01\x12\x30\n\x0fstatus_code_500\x18\x03 \x01(\x0b\x32\x12.otg.ResponseErrorH\x02\x88\x01\x01\x42\x12\n\x10_status_code_200B\x12\n\x10_status_code_400B\x12\n\x10_status_code_500\"\xde\x01\n\x11GetConfigResponse\x12)\n\x0fstatus_code_200\x18\x01 \x01(\x0b\x32\x0b.otg.ConfigH\x00\x88\x01\x01\x12\x30\n\x0fstatus_code_400\x18\x02 \x01(\x0b\x32\x12.otg.ResponseErrorH\x01\x88\x01\x01\x12\x30\n\x0fstatus_code_500\x18\x03 \x01(\x0b\x32\x12.otg.ResponseErrorH\x02\x88\x01\x01\x42\x12\n\x10_status_code_200B\x12\n\x10_status_code_400B\x12\n\x10_status_code_500\"E\n\x17SetTransmitStateRequest\x12*\n\x0etransmit_state\x18\x01 \x01(\x0b\x32\x12.otg.TransmitState\"\xee\x01\n\x18SetTransmitStateResponse\x12\x32\n\x0fstatus_code_200\x18\x01 \x01(\x0b\x32\x14.otg.ResponseWarningH\x00\x88\x01\x01\x12\x30\n\x0fstatus_code_400\x18\x02 \x01(\x0b\x32\x12.otg.ResponseErrorH\x01\x88\x01\x01\x12\x30\n\x0fstatus_code_500\x18\x03 \x01(\x0b\x32\x12.otg.ResponseErrorH\x02\x88\x01\x01\x42\x12\n\x10_status_code_200B\x12\n\x10_status_code_400B\x12\n\x10_status_code_500\"9\n\x13SetLinkStateRequest\x12\"\n\nlink_state\x18\x01 \x01(\x0b\x32\x0e.otg.LinkState\"\xea\x01\n\x14SetLinkStateResponse\x12\x32\n\x0fstatus_code_200\x18\x01 \x01(\x0b\x32\x14.otg.ResponseWarningH\x00\x88\x01\x01\x12\x30\n\x0fstatus_code_400\x18\x02 \x01(\x0b\x32\x12.otg.ResponseErrorH\x01\x88\x01\x01\x12\x30\n\x0fstatus_code_500\x18\x03 \x01(\x0b\x32\x12.otg.ResponseErrorH\x02\x88\x01\x01\x42\x12\n\x10_status_code_200B\x12\n\x10_status_code_400B\x12\n\x10_status_code_500\"B\n\x16SetCaptureStateRequest\x12(\n\rcapture_state\x18\x01 \x01(\x0b\x32\x11.otg.CaptureState\"\xed\x01\n\x17SetCaptureStateResponse\x12\x32\n\x0fstatus_code_200\x18\x01 \x01(\x0b\x32\x14.otg.ResponseWarningH\x00\x88\x01\x01\x12\x30\n\x0fstatus_code_400\x18\x02 \x01(\x0b\x32\x12.otg.ResponseErrorH\x01\x88\x01\x01\x12\x30\n\x0fstatus_code_500\x18\x03 \x01(\x0b\x32\x12.otg.ResponseErrorH\x02\x88\x01\x01\x42\x12\n\x10_status_code_200B\x12\n\x10_status_code_400B\x12\n\x10_status_code_500\"<\n\x12UpdateFlowsRequest\x12&\n\x0c\x66lows_update\x18\x01 \x01(\x0b\x32\x10.otg.FlowsUpdate\"\xe0\x01\n\x13UpdateFlowsResponse\x12)\n\x0fstatus_code_200\x18\x01 \x01(\x0b\x32\x0b.otg.ConfigH\x00\x88\x01\x01\x12\x30\n\x0fstatus_code_400\x18\x02 \x01(\x0b\x32\x12.otg.ResponseErrorH\x01\x88\x01\x01\x12\x30\n\x0fstatus_code_500\x18\x03 \x01(\x0b\x32\x12.otg.ResponseErrorH\x02\x88\x01\x01\x42\x12\n\x10_status_code_200B\x12\n\x10_status_code_400B\x12\n\x10_status_code_500\"<\n\x14SetRouteStateRequest\x12$\n\x0broute_state\x18\x01 \x01(\x0b\x32\x0f.otg.RouteState\"\xeb\x01\n\x15SetRouteStateResponse\x12\x32\n\x0fstatus_code_200\x18\x01 \x01(\x0b\x32\x14.otg.ResponseWarningH\x00\x88\x01\x01\x12\x30\n\x0fstatus_code_400\x18\x02 \x01(\x0b\x32\x12.otg.ResponseErrorH\x01\x88\x01\x01\x12\x30\n\x0fstatus_code_500\x18\x03 \x01(\x0b\x32\x12.otg.ResponseErrorH\x02\x88\x01\x01\x42\x12\n\x10_status_code_200B\x12\n\x10_status_code_400B\x12\n\x10_status_code_500\"9\n\x0fSendPingRequest\x12&\n\x0cping_request\x18\x01 \x01(\x0b\x32\x10.otg.PingRequest\"\xe3\x01\n\x10SendPingResponse\x12/\n\x0fstatus_code_200\x18\x01 \x01(\x0b\x32\x11.otg.PingResponseH\x00\x88\x01\x01\x12\x30\n\x0fstatus_code_400\x18\x02 \x01(\x0b\x32\x12.otg.ResponseErrorH\x01\x88\x01\x01\x12\x30\n\x0fstatus_code_500\x18\x03 \x01(\x0b\x32\x12.otg.ResponseErrorH\x02\x88\x01\x01\x42\x12\n\x10_status_code_200B\x12\n\x10_status_code_400B\x12\n\x10_status_code_500\"E\n\x17SetProtocolStateRequest\x12*\n\x0eprotocol_state\x18\x01 \x01(\x0b\x32\x12.otg.ProtocolState\"\xee\x01\n\x18SetProtocolStateResponse\x12\x32\n\x0fstatus_code_200\x18\x01 \x01(\x0b\x32\x14.otg.ResponseWarningH\x00\x88\x01\x01\x12\x30\n\x0fstatus_code_400\x18\x02 \x01(\x0b\x32\x12.otg.ResponseErrorH\x01\x88\x01\x01\x12\x30\n\x0fstatus_code_500\x18\x03 \x01(\x0b\x32\x12.otg.ResponseErrorH\x02\x88\x01\x01\x42\x12\n\x10_status_code_200B\x12\n\x10_status_code_400B\x12\n\x10_status_code_500\"A\n\x11GetMetricsRequest\x12,\n\x0fmetrics_request\x18\x01 \x01(\x0b\x32\x13.otg.MetricsRequest\"\xe8\x01\n\x12GetMetricsResponse\x12\x32\n\x0fstatus_code_200\x18\x01 \x01(\x0b\x32\x14.otg.MetricsResponseH\x00\x88\x01\x01\x12\x30\n\x0fstatus_code_400\x18\x02 \x01(\x0b\x32\x12.otg.ResponseErrorH\x01\x88\x01\x01\x12\x30\n\x0fstatus_code_500\x18\x03 \x01(\x0b\x32\x12.otg.ResponseErrorH\x02\x88\x01\x01\x42\x12\n\x10_status_code_200B\x12\n\x10_status_code_400B\x12\n\x10_status_code_500\">\n\x10GetStatesRequest\x12*\n\x0estates_request\x18\x01 \x01(\x0b\x32\x12.otg.StatesRequest\"\xe6\x01\n\x11GetStatesResponse\x12\x31\n\x0fstatus_code_200\x18\x01 \x01(\x0b\x32\x13.otg.StatesResponseH\x00\x88\x01\x01\x12\x30\n\x0fstatus_code_400\x18\x02 \x01(\x0b\x32\x12.otg.ResponseErrorH\x01\x88\x01\x01\x12\x30\n\x0fstatus_code_500\x18\x03 \x01(\x0b\x32\x12.otg.ResponseErrorH\x02\x88\x01\x01\x42\x12\n\x10_status_code_200B\x12\n\x10_status_code_400B\x12\n\x10_status_code_500\"A\n\x11GetCaptureRequest\x12,\n\x0f\x63\x61pture_request\x18\x01 \x01(\x0b\x32\x13.otg.CaptureRequest\"\xd2\x01\n\x12GetCaptureResponse\x12\x1c\n\x0fstatus_code_200\x18\x01 \x01(\x0cH\x00\x88\x01\x01\x12\x30\n\x0fstatus_code_400\x18\x02 \x01(\x0b\x32\x12.otg.ResponseErrorH\x01\x88\x01\x01\x12\x30\n\x0fstatus_code_500\x18\x03 \x01(\x0b\x32\x12.otg.ResponseErrorH\x02\x88\x01\x01\x42\x12\n\x10_status_code_200B\x12\n\x10_status_code_400B\x12\n\x10_status_code_5002\xb4\x06\n\x07Openapi\x12:\n\tSetConfig\x12\x15.otg.SetConfigRequest\x1a\x16.otg.SetConfigResponse\x12;\n\tGetConfig\x12\x16.google.protobuf.Empty\x1a\x16.otg.GetConfigResponse\x12O\n\x10SetTransmitState\x12\x1c.otg.SetTransmitStateRequest\x1a\x1d.otg.SetTransmitStateResponse\x12\x43\n\x0cSetLinkState\x12\x18.otg.SetLinkStateRequest\x1a\x19.otg.SetLinkStateResponse\x12L\n\x0fSetCaptureState\x12\x1b.otg.SetCaptureStateRequest\x1a\x1c.otg.SetCaptureStateResponse\x12@\n\x0bUpdateFlows\x12\x17.otg.UpdateFlowsRequest\x1a\x18.otg.UpdateFlowsResponse\x12\x46\n\rSetRouteState\x12\x19.otg.SetRouteStateRequest\x1a\x1a.otg.SetRouteStateResponse\x12\x37\n\x08SendPing\x12\x14.otg.SendPingRequest\x1a\x15.otg.SendPingResponse\x12O\n\x10SetProtocolState\x12\x1c.otg.SetProtocolStateRequest\x1a\x1d.otg.SetProtocolStateResponse\x12=\n\nGetMetrics\x12\x16.otg.GetMetricsRequest\x1a\x17.otg.GetMetricsResponse\x12:\n\tGetStates\x12\x15.otg.GetStatesRequest\x1a\x16.otg.GetStatesResponse\x12=\n\nGetCapture\x12\x16.otg.GetCaptureRequest\x1a\x17.otg.GetCaptureResponseb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])



_LAGPROTOCOL_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.LagProtocol.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='lacp', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='static', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=873,
  serialized_end=918,
)
_sym_db.RegisterEnumDescriptor(_LAGPROTOCOL_CHOICE_ENUM)

_LAGLACP_ACTORACTIVITY_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.LagLacp.ActorActivity.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='passive', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='active', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1316,
  serialized_end=1364,
)
_sym_db.RegisterEnumDescriptor(_LAGLACP_ACTORACTIVITY_ENUM)

_DEVICEVLAN_TPID_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.DeviceVlan.Tpid.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='x8100', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='x88a8', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='x9100', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='x9200', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='x9300', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1979,
  serialized_end=2057,
)
_sym_db.RegisterEnumDescriptor(_DEVICEVLAN_TPID_ENUM)

_LAYER1_SPEED_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.Layer1.Speed.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='speed_10_fd_mbps', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='speed_10_hd_mbps', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='speed_100_fd_mbps', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='speed_100_hd_mbps', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='speed_1_gbps', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='speed_10_gbps', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='speed_25_gbps', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='speed_40_gbps', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='speed_50_gbps', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='speed_100_gbps', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='speed_200_gbps', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='speed_400_gbps', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2813,
  serialized_end=3080,
)
_sym_db.RegisterEnumDescriptor(_LAYER1_SPEED_ENUM)

_LAYER1_MEDIA_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.Layer1.Media.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='copper', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='fiber', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='sgmii', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3091,
  serialized_end=3148,
)
_sym_db.RegisterEnumDescriptor(_LAYER1_MEDIA_ENUM)

_LAYER1FLOWCONTROL_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.Layer1FlowControl.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ieee_802_1qbb', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ieee_802_3x', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3901,
  serialized_end=3960,
)
_sym_db.RegisterEnumDescriptor(_LAYER1FLOWCONTROL_CHOICE_ENUM)

_CAPTURE_FORMAT_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.Capture.Format.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='pcap', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='pcapng', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4633,
  serialized_end=4678,
)
_sym_db.RegisterEnumDescriptor(_CAPTURE_FORMAT_ENUM)

_CAPTUREFILTER_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.CaptureFilter.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='custom', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ethernet', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='vlan', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ipv4', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ipv6', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4999,
  serialized_end=5078,
)
_sym_db.RegisterEnumDescriptor(_CAPTUREFILTER_CHOICE_ENUM)

_ISISINTERFACE_NETWORKTYPE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.IsisInterface.NetworkType.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='broadcast', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='point_to_point', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8529,
  serialized_end=8587,
)
_sym_db.RegisterEnumDescriptor(_ISISINTERFACE_NETWORKTYPE_ENUM)

_ISISINTERFACE_LEVELTYPE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.IsisInterface.LevelType.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='level_1', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='level_2', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='level_1_2', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8602,
  serialized_end=8666,
)
_sym_db.RegisterEnumDescriptor(_ISISINTERFACE_LEVELTYPE_ENUM)

_ISISINTERFACEAUTHENTICATION_AUTHTYPE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.IsisInterfaceAuthentication.AuthType.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='md5', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='password', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9746,
  serialized_end=9792,
)
_sym_db.RegisterEnumDescriptor(_ISISINTERFACEAUTHENTICATION_AUTHTYPE_ENUM)

_ISISAUTHENTICATIONBASE_AUTHTYPE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.IsisAuthenticationBase.AuthType.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='md5', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='password', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9746,
  serialized_end=9792,
)
_sym_db.RegisterEnumDescriptor(_ISISAUTHENTICATIONBASE_AUTHTYPE_ENUM)

_ISISV4ROUTERANGE_ORIGINTYPE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.IsisV4RouteRange.OriginType.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='internal', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='external', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11938,
  serialized_end=11989,
)
_sym_db.RegisterEnumDescriptor(_ISISV4ROUTERANGE_ORIGINTYPE_ENUM)

_ISISV4ROUTERANGE_REDISTRIBUTIONTYPE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.IsisV4RouteRange.RedistributionType.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='up', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='down', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12013,
  serialized_end=12054,
)
_sym_db.RegisterEnumDescriptor(_ISISV4ROUTERANGE_REDISTRIBUTIONTYPE_ENUM)

_ISISV6ROUTERANGE_ORIGINTYPE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.IsisV6RouteRange.OriginType.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='internal', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='external', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11938,
  serialized_end=11989,
)
_sym_db.RegisterEnumDescriptor(_ISISV6ROUTERANGE_ORIGINTYPE_ENUM)

_ISISV6ROUTERANGE_REDISTRIBUTIONTYPE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.IsisV6RouteRange.RedistributionType.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='up', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='down', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12013,
  serialized_end=12054,
)
_sym_db.RegisterEnumDescriptor(_ISISV6ROUTERANGE_REDISTRIBUTIONTYPE_ENUM)

_BGPV4PEER_ASTYPE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.BgpV4Peer.AsType.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ibgp', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ebgp', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=13592,
  serialized_end=13635,
)
_sym_db.RegisterEnumDescriptor(_BGPV4PEER_ASTYPE_ENUM)

_BGPV4PEER_ASNUMBERWIDTH_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.BgpV4Peer.AsNumberWidth.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='two', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='four', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=13654,
  serialized_end=13696,
)
_sym_db.RegisterEnumDescriptor(_BGPV4PEER_ASNUMBERWIDTH_ENUM)

_BGPV4ROUTERANGE_NEXTHOPMODE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.BgpV4RouteRange.NextHopMode.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='local_ip', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='manual', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15846,
  serialized_end=15895,
)
_sym_db.RegisterEnumDescriptor(_BGPV4ROUTERANGE_NEXTHOPMODE_ENUM)

_BGPV4ROUTERANGE_NEXTHOPADDRESSTYPE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.BgpV4RouteRange.NextHopAddressType.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ipv4', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ipv6', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15919,
  serialized_end=15962,
)
_sym_db.RegisterEnumDescriptor(_BGPV4ROUTERANGE_NEXTHOPADDRESSTYPE_ENUM)

_BGPROUTEADVANCED_ORIGIN_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.BgpRouteAdvanced.Origin.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='igp', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='egp', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16224,
  serialized_end=16265,
)
_sym_db.RegisterEnumDescriptor(_BGPROUTEADVANCED_ORIGIN_ENUM)

_BGPCOMMUNITY_TYPE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.BgpCommunity.Type.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='manual_as_number', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='no_export', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='no_advertised', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='no_export_subconfed', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='llgr_stale', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='no_llgr', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16430,
  serialized_end=16563,
)
_sym_db.RegisterEnumDescriptor(_BGPCOMMUNITY_TYPE_ENUM)

_BGPASPATH_ASSETMODE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.BgpAsPath.AsSetMode.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='do_not_include_local_as', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='include_as_seq', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='include_as_set', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='include_as_confed_seq', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='include_as_confed_set', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='prepend_to_first_segment', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16729,
  serialized_end=16905,
)
_sym_db.RegisterEnumDescriptor(_BGPASPATH_ASSETMODE_ENUM)

_BGPASPATHSEGMENT_TYPE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.BgpAsPathSegment.Type.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='as_seq', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='as_set', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='as_confed_seq', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='as_confed_set', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=17024,
  serialized_end=17109,
)
_sym_db.RegisterEnumDescriptor(_BGPASPATHSEGMENT_TYPE_ENUM)

_BGPV6ROUTERANGE_NEXTHOPMODE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.BgpV6RouteRange.NextHopMode.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='local_ip', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='manual', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15846,
  serialized_end=15895,
)
_sym_db.RegisterEnumDescriptor(_BGPV6ROUTERANGE_NEXTHOPMODE_ENUM)

_BGPV6ROUTERANGE_NEXTHOPADDRESSTYPE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.BgpV6RouteRange.NextHopAddressType.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ipv4', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ipv6', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15919,
  serialized_end=15962,
)
_sym_db.RegisterEnumDescriptor(_BGPV6ROUTERANGE_NEXTHOPADDRESSTYPE_ENUM)

_BGPSRTEV4POLICY_NEXTHOPMODE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.BgpSrteV4Policy.NextHopMode.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='local_ip', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='manual', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15846,
  serialized_end=15895,
)
_sym_db.RegisterEnumDescriptor(_BGPSRTEV4POLICY_NEXTHOPMODE_ENUM)

_BGPSRTEV4POLICY_NEXTHOPADDRESSTYPE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.BgpSrteV4Policy.NextHopAddressType.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ipv4', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ipv6', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15919,
  serialized_end=15962,
)
_sym_db.RegisterEnumDescriptor(_BGPSRTEV4POLICY_NEXTHOPADDRESSTYPE_ENUM)

_BGPEXTCOMMUNITY_TYPE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.BgpExtCommunity.Type.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='administrator_as_2octet', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='administrator_ipv4_address', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='administrator_as_4octet', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='opaque', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='evpn', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='administrator_as_2octet_link_bandwidth', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=18962,
  serialized_end=19141,
)
_sym_db.RegisterEnumDescriptor(_BGPEXTCOMMUNITY_TYPE_ENUM)

_BGPEXTCOMMUNITY_SUBTYPE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.BgpExtCommunity.Subtype.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='route_target', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='origin', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='extended_bandwidth', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='color', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='encapsulation', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='mac_address', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=19155,
  serialized_end=19279,
)
_sym_db.RegisterEnumDescriptor(_BGPEXTCOMMUNITY_SUBTYPE_ENUM)

_BGPSRTEREMOTEENDPOINTSUBTLV_ADDRESSFAMILY_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.BgpSrteRemoteEndpointSubTlv.AddressFamily.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ipv4', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ipv6', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15919,
  serialized_end=15962,
)
_sym_db.RegisterEnumDescriptor(_BGPSRTEREMOTEENDPOINTSUBTLV_ADDRESSFAMILY_ENUM)

_BGPSRTEBINDINGSUBTLV_BINDINGSIDTYPE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.BgpSrteBindingSubTlv.BindingSidType.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='no_binding', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='four_octet_sid', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ipv6_sid', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=20670,
  serialized_end=20743,
)
_sym_db.RegisterEnumDescriptor(_BGPSRTEBINDINGSUBTLV_BINDINGSIDTYPE_ENUM)

_BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV_EXPLICITNULLLABELPOLICY_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.BgpSrteExplicitNullLabelPolicySubTlv.ExplicitNullLabelPolicy.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='reserved_enlp', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='push_ipv4_enlp', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='push_ipv6_enlp', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='push_ipv4_ipv6_enlp', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='do_not_push_enlp', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=21220,
  serialized_end=21349,
)
_sym_db.RegisterEnumDescriptor(_BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV_EXPLICITNULLLABELPOLICY_ENUM)

_BGPSRTESEGMENT_SEGMENTTYPE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.BgpSrteSegment.SegmentType.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='type_a', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='type_b', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='type_c', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='type_d', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='type_e', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='type_f', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='type_g', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='type_h', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='type_i', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='type_j', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='type_k', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=22236,
  serialized_end=22391,
)
_sym_db.RegisterEnumDescriptor(_BGPSRTESEGMENT_SEGMENTTYPE_ENUM)

_BGPSRTEV6POLICY_NEXTHOPMODE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.BgpSrteV6Policy.NextHopMode.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='local_ip', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='manual', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15846,
  serialized_end=15895,
)
_sym_db.RegisterEnumDescriptor(_BGPSRTEV6POLICY_NEXTHOPMODE_ENUM)

_BGPSRTEV6POLICY_NEXTHOPADDRESSTYPE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.BgpSrteV6Policy.NextHopAddressType.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ipv4', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ipv6', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15919,
  serialized_end=15962,
)
_sym_db.RegisterEnumDescriptor(_BGPSRTEV6POLICY_NEXTHOPADDRESSTYPE_ENUM)

_BGPV6PEER_ASTYPE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.BgpV6Peer.AsType.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ibgp', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ebgp', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=13592,
  serialized_end=13635,
)
_sym_db.RegisterEnumDescriptor(_BGPV6PEER_ASTYPE_ENUM)

_BGPV6PEER_ASNUMBERWIDTH_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.BgpV6Peer.AsNumberWidth.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='two', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='four', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=13654,
  serialized_end=13696,
)
_sym_db.RegisterEnumDescriptor(_BGPV6PEER_ASNUMBERWIDTH_ENUM)

_FLOWTXRX_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.FlowTxRx.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='port', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='device', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=28856,
  serialized_end=28901,
)
_sym_db.RegisterEnumDescriptor(_FLOWTXRX_CHOICE_ENUM)

_FLOWROUTER_MODE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.FlowRouter.Mode.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='mesh', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='one_to_one', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=29102,
  serialized_end=29151,
)
_sym_db.RegisterEnumDescriptor(_FLOWROUTER_MODE_ENUM)

_FLOWHEADER_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.FlowHeader.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='custom', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ethernet', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='vlan', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='vxlan', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ipv4', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ipv6', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='pfcpause', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ethernetpause', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='tcp', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='udp', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='gre', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='gtpv1', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='gtpv2', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='arp', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='icmp', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='icmpv6', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ppp', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='igmpv1', index=18, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=29893,
  serialized_end=30117,
)
_sym_db.RegisterEnumDescriptor(_FLOWHEADER_CHOICE_ENUM)

_FLOWIPV4PRIORITY_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.FlowIpv4Priority.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='raw', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='tos', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='dscp', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=32345,
  serialized_end=32396,
)
_sym_db.RegisterEnumDescriptor(_FLOWIPV4PRIORITY_CHOICE_ENUM)

_FLOWICMP_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.FlowIcmp.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='echo', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=39457,
  serialized_end=39490,
)
_sym_db.RegisterEnumDescriptor(_FLOWICMP_CHOICE_ENUM)

_FLOWICMPV6_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.FlowIcmpv6.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='echo', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=39457,
  serialized_end=39490,
)
_sym_db.RegisterEnumDescriptor(_FLOWICMPV6_CHOICE_ENUM)

_FLOWSIZE_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.FlowSize.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='fixed', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='random', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=41176,
  serialized_end=41237,
)
_sym_db.RegisterEnumDescriptor(_FLOWSIZE_CHOICE_ENUM)

_FLOWRATE_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.FlowRate.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='pps', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='bps', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='kbps', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='mbps', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='gbps', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='percentage', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=41649,
  serialized_end=41736,
)
_sym_db.RegisterEnumDescriptor(_FLOWRATE_CHOICE_ENUM)

_FLOWDURATION_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.FlowDuration.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='fixed_packets', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='fixed_seconds', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='burst', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='continuous', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=42070,
  serialized_end=42158,
)
_sym_db.RegisterEnumDescriptor(_FLOWDURATION_CHOICE_ENUM)

_FLOWDELAY_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.FlowDelay.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='bytes', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='nanoseconds', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='microseconds', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=42468,
  serialized_end=42537,
)
_sym_db.RegisterEnumDescriptor(_FLOWDELAY_CHOICE_ENUM)

_FLOWDURATIONINTERBURSTGAP_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.FlowDurationInterBurstGap.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='bytes', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='nanoseconds', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='microseconds', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=42468,
  serialized_end=42537,
)
_sym_db.RegisterEnumDescriptor(_FLOWDURATIONINTERBURSTGAP_CHOICE_ENUM)

_FLOWLATENCYMETRICS_MODE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.FlowLatencyMetrics.Mode.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='store_forward', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='cut_through', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=43617,
  serialized_end=43676,
)
_sym_db.RegisterEnumDescriptor(_FLOWLATENCYMETRICS_MODE_ENUM)

_EVENTREQUEST_TYPE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.EventRequest.Type.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='link_down', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='link_up', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='route_withdraw', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='route_advertise', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='flow_rx_rate_above_threshold', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='flow_rx_rate_below_threshold', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=44255,
  serialized_end=44415,
)
_sym_db.RegisterEnumDescriptor(_EVENTREQUEST_TYPE_ENUM)

_LINKSTATE_STATE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.LinkState.State.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='up', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='down', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12013,
  serialized_end=12054,
)
_sym_db.RegisterEnumDescriptor(_LINKSTATE_STATE_ENUM)

_TRANSMITSTATE_STATE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.TransmitState.State.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='start', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='stop', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='pause', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=44821,
  serialized_end=44876,
)
_sym_db.RegisterEnumDescriptor(_TRANSMITSTATE_STATE_ENUM)

_CAPTURESTATE_STATE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.CaptureState.State.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='start', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='stop', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=44821,
  serialized_end=44865,
)
_sym_db.RegisterEnumDescriptor(_CAPTURESTATE_STATE_ENUM)

_FLOWSUPDATE_PROPERTYNAMES_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.FlowsUpdate.PropertyNames.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='rate', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='size', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=45135,
  serialized_end=45178,
)
_sym_db.RegisterEnumDescriptor(_FLOWSUPDATE_PROPERTYNAMES_ENUM)

_ROUTESTATE_STATE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.RouteState.State.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='withdraw', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='advertise', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=45262,
  serialized_end=45314,
)
_sym_db.RegisterEnumDescriptor(_ROUTESTATE_STATE_ENUM)

_PROTOCOLSTATE_STATE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.ProtocolState.State.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='start', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='stop', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=44821,
  serialized_end=44865,
)
_sym_db.RegisterEnumDescriptor(_PROTOCOLSTATE_STATE_ENUM)

_PING_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.Ping.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ipv4', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ipv6', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15919,
  serialized_end=15962,
)
_sym_db.RegisterEnumDescriptor(_PING_CHOICE_ENUM)

_RESPONSE_RESULT_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.Response.Result.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='success', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='failure', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=46009,
  serialized_end=46058,
)
_sym_db.RegisterEnumDescriptor(_RESPONSE_RESULT_ENUM)

_METRICSREQUEST_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.MetricsRequest.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='port', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='flow', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='bgpv4', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='bgpv6', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='isis', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=46402,
  serialized_end=46477,
)
_sym_db.RegisterEnumDescriptor(_METRICSREQUEST_CHOICE_ENUM)

_METRICSRESPONSE_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.MetricsResponse.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='flow_metrics', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='port_metrics', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='bgpv4_metrics', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='bgpv6_metrics', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='isis_metrics', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=46821,
  serialized_end=46936,
)
_sym_db.RegisterEnumDescriptor(_METRICSRESPONSE_CHOICE_ENUM)

_PORTMETRICSREQUEST_COLUMNNAMES_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PortMetricsRequest.ColumnNames.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='transmit', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='location', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='link', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='capture', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='frames_tx', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='frames_rx', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='bytes_tx', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='bytes_rx', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='frames_tx_rate', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='frames_rx_rate', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='bytes_tx_rate', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='bytes_rx_rate', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=47073,
  serialized_end=47283,
)
_sym_db.RegisterEnumDescriptor(_PORTMETRICSREQUEST_COLUMNNAMES_ENUM)

_PORTMETRIC_LINK_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PortMetric.Link.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='up', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='down', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12013,
  serialized_end=12054,
)
_sym_db.RegisterEnumDescriptor(_PORTMETRIC_LINK_ENUM)

_PORTMETRIC_CAPTURE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PortMetric.Capture.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='started', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='stopped', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=47710,
  serialized_end=47759,
)
_sym_db.RegisterEnumDescriptor(_PORTMETRIC_CAPTURE_ENUM)

_FLOWMETRICSREQUEST_METRICNAMES_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.FlowMetricsRequest.MetricNames.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='transmit', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='frames_tx', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='frames_rx', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='bytes_tx', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='bytes_rx', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='frames_tx_rate', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='frames_rx_rate', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=48113,
  serialized_end=48248,
)
_sym_db.RegisterEnumDescriptor(_FLOWMETRICSREQUEST_METRICNAMES_ENUM)

_FLOWMETRICGROUPREQUEST_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.FlowMetricGroupRequest.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ingress', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='egress', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=48400,
  serialized_end=48448,
)
_sym_db.RegisterEnumDescriptor(_FLOWMETRICGROUPREQUEST_CHOICE_ENUM)

_FLOWMETRIC_TRANSMIT_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.FlowMetric.Transmit.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='started', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='stopped', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='paused', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=48910,
  serialized_end=48971,
)
_sym_db.RegisterEnumDescriptor(_FLOWMETRIC_TRANSMIT_ENUM)

_BGPV4METRICSREQUEST_COLUMNNAMES_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.Bgpv4MetricsRequest.ColumnNames.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='session_state', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='session_flap_count', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='routes_advertised', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='routes_received', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='route_withdraws_sent', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='route_withdraws_received', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='updates_sent', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='updates_received', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='opens_sent', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='opens_received', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='keepalives_sent', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='keepalives_received', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='notifications_sent', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='notifications_received', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=49617,
  serialized_end=49957,
)
_sym_db.RegisterEnumDescriptor(_BGPV4METRICSREQUEST_COLUMNNAMES_ENUM)

_BGPV4METRIC_SESSIONSTATE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.Bgpv4Metric.SessionState.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='up', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='down', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12013,
  serialized_end=12054,
)
_sym_db.RegisterEnumDescriptor(_BGPV4METRIC_SESSIONSTATE_ENUM)

_BGPV6METRICSREQUEST_COLUMNNAMES_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.Bgpv6MetricsRequest.ColumnNames.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='session_state', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='session_flap_count', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='routes_advertised', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='routes_received', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='route_withdraws_sent', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='route_withdraws_received', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='updates_sent', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='updates_received', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='opens_sent', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='opens_received', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='keepalives_sent', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='keepalives_received', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='notifications_sent', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='notifications_received', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=49617,
  serialized_end=49957,
)
_sym_db.RegisterEnumDescriptor(_BGPV6METRICSREQUEST_COLUMNNAMES_ENUM)

_BGPV6METRIC_SESSIONSTATE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.Bgpv6Metric.SessionState.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='up', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='down', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12013,
  serialized_end=12054,
)
_sym_db.RegisterEnumDescriptor(_BGPV6METRIC_SESSIONSTATE_ENUM)

_ISISMETRICSREQUEST_COLUMNNAMES_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.IsisMetricsRequest.ColumnNames.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='l1_sessions_up', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='l1_session_flap', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='l1_database_size', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='l1_broadcast_hellos_sent', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='l1_broadcast_hellos_received', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='l1_point_to_point_hellos_sent', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='l1_point_to_point_hellos_received', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='l1_psnp_sent', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='l1_psnp_received', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='l1_csnp_sent', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='l1_csnp_received', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='l1_lsp_sent', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='l1_lsp_received', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='l2_sessions_up', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='l2_session_flap', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='l2_database_size', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='l2_broadcast_hellos_sent', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='l2_broadcast_hellos_received', index=18, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='l2_point_to_point_hellos_sent', index=19, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='l2_point_to_point_hellos_received', index=20, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='l2_psnp_sent', index=21, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='l2_psnp_received', index=22, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='l2_csnp_sent', index=23, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='l2_csnp_received', index=24, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='l2_lsp_sent', index=25, number=25,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='l2_lsp_received', index=26, number=26,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=52323,
  serialized_end=52984,
)
_sym_db.RegisterEnumDescriptor(_ISISMETRICSREQUEST_COLUMNNAMES_ENUM)

_STATESREQUEST_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.StatesRequest.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ipv4_neighbors', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ipv6_neighbors', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=54714,
  serialized_end=54777,
)
_sym_db.RegisterEnumDescriptor(_STATESREQUEST_CHOICE_ENUM)

_STATESRESPONSE_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.StatesResponse.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ipv4_neighbors', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ipv6_neighbors', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=54714,
  serialized_end=54777,
)
_sym_db.RegisterEnumDescriptor(_STATESRESPONSE_CHOICE_ENUM)

_PATTERNFLOWETHERNETDST_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowEthernetDst.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWETHERNETDST_CHOICE_ENUM)

_PATTERNFLOWETHERNETSRC_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowEthernetSrc.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWETHERNETSRC_CHOICE_ENUM)

_PATTERNFLOWETHERNETETHERTYPE_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowEthernetEtherType.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='auto', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=57055,
  serialized_end=57141,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWETHERNETETHERTYPE_CHOICE_ENUM)

_PATTERNFLOWETHERNETETHERTYPE_AUTO_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowEthernetEtherType.Auto.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='auto', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=57151,
  serialized_end=57184,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWETHERNETETHERTYPE_AUTO_ENUM)

_PATTERNFLOWETHERNETPFCQUEUE_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowEthernetPfcQueue.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWETHERNETPFCQUEUE_CHOICE_ENUM)

_PATTERNFLOWVLANPRIORITY_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowVlanPriority.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWVLANPRIORITY_CHOICE_ENUM)

_PATTERNFLOWVLANCFI_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowVlanCfi.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWVLANCFI_CHOICE_ENUM)

_PATTERNFLOWVLANID_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowVlanId.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWVLANID_CHOICE_ENUM)

_PATTERNFLOWVLANTPID_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowVlanTpid.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWVLANTPID_CHOICE_ENUM)

_PATTERNFLOWVXLANFLAGS_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowVxlanFlags.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWVXLANFLAGS_CHOICE_ENUM)

_PATTERNFLOWVXLANRESERVED0_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowVxlanReserved0.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWVXLANRESERVED0_CHOICE_ENUM)

_PATTERNFLOWVXLANVNI_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowVxlanVni.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWVXLANVNI_CHOICE_ENUM)

_PATTERNFLOWVXLANRESERVED1_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowVxlanReserved1.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWVXLANRESERVED1_CHOICE_ENUM)

_PATTERNFLOWIPV4VERSION_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIpv4Version.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIPV4VERSION_CHOICE_ENUM)

_PATTERNFLOWIPV4HEADERLENGTH_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIpv4HeaderLength.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='auto', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=57055,
  serialized_end=57141,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIPV4HEADERLENGTH_CHOICE_ENUM)

_PATTERNFLOWIPV4HEADERLENGTH_AUTO_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIpv4HeaderLength.Auto.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='auto', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=57151,
  serialized_end=57184,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIPV4HEADERLENGTH_AUTO_ENUM)

_PATTERNFLOWIPV4TOTALLENGTH_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIpv4TotalLength.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='auto', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=57055,
  serialized_end=57141,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIPV4TOTALLENGTH_CHOICE_ENUM)

_PATTERNFLOWIPV4TOTALLENGTH_AUTO_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIpv4TotalLength.Auto.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='auto', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=57151,
  serialized_end=57184,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIPV4TOTALLENGTH_AUTO_ENUM)

_PATTERNFLOWIPV4IDENTIFICATION_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIpv4Identification.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIPV4IDENTIFICATION_CHOICE_ENUM)

_PATTERNFLOWIPV4RESERVED_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIpv4Reserved.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIPV4RESERVED_CHOICE_ENUM)

_PATTERNFLOWIPV4DONTFRAGMENT_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIpv4DontFragment.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIPV4DONTFRAGMENT_CHOICE_ENUM)

_PATTERNFLOWIPV4MOREFRAGMENTS_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIpv4MoreFragments.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIPV4MOREFRAGMENTS_CHOICE_ENUM)

_PATTERNFLOWIPV4FRAGMENTOFFSET_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIpv4FragmentOffset.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIPV4FRAGMENTOFFSET_CHOICE_ENUM)

_PATTERNFLOWIPV4TIMETOLIVE_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIpv4TimeToLive.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIPV4TIMETOLIVE_CHOICE_ENUM)

_PATTERNFLOWIPV4PROTOCOL_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIpv4Protocol.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='auto', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=57055,
  serialized_end=57141,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIPV4PROTOCOL_CHOICE_ENUM)

_PATTERNFLOWIPV4PROTOCOL_AUTO_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIpv4Protocol.Auto.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='auto', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=57151,
  serialized_end=57184,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIPV4PROTOCOL_AUTO_ENUM)

_PATTERNFLOWIPV4HEADERCHECKSUM_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIpv4HeaderChecksum.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='generated', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='custom', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=68408,
  serialized_end=68458,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIPV4HEADERCHECKSUM_CHOICE_ENUM)

_PATTERNFLOWIPV4HEADERCHECKSUM_GENERATED_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIpv4HeaderChecksum.Generated.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='good', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='bad', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=68473,
  serialized_end=68515,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIPV4HEADERCHECKSUM_GENERATED_ENUM)

_PATTERNFLOWIPV4SRC_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIpv4Src.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIPV4SRC_CHOICE_ENUM)

_PATTERNFLOWIPV4DST_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIpv4Dst.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIPV4DST_CHOICE_ENUM)

_PATTERNFLOWIPV4PRIORITYRAW_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIpv4PriorityRaw.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIPV4PRIORITYRAW_CHOICE_ENUM)

_PATTERNFLOWIPV4DSCPPHB_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIpv4DscpPhb.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIPV4DSCPPHB_CHOICE_ENUM)

_PATTERNFLOWIPV4DSCPECN_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIpv4DscpEcn.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIPV4DSCPECN_CHOICE_ENUM)

_PATTERNFLOWIPV4TOSPRECEDENCE_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIpv4TosPrecedence.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIPV4TOSPRECEDENCE_CHOICE_ENUM)

_PATTERNFLOWIPV4TOSDELAY_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIpv4TosDelay.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIPV4TOSDELAY_CHOICE_ENUM)

_PATTERNFLOWIPV4TOSTHROUGHPUT_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIpv4TosThroughput.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIPV4TOSTHROUGHPUT_CHOICE_ENUM)

_PATTERNFLOWIPV4TOSRELIABILITY_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIpv4TosReliability.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIPV4TOSRELIABILITY_CHOICE_ENUM)

_PATTERNFLOWIPV4TOSMONETARY_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIpv4TosMonetary.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIPV4TOSMONETARY_CHOICE_ENUM)

_PATTERNFLOWIPV4TOSUNUSED_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIpv4TosUnused.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIPV4TOSUNUSED_CHOICE_ENUM)

_PATTERNFLOWIPV6VERSION_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIpv6Version.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIPV6VERSION_CHOICE_ENUM)

_PATTERNFLOWIPV6TRAFFICCLASS_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIpv6TrafficClass.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIPV6TRAFFICCLASS_CHOICE_ENUM)

_PATTERNFLOWIPV6FLOWLABEL_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIpv6FlowLabel.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIPV6FLOWLABEL_CHOICE_ENUM)

_PATTERNFLOWIPV6PAYLOADLENGTH_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIpv6PayloadLength.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='auto', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=57055,
  serialized_end=57141,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIPV6PAYLOADLENGTH_CHOICE_ENUM)

_PATTERNFLOWIPV6PAYLOADLENGTH_AUTO_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIpv6PayloadLength.Auto.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='auto', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=57151,
  serialized_end=57184,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIPV6PAYLOADLENGTH_AUTO_ENUM)

_PATTERNFLOWIPV6NEXTHEADER_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIpv6NextHeader.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIPV6NEXTHEADER_CHOICE_ENUM)

_PATTERNFLOWIPV6HOPLIMIT_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIpv6HopLimit.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIPV6HOPLIMIT_CHOICE_ENUM)

_PATTERNFLOWIPV6SRC_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIpv6Src.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIPV6SRC_CHOICE_ENUM)

_PATTERNFLOWIPV6DST_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIpv6Dst.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIPV6DST_CHOICE_ENUM)

_PATTERNFLOWPFCPAUSEDST_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowPfcPauseDst.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWPFCPAUSEDST_CHOICE_ENUM)

_PATTERNFLOWPFCPAUSESRC_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowPfcPauseSrc.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWPFCPAUSESRC_CHOICE_ENUM)

_PATTERNFLOWPFCPAUSEETHERTYPE_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowPfcPauseEtherType.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWPFCPAUSEETHERTYPE_CHOICE_ENUM)

_PATTERNFLOWPFCPAUSECONTROLOPCODE_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowPfcPauseControlOpCode.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWPFCPAUSECONTROLOPCODE_CHOICE_ENUM)

_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowPfcPauseClassEnableVector.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR_CHOICE_ENUM)

_PATTERNFLOWPFCPAUSEPAUSECLASS0_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowPfcPausePauseClass0.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWPFCPAUSEPAUSECLASS0_CHOICE_ENUM)

_PATTERNFLOWPFCPAUSEPAUSECLASS1_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowPfcPausePauseClass1.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWPFCPAUSEPAUSECLASS1_CHOICE_ENUM)

_PATTERNFLOWPFCPAUSEPAUSECLASS2_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowPfcPausePauseClass2.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWPFCPAUSEPAUSECLASS2_CHOICE_ENUM)

_PATTERNFLOWPFCPAUSEPAUSECLASS3_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowPfcPausePauseClass3.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWPFCPAUSEPAUSECLASS3_CHOICE_ENUM)

_PATTERNFLOWPFCPAUSEPAUSECLASS4_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowPfcPausePauseClass4.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWPFCPAUSEPAUSECLASS4_CHOICE_ENUM)

_PATTERNFLOWPFCPAUSEPAUSECLASS5_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowPfcPausePauseClass5.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWPFCPAUSEPAUSECLASS5_CHOICE_ENUM)

_PATTERNFLOWPFCPAUSEPAUSECLASS6_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowPfcPausePauseClass6.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWPFCPAUSEPAUSECLASS6_CHOICE_ENUM)

_PATTERNFLOWPFCPAUSEPAUSECLASS7_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowPfcPausePauseClass7.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWPFCPAUSEPAUSECLASS7_CHOICE_ENUM)

_PATTERNFLOWETHERNETPAUSEDST_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowEthernetPauseDst.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWETHERNETPAUSEDST_CHOICE_ENUM)

_PATTERNFLOWETHERNETPAUSESRC_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowEthernetPauseSrc.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWETHERNETPAUSESRC_CHOICE_ENUM)

_PATTERNFLOWETHERNETPAUSEETHERTYPE_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowEthernetPauseEtherType.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWETHERNETPAUSEETHERTYPE_CHOICE_ENUM)

_PATTERNFLOWETHERNETPAUSECONTROLOPCODE_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowEthernetPauseControlOpCode.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWETHERNETPAUSECONTROLOPCODE_CHOICE_ENUM)

_PATTERNFLOWETHERNETPAUSETIME_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowEthernetPauseTime.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWETHERNETPAUSETIME_CHOICE_ENUM)

_PATTERNFLOWTCPSRCPORT_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowTcpSrcPort.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWTCPSRCPORT_CHOICE_ENUM)

_PATTERNFLOWTCPDSTPORT_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowTcpDstPort.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWTCPDSTPORT_CHOICE_ENUM)

_PATTERNFLOWTCPSEQNUM_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowTcpSeqNum.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWTCPSEQNUM_CHOICE_ENUM)

_PATTERNFLOWTCPACKNUM_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowTcpAckNum.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWTCPACKNUM_CHOICE_ENUM)

_PATTERNFLOWTCPDATAOFFSET_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowTcpDataOffset.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWTCPDATAOFFSET_CHOICE_ENUM)

_PATTERNFLOWTCPECNNS_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowTcpEcnNs.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWTCPECNNS_CHOICE_ENUM)

_PATTERNFLOWTCPECNCWR_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowTcpEcnCwr.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWTCPECNCWR_CHOICE_ENUM)

_PATTERNFLOWTCPECNECHO_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowTcpEcnEcho.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWTCPECNECHO_CHOICE_ENUM)

_PATTERNFLOWTCPCTLURG_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowTcpCtlUrg.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWTCPCTLURG_CHOICE_ENUM)

_PATTERNFLOWTCPCTLACK_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowTcpCtlAck.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWTCPCTLACK_CHOICE_ENUM)

_PATTERNFLOWTCPCTLPSH_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowTcpCtlPsh.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWTCPCTLPSH_CHOICE_ENUM)

_PATTERNFLOWTCPCTLRST_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowTcpCtlRst.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWTCPCTLRST_CHOICE_ENUM)

_PATTERNFLOWTCPCTLSYN_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowTcpCtlSyn.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWTCPCTLSYN_CHOICE_ENUM)

_PATTERNFLOWTCPCTLFIN_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowTcpCtlFin.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWTCPCTLFIN_CHOICE_ENUM)

_PATTERNFLOWTCPWINDOW_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowTcpWindow.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWTCPWINDOW_CHOICE_ENUM)

_PATTERNFLOWUDPSRCPORT_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowUdpSrcPort.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWUDPSRCPORT_CHOICE_ENUM)

_PATTERNFLOWUDPDSTPORT_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowUdpDstPort.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWUDPDSTPORT_CHOICE_ENUM)

_PATTERNFLOWUDPLENGTH_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowUdpLength.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWUDPLENGTH_CHOICE_ENUM)

_PATTERNFLOWUDPCHECKSUM_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowUdpChecksum.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='generated', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='custom', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=68408,
  serialized_end=68458,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWUDPCHECKSUM_CHOICE_ENUM)

_PATTERNFLOWUDPCHECKSUM_GENERATED_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowUdpChecksum.Generated.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='good', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='bad', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=68473,
  serialized_end=68515,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWUDPCHECKSUM_GENERATED_ENUM)

_PATTERNFLOWGRECHECKSUMPRESENT_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowGreChecksumPresent.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWGRECHECKSUMPRESENT_CHOICE_ENUM)

_PATTERNFLOWGRERESERVED0_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowGreReserved0.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWGRERESERVED0_CHOICE_ENUM)

_PATTERNFLOWGREVERSION_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowGreVersion.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWGREVERSION_CHOICE_ENUM)

_PATTERNFLOWGREPROTOCOL_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowGreProtocol.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWGREPROTOCOL_CHOICE_ENUM)

_PATTERNFLOWGRECHECKSUM_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowGreChecksum.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='generated', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='custom', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=68408,
  serialized_end=68458,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWGRECHECKSUM_CHOICE_ENUM)

_PATTERNFLOWGRECHECKSUM_GENERATED_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowGreChecksum.Generated.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='good', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='bad', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=68473,
  serialized_end=68515,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWGRECHECKSUM_GENERATED_ENUM)

_PATTERNFLOWGRERESERVED1_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowGreReserved1.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWGRERESERVED1_CHOICE_ENUM)

_PATTERNFLOWGTPV1VERSION_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowGtpv1Version.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWGTPV1VERSION_CHOICE_ENUM)

_PATTERNFLOWGTPV1PROTOCOLTYPE_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowGtpv1ProtocolType.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWGTPV1PROTOCOLTYPE_CHOICE_ENUM)

_PATTERNFLOWGTPV1RESERVED_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowGtpv1Reserved.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWGTPV1RESERVED_CHOICE_ENUM)

_PATTERNFLOWGTPV1EFLAG_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowGtpv1EFlag.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWGTPV1EFLAG_CHOICE_ENUM)

_PATTERNFLOWGTPV1SFLAG_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowGtpv1SFlag.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWGTPV1SFLAG_CHOICE_ENUM)

_PATTERNFLOWGTPV1PNFLAG_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowGtpv1PnFlag.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWGTPV1PNFLAG_CHOICE_ENUM)

_PATTERNFLOWGTPV1MESSAGETYPE_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowGtpv1MessageType.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWGTPV1MESSAGETYPE_CHOICE_ENUM)

_PATTERNFLOWGTPV1MESSAGELENGTH_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowGtpv1MessageLength.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWGTPV1MESSAGELENGTH_CHOICE_ENUM)

_PATTERNFLOWGTPV1TEID_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowGtpv1Teid.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWGTPV1TEID_CHOICE_ENUM)

_PATTERNFLOWGTPV1SQUENCENUMBER_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowGtpv1SquenceNumber.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWGTPV1SQUENCENUMBER_CHOICE_ENUM)

_PATTERNFLOWGTPV1NPDUNUMBER_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowGtpv1NPduNumber.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWGTPV1NPDUNUMBER_CHOICE_ENUM)

_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowGtpv1NextExtensionHeaderType.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE_CHOICE_ENUM)

_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowGtpExtensionExtensionLength.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH_CHOICE_ENUM)

_PATTERNFLOWGTPEXTENSIONCONTENTS_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowGtpExtensionContents.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWGTPEXTENSIONCONTENTS_CHOICE_ENUM)

_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowGtpExtensionNextExtensionHeader.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER_CHOICE_ENUM)

_PATTERNFLOWGTPV2VERSION_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowGtpv2Version.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWGTPV2VERSION_CHOICE_ENUM)

_PATTERNFLOWGTPV2PIGGYBACKINGFLAG_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowGtpv2PiggybackingFlag.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWGTPV2PIGGYBACKINGFLAG_CHOICE_ENUM)

_PATTERNFLOWGTPV2TEIDFLAG_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowGtpv2TeidFlag.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWGTPV2TEIDFLAG_CHOICE_ENUM)

_PATTERNFLOWGTPV2SPARE1_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowGtpv2Spare1.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWGTPV2SPARE1_CHOICE_ENUM)

_PATTERNFLOWGTPV2MESSAGETYPE_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowGtpv2MessageType.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWGTPV2MESSAGETYPE_CHOICE_ENUM)

_PATTERNFLOWGTPV2MESSAGELENGTH_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowGtpv2MessageLength.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWGTPV2MESSAGELENGTH_CHOICE_ENUM)

_PATTERNFLOWGTPV2TEID_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowGtpv2Teid.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWGTPV2TEID_CHOICE_ENUM)

_PATTERNFLOWGTPV2SEQUENCENUMBER_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowGtpv2SequenceNumber.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWGTPV2SEQUENCENUMBER_CHOICE_ENUM)

_PATTERNFLOWGTPV2SPARE2_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowGtpv2Spare2.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWGTPV2SPARE2_CHOICE_ENUM)

_PATTERNFLOWARPHARDWARETYPE_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowArpHardwareType.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWARPHARDWARETYPE_CHOICE_ENUM)

_PATTERNFLOWARPPROTOCOLTYPE_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowArpProtocolType.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWARPPROTOCOLTYPE_CHOICE_ENUM)

_PATTERNFLOWARPHARDWARELENGTH_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowArpHardwareLength.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWARPHARDWARELENGTH_CHOICE_ENUM)

_PATTERNFLOWARPPROTOCOLLENGTH_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowArpProtocolLength.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWARPPROTOCOLLENGTH_CHOICE_ENUM)

_PATTERNFLOWARPOPERATION_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowArpOperation.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWARPOPERATION_CHOICE_ENUM)

_PATTERNFLOWARPSENDERHARDWAREADDR_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowArpSenderHardwareAddr.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWARPSENDERHARDWAREADDR_CHOICE_ENUM)

_PATTERNFLOWARPSENDERPROTOCOLADDR_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowArpSenderProtocolAddr.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWARPSENDERPROTOCOLADDR_CHOICE_ENUM)

_PATTERNFLOWARPTARGETHARDWAREADDR_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowArpTargetHardwareAddr.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWARPTARGETHARDWAREADDR_CHOICE_ENUM)

_PATTERNFLOWARPTARGETPROTOCOLADDR_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowArpTargetProtocolAddr.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWARPTARGETPROTOCOLADDR_CHOICE_ENUM)

_PATTERNFLOWICMPECHOTYPE_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIcmpEchoType.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWICMPECHOTYPE_CHOICE_ENUM)

_PATTERNFLOWICMPECHOCODE_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIcmpEchoCode.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWICMPECHOCODE_CHOICE_ENUM)

_PATTERNFLOWICMPECHOCHECKSUM_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIcmpEchoChecksum.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='generated', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='custom', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=68408,
  serialized_end=68458,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWICMPECHOCHECKSUM_CHOICE_ENUM)

_PATTERNFLOWICMPECHOCHECKSUM_GENERATED_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIcmpEchoChecksum.Generated.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='good', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='bad', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=68473,
  serialized_end=68515,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWICMPECHOCHECKSUM_GENERATED_ENUM)

_PATTERNFLOWICMPECHOIDENTIFIER_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIcmpEchoIdentifier.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWICMPECHOIDENTIFIER_CHOICE_ENUM)

_PATTERNFLOWICMPECHOSEQUENCENUMBER_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIcmpEchoSequenceNumber.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWICMPECHOSEQUENCENUMBER_CHOICE_ENUM)

_PATTERNFLOWICMPCOMMONCHECKSUM_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIcmpCommonChecksum.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='generated', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='custom', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=68408,
  serialized_end=68458,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWICMPCOMMONCHECKSUM_CHOICE_ENUM)

_PATTERNFLOWICMPCOMMONCHECKSUM_GENERATED_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIcmpCommonChecksum.Generated.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='good', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='bad', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=68473,
  serialized_end=68515,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWICMPCOMMONCHECKSUM_GENERATED_ENUM)

_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIcmpNextFieldsIdentifier.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER_CHOICE_ENUM)

_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIcmpNextFieldsSequenceNumber.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER_CHOICE_ENUM)

_PATTERNFLOWICMPV6ECHOTYPE_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIcmpv6EchoType.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWICMPV6ECHOTYPE_CHOICE_ENUM)

_PATTERNFLOWICMPV6ECHOCODE_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIcmpv6EchoCode.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWICMPV6ECHOCODE_CHOICE_ENUM)

_PATTERNFLOWICMPV6ECHOIDENTIFIER_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIcmpv6EchoIdentifier.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWICMPV6ECHOIDENTIFIER_CHOICE_ENUM)

_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIcmpv6EchoSequenceNumber.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER_CHOICE_ENUM)

_PATTERNFLOWICMPV6ECHOCHECKSUM_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIcmpv6EchoChecksum.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='generated', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='custom', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=68408,
  serialized_end=68458,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWICMPV6ECHOCHECKSUM_CHOICE_ENUM)

_PATTERNFLOWICMPV6ECHOCHECKSUM_GENERATED_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIcmpv6EchoChecksum.Generated.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='good', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='bad', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=68473,
  serialized_end=68515,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWICMPV6ECHOCHECKSUM_GENERATED_ENUM)

_PATTERNFLOWICMPV6COMMONCHECKSUM_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIcmpv6CommonChecksum.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='generated', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='custom', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=68408,
  serialized_end=68458,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWICMPV6COMMONCHECKSUM_CHOICE_ENUM)

_PATTERNFLOWICMPV6COMMONCHECKSUM_GENERATED_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIcmpv6CommonChecksum.Generated.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='good', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='bad', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=68473,
  serialized_end=68515,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWICMPV6COMMONCHECKSUM_GENERATED_ENUM)

_PATTERNFLOWPPPADDRESS_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowPppAddress.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWPPPADDRESS_CHOICE_ENUM)

_PATTERNFLOWPPPCONTROL_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowPppControl.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWPPPCONTROL_CHOICE_ENUM)

_PATTERNFLOWPPPPROTOCOLTYPE_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowPppProtocolType.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='auto', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=57055,
  serialized_end=57141,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWPPPPROTOCOLTYPE_CHOICE_ENUM)

_PATTERNFLOWPPPPROTOCOLTYPE_AUTO_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowPppProtocolType.Auto.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='auto', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=57151,
  serialized_end=57184,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWPPPPROTOCOLTYPE_AUTO_ENUM)

_PATTERNFLOWIGMPV1VERSION_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIgmpv1Version.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIGMPV1VERSION_CHOICE_ENUM)

_PATTERNFLOWIGMPV1TYPE_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIgmpv1Type.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIGMPV1TYPE_CHOICE_ENUM)

_PATTERNFLOWIGMPV1UNUSED_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIgmpv1Unused.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIGMPV1UNUSED_CHOICE_ENUM)

_PATTERNFLOWIGMPV1CHECKSUM_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIgmpv1Checksum.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='generated', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='custom', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=68408,
  serialized_end=68458,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIGMPV1CHECKSUM_CHOICE_ENUM)

_PATTERNFLOWIGMPV1CHECKSUM_GENERATED_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIgmpv1Checksum.Generated.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='good', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='bad', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=68473,
  serialized_end=68515,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIGMPV1CHECKSUM_GENERATED_ENUM)

_PATTERNFLOWIGMPV1GROUPADDRESS_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='otg.PatternFlowIgmpv1GroupAddress.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='value', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='values', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='increment', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='decrement', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55867,
  serialized_end=55943,
)
_sym_db.RegisterEnumDescriptor(_PATTERNFLOWIGMPV1GROUPADDRESS_CHOICE_ENUM)


_CONFIG = _descriptor.Descriptor(
  name='Config',
  full_name='otg.Config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ports', full_name='otg.Config.ports', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lags', full_name='otg.Config.lags', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='layer1', full_name='otg.Config.layer1', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='captures', full_name='otg.Config.captures', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='devices', full_name='otg.Config.devices', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flows', full_name='otg.Config.flows', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='events', full_name='otg.Config.events', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='otg.Config.options', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_events', full_name='otg.Config._events',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_options', full_name='otg.Config._options',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=82,
  serialized_end=355,
)


_CONFIGOPTIONS = _descriptor.Descriptor(
  name='ConfigOptions',
  full_name='otg.ConfigOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port_options', full_name='otg.ConfigOptions.port_options', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_port_options', full_name='otg.ConfigOptions._port_options',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=357,
  serialized_end=434,
)


_PORT = _descriptor.Descriptor(
  name='Port',
  full_name='otg.Port',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='location', full_name='otg.Port.location', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='otg.Port.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_location', full_name='otg.Port._location',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=436,
  serialized_end=492,
)


_PORTOPTIONS = _descriptor.Descriptor(
  name='PortOptions',
  full_name='otg.PortOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='location_preemption', full_name='otg.PortOptions.location_preemption', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_location_preemption', full_name='otg.PortOptions._location_preemption',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=494,
  serialized_end=565,
)


_LAG = _descriptor.Descriptor(
  name='Lag',
  full_name='otg.Lag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ports', full_name='otg.Lag.ports', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='otg.Lag.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=567,
  serialized_end=615,
)


_LAGPORT = _descriptor.Descriptor(
  name='LagPort',
  full_name='otg.LagPort',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port_name', full_name='otg.LagPort.port_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='otg.LagPort.protocol', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ethernet', full_name='otg.LagPort.ethernet', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=617,
  serialized_end=724,
)


_LAGPROTOCOL_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.LagProtocol.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LAGPROTOCOL_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=863,
  serialized_end=918,
)

_LAGPROTOCOL = _descriptor.Descriptor(
  name='LagProtocol',
  full_name='otg.LagProtocol',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.LagProtocol.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lacp', full_name='otg.LagProtocol.lacp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='static', full_name='otg.LagProtocol.static', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LAGPROTOCOL_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.LagProtocol._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_lacp', full_name='otg.LagProtocol._lacp',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_static', full_name='otg.LagProtocol._static',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=727,
  serialized_end=949,
)


_LAGSTATIC = _descriptor.Descriptor(
  name='LagStatic',
  full_name='otg.LagStatic',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lag_id', full_name='otg.LagStatic.lag_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_lag_id', full_name='otg.LagStatic._lag_id',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=951,
  serialized_end=994,
)


_LAGLACP_ACTORACTIVITY = _descriptor.Descriptor(
  name='ActorActivity',
  full_name='otg.LagLacp.ActorActivity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LAGLACP_ACTORACTIVITY_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1299,
  serialized_end=1364,
)

_LAGLACP = _descriptor.Descriptor(
  name='LagLacp',
  full_name='otg.LagLacp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='actor_key', full_name='otg.LagLacp.actor_key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actor_port_number', full_name='otg.LagLacp.actor_port_number', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actor_port_priority', full_name='otg.LagLacp.actor_port_priority', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actor_system_id', full_name='otg.LagLacp.actor_system_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actor_system_priority', full_name='otg.LagLacp.actor_system_priority', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lacpdu_periodic_time_interval', full_name='otg.LagLacp.lacpdu_periodic_time_interval', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lacpdu_timeout', full_name='otg.LagLacp.lacpdu_timeout', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actor_activity', full_name='otg.LagLacp.actor_activity', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LAGLACP_ACTORACTIVITY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_actor_key', full_name='otg.LagLacp._actor_key',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_actor_port_number', full_name='otg.LagLacp._actor_port_number',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_actor_port_priority', full_name='otg.LagLacp._actor_port_priority',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_actor_system_id', full_name='otg.LagLacp._actor_system_id',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_actor_system_priority', full_name='otg.LagLacp._actor_system_priority',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_lacpdu_periodic_time_interval', full_name='otg.LagLacp._lacpdu_periodic_time_interval',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_lacpdu_timeout', full_name='otg.LagLacp._lacpdu_timeout',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_actor_activity', full_name='otg.LagLacp._actor_activity',
      index=7, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=997,
  serialized_end=1542,
)


_DEVICEETHERNETBASE = _descriptor.Descriptor(
  name='DeviceEthernetBase',
  full_name='otg.DeviceEthernetBase',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mac', full_name='otg.DeviceEthernetBase.mac', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mtu', full_name='otg.DeviceEthernetBase.mtu', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vlans', full_name='otg.DeviceEthernetBase.vlans', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='otg.DeviceEthernetBase.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_mtu', full_name='otg.DeviceEthernetBase._mtu',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1544,
  serialized_end=1649,
)


_DEVICEETHERNET = _descriptor.Descriptor(
  name='DeviceEthernet',
  full_name='otg.DeviceEthernet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port_name', full_name='otg.DeviceEthernet.port_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv4_addresses', full_name='otg.DeviceEthernet.ipv4_addresses', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv6_addresses', full_name='otg.DeviceEthernet.ipv6_addresses', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mac', full_name='otg.DeviceEthernet.mac', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mtu', full_name='otg.DeviceEthernet.mtu', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vlans', full_name='otg.DeviceEthernet.vlans', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='otg.DeviceEthernet.name', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_mtu', full_name='otg.DeviceEthernet._mtu',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1652,
  serialized_end=1854,
)


_DEVICEVLAN_TPID = _descriptor.Descriptor(
  name='Tpid',
  full_name='otg.DeviceVlan.Tpid',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DEVICEVLAN_TPID_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1971,
  serialized_end=2057,
)

_DEVICEVLAN = _descriptor.Descriptor(
  name='DeviceVlan',
  full_name='otg.DeviceVlan',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tpid', full_name='otg.DeviceVlan.tpid', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority', full_name='otg.DeviceVlan.priority', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='otg.DeviceVlan.id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='otg.DeviceVlan.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DEVICEVLAN_TPID, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_tpid', full_name='otg.DeviceVlan._tpid',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_priority', full_name='otg.DeviceVlan._priority',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_id', full_name='otg.DeviceVlan._id',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1857,
  serialized_end=2086,
)


_DEVICEIPV4 = _descriptor.Descriptor(
  name='DeviceIpv4',
  full_name='otg.DeviceIpv4',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gateway', full_name='otg.DeviceIpv4.gateway', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='otg.DeviceIpv4.address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefix', full_name='otg.DeviceIpv4.prefix', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='otg.DeviceIpv4.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_prefix', full_name='otg.DeviceIpv4._prefix',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2088,
  serialized_end=2180,
)


_DEVICEIPV4LOOPBACK = _descriptor.Descriptor(
  name='DeviceIpv4Loopback',
  full_name='otg.DeviceIpv4Loopback',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eth_name', full_name='otg.DeviceIpv4Loopback.eth_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='otg.DeviceIpv4Loopback.address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='otg.DeviceIpv4Loopback.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_address', full_name='otg.DeviceIpv4Loopback._address',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2182,
  serialized_end=2268,
)


_DEVICEIPV6 = _descriptor.Descriptor(
  name='DeviceIpv6',
  full_name='otg.DeviceIpv6',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gateway', full_name='otg.DeviceIpv6.gateway', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='otg.DeviceIpv6.address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefix', full_name='otg.DeviceIpv6.prefix', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='otg.DeviceIpv6.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_prefix', full_name='otg.DeviceIpv6._prefix',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2270,
  serialized_end=2362,
)


_DEVICEIPV6LOOPBACK = _descriptor.Descriptor(
  name='DeviceIpv6Loopback',
  full_name='otg.DeviceIpv6Loopback',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eth_name', full_name='otg.DeviceIpv6Loopback.eth_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='otg.DeviceIpv6Loopback.address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='otg.DeviceIpv6Loopback.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_address', full_name='otg.DeviceIpv6Loopback._address',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2364,
  serialized_end=2450,
)


_LAYER1_SPEED = _descriptor.Descriptor(
  name='Speed',
  full_name='otg.Layer1.Speed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LAYER1_SPEED_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2803,
  serialized_end=3080,
)

_LAYER1_MEDIA = _descriptor.Descriptor(
  name='Media',
  full_name='otg.Layer1.Media',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LAYER1_MEDIA_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3082,
  serialized_end=3148,
)

_LAYER1 = _descriptor.Descriptor(
  name='Layer1',
  full_name='otg.Layer1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port_names', full_name='otg.Layer1.port_names', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed', full_name='otg.Layer1.speed', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='media', full_name='otg.Layer1.media', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='promiscuous', full_name='otg.Layer1.promiscuous', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mtu', full_name='otg.Layer1.mtu', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ieee_media_defaults', full_name='otg.Layer1.ieee_media_defaults', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_negotiate', full_name='otg.Layer1.auto_negotiate', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_negotiation', full_name='otg.Layer1.auto_negotiation', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flow_control', full_name='otg.Layer1.flow_control', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='otg.Layer1.name', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LAYER1_SPEED, _LAYER1_MEDIA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_speed', full_name='otg.Layer1._speed',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_media', full_name='otg.Layer1._media',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_promiscuous', full_name='otg.Layer1._promiscuous',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_mtu', full_name='otg.Layer1._mtu',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ieee_media_defaults', full_name='otg.Layer1._ieee_media_defaults',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_auto_negotiate', full_name='otg.Layer1._auto_negotiate',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_auto_negotiation', full_name='otg.Layer1._auto_negotiation',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_flow_control', full_name='otg.Layer1._flow_control',
      index=7, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2453,
  serialized_end=3273,
)


_LAYER1AUTONEGOTIATION = _descriptor.Descriptor(
  name='Layer1AutoNegotiation',
  full_name='otg.Layer1AutoNegotiation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='advertise_1000_mbps', full_name='otg.Layer1AutoNegotiation.advertise_1000_mbps', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='advertise_100_fd_mbps', full_name='otg.Layer1AutoNegotiation.advertise_100_fd_mbps', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='advertise_100_hd_mbps', full_name='otg.Layer1AutoNegotiation.advertise_100_hd_mbps', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='advertise_10_fd_mbps', full_name='otg.Layer1AutoNegotiation.advertise_10_fd_mbps', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='advertise_10_hd_mbps', full_name='otg.Layer1AutoNegotiation.advertise_10_hd_mbps', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link_training', full_name='otg.Layer1AutoNegotiation.link_training', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rs_fec', full_name='otg.Layer1AutoNegotiation.rs_fec', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_advertise_1000_mbps', full_name='otg.Layer1AutoNegotiation._advertise_1000_mbps',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_advertise_100_fd_mbps', full_name='otg.Layer1AutoNegotiation._advertise_100_fd_mbps',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_advertise_100_hd_mbps', full_name='otg.Layer1AutoNegotiation._advertise_100_hd_mbps',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_advertise_10_fd_mbps', full_name='otg.Layer1AutoNegotiation._advertise_10_fd_mbps',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_advertise_10_hd_mbps', full_name='otg.Layer1AutoNegotiation._advertise_10_hd_mbps',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_link_training', full_name='otg.Layer1AutoNegotiation._link_training',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_rs_fec', full_name='otg.Layer1AutoNegotiation._rs_fec',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3276,
  serialized_end=3679,
)


_LAYER1FLOWCONTROL_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.Layer1FlowControl.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LAYER1FLOWCONTROL_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3891,
  serialized_end=3960,
)

_LAYER1FLOWCONTROL = _descriptor.Descriptor(
  name='Layer1FlowControl',
  full_name='otg.Layer1FlowControl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='directed_address', full_name='otg.Layer1FlowControl.directed_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.Layer1FlowControl.choice', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ieee_802_1qbb', full_name='otg.Layer1FlowControl.ieee_802_1qbb', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ieee_802_3x', full_name='otg.Layer1FlowControl.ieee_802_3x', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LAYER1FLOWCONTROL_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_directed_address', full_name='otg.Layer1FlowControl._directed_address',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.Layer1FlowControl._choice',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ieee_802_1qbb', full_name='otg.Layer1FlowControl._ieee_802_1qbb',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ieee_802_3x', full_name='otg.Layer1FlowControl._ieee_802_3x',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3682,
  serialized_end=4026,
)


_LAYER1IEEE8023X = _descriptor.Descriptor(
  name='Layer1Ieee8023x',
  full_name='otg.Layer1Ieee8023x',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4028,
  serialized_end=4045,
)


_LAYER1IEEE8021QBB = _descriptor.Descriptor(
  name='Layer1Ieee8021qbb',
  full_name='otg.Layer1Ieee8021qbb',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pfc_delay', full_name='otg.Layer1Ieee8021qbb.pfc_delay', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pfc_class_0', full_name='otg.Layer1Ieee8021qbb.pfc_class_0', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pfc_class_1', full_name='otg.Layer1Ieee8021qbb.pfc_class_1', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pfc_class_2', full_name='otg.Layer1Ieee8021qbb.pfc_class_2', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pfc_class_3', full_name='otg.Layer1Ieee8021qbb.pfc_class_3', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pfc_class_4', full_name='otg.Layer1Ieee8021qbb.pfc_class_4', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pfc_class_5', full_name='otg.Layer1Ieee8021qbb.pfc_class_5', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pfc_class_6', full_name='otg.Layer1Ieee8021qbb.pfc_class_6', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pfc_class_7', full_name='otg.Layer1Ieee8021qbb.pfc_class_7', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_pfc_delay', full_name='otg.Layer1Ieee8021qbb._pfc_delay',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_pfc_class_0', full_name='otg.Layer1Ieee8021qbb._pfc_class_0',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_pfc_class_1', full_name='otg.Layer1Ieee8021qbb._pfc_class_1',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_pfc_class_2', full_name='otg.Layer1Ieee8021qbb._pfc_class_2',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_pfc_class_3', full_name='otg.Layer1Ieee8021qbb._pfc_class_3',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_pfc_class_4', full_name='otg.Layer1Ieee8021qbb._pfc_class_4',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_pfc_class_5', full_name='otg.Layer1Ieee8021qbb._pfc_class_5',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_pfc_class_6', full_name='otg.Layer1Ieee8021qbb._pfc_class_6',
      index=7, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_pfc_class_7', full_name='otg.Layer1Ieee8021qbb._pfc_class_7',
      index=8, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4048,
  serialized_end=4441,
)


_CAPTURE_FORMAT = _descriptor.Descriptor(
  name='Format',
  full_name='otg.Capture.Format',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CAPTURE_FORMAT_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4623,
  serialized_end=4678,
)

_CAPTURE = _descriptor.Descriptor(
  name='Capture',
  full_name='otg.Capture',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port_names', full_name='otg.Capture.port_names', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='otg.Capture.filters', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overwrite', full_name='otg.Capture.overwrite', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packet_size', full_name='otg.Capture.packet_size', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='format', full_name='otg.Capture.format', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='otg.Capture.name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CAPTURE_FORMAT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_overwrite', full_name='otg.Capture._overwrite',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_packet_size', full_name='otg.Capture._packet_size',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_format', full_name='otg.Capture._format',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4444,
  serialized_end=4719,
)


_CAPTUREFILTER_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.CaptureFilter.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CAPTUREFILTER_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4989,
  serialized_end=5078,
)

_CAPTUREFILTER = _descriptor.Descriptor(
  name='CaptureFilter',
  full_name='otg.CaptureFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.CaptureFilter.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom', full_name='otg.CaptureFilter.custom', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ethernet', full_name='otg.CaptureFilter.ethernet', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vlan', full_name='otg.CaptureFilter.vlan', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv4', full_name='otg.CaptureFilter.ipv4', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv6', full_name='otg.CaptureFilter.ipv6', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CAPTUREFILTER_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.CaptureFilter._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_custom', full_name='otg.CaptureFilter._custom',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ethernet', full_name='otg.CaptureFilter._ethernet',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_vlan', full_name='otg.CaptureFilter._vlan',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ipv4', full_name='otg.CaptureFilter._ipv4',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ipv6', full_name='otg.CaptureFilter._ipv6',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4722,
  serialized_end=5140,
)


_CAPTURECUSTOM = _descriptor.Descriptor(
  name='CaptureCustom',
  full_name='otg.CaptureCustom',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='otg.CaptureCustom.offset', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bit_length', full_name='otg.CaptureCustom.bit_length', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.CaptureCustom.value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mask', full_name='otg.CaptureCustom.mask', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='negate', full_name='otg.CaptureCustom.negate', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_offset', full_name='otg.CaptureCustom._offset',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_bit_length', full_name='otg.CaptureCustom._bit_length',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.CaptureCustom._value',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_mask', full_name='otg.CaptureCustom._mask',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_negate', full_name='otg.CaptureCustom._negate',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=5143,
  serialized_end=5320,
)


_CAPTUREFIELD = _descriptor.Descriptor(
  name='CaptureField',
  full_name='otg.CaptureField',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.CaptureField.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mask', full_name='otg.CaptureField.mask', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='negate', full_name='otg.CaptureField.negate', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.CaptureField._value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_mask', full_name='otg.CaptureField._mask',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_negate', full_name='otg.CaptureField._negate',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=5322,
  serialized_end=5426,
)


_CAPTUREETHERNET = _descriptor.Descriptor(
  name='CaptureEthernet',
  full_name='otg.CaptureEthernet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='src', full_name='otg.CaptureEthernet.src', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dst', full_name='otg.CaptureEthernet.dst', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ether_type', full_name='otg.CaptureEthernet.ether_type', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pfc_queue', full_name='otg.CaptureEthernet.pfc_queue', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_src', full_name='otg.CaptureEthernet._src',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_dst', full_name='otg.CaptureEthernet._dst',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ether_type', full_name='otg.CaptureEthernet._ether_type',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_pfc_queue', full_name='otg.CaptureEthernet._pfc_queue',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=5429,
  serialized_end=5652,
)


_CAPTUREVLAN = _descriptor.Descriptor(
  name='CaptureVlan',
  full_name='otg.CaptureVlan',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='priority', full_name='otg.CaptureVlan.priority', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cfi', full_name='otg.CaptureVlan.cfi', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='otg.CaptureVlan.id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='otg.CaptureVlan.protocol', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_priority', full_name='otg.CaptureVlan._priority',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_cfi', full_name='otg.CaptureVlan._cfi',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_id', full_name='otg.CaptureVlan._id',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_protocol', full_name='otg.CaptureVlan._protocol',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=5655,
  serialized_end=5866,
)


_CAPTUREIPV4 = _descriptor.Descriptor(
  name='CaptureIpv4',
  full_name='otg.CaptureIpv4',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='otg.CaptureIpv4.version', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header_length', full_name='otg.CaptureIpv4.header_length', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority', full_name='otg.CaptureIpv4.priority', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_length', full_name='otg.CaptureIpv4.total_length', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='identification', full_name='otg.CaptureIpv4.identification', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reserved', full_name='otg.CaptureIpv4.reserved', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dont_fragment', full_name='otg.CaptureIpv4.dont_fragment', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='more_fragments', full_name='otg.CaptureIpv4.more_fragments', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fragment_offset', full_name='otg.CaptureIpv4.fragment_offset', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_to_live', full_name='otg.CaptureIpv4.time_to_live', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='otg.CaptureIpv4.protocol', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header_checksum', full_name='otg.CaptureIpv4.header_checksum', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='src', full_name='otg.CaptureIpv4.src', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dst', full_name='otg.CaptureIpv4.dst', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_version', full_name='otg.CaptureIpv4._version',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_header_length', full_name='otg.CaptureIpv4._header_length',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_priority', full_name='otg.CaptureIpv4._priority',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_total_length', full_name='otg.CaptureIpv4._total_length',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_identification', full_name='otg.CaptureIpv4._identification',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_reserved', full_name='otg.CaptureIpv4._reserved',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_dont_fragment', full_name='otg.CaptureIpv4._dont_fragment',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_more_fragments', full_name='otg.CaptureIpv4._more_fragments',
      index=7, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_fragment_offset', full_name='otg.CaptureIpv4._fragment_offset',
      index=8, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_time_to_live', full_name='otg.CaptureIpv4._time_to_live',
      index=9, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_protocol', full_name='otg.CaptureIpv4._protocol',
      index=10, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_header_checksum', full_name='otg.CaptureIpv4._header_checksum',
      index=11, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_src', full_name='otg.CaptureIpv4._src',
      index=12, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_dst', full_name='otg.CaptureIpv4._dst',
      index=13, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=5869,
  serialized_end=6718,
)


_CAPTUREIPV6 = _descriptor.Descriptor(
  name='CaptureIpv6',
  full_name='otg.CaptureIpv6',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='otg.CaptureIpv6.version', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic_class', full_name='otg.CaptureIpv6.traffic_class', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flow_label', full_name='otg.CaptureIpv6.flow_label', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload_length', full_name='otg.CaptureIpv6.payload_length', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_header', full_name='otg.CaptureIpv6.next_header', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hop_limit', full_name='otg.CaptureIpv6.hop_limit', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='src', full_name='otg.CaptureIpv6.src', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dst', full_name='otg.CaptureIpv6.dst', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_version', full_name='otg.CaptureIpv6._version',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_traffic_class', full_name='otg.CaptureIpv6._traffic_class',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_flow_label', full_name='otg.CaptureIpv6._flow_label',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_payload_length', full_name='otg.CaptureIpv6._payload_length',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_next_header', full_name='otg.CaptureIpv6._next_header',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_hop_limit', full_name='otg.CaptureIpv6._hop_limit',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_src', full_name='otg.CaptureIpv6._src',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_dst', full_name='otg.CaptureIpv6._dst',
      index=7, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=6721,
  serialized_end=7186,
)


_DEVICE = _descriptor.Descriptor(
  name='Device',
  full_name='otg.Device',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ethernets', full_name='otg.Device.ethernets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv4_loopbacks', full_name='otg.Device.ipv4_loopbacks', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv6_loopbacks', full_name='otg.Device.ipv6_loopbacks', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isis', full_name='otg.Device.isis', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bgp', full_name='otg.Device.bgp', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='otg.Device.name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_isis', full_name='otg.Device._isis',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_bgp', full_name='otg.Device._bgp',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=7189,
  serialized_end=7448,
)


_DEVICEISISROUTER = _descriptor.Descriptor(
  name='DeviceIsisRouter',
  full_name='otg.DeviceIsisRouter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='otg.DeviceIsisRouter.instance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='system_id', full_name='otg.DeviceIsisRouter.system_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interfaces', full_name='otg.DeviceIsisRouter.interfaces', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='basic', full_name='otg.DeviceIsisRouter.basic', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='advanced', full_name='otg.DeviceIsisRouter.advanced', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='router_auth', full_name='otg.DeviceIsisRouter.router_auth', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v4_routes', full_name='otg.DeviceIsisRouter.v4_routes', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v6_routes', full_name='otg.DeviceIsisRouter.v6_routes', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='otg.DeviceIsisRouter.name', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_instance', full_name='otg.DeviceIsisRouter._instance',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_basic', full_name='otg.DeviceIsisRouter._basic',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_advanced', full_name='otg.DeviceIsisRouter._advanced',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_router_auth', full_name='otg.DeviceIsisRouter._router_auth',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=7451,
  serialized_end=7860,
)


_DEVICEISISMULTIINSTANCE = _descriptor.Descriptor(
  name='DeviceIsisMultiInstance',
  full_name='otg.DeviceIsisMultiInstance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='iid', full_name='otg.DeviceIsisMultiInstance.iid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='itids', full_name='otg.DeviceIsisMultiInstance.itids', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_iid', full_name='otg.DeviceIsisMultiInstance._iid',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=7862,
  serialized_end=7928,
)


_ISISINTERFACE_NETWORKTYPE = _descriptor.Descriptor(
  name='NetworkType',
  full_name='otg.IsisInterface.NetworkType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ISISINTERFACE_NETWORKTYPE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8514,
  serialized_end=8587,
)

_ISISINTERFACE_LEVELTYPE = _descriptor.Descriptor(
  name='LevelType',
  full_name='otg.IsisInterface.LevelType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ISISINTERFACE_LEVELTYPE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8589,
  serialized_end=8666,
)

_ISISINTERFACE = _descriptor.Descriptor(
  name='IsisInterface',
  full_name='otg.IsisInterface',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eth_name', full_name='otg.IsisInterface.eth_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric', full_name='otg.IsisInterface.metric', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_type', full_name='otg.IsisInterface.network_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='level_type', full_name='otg.IsisInterface.level_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='l1_settings', full_name='otg.IsisInterface.l1_settings', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='l2_settings', full_name='otg.IsisInterface.l2_settings', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='multi_topology_ids', full_name='otg.IsisInterface.multi_topology_ids', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic_engineering', full_name='otg.IsisInterface.traffic_engineering', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authentication', full_name='otg.IsisInterface.authentication', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='advanced', full_name='otg.IsisInterface.advanced', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link_protection', full_name='otg.IsisInterface.link_protection', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='srlg_values', full_name='otg.IsisInterface.srlg_values', index=11,
      number=12, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='otg.IsisInterface.name', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ISISINTERFACE_NETWORKTYPE, _ISISINTERFACE_LEVELTYPE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_metric', full_name='otg.IsisInterface._metric',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_network_type', full_name='otg.IsisInterface._network_type',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_level_type', full_name='otg.IsisInterface._level_type',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_l1_settings', full_name='otg.IsisInterface._l1_settings',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_l2_settings', full_name='otg.IsisInterface._l2_settings',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_authentication', full_name='otg.IsisInterface._authentication',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_advanced', full_name='otg.IsisInterface._advanced',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_link_protection', full_name='otg.IsisInterface._link_protection',
      index=7, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=7931,
  serialized_end=8793,
)


_ISISINTERFACELEVEL = _descriptor.Descriptor(
  name='IsisInterfaceLevel',
  full_name='otg.IsisInterfaceLevel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='priority', full_name='otg.IsisInterfaceLevel.priority', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hello_interval', full_name='otg.IsisInterfaceLevel.hello_interval', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dead_interval', full_name='otg.IsisInterfaceLevel.dead_interval', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_priority', full_name='otg.IsisInterfaceLevel._priority',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_hello_interval', full_name='otg.IsisInterfaceLevel._hello_interval',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_dead_interval', full_name='otg.IsisInterfaceLevel._dead_interval',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=8796,
  serialized_end=8946,
)


_ISISMT = _descriptor.Descriptor(
  name='IsisMT',
  full_name='otg.IsisMT',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mt_id', full_name='otg.IsisMT.mt_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link_metric', full_name='otg.IsisMT.link_metric', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_mt_id', full_name='otg.IsisMT._mt_id',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_link_metric', full_name='otg.IsisMT._link_metric',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=8948,
  serialized_end=9028,
)


_LINKSTATETE = _descriptor.Descriptor(
  name='LinkStateTE',
  full_name='otg.LinkStateTE',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='administrative_group', full_name='otg.LinkStateTE.administrative_group', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_level', full_name='otg.LinkStateTE.metric_level', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_bandwith', full_name='otg.LinkStateTE.max_bandwith', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_reservable_bandwidth', full_name='otg.LinkStateTE.max_reservable_bandwidth', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority_bandwidths', full_name='otg.LinkStateTE.priority_bandwidths', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_administrative_group', full_name='otg.LinkStateTE._administrative_group',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_level', full_name='otg.LinkStateTE._metric_level',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_max_bandwith', full_name='otg.LinkStateTE._max_bandwith',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_max_reservable_bandwidth', full_name='otg.LinkStateTE._max_reservable_bandwidth',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_priority_bandwidths', full_name='otg.LinkStateTE._priority_bandwidths',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=9031,
  serialized_end=9352,
)


_LINKSTATEPRIORITYBANDWIDTHS = _descriptor.Descriptor(
  name='LinkStatepriorityBandwidths',
  full_name='otg.LinkStatepriorityBandwidths',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pb0', full_name='otg.LinkStatepriorityBandwidths.pb0', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pb1', full_name='otg.LinkStatepriorityBandwidths.pb1', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pb2', full_name='otg.LinkStatepriorityBandwidths.pb2', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pb3', full_name='otg.LinkStatepriorityBandwidths.pb3', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pb4', full_name='otg.LinkStatepriorityBandwidths.pb4', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pb5', full_name='otg.LinkStatepriorityBandwidths.pb5', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pb6', full_name='otg.LinkStatepriorityBandwidths.pb6', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pb7', full_name='otg.LinkStatepriorityBandwidths.pb7', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_pb0', full_name='otg.LinkStatepriorityBandwidths._pb0',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_pb1', full_name='otg.LinkStatepriorityBandwidths._pb1',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_pb2', full_name='otg.LinkStatepriorityBandwidths._pb2',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_pb3', full_name='otg.LinkStatepriorityBandwidths._pb3',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_pb4', full_name='otg.LinkStatepriorityBandwidths._pb4',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_pb5', full_name='otg.LinkStatepriorityBandwidths._pb5',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_pb6', full_name='otg.LinkStatepriorityBandwidths._pb6',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_pb7', full_name='otg.LinkStatepriorityBandwidths._pb7',
      index=7, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=9355,
  serialized_end=9592,
)


_ISISINTERFACEAUTHENTICATION_AUTHTYPE = _descriptor.Descriptor(
  name='AuthType',
  full_name='otg.IsisInterfaceAuthentication.AuthType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ISISINTERFACEAUTHENTICATION_AUTHTYPE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9734,
  serialized_end=9792,
)

_ISISINTERFACEAUTHENTICATION = _descriptor.Descriptor(
  name='IsisInterfaceAuthentication',
  full_name='otg.IsisInterfaceAuthentication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='auth_type', full_name='otg.IsisInterfaceAuthentication.auth_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='md5', full_name='otg.IsisInterfaceAuthentication.md5', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='otg.IsisInterfaceAuthentication.password', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ISISINTERFACEAUTHENTICATION_AUTHTYPE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_md5', full_name='otg.IsisInterfaceAuthentication._md5',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_password', full_name='otg.IsisInterfaceAuthentication._password',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=9595,
  serialized_end=9813,
)


_ISISINTERFACEADVANCED = _descriptor.Descriptor(
  name='IsisInterfaceAdvanced',
  full_name='otg.IsisInterfaceAdvanced',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='auto_adjust_mtu', full_name='otg.IsisInterfaceAdvanced.auto_adjust_mtu', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_adjust_area', full_name='otg.IsisInterfaceAdvanced.auto_adjust_area', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_adjust_supported_protocols', full_name='otg.IsisInterfaceAdvanced.auto_adjust_supported_protocols', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_3way_handshake', full_name='otg.IsisInterfaceAdvanced.enable_3way_handshake', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_auto_adjust_mtu', full_name='otg.IsisInterfaceAdvanced._auto_adjust_mtu',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_auto_adjust_area', full_name='otg.IsisInterfaceAdvanced._auto_adjust_area',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_auto_adjust_supported_protocols', full_name='otg.IsisInterfaceAdvanced._auto_adjust_supported_protocols',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_enable_3way_handshake', full_name='otg.IsisInterfaceAdvanced._enable_3way_handshake',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=9816,
  serialized_end=10085,
)


_ISISINTERFACELINKPROTECTION = _descriptor.Descriptor(
  name='IsisInterfaceLinkProtection',
  full_name='otg.IsisInterfaceLinkProtection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='extra_traffic', full_name='otg.IsisInterfaceLinkProtection.extra_traffic', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unprotected', full_name='otg.IsisInterfaceLinkProtection.unprotected', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shared', full_name='otg.IsisInterfaceLinkProtection.shared', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dedicated_1_to_1', full_name='otg.IsisInterfaceLinkProtection.dedicated_1_to_1', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dedicated_1_plus_1', full_name='otg.IsisInterfaceLinkProtection.dedicated_1_plus_1', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enhanced', full_name='otg.IsisInterfaceLinkProtection.enhanced', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reserved_40', full_name='otg.IsisInterfaceLinkProtection.reserved_40', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reserved_80', full_name='otg.IsisInterfaceLinkProtection.reserved_80', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_extra_traffic', full_name='otg.IsisInterfaceLinkProtection._extra_traffic',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_unprotected', full_name='otg.IsisInterfaceLinkProtection._unprotected',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_shared', full_name='otg.IsisInterfaceLinkProtection._shared',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_dedicated_1_to_1', full_name='otg.IsisInterfaceLinkProtection._dedicated_1_to_1',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_dedicated_1_plus_1', full_name='otg.IsisInterfaceLinkProtection._dedicated_1_plus_1',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_enhanced', full_name='otg.IsisInterfaceLinkProtection._enhanced',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_reserved_40', full_name='otg.IsisInterfaceLinkProtection._reserved_40',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_reserved_80', full_name='otg.IsisInterfaceLinkProtection._reserved_80',
      index=7, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=10088,
  serialized_end=10465,
)


_ISISBASIC = _descriptor.Descriptor(
  name='IsisBasic',
  full_name='otg.IsisBasic',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ipv4_te_router_id', full_name='otg.IsisBasic.ipv4_te_router_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='otg.IsisBasic.hostname', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_wide_metric', full_name='otg.IsisBasic.enable_wide_metric', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_ipv4_te_router_id', full_name='otg.IsisBasic._ipv4_te_router_id',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_hostname', full_name='otg.IsisBasic._hostname',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_enable_wide_metric', full_name='otg.IsisBasic._enable_wide_metric',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=10468,
  serialized_end=10625,
)


_ISISADVANCED = _descriptor.Descriptor(
  name='IsisAdvanced',
  full_name='otg.IsisAdvanced',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enable_hello_padding', full_name='otg.IsisAdvanced.enable_hello_padding', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_area_addresses', full_name='otg.IsisAdvanced.max_area_addresses', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='area_addresses', full_name='otg.IsisAdvanced.area_addresses', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lsp_refresh_rate', full_name='otg.IsisAdvanced.lsp_refresh_rate', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lsp_lifetime', full_name='otg.IsisAdvanced.lsp_lifetime', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='psnp_interval', full_name='otg.IsisAdvanced.psnp_interval', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='csnp_interval', full_name='otg.IsisAdvanced.csnp_interval', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_lsp_size', full_name='otg.IsisAdvanced.max_lsp_size', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lsp_mgroup_min_trans_interval', full_name='otg.IsisAdvanced.lsp_mgroup_min_trans_interval', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_attached_bit', full_name='otg.IsisAdvanced.enable_attached_bit', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_enable_hello_padding', full_name='otg.IsisAdvanced._enable_hello_padding',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_max_area_addresses', full_name='otg.IsisAdvanced._max_area_addresses',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_lsp_refresh_rate', full_name='otg.IsisAdvanced._lsp_refresh_rate',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_lsp_lifetime', full_name='otg.IsisAdvanced._lsp_lifetime',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_psnp_interval', full_name='otg.IsisAdvanced._psnp_interval',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_csnp_interval', full_name='otg.IsisAdvanced._csnp_interval',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_max_lsp_size', full_name='otg.IsisAdvanced._max_lsp_size',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_lsp_mgroup_min_trans_interval', full_name='otg.IsisAdvanced._lsp_mgroup_min_trans_interval',
      index=7, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_enable_attached_bit', full_name='otg.IsisAdvanced._enable_attached_bit',
      index=8, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=10628,
  serialized_end=11150,
)


_ISISAUTHENTICATION = _descriptor.Descriptor(
  name='IsisAuthentication',
  full_name='otg.IsisAuthentication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ignore_receive_md5', full_name='otg.IsisAuthentication.ignore_receive_md5', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='area_auth', full_name='otg.IsisAuthentication.area_auth', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='domain_auth', full_name='otg.IsisAuthentication.domain_auth', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_ignore_receive_md5', full_name='otg.IsisAuthentication._ignore_receive_md5',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_area_auth', full_name='otg.IsisAuthentication._area_auth',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_domain_auth', full_name='otg.IsisAuthentication._domain_auth',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=11153,
  serialized_end=11367,
)


_ISISAUTHENTICATIONBASE_AUTHTYPE = _descriptor.Descriptor(
  name='AuthType',
  full_name='otg.IsisAuthenticationBase.AuthType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ISISAUTHENTICATIONBASE_AUTHTYPE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9734,
  serialized_end=9792,
)

_ISISAUTHENTICATIONBASE = _descriptor.Descriptor(
  name='IsisAuthenticationBase',
  full_name='otg.IsisAuthenticationBase',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='auth_type', full_name='otg.IsisAuthenticationBase.auth_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='md5', full_name='otg.IsisAuthenticationBase.md5', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='otg.IsisAuthenticationBase.password', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ISISAUTHENTICATIONBASE_AUTHTYPE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_md5', full_name='otg.IsisAuthenticationBase._md5',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_password', full_name='otg.IsisAuthenticationBase._password',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=11370,
  serialized_end=11578,
)


_ISISV4ROUTERANGE_ORIGINTYPE = _descriptor.Descriptor(
  name='OriginType',
  full_name='otg.IsisV4RouteRange.OriginType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ISISV4ROUTERANGE_ORIGINTYPE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11924,
  serialized_end=11989,
)

_ISISV4ROUTERANGE_REDISTRIBUTIONTYPE = _descriptor.Descriptor(
  name='RedistributionType',
  full_name='otg.IsisV4RouteRange.RedistributionType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ISISV4ROUTERANGE_REDISTRIBUTIONTYPE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11991,
  serialized_end=12054,
)

_ISISV4ROUTERANGE = _descriptor.Descriptor(
  name='IsisV4RouteRange',
  full_name='otg.IsisV4RouteRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='addresses', full_name='otg.IsisV4RouteRange.addresses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link_metric', full_name='otg.IsisV4RouteRange.link_metric', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin_type', full_name='otg.IsisV4RouteRange.origin_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redistribution_type', full_name='otg.IsisV4RouteRange.redistribution_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='otg.IsisV4RouteRange.name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefix_attr_enabled', full_name='otg.IsisV4RouteRange.prefix_attr_enabled', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='x_flag', full_name='otg.IsisV4RouteRange.x_flag', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='r_flag', full_name='otg.IsisV4RouteRange.r_flag', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='n_flag', full_name='otg.IsisV4RouteRange.n_flag', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ISISV4ROUTERANGE_ORIGINTYPE, _ISISV4ROUTERANGE_REDISTRIBUTIONTYPE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_link_metric', full_name='otg.IsisV4RouteRange._link_metric',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_origin_type', full_name='otg.IsisV4RouteRange._origin_type',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_redistribution_type', full_name='otg.IsisV4RouteRange._redistribution_type',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_prefix_attr_enabled', full_name='otg.IsisV4RouteRange._prefix_attr_enabled',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_x_flag', full_name='otg.IsisV4RouteRange._x_flag',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_r_flag', full_name='otg.IsisV4RouteRange._r_flag',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_n_flag', full_name='otg.IsisV4RouteRange._n_flag',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=11581,
  serialized_end=12167,
)


_V4ROUTEADDRESS = _descriptor.Descriptor(
  name='V4RouteAddress',
  full_name='otg.V4RouteAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='otg.V4RouteAddress.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefix', full_name='otg.V4RouteAddress.prefix', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.V4RouteAddress.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.V4RouteAddress.step', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_prefix', full_name='otg.V4RouteAddress._prefix',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.V4RouteAddress._count',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.V4RouteAddress._step',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=12169,
  serialized_end=12292,
)


_V6ROUTEADDRESS = _descriptor.Descriptor(
  name='V6RouteAddress',
  full_name='otg.V6RouteAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='otg.V6RouteAddress.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefix', full_name='otg.V6RouteAddress.prefix', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.V6RouteAddress.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.V6RouteAddress.step', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_prefix', full_name='otg.V6RouteAddress._prefix',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.V6RouteAddress._count',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.V6RouteAddress._step',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=12294,
  serialized_end=12417,
)


_ISISV6ROUTERANGE_ORIGINTYPE = _descriptor.Descriptor(
  name='OriginType',
  full_name='otg.IsisV6RouteRange.OriginType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ISISV6ROUTERANGE_ORIGINTYPE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11924,
  serialized_end=11989,
)

_ISISV6ROUTERANGE_REDISTRIBUTIONTYPE = _descriptor.Descriptor(
  name='RedistributionType',
  full_name='otg.IsisV6RouteRange.RedistributionType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ISISV6ROUTERANGE_REDISTRIBUTIONTYPE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11991,
  serialized_end=12054,
)

_ISISV6ROUTERANGE = _descriptor.Descriptor(
  name='IsisV6RouteRange',
  full_name='otg.IsisV6RouteRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='addresses', full_name='otg.IsisV6RouteRange.addresses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link_metric', full_name='otg.IsisV6RouteRange.link_metric', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin_type', full_name='otg.IsisV6RouteRange.origin_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redistribution_type', full_name='otg.IsisV6RouteRange.redistribution_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='otg.IsisV6RouteRange.name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefix_attr_enabled', full_name='otg.IsisV6RouteRange.prefix_attr_enabled', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='x_flag', full_name='otg.IsisV6RouteRange.x_flag', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='r_flag', full_name='otg.IsisV6RouteRange.r_flag', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='n_flag', full_name='otg.IsisV6RouteRange.n_flag', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ISISV6ROUTERANGE_ORIGINTYPE, _ISISV6ROUTERANGE_REDISTRIBUTIONTYPE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_link_metric', full_name='otg.IsisV6RouteRange._link_metric',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_origin_type', full_name='otg.IsisV6RouteRange._origin_type',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_redistribution_type', full_name='otg.IsisV6RouteRange._redistribution_type',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_prefix_attr_enabled', full_name='otg.IsisV6RouteRange._prefix_attr_enabled',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_x_flag', full_name='otg.IsisV6RouteRange._x_flag',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_r_flag', full_name='otg.IsisV6RouteRange._r_flag',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_n_flag', full_name='otg.IsisV6RouteRange._n_flag',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=12420,
  serialized_end=13006,
)


_DEVICEBGPROUTER = _descriptor.Descriptor(
  name='DeviceBgpRouter',
  full_name='otg.DeviceBgpRouter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='router_id', full_name='otg.DeviceBgpRouter.router_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv4_interfaces', full_name='otg.DeviceBgpRouter.ipv4_interfaces', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv6_interfaces', full_name='otg.DeviceBgpRouter.ipv6_interfaces', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13009,
  serialized_end=13137,
)


_BGPV4PEER_ASTYPE = _descriptor.Descriptor(
  name='AsType',
  full_name='otg.BgpV4Peer.AsType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BGPV4PEER_ASTYPE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13582,
  serialized_end=13635,
)

_BGPV4PEER_ASNUMBERWIDTH = _descriptor.Descriptor(
  name='AsNumberWidth',
  full_name='otg.BgpV4Peer.AsNumberWidth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BGPV4PEER_ASNUMBERWIDTH_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13637,
  serialized_end=13696,
)

_BGPV4PEER = _descriptor.Descriptor(
  name='BgpV4Peer',
  full_name='otg.BgpV4Peer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer_address', full_name='otg.BgpV4Peer.peer_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='as_type', full_name='otg.BgpV4Peer.as_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='as_number', full_name='otg.BgpV4Peer.as_number', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='as_number_width', full_name='otg.BgpV4Peer.as_number_width', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='advanced', full_name='otg.BgpV4Peer.advanced', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='capability', full_name='otg.BgpV4Peer.capability', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v4_routes', full_name='otg.BgpV4Peer.v4_routes', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v6_routes', full_name='otg.BgpV4Peer.v6_routes', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v4_srte_policies', full_name='otg.BgpV4Peer.v4_srte_policies', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v6_srte_policies', full_name='otg.BgpV4Peer.v6_srte_policies', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='otg.BgpV4Peer.name', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BGPV4PEER_ASTYPE, _BGPV4PEER_ASNUMBERWIDTH, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_as_number_width', full_name='otg.BgpV4Peer._as_number_width',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_advanced', full_name='otg.BgpV4Peer._advanced',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_capability', full_name='otg.BgpV4Peer._capability',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=13140,
  serialized_end=13744,
)


_BGPV4INTERFACE = _descriptor.Descriptor(
  name='BgpV4Interface',
  full_name='otg.BgpV4Interface',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ipv4_name', full_name='otg.BgpV4Interface.ipv4_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='peers', full_name='otg.BgpV4Interface.peers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13746,
  serialized_end=13812,
)


_BGPADVANCED = _descriptor.Descriptor(
  name='BgpAdvanced',
  full_name='otg.BgpAdvanced',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hold_time_interval', full_name='otg.BgpAdvanced.hold_time_interval', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keep_alive_interval', full_name='otg.BgpAdvanced.keep_alive_interval', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_interval', full_name='otg.BgpAdvanced.update_interval', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_to_live', full_name='otg.BgpAdvanced.time_to_live', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='md5_key', full_name='otg.BgpAdvanced.md5_key', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_hold_time_interval', full_name='otg.BgpAdvanced._hold_time_interval',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_keep_alive_interval', full_name='otg.BgpAdvanced._keep_alive_interval',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_update_interval', full_name='otg.BgpAdvanced._update_interval',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_time_to_live', full_name='otg.BgpAdvanced._time_to_live',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_md5_key', full_name='otg.BgpAdvanced._md5_key',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=13815,
  serialized_end=14070,
)


_BGPCAPABILITY = _descriptor.Descriptor(
  name='BgpCapability',
  full_name='otg.BgpCapability',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ipv4_unicast', full_name='otg.BgpCapability.ipv4_unicast', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv4_multicast', full_name='otg.BgpCapability.ipv4_multicast', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv6_unicast', full_name='otg.BgpCapability.ipv6_unicast', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv6_multicast', full_name='otg.BgpCapability.ipv6_multicast', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vpls', full_name='otg.BgpCapability.vpls', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_refresh', full_name='otg.BgpCapability.route_refresh', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_constraint', full_name='otg.BgpCapability.route_constraint', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link_state_non_vpn', full_name='otg.BgpCapability.link_state_non_vpn', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link_state_vpn', full_name='otg.BgpCapability.link_state_vpn', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='evpn', full_name='otg.BgpCapability.evpn', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extended_next_hop_encoding', full_name='otg.BgpCapability.extended_next_hop_encoding', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv4_multicast_vpn', full_name='otg.BgpCapability.ipv4_multicast_vpn', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv4_mpls_vpn', full_name='otg.BgpCapability.ipv4_mpls_vpn', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv4_mdt', full_name='otg.BgpCapability.ipv4_mdt', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv4_multicast_mpls_vpn', full_name='otg.BgpCapability.ipv4_multicast_mpls_vpn', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv4_unicast_flow_spec', full_name='otg.BgpCapability.ipv4_unicast_flow_spec', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv4_sr_te_policy', full_name='otg.BgpCapability.ipv4_sr_te_policy', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv4_unicast_add_path', full_name='otg.BgpCapability.ipv4_unicast_add_path', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv6_multicast_vpn', full_name='otg.BgpCapability.ipv6_multicast_vpn', index=18,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv6_mpls_vpn', full_name='otg.BgpCapability.ipv6_mpls_vpn', index=19,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv6_mdt', full_name='otg.BgpCapability.ipv6_mdt', index=20,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv6_multicast_mpls_vpn', full_name='otg.BgpCapability.ipv6_multicast_mpls_vpn', index=21,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv6_unicast_flow_spec', full_name='otg.BgpCapability.ipv6_unicast_flow_spec', index=22,
      number=23, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv6_sr_te_policy', full_name='otg.BgpCapability.ipv6_sr_te_policy', index=23,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv6_unicast_add_path', full_name='otg.BgpCapability.ipv6_unicast_add_path', index=24,
      number=25, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_ipv4_unicast', full_name='otg.BgpCapability._ipv4_unicast',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ipv4_multicast', full_name='otg.BgpCapability._ipv4_multicast',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ipv6_unicast', full_name='otg.BgpCapability._ipv6_unicast',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ipv6_multicast', full_name='otg.BgpCapability._ipv6_multicast',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_vpls', full_name='otg.BgpCapability._vpls',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_route_refresh', full_name='otg.BgpCapability._route_refresh',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_route_constraint', full_name='otg.BgpCapability._route_constraint',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_link_state_non_vpn', full_name='otg.BgpCapability._link_state_non_vpn',
      index=7, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_link_state_vpn', full_name='otg.BgpCapability._link_state_vpn',
      index=8, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_evpn', full_name='otg.BgpCapability._evpn',
      index=9, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_extended_next_hop_encoding', full_name='otg.BgpCapability._extended_next_hop_encoding',
      index=10, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ipv4_multicast_vpn', full_name='otg.BgpCapability._ipv4_multicast_vpn',
      index=11, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ipv4_mpls_vpn', full_name='otg.BgpCapability._ipv4_mpls_vpn',
      index=12, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ipv4_mdt', full_name='otg.BgpCapability._ipv4_mdt',
      index=13, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ipv4_multicast_mpls_vpn', full_name='otg.BgpCapability._ipv4_multicast_mpls_vpn',
      index=14, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ipv4_unicast_flow_spec', full_name='otg.BgpCapability._ipv4_unicast_flow_spec',
      index=15, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ipv4_sr_te_policy', full_name='otg.BgpCapability._ipv4_sr_te_policy',
      index=16, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ipv4_unicast_add_path', full_name='otg.BgpCapability._ipv4_unicast_add_path',
      index=17, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ipv6_multicast_vpn', full_name='otg.BgpCapability._ipv6_multicast_vpn',
      index=18, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ipv6_mpls_vpn', full_name='otg.BgpCapability._ipv6_mpls_vpn',
      index=19, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ipv6_mdt', full_name='otg.BgpCapability._ipv6_mdt',
      index=20, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ipv6_multicast_mpls_vpn', full_name='otg.BgpCapability._ipv6_multicast_mpls_vpn',
      index=21, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ipv6_unicast_flow_spec', full_name='otg.BgpCapability._ipv6_unicast_flow_spec',
      index=22, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ipv6_sr_te_policy', full_name='otg.BgpCapability._ipv6_sr_te_policy',
      index=23, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ipv6_unicast_add_path', full_name='otg.BgpCapability._ipv6_unicast_add_path',
      index=24, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=14073,
  serialized_end=15370,
)


_BGPV4ROUTERANGE_NEXTHOPMODE = _descriptor.Descriptor(
  name='NextHopMode',
  full_name='otg.BgpV4RouteRange.NextHopMode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BGPV4ROUTERANGE_NEXTHOPMODE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15831,
  serialized_end=15895,
)

_BGPV4ROUTERANGE_NEXTHOPADDRESSTYPE = _descriptor.Descriptor(
  name='NextHopAddressType',
  full_name='otg.BgpV4RouteRange.NextHopAddressType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BGPV4ROUTERANGE_NEXTHOPADDRESSTYPE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15897,
  serialized_end=15962,
)

_BGPV4ROUTERANGE = _descriptor.Descriptor(
  name='BgpV4RouteRange',
  full_name='otg.BgpV4RouteRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='addresses', full_name='otg.BgpV4RouteRange.addresses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_hop_mode', full_name='otg.BgpV4RouteRange.next_hop_mode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_hop_address_type', full_name='otg.BgpV4RouteRange.next_hop_address_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_hop_ipv4_address', full_name='otg.BgpV4RouteRange.next_hop_ipv4_address', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_hop_ipv6_address', full_name='otg.BgpV4RouteRange.next_hop_ipv6_address', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='advanced', full_name='otg.BgpV4RouteRange.advanced', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='communities', full_name='otg.BgpV4RouteRange.communities', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='as_path', full_name='otg.BgpV4RouteRange.as_path', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='add_path', full_name='otg.BgpV4RouteRange.add_path', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='otg.BgpV4RouteRange.name', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BGPV4ROUTERANGE_NEXTHOPMODE, _BGPV4ROUTERANGE_NEXTHOPADDRESSTYPE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_next_hop_mode', full_name='otg.BgpV4RouteRange._next_hop_mode',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_next_hop_address_type', full_name='otg.BgpV4RouteRange._next_hop_address_type',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_next_hop_ipv4_address', full_name='otg.BgpV4RouteRange._next_hop_ipv4_address',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_next_hop_ipv6_address', full_name='otg.BgpV4RouteRange._next_hop_ipv6_address',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_advanced', full_name='otg.BgpV4RouteRange._advanced',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_as_path', full_name='otg.BgpV4RouteRange._as_path',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_add_path', full_name='otg.BgpV4RouteRange._add_path',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=15373,
  serialized_end=16096,
)


_BGPROUTEADVANCED_ORIGIN = _descriptor.Descriptor(
  name='Origin',
  full_name='otg.BgpRouteAdvanced.Origin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BGPROUTEADVANCED_ORIGIN_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16214,
  serialized_end=16265,
)

_BGPROUTEADVANCED = _descriptor.Descriptor(
  name='BgpRouteAdvanced',
  full_name='otg.BgpRouteAdvanced',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='multi_exit_discriminator', full_name='otg.BgpRouteAdvanced.multi_exit_discriminator', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin', full_name='otg.BgpRouteAdvanced.origin', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BGPROUTEADVANCED_ORIGIN, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_multi_exit_discriminator', full_name='otg.BgpRouteAdvanced._multi_exit_discriminator',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_origin', full_name='otg.BgpRouteAdvanced._origin',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=16099,
  serialized_end=16305,
)


_BGPCOMMUNITY_TYPE = _descriptor.Descriptor(
  name='Type',
  full_name='otg.BgpCommunity.Type',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BGPCOMMUNITY_TYPE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16421,
  serialized_end=16563,
)

_BGPCOMMUNITY = _descriptor.Descriptor(
  name='BgpCommunity',
  full_name='otg.BgpCommunity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='otg.BgpCommunity.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='as_number', full_name='otg.BgpCommunity.as_number', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='as_custom', full_name='otg.BgpCommunity.as_custom', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BGPCOMMUNITY_TYPE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_type', full_name='otg.BgpCommunity._type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_as_number', full_name='otg.BgpCommunity._as_number',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_as_custom', full_name='otg.BgpCommunity._as_custom',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=16308,
  serialized_end=16600,
)


_BGPASPATH_ASSETMODE = _descriptor.Descriptor(
  name='AsSetMode',
  full_name='otg.BgpAsPath.AsSetMode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BGPASPATH_ASSETMODE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16715,
  serialized_end=16905,
)

_BGPASPATH = _descriptor.Descriptor(
  name='BgpAsPath',
  full_name='otg.BgpAsPath',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='as_set_mode', full_name='otg.BgpAsPath.as_set_mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='segments', full_name='otg.BgpAsPath.segments', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BGPASPATH_ASSETMODE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_as_set_mode', full_name='otg.BgpAsPath._as_set_mode',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=16603,
  serialized_end=16921,
)


_BGPASPATHSEGMENT_TYPE = _descriptor.Descriptor(
  name='Type',
  full_name='otg.BgpAsPathSegment.Type',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BGPASPATHSEGMENT_TYPE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17016,
  serialized_end=17109,
)

_BGPASPATHSEGMENT = _descriptor.Descriptor(
  name='BgpAsPathSegment',
  full_name='otg.BgpAsPathSegment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='otg.BgpAsPathSegment.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='as_numbers', full_name='otg.BgpAsPathSegment.as_numbers', index=1,
      number=2, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BGPASPATHSEGMENT_TYPE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_type', full_name='otg.BgpAsPathSegment._type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=16924,
  serialized_end=17118,
)


_BGPADDPATH = _descriptor.Descriptor(
  name='BgpAddPath',
  full_name='otg.BgpAddPath',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path_id', full_name='otg.BgpAddPath.path_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_path_id', full_name='otg.BgpAddPath._path_id',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=17120,
  serialized_end=17166,
)


_BGPV6ROUTERANGE_NEXTHOPMODE = _descriptor.Descriptor(
  name='NextHopMode',
  full_name='otg.BgpV6RouteRange.NextHopMode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BGPV6ROUTERANGE_NEXTHOPMODE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15831,
  serialized_end=15895,
)

_BGPV6ROUTERANGE_NEXTHOPADDRESSTYPE = _descriptor.Descriptor(
  name='NextHopAddressType',
  full_name='otg.BgpV6RouteRange.NextHopAddressType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BGPV6ROUTERANGE_NEXTHOPADDRESSTYPE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15897,
  serialized_end=15962,
)

_BGPV6ROUTERANGE = _descriptor.Descriptor(
  name='BgpV6RouteRange',
  full_name='otg.BgpV6RouteRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='addresses', full_name='otg.BgpV6RouteRange.addresses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_hop_mode', full_name='otg.BgpV6RouteRange.next_hop_mode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_hop_address_type', full_name='otg.BgpV6RouteRange.next_hop_address_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_hop_ipv4_address', full_name='otg.BgpV6RouteRange.next_hop_ipv4_address', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_hop_ipv6_address', full_name='otg.BgpV6RouteRange.next_hop_ipv6_address', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='advanced', full_name='otg.BgpV6RouteRange.advanced', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='communities', full_name='otg.BgpV6RouteRange.communities', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='as_path', full_name='otg.BgpV6RouteRange.as_path', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='add_path', full_name='otg.BgpV6RouteRange.add_path', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='otg.BgpV6RouteRange.name', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BGPV6ROUTERANGE_NEXTHOPMODE, _BGPV6ROUTERANGE_NEXTHOPADDRESSTYPE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_next_hop_mode', full_name='otg.BgpV6RouteRange._next_hop_mode',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_next_hop_address_type', full_name='otg.BgpV6RouteRange._next_hop_address_type',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_next_hop_ipv4_address', full_name='otg.BgpV6RouteRange._next_hop_ipv4_address',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_next_hop_ipv6_address', full_name='otg.BgpV6RouteRange._next_hop_ipv6_address',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_advanced', full_name='otg.BgpV6RouteRange._advanced',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_as_path', full_name='otg.BgpV6RouteRange._as_path',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_add_path', full_name='otg.BgpV6RouteRange._add_path',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=17169,
  serialized_end=17892,
)


_BGPSRTEV4POLICY_NEXTHOPMODE = _descriptor.Descriptor(
  name='NextHopMode',
  full_name='otg.BgpSrteV4Policy.NextHopMode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BGPSRTEV4POLICY_NEXTHOPMODE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15831,
  serialized_end=15895,
)

_BGPSRTEV4POLICY_NEXTHOPADDRESSTYPE = _descriptor.Descriptor(
  name='NextHopAddressType',
  full_name='otg.BgpSrteV4Policy.NextHopAddressType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BGPSRTEV4POLICY_NEXTHOPADDRESSTYPE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15897,
  serialized_end=15962,
)

_BGPSRTEV4POLICY = _descriptor.Descriptor(
  name='BgpSrteV4Policy',
  full_name='otg.BgpSrteV4Policy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='distinguisher', full_name='otg.BgpSrteV4Policy.distinguisher', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='color', full_name='otg.BgpSrteV4Policy.color', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv4_endpoint', full_name='otg.BgpSrteV4Policy.ipv4_endpoint', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_hop_mode', full_name='otg.BgpSrteV4Policy.next_hop_mode', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_hop_address_type', full_name='otg.BgpSrteV4Policy.next_hop_address_type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_hop_ipv4_address', full_name='otg.BgpSrteV4Policy.next_hop_ipv4_address', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_hop_ipv6_address', full_name='otg.BgpSrteV4Policy.next_hop_ipv6_address', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='advanced', full_name='otg.BgpSrteV4Policy.advanced', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='add_path', full_name='otg.BgpSrteV4Policy.add_path', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='as_path', full_name='otg.BgpSrteV4Policy.as_path', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='communities', full_name='otg.BgpSrteV4Policy.communities', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ext_communities', full_name='otg.BgpSrteV4Policy.ext_communities', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tunnel_tlvs', full_name='otg.BgpSrteV4Policy.tunnel_tlvs', index=12,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='otg.BgpSrteV4Policy.name', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active', full_name='otg.BgpSrteV4Policy.active', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BGPSRTEV4POLICY_NEXTHOPMODE, _BGPSRTEV4POLICY_NEXTHOPADDRESSTYPE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_distinguisher', full_name='otg.BgpSrteV4Policy._distinguisher',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_color', full_name='otg.BgpSrteV4Policy._color',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_next_hop_mode', full_name='otg.BgpSrteV4Policy._next_hop_mode',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_next_hop_address_type', full_name='otg.BgpSrteV4Policy._next_hop_address_type',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_next_hop_ipv4_address', full_name='otg.BgpSrteV4Policy._next_hop_ipv4_address',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_next_hop_ipv6_address', full_name='otg.BgpSrteV4Policy._next_hop_ipv6_address',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_advanced', full_name='otg.BgpSrteV4Policy._advanced',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_add_path', full_name='otg.BgpSrteV4Policy._add_path',
      index=7, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_as_path', full_name='otg.BgpSrteV4Policy._as_path',
      index=8, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_active', full_name='otg.BgpSrteV4Policy._active',
      index=9, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=17895,
  serialized_end=18802,
)


_BGPEXTCOMMUNITY_TYPE = _descriptor.Descriptor(
  name='Type',
  full_name='otg.BgpExtCommunity.Type',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BGPEXTCOMMUNITY_TYPE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18953,
  serialized_end=19141,
)

_BGPEXTCOMMUNITY_SUBTYPE = _descriptor.Descriptor(
  name='Subtype',
  full_name='otg.BgpExtCommunity.Subtype',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BGPEXTCOMMUNITY_SUBTYPE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19144,
  serialized_end=19279,
)

_BGPEXTCOMMUNITY = _descriptor.Descriptor(
  name='BgpExtCommunity',
  full_name='otg.BgpExtCommunity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='otg.BgpExtCommunity.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subtype', full_name='otg.BgpExtCommunity.subtype', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.BgpExtCommunity.value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BGPEXTCOMMUNITY_TYPE, _BGPEXTCOMMUNITY_SUBTYPE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_type', full_name='otg.BgpExtCommunity._type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_subtype', full_name='otg.BgpExtCommunity._subtype',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.BgpExtCommunity._value',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=18805,
  serialized_end=19310,
)


_BGPSRTEV4TUNNELTLV = _descriptor.Descriptor(
  name='BgpSrteV4TunnelTlv',
  full_name='otg.BgpSrteV4TunnelTlv',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='remote_endpoint_sub_tlv', full_name='otg.BgpSrteV4TunnelTlv.remote_endpoint_sub_tlv', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='color_sub_tlv', full_name='otg.BgpSrteV4TunnelTlv.color_sub_tlv', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='binding_sub_tlv', full_name='otg.BgpSrteV4TunnelTlv.binding_sub_tlv', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preference_sub_tlv', full_name='otg.BgpSrteV4TunnelTlv.preference_sub_tlv', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='policy_priority_sub_tlv', full_name='otg.BgpSrteV4TunnelTlv.policy_priority_sub_tlv', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='policy_name_sub_tlv', full_name='otg.BgpSrteV4TunnelTlv.policy_name_sub_tlv', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='explicit_null_label_policy_sub_tlv', full_name='otg.BgpSrteV4TunnelTlv.explicit_null_label_policy_sub_tlv', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='segment_lists', full_name='otg.BgpSrteV4TunnelTlv.segment_lists', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='otg.BgpSrteV4TunnelTlv.name', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active', full_name='otg.BgpSrteV4TunnelTlv.active', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_remote_endpoint_sub_tlv', full_name='otg.BgpSrteV4TunnelTlv._remote_endpoint_sub_tlv',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_color_sub_tlv', full_name='otg.BgpSrteV4TunnelTlv._color_sub_tlv',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_binding_sub_tlv', full_name='otg.BgpSrteV4TunnelTlv._binding_sub_tlv',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_preference_sub_tlv', full_name='otg.BgpSrteV4TunnelTlv._preference_sub_tlv',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_policy_priority_sub_tlv', full_name='otg.BgpSrteV4TunnelTlv._policy_priority_sub_tlv',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_policy_name_sub_tlv', full_name='otg.BgpSrteV4TunnelTlv._policy_name_sub_tlv',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_explicit_null_label_policy_sub_tlv', full_name='otg.BgpSrteV4TunnelTlv._explicit_null_label_policy_sub_tlv',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_active', full_name='otg.BgpSrteV4TunnelTlv._active',
      index=7, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=19313,
  serialized_end=20080,
)


_BGPSRTEREMOTEENDPOINTSUBTLV_ADDRESSFAMILY = _descriptor.Descriptor(
  name='AddressFamily',
  full_name='otg.BgpSrteRemoteEndpointSubTlv.AddressFamily',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BGPSRTEREMOTEENDPOINTSUBTLV_ADDRESSFAMILY_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20274,
  serialized_end=20334,
)

_BGPSRTEREMOTEENDPOINTSUBTLV = _descriptor.Descriptor(
  name='BgpSrteRemoteEndpointSubTlv',
  full_name='otg.BgpSrteRemoteEndpointSubTlv',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='as_number', full_name='otg.BgpSrteRemoteEndpointSubTlv.as_number', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address_family', full_name='otg.BgpSrteRemoteEndpointSubTlv.address_family', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv4_address', full_name='otg.BgpSrteRemoteEndpointSubTlv.ipv4_address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv6_address', full_name='otg.BgpSrteRemoteEndpointSubTlv.ipv6_address', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BGPSRTEREMOTEENDPOINTSUBTLV_ADDRESSFAMILY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_as_number', full_name='otg.BgpSrteRemoteEndpointSubTlv._as_number',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_address_family', full_name='otg.BgpSrteRemoteEndpointSubTlv._address_family',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ipv4_address', full_name='otg.BgpSrteRemoteEndpointSubTlv._ipv4_address',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ipv6_address', full_name='otg.BgpSrteRemoteEndpointSubTlv._ipv6_address',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=20083,
  serialized_end=20401,
)


_BGPSRTECOLORSUBTLV = _descriptor.Descriptor(
  name='BgpSrteColorSubTlv',
  full_name='otg.BgpSrteColorSubTlv',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='color', full_name='otg.BgpSrteColorSubTlv.color', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_color', full_name='otg.BgpSrteColorSubTlv._color',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=20403,
  serialized_end=20453,
)


_BGPSRTEBINDINGSUBTLV_BINDINGSIDTYPE = _descriptor.Descriptor(
  name='BindingSidType',
  full_name='otg.BgpSrteBindingSubTlv.BindingSidType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BGPSRTEBINDINGSUBTLV_BINDINGSIDTYPE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20652,
  serialized_end=20743,
)

_BGPSRTEBINDINGSUBTLV = _descriptor.Descriptor(
  name='BgpSrteBindingSubTlv',
  full_name='otg.BgpSrteBindingSubTlv',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='binding_sid_type', full_name='otg.BgpSrteBindingSubTlv.binding_sid_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='four_octet_sid', full_name='otg.BgpSrteBindingSubTlv.four_octet_sid', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv6_sid', full_name='otg.BgpSrteBindingSubTlv.ipv6_sid', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s_flag', full_name='otg.BgpSrteBindingSubTlv.s_flag', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='i_flag', full_name='otg.BgpSrteBindingSubTlv.i_flag', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BGPSRTEBINDINGSUBTLV_BINDINGSIDTYPE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_binding_sid_type', full_name='otg.BgpSrteBindingSubTlv._binding_sid_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_four_octet_sid', full_name='otg.BgpSrteBindingSubTlv._four_octet_sid',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ipv6_sid', full_name='otg.BgpSrteBindingSubTlv._ipv6_sid',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_s_flag', full_name='otg.BgpSrteBindingSubTlv._s_flag',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_i_flag', full_name='otg.BgpSrteBindingSubTlv._i_flag',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=20456,
  serialized_end=20818,
)


_BGPSRTEPREFERENCESUBTLV = _descriptor.Descriptor(
  name='BgpSrtePreferenceSubTlv',
  full_name='otg.BgpSrtePreferenceSubTlv',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='preference', full_name='otg.BgpSrtePreferenceSubTlv.preference', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_preference', full_name='otg.BgpSrtePreferenceSubTlv._preference',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=20820,
  serialized_end=20885,
)


_BGPSRTEPOLICYPRIORITYSUBTLV = _descriptor.Descriptor(
  name='BgpSrtePolicyPrioritySubTlv',
  full_name='otg.BgpSrtePolicyPrioritySubTlv',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='policy_priority', full_name='otg.BgpSrtePolicyPrioritySubTlv.policy_priority', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_policy_priority', full_name='otg.BgpSrtePolicyPrioritySubTlv._policy_priority',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=20887,
  serialized_end=20966,
)


_BGPSRTEPOLICYNAMESUBTLV = _descriptor.Descriptor(
  name='BgpSrtePolicyNameSubTlv',
  full_name='otg.BgpSrtePolicyNameSubTlv',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='policy_name', full_name='otg.BgpSrtePolicyNameSubTlv.policy_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_policy_name', full_name='otg.BgpSrtePolicyNameSubTlv._policy_name',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=20968,
  serialized_end=21035,
)


_BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV_EXPLICITNULLLABELPOLICY = _descriptor.Descriptor(
  name='ExplicitNullLabelPolicy',
  full_name='otg.BgpSrteExplicitNullLabelPolicySubTlv.ExplicitNullLabelPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV_EXPLICITNULLLABELPOLICY_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21192,
  serialized_end=21349,
)

_BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV = _descriptor.Descriptor(
  name='BgpSrteExplicitNullLabelPolicySubTlv',
  full_name='otg.BgpSrteExplicitNullLabelPolicySubTlv',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='explicit_null_label_policy', full_name='otg.BgpSrteExplicitNullLabelPolicySubTlv.explicit_null_label_policy', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV_EXPLICITNULLLABELPOLICY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_explicit_null_label_policy', full_name='otg.BgpSrteExplicitNullLabelPolicySubTlv._explicit_null_label_policy',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=21038,
  serialized_end=21380,
)


_BGPSRTESEGMENTLIST = _descriptor.Descriptor(
  name='BgpSrteSegmentList',
  full_name='otg.BgpSrteSegmentList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='weight', full_name='otg.BgpSrteSegmentList.weight', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='segments', full_name='otg.BgpSrteSegmentList.segments', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='otg.BgpSrteSegmentList.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active', full_name='otg.BgpSrteSegmentList.active', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_weight', full_name='otg.BgpSrteSegmentList._weight',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_active', full_name='otg.BgpSrteSegmentList._active',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=21383,
  serialized_end=21520,
)


_BGPSRTESEGMENT_SEGMENTTYPE = _descriptor.Descriptor(
  name='SegmentType',
  full_name='otg.BgpSrteSegment.SegmentType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BGPSRTESEGMENT_SEGMENTTYPE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22220,
  serialized_end=22391,
)

_BGPSRTESEGMENT = _descriptor.Descriptor(
  name='BgpSrteSegment',
  full_name='otg.BgpSrteSegment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='segment_type', full_name='otg.BgpSrteSegment.segment_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_a', full_name='otg.BgpSrteSegment.type_a', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_b', full_name='otg.BgpSrteSegment.type_b', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_c', full_name='otg.BgpSrteSegment.type_c', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_d', full_name='otg.BgpSrteSegment.type_d', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_e', full_name='otg.BgpSrteSegment.type_e', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_f', full_name='otg.BgpSrteSegment.type_f', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_g', full_name='otg.BgpSrteSegment.type_g', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_h', full_name='otg.BgpSrteSegment.type_h', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_i', full_name='otg.BgpSrteSegment.type_i', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_j', full_name='otg.BgpSrteSegment.type_j', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_k', full_name='otg.BgpSrteSegment.type_k', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='otg.BgpSrteSegment.name', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active', full_name='otg.BgpSrteSegment.active', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BGPSRTESEGMENT_SEGMENTTYPE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_type_a', full_name='otg.BgpSrteSegment._type_a',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_type_b', full_name='otg.BgpSrteSegment._type_b',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_type_c', full_name='otg.BgpSrteSegment._type_c',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_type_d', full_name='otg.BgpSrteSegment._type_d',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_type_e', full_name='otg.BgpSrteSegment._type_e',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_type_f', full_name='otg.BgpSrteSegment._type_f',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_type_g', full_name='otg.BgpSrteSegment._type_g',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_type_h', full_name='otg.BgpSrteSegment._type_h',
      index=7, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_type_i', full_name='otg.BgpSrteSegment._type_i',
      index=8, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_type_j', full_name='otg.BgpSrteSegment._type_j',
      index=9, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_type_k', full_name='otg.BgpSrteSegment._type_k',
      index=10, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_active', full_name='otg.BgpSrteSegment._active',
      index=11, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=21523,
  serialized_end=22523,
)


_BGPSRTESRMPLSSID = _descriptor.Descriptor(
  name='BgpSrteSrMplsSid',
  full_name='otg.BgpSrteSrMplsSid',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='otg.BgpSrteSrMplsSid.label', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tc', full_name='otg.BgpSrteSrMplsSid.tc', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s_bit', full_name='otg.BgpSrteSrMplsSid.s_bit', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ttl', full_name='otg.BgpSrteSrMplsSid.ttl', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_label', full_name='otg.BgpSrteSrMplsSid._label',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_tc', full_name='otg.BgpSrteSrMplsSid._tc',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_s_bit', full_name='otg.BgpSrteSrMplsSid._s_bit',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ttl', full_name='otg.BgpSrteSrMplsSid._ttl',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=22526,
  serialized_end=22654,
)


_BGPSRTESRV6SIDENDPOINTBEHAVIORANDSTRUCTURE = _descriptor.Descriptor(
  name='BgpSrteSRv6SIDEndpointBehaviorAndStructure',
  full_name='otg.BgpSrteSRv6SIDEndpointBehaviorAndStructure',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lb_length', full_name='otg.BgpSrteSRv6SIDEndpointBehaviorAndStructure.lb_length', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ln_length', full_name='otg.BgpSrteSRv6SIDEndpointBehaviorAndStructure.ln_length', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='func_length', full_name='otg.BgpSrteSRv6SIDEndpointBehaviorAndStructure.func_length', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arg_length', full_name='otg.BgpSrteSRv6SIDEndpointBehaviorAndStructure.arg_length', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_lb_length', full_name='otg.BgpSrteSRv6SIDEndpointBehaviorAndStructure._lb_length',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ln_length', full_name='otg.BgpSrteSRv6SIDEndpointBehaviorAndStructure._ln_length',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_func_length', full_name='otg.BgpSrteSRv6SIDEndpointBehaviorAndStructure._func_length',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_arg_length', full_name='otg.BgpSrteSRv6SIDEndpointBehaviorAndStructure._arg_length',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=22657,
  serialized_end=22859,
)


_BGPSRTESEGMENTATYPESUBTLV = _descriptor.Descriptor(
  name='BgpSrteSegmentATypeSubTlv',
  full_name='otg.BgpSrteSegmentATypeSubTlv',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flags', full_name='otg.BgpSrteSegmentATypeSubTlv.flags', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label', full_name='otg.BgpSrteSegmentATypeSubTlv.label', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tc', full_name='otg.BgpSrteSegmentATypeSubTlv.tc', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s_bit', full_name='otg.BgpSrteSegmentATypeSubTlv.s_bit', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ttl', full_name='otg.BgpSrteSegmentATypeSubTlv.ttl', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_flags', full_name='otg.BgpSrteSegmentATypeSubTlv._flags',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_label', full_name='otg.BgpSrteSegmentATypeSubTlv._label',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_tc', full_name='otg.BgpSrteSegmentATypeSubTlv._tc',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_s_bit', full_name='otg.BgpSrteSegmentATypeSubTlv._s_bit',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ttl', full_name='otg.BgpSrteSegmentATypeSubTlv._ttl',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=22862,
  serialized_end=23029,
)


_BGPSRTESEGMENTBTYPESUBTLV = _descriptor.Descriptor(
  name='BgpSrteSegmentBTypeSubTlv',
  full_name='otg.BgpSrteSegmentBTypeSubTlv',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flags', full_name='otg.BgpSrteSegmentBTypeSubTlv.flags', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='srv6_sid', full_name='otg.BgpSrteSegmentBTypeSubTlv.srv6_sid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='srv6_sid_endpoint_behavior', full_name='otg.BgpSrteSegmentBTypeSubTlv.srv6_sid_endpoint_behavior', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_flags', full_name='otg.BgpSrteSegmentBTypeSubTlv._flags',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_srv6_sid_endpoint_behavior', full_name='otg.BgpSrteSegmentBTypeSubTlv._srv6_sid_endpoint_behavior',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=23032,
  serialized_end=23228,
)


_BGPSRTESEGMENTCTYPESUBTLV = _descriptor.Descriptor(
  name='BgpSrteSegmentCTypeSubTlv',
  full_name='otg.BgpSrteSegmentCTypeSubTlv',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flags', full_name='otg.BgpSrteSegmentCTypeSubTlv.flags', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sr_algorithm', full_name='otg.BgpSrteSegmentCTypeSubTlv.sr_algorithm', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv4_node_address', full_name='otg.BgpSrteSegmentCTypeSubTlv.ipv4_node_address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sr_mpls_sid', full_name='otg.BgpSrteSegmentCTypeSubTlv.sr_mpls_sid', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_flags', full_name='otg.BgpSrteSegmentCTypeSubTlv._flags',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_sr_algorithm', full_name='otg.BgpSrteSegmentCTypeSubTlv._sr_algorithm',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_sr_mpls_sid', full_name='otg.BgpSrteSegmentCTypeSubTlv._sr_mpls_sid',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=23231,
  serialized_end=23424,
)


_BGPSRTESEGMENTDTYPESUBTLV = _descriptor.Descriptor(
  name='BgpSrteSegmentDTypeSubTlv',
  full_name='otg.BgpSrteSegmentDTypeSubTlv',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flags', full_name='otg.BgpSrteSegmentDTypeSubTlv.flags', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sr_algorithm', full_name='otg.BgpSrteSegmentDTypeSubTlv.sr_algorithm', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv6_node_address', full_name='otg.BgpSrteSegmentDTypeSubTlv.ipv6_node_address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sr_mpls_sid', full_name='otg.BgpSrteSegmentDTypeSubTlv.sr_mpls_sid', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_flags', full_name='otg.BgpSrteSegmentDTypeSubTlv._flags',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_sr_algorithm', full_name='otg.BgpSrteSegmentDTypeSubTlv._sr_algorithm',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_sr_mpls_sid', full_name='otg.BgpSrteSegmentDTypeSubTlv._sr_mpls_sid',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=23427,
  serialized_end=23620,
)


_BGPSRTESEGMENTETYPESUBTLV = _descriptor.Descriptor(
  name='BgpSrteSegmentETypeSubTlv',
  full_name='otg.BgpSrteSegmentETypeSubTlv',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flags', full_name='otg.BgpSrteSegmentETypeSubTlv.flags', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_interface_id', full_name='otg.BgpSrteSegmentETypeSubTlv.local_interface_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv4_node_address', full_name='otg.BgpSrteSegmentETypeSubTlv.ipv4_node_address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sr_mpls_sid', full_name='otg.BgpSrteSegmentETypeSubTlv.sr_mpls_sid', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_flags', full_name='otg.BgpSrteSegmentETypeSubTlv._flags',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_local_interface_id', full_name='otg.BgpSrteSegmentETypeSubTlv._local_interface_id',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_sr_mpls_sid', full_name='otg.BgpSrteSegmentETypeSubTlv._sr_mpls_sid',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=23623,
  serialized_end=23828,
)


_BGPSRTESEGMENTFTYPESUBTLV = _descriptor.Descriptor(
  name='BgpSrteSegmentFTypeSubTlv',
  full_name='otg.BgpSrteSegmentFTypeSubTlv',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flags', full_name='otg.BgpSrteSegmentFTypeSubTlv.flags', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_ipv4_address', full_name='otg.BgpSrteSegmentFTypeSubTlv.local_ipv4_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remote_ipv4_address', full_name='otg.BgpSrteSegmentFTypeSubTlv.remote_ipv4_address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sr_mpls_sid', full_name='otg.BgpSrteSegmentFTypeSubTlv.sr_mpls_sid', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_flags', full_name='otg.BgpSrteSegmentFTypeSubTlv._flags',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_sr_mpls_sid', full_name='otg.BgpSrteSegmentFTypeSubTlv._sr_mpls_sid',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=23831,
  serialized_end=24010,
)


_BGPSRTESEGMENTGTYPESUBTLV = _descriptor.Descriptor(
  name='BgpSrteSegmentGTypeSubTlv',
  full_name='otg.BgpSrteSegmentGTypeSubTlv',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flags', full_name='otg.BgpSrteSegmentGTypeSubTlv.flags', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_interface_id', full_name='otg.BgpSrteSegmentGTypeSubTlv.local_interface_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_ipv6_node_address', full_name='otg.BgpSrteSegmentGTypeSubTlv.local_ipv6_node_address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remote_interface_id', full_name='otg.BgpSrteSegmentGTypeSubTlv.remote_interface_id', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remote_ipv6_node_address', full_name='otg.BgpSrteSegmentGTypeSubTlv.remote_ipv6_node_address', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sr_mpls_sid', full_name='otg.BgpSrteSegmentGTypeSubTlv.sr_mpls_sid', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_flags', full_name='otg.BgpSrteSegmentGTypeSubTlv._flags',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_local_interface_id', full_name='otg.BgpSrteSegmentGTypeSubTlv._local_interface_id',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_remote_interface_id', full_name='otg.BgpSrteSegmentGTypeSubTlv._remote_interface_id',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_sr_mpls_sid', full_name='otg.BgpSrteSegmentGTypeSubTlv._sr_mpls_sid',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=24013,
  serialized_end=24316,
)


_BGPSRTESEGMENTHTYPESUBTLV = _descriptor.Descriptor(
  name='BgpSrteSegmentHTypeSubTlv',
  full_name='otg.BgpSrteSegmentHTypeSubTlv',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flags', full_name='otg.BgpSrteSegmentHTypeSubTlv.flags', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_ipv6_address', full_name='otg.BgpSrteSegmentHTypeSubTlv.local_ipv6_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remote_ipv6_address', full_name='otg.BgpSrteSegmentHTypeSubTlv.remote_ipv6_address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sr_mpls_sid', full_name='otg.BgpSrteSegmentHTypeSubTlv.sr_mpls_sid', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_flags', full_name='otg.BgpSrteSegmentHTypeSubTlv._flags',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_sr_mpls_sid', full_name='otg.BgpSrteSegmentHTypeSubTlv._sr_mpls_sid',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=24319,
  serialized_end=24498,
)


_BGPSRTESEGMENTITYPESUBTLV = _descriptor.Descriptor(
  name='BgpSrteSegmentITypeSubTlv',
  full_name='otg.BgpSrteSegmentITypeSubTlv',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flags', full_name='otg.BgpSrteSegmentITypeSubTlv.flags', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv6_node_address', full_name='otg.BgpSrteSegmentITypeSubTlv.ipv6_node_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='srv6_sid', full_name='otg.BgpSrteSegmentITypeSubTlv.srv6_sid', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='srv6_sid_endpoint_behavior', full_name='otg.BgpSrteSegmentITypeSubTlv.srv6_sid_endpoint_behavior', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_flags', full_name='otg.BgpSrteSegmentITypeSubTlv._flags',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_srv6_sid', full_name='otg.BgpSrteSegmentITypeSubTlv._srv6_sid',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_srv6_sid_endpoint_behavior', full_name='otg.BgpSrteSegmentITypeSubTlv._srv6_sid_endpoint_behavior',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=24501,
  serialized_end=24742,
)


_BGPSRTESEGMENTJTYPESUBTLV = _descriptor.Descriptor(
  name='BgpSrteSegmentJTypeSubTlv',
  full_name='otg.BgpSrteSegmentJTypeSubTlv',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flags', full_name='otg.BgpSrteSegmentJTypeSubTlv.flags', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sr_algorithm', full_name='otg.BgpSrteSegmentJTypeSubTlv.sr_algorithm', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_interface_id', full_name='otg.BgpSrteSegmentJTypeSubTlv.local_interface_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_ipv6_node_address', full_name='otg.BgpSrteSegmentJTypeSubTlv.local_ipv6_node_address', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remote_interface_id', full_name='otg.BgpSrteSegmentJTypeSubTlv.remote_interface_id', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remote_ipv6_node_address', full_name='otg.BgpSrteSegmentJTypeSubTlv.remote_ipv6_node_address', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='srv6_sid', full_name='otg.BgpSrteSegmentJTypeSubTlv.srv6_sid', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='srv6_sid_endpoint_behavior', full_name='otg.BgpSrteSegmentJTypeSubTlv.srv6_sid_endpoint_behavior', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_flags', full_name='otg.BgpSrteSegmentJTypeSubTlv._flags',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_sr_algorithm', full_name='otg.BgpSrteSegmentJTypeSubTlv._sr_algorithm',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_local_interface_id', full_name='otg.BgpSrteSegmentJTypeSubTlv._local_interface_id',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_remote_interface_id', full_name='otg.BgpSrteSegmentJTypeSubTlv._remote_interface_id',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_srv6_sid', full_name='otg.BgpSrteSegmentJTypeSubTlv._srv6_sid',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_srv6_sid_endpoint_behavior', full_name='otg.BgpSrteSegmentJTypeSubTlv._srv6_sid_endpoint_behavior',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=24745,
  serialized_end=25184,
)


_BGPSRTESEGMENTKTYPESUBTLV = _descriptor.Descriptor(
  name='BgpSrteSegmentKTypeSubTlv',
  full_name='otg.BgpSrteSegmentKTypeSubTlv',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flags', full_name='otg.BgpSrteSegmentKTypeSubTlv.flags', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sr_algorithm', full_name='otg.BgpSrteSegmentKTypeSubTlv.sr_algorithm', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_ipv6_address', full_name='otg.BgpSrteSegmentKTypeSubTlv.local_ipv6_address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remote_ipv6_address', full_name='otg.BgpSrteSegmentKTypeSubTlv.remote_ipv6_address', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='srv6_sid', full_name='otg.BgpSrteSegmentKTypeSubTlv.srv6_sid', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='srv6_sid_endpoint_behavior', full_name='otg.BgpSrteSegmentKTypeSubTlv.srv6_sid_endpoint_behavior', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_flags', full_name='otg.BgpSrteSegmentKTypeSubTlv._flags',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_sr_algorithm', full_name='otg.BgpSrteSegmentKTypeSubTlv._sr_algorithm',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_srv6_sid', full_name='otg.BgpSrteSegmentKTypeSubTlv._srv6_sid',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_srv6_sid_endpoint_behavior', full_name='otg.BgpSrteSegmentKTypeSubTlv._srv6_sid_endpoint_behavior',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=25187,
  serialized_end=25502,
)


_BGPSRTEV6POLICY_NEXTHOPMODE = _descriptor.Descriptor(
  name='NextHopMode',
  full_name='otg.BgpSrteV6Policy.NextHopMode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BGPSRTEV6POLICY_NEXTHOPMODE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15831,
  serialized_end=15895,
)

_BGPSRTEV6POLICY_NEXTHOPADDRESSTYPE = _descriptor.Descriptor(
  name='NextHopAddressType',
  full_name='otg.BgpSrteV6Policy.NextHopAddressType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BGPSRTEV6POLICY_NEXTHOPADDRESSTYPE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15897,
  serialized_end=15962,
)

_BGPSRTEV6POLICY = _descriptor.Descriptor(
  name='BgpSrteV6Policy',
  full_name='otg.BgpSrteV6Policy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='distinguisher', full_name='otg.BgpSrteV6Policy.distinguisher', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='color', full_name='otg.BgpSrteV6Policy.color', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv6_endpoint', full_name='otg.BgpSrteV6Policy.ipv6_endpoint', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_hop_mode', full_name='otg.BgpSrteV6Policy.next_hop_mode', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_hop_address_type', full_name='otg.BgpSrteV6Policy.next_hop_address_type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_hop_ipv4_address', full_name='otg.BgpSrteV6Policy.next_hop_ipv4_address', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_hop_ipv6_address', full_name='otg.BgpSrteV6Policy.next_hop_ipv6_address', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='advanced', full_name='otg.BgpSrteV6Policy.advanced', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='add_path', full_name='otg.BgpSrteV6Policy.add_path', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='as_path', full_name='otg.BgpSrteV6Policy.as_path', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='communities', full_name='otg.BgpSrteV6Policy.communities', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extcommunities', full_name='otg.BgpSrteV6Policy.extcommunities', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tunnel_tlvs', full_name='otg.BgpSrteV6Policy.tunnel_tlvs', index=12,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='otg.BgpSrteV6Policy.name', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active', full_name='otg.BgpSrteV6Policy.active', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BGPSRTEV6POLICY_NEXTHOPMODE, _BGPSRTEV6POLICY_NEXTHOPADDRESSTYPE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_distinguisher', full_name='otg.BgpSrteV6Policy._distinguisher',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_color', full_name='otg.BgpSrteV6Policy._color',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_next_hop_mode', full_name='otg.BgpSrteV6Policy._next_hop_mode',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_next_hop_address_type', full_name='otg.BgpSrteV6Policy._next_hop_address_type',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_next_hop_ipv4_address', full_name='otg.BgpSrteV6Policy._next_hop_ipv4_address',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_next_hop_ipv6_address', full_name='otg.BgpSrteV6Policy._next_hop_ipv6_address',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_advanced', full_name='otg.BgpSrteV6Policy._advanced',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_add_path', full_name='otg.BgpSrteV6Policy._add_path',
      index=7, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_as_path', full_name='otg.BgpSrteV6Policy._as_path',
      index=8, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_active', full_name='otg.BgpSrteV6Policy._active',
      index=9, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=25505,
  serialized_end=26411,
)


_BGPSRTEV6TUNNELTLV = _descriptor.Descriptor(
  name='BgpSrteV6TunnelTlv',
  full_name='otg.BgpSrteV6TunnelTlv',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='remote_endpoint_sub_tlv', full_name='otg.BgpSrteV6TunnelTlv.remote_endpoint_sub_tlv', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='color_sub_tlv', full_name='otg.BgpSrteV6TunnelTlv.color_sub_tlv', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='binding_sub_tlv', full_name='otg.BgpSrteV6TunnelTlv.binding_sub_tlv', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preference_sub_tlv', full_name='otg.BgpSrteV6TunnelTlv.preference_sub_tlv', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='policy_priority_sub_tlv', full_name='otg.BgpSrteV6TunnelTlv.policy_priority_sub_tlv', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='policy_name_sub_tlv', full_name='otg.BgpSrteV6TunnelTlv.policy_name_sub_tlv', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='explicit_null_label_policy_sub_tlv', full_name='otg.BgpSrteV6TunnelTlv.explicit_null_label_policy_sub_tlv', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='segment_lists', full_name='otg.BgpSrteV6TunnelTlv.segment_lists', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='otg.BgpSrteV6TunnelTlv.name', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active', full_name='otg.BgpSrteV6TunnelTlv.active', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_remote_endpoint_sub_tlv', full_name='otg.BgpSrteV6TunnelTlv._remote_endpoint_sub_tlv',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_color_sub_tlv', full_name='otg.BgpSrteV6TunnelTlv._color_sub_tlv',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_binding_sub_tlv', full_name='otg.BgpSrteV6TunnelTlv._binding_sub_tlv',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_preference_sub_tlv', full_name='otg.BgpSrteV6TunnelTlv._preference_sub_tlv',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_policy_priority_sub_tlv', full_name='otg.BgpSrteV6TunnelTlv._policy_priority_sub_tlv',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_policy_name_sub_tlv', full_name='otg.BgpSrteV6TunnelTlv._policy_name_sub_tlv',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_explicit_null_label_policy_sub_tlv', full_name='otg.BgpSrteV6TunnelTlv._explicit_null_label_policy_sub_tlv',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_active', full_name='otg.BgpSrteV6TunnelTlv._active',
      index=7, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=26414,
  serialized_end=27181,
)


_BGPV6PEER_ASTYPE = _descriptor.Descriptor(
  name='AsType',
  full_name='otg.BgpV6Peer.AsType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BGPV6PEER_ASTYPE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13582,
  serialized_end=13635,
)

_BGPV6PEER_ASNUMBERWIDTH = _descriptor.Descriptor(
  name='AsNumberWidth',
  full_name='otg.BgpV6Peer.AsNumberWidth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BGPV6PEER_ASNUMBERWIDTH_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13637,
  serialized_end=13696,
)

_BGPV6PEER = _descriptor.Descriptor(
  name='BgpV6Peer',
  full_name='otg.BgpV6Peer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer_address', full_name='otg.BgpV6Peer.peer_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='segment_routing', full_name='otg.BgpV6Peer.segment_routing', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='as_type', full_name='otg.BgpV6Peer.as_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='as_number', full_name='otg.BgpV6Peer.as_number', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='as_number_width', full_name='otg.BgpV6Peer.as_number_width', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='advanced', full_name='otg.BgpV6Peer.advanced', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='capability', full_name='otg.BgpV6Peer.capability', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v4_routes', full_name='otg.BgpV6Peer.v4_routes', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v6_routes', full_name='otg.BgpV6Peer.v6_routes', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v4_srte_policies', full_name='otg.BgpV6Peer.v4_srte_policies', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v6_srte_policies', full_name='otg.BgpV6Peer.v6_srte_policies', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='otg.BgpV6Peer.name', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BGPV6PEER_ASTYPE, _BGPV6PEER_ASNUMBERWIDTH, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_segment_routing', full_name='otg.BgpV6Peer._segment_routing',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_as_number_width', full_name='otg.BgpV6Peer._as_number_width',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_advanced', full_name='otg.BgpV6Peer._advanced',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_capability', full_name='otg.BgpV6Peer._capability',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=27184,
  serialized_end=27864,
)


_BGPV6INTERFACE = _descriptor.Descriptor(
  name='BgpV6Interface',
  full_name='otg.BgpV6Interface',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ipv6_name', full_name='otg.BgpV6Interface.ipv6_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='peers', full_name='otg.BgpV6Interface.peers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27866,
  serialized_end=27932,
)


_BGPV6SEGMENTROUTING = _descriptor.Descriptor(
  name='BgpV6SegmentRouting',
  full_name='otg.BgpV6SegmentRouting',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ingress_supports_vpn', full_name='otg.BgpV6SegmentRouting.ingress_supports_vpn', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reduced_encapsulation', full_name='otg.BgpV6SegmentRouting.reduced_encapsulation', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='copy_time_to_live', full_name='otg.BgpV6SegmentRouting.copy_time_to_live', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_to_live', full_name='otg.BgpV6SegmentRouting.time_to_live', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_sids_per_srh', full_name='otg.BgpV6SegmentRouting.max_sids_per_srh', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_generate_segment_left_value', full_name='otg.BgpV6SegmentRouting.auto_generate_segment_left_value', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='segment_left_value', full_name='otg.BgpV6SegmentRouting.segment_left_value', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='advertise_sr_te_policy', full_name='otg.BgpV6SegmentRouting.advertise_sr_te_policy', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_ingress_supports_vpn', full_name='otg.BgpV6SegmentRouting._ingress_supports_vpn',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_reduced_encapsulation', full_name='otg.BgpV6SegmentRouting._reduced_encapsulation',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_copy_time_to_live', full_name='otg.BgpV6SegmentRouting._copy_time_to_live',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_time_to_live', full_name='otg.BgpV6SegmentRouting._time_to_live',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_max_sids_per_srh', full_name='otg.BgpV6SegmentRouting._max_sids_per_srh',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_auto_generate_segment_left_value', full_name='otg.BgpV6SegmentRouting._auto_generate_segment_left_value',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_segment_left_value', full_name='otg.BgpV6SegmentRouting._segment_left_value',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_advertise_sr_te_policy', full_name='otg.BgpV6SegmentRouting._advertise_sr_te_policy',
      index=7, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=27935,
  serialized_end=28432,
)


_FLOW = _descriptor.Descriptor(
  name='Flow',
  full_name='otg.Flow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx_rx', full_name='otg.Flow.tx_rx', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packet', full_name='otg.Flow.packet', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='otg.Flow.size', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rate', full_name='otg.Flow.rate', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duration', full_name='otg.Flow.duration', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metrics', full_name='otg.Flow.metrics', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='otg.Flow.name', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_size', full_name='otg.Flow._size',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_rate', full_name='otg.Flow._rate',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_duration', full_name='otg.Flow._duration',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metrics', full_name='otg.Flow._metrics',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=28435,
  serialized_end=28711,
)


_FLOWTXRX_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.FlowTxRx.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FLOWTXRX_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28846,
  serialized_end=28901,
)

_FLOWTXRX = _descriptor.Descriptor(
  name='FlowTxRx',
  full_name='otg.FlowTxRx',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.FlowTxRx.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='otg.FlowTxRx.port', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='otg.FlowTxRx.device', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FLOWTXRX_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.FlowTxRx._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_port', full_name='otg.FlowTxRx._port',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_device', full_name='otg.FlowTxRx._device',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=28714,
  serialized_end=28932,
)


_FLOWPORT = _descriptor.Descriptor(
  name='FlowPort',
  full_name='otg.FlowPort',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx_name', full_name='otg.FlowPort.tx_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rx_name', full_name='otg.FlowPort.rx_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_rx_name', full_name='otg.FlowPort._rx_name',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=28934,
  serialized_end=28995,
)


_FLOWROUTER_MODE = _descriptor.Descriptor(
  name='Mode',
  full_name='otg.FlowRouter.Mode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FLOWROUTER_MODE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29094,
  serialized_end=29151,
)

_FLOWROUTER = _descriptor.Descriptor(
  name='FlowRouter',
  full_name='otg.FlowRouter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='otg.FlowRouter.mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_names', full_name='otg.FlowRouter.tx_names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rx_names', full_name='otg.FlowRouter.rx_names', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FLOWROUTER_MODE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_mode', full_name='otg.FlowRouter._mode',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=28998,
  serialized_end=29160,
)


_FLOWHEADER_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.FlowHeader.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FLOWHEADER_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29882,
  serialized_end=30117,
)

_FLOWHEADER = _descriptor.Descriptor(
  name='FlowHeader',
  full_name='otg.FlowHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.FlowHeader.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom', full_name='otg.FlowHeader.custom', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ethernet', full_name='otg.FlowHeader.ethernet', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vlan', full_name='otg.FlowHeader.vlan', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vxlan', full_name='otg.FlowHeader.vxlan', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv4', full_name='otg.FlowHeader.ipv4', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv6', full_name='otg.FlowHeader.ipv6', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pfcpause', full_name='otg.FlowHeader.pfcpause', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ethernetpause', full_name='otg.FlowHeader.ethernetpause', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tcp', full_name='otg.FlowHeader.tcp', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='udp', full_name='otg.FlowHeader.udp', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gre', full_name='otg.FlowHeader.gre', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gtpv1', full_name='otg.FlowHeader.gtpv1', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gtpv2', full_name='otg.FlowHeader.gtpv2', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arp', full_name='otg.FlowHeader.arp', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='icmp', full_name='otg.FlowHeader.icmp', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='icmpv6', full_name='otg.FlowHeader.icmpv6', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ppp', full_name='otg.FlowHeader.ppp', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='igmpv1', full_name='otg.FlowHeader.igmpv1', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FLOWHEADER_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.FlowHeader._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_custom', full_name='otg.FlowHeader._custom',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ethernet', full_name='otg.FlowHeader._ethernet',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_vlan', full_name='otg.FlowHeader._vlan',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_vxlan', full_name='otg.FlowHeader._vxlan',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ipv4', full_name='otg.FlowHeader._ipv4',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ipv6', full_name='otg.FlowHeader._ipv6',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_pfcpause', full_name='otg.FlowHeader._pfcpause',
      index=7, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ethernetpause', full_name='otg.FlowHeader._ethernetpause',
      index=8, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_tcp', full_name='otg.FlowHeader._tcp',
      index=9, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_udp', full_name='otg.FlowHeader._udp',
      index=10, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_gre', full_name='otg.FlowHeader._gre',
      index=11, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_gtpv1', full_name='otg.FlowHeader._gtpv1',
      index=12, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_gtpv2', full_name='otg.FlowHeader._gtpv2',
      index=13, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_arp', full_name='otg.FlowHeader._arp',
      index=14, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_icmp', full_name='otg.FlowHeader._icmp',
      index=15, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_icmpv6', full_name='otg.FlowHeader._icmpv6',
      index=16, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ppp', full_name='otg.FlowHeader._ppp',
      index=17, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_igmpv1', full_name='otg.FlowHeader._igmpv1',
      index=18, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=29163,
  serialized_end=30311,
)


_FLOWCUSTOM = _descriptor.Descriptor(
  name='FlowCustom',
  full_name='otg.FlowCustom',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bytes', full_name='otg.FlowCustom.bytes', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=30313,
  serialized_end=30340,
)


_FLOWETHERNET = _descriptor.Descriptor(
  name='FlowEthernet',
  full_name='otg.FlowEthernet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dst', full_name='otg.FlowEthernet.dst', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='src', full_name='otg.FlowEthernet.src', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ether_type', full_name='otg.FlowEthernet.ether_type', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pfc_queue', full_name='otg.FlowEthernet.pfc_queue', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_dst', full_name='otg.FlowEthernet._dst',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_src', full_name='otg.FlowEthernet._src',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ether_type', full_name='otg.FlowEthernet._ether_type',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_pfc_queue', full_name='otg.FlowEthernet._pfc_queue',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=30343,
  serialized_end=30614,
)


_FLOWVLAN = _descriptor.Descriptor(
  name='FlowVlan',
  full_name='otg.FlowVlan',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='priority', full_name='otg.FlowVlan.priority', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cfi', full_name='otg.FlowVlan.cfi', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='otg.FlowVlan.id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tpid', full_name='otg.FlowVlan.tpid', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_priority', full_name='otg.FlowVlan._priority',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_cfi', full_name='otg.FlowVlan._cfi',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_id', full_name='otg.FlowVlan._id',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_tpid', full_name='otg.FlowVlan._tpid',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=30617,
  serialized_end=30846,
)


_FLOWVXLAN = _descriptor.Descriptor(
  name='FlowVxlan',
  full_name='otg.FlowVxlan',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flags', full_name='otg.FlowVxlan.flags', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reserved0', full_name='otg.FlowVxlan.reserved0', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vni', full_name='otg.FlowVxlan.vni', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reserved1', full_name='otg.FlowVxlan.reserved1', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_flags', full_name='otg.FlowVxlan._flags',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_reserved0', full_name='otg.FlowVxlan._reserved0',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_vni', full_name='otg.FlowVxlan._vni',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_reserved1', full_name='otg.FlowVxlan._reserved1',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=30849,
  serialized_end=31110,
)


_FLOWIPV4 = _descriptor.Descriptor(
  name='FlowIpv4',
  full_name='otg.FlowIpv4',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='otg.FlowIpv4.version', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header_length', full_name='otg.FlowIpv4.header_length', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority', full_name='otg.FlowIpv4.priority', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_length', full_name='otg.FlowIpv4.total_length', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='identification', full_name='otg.FlowIpv4.identification', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reserved', full_name='otg.FlowIpv4.reserved', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dont_fragment', full_name='otg.FlowIpv4.dont_fragment', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='more_fragments', full_name='otg.FlowIpv4.more_fragments', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fragment_offset', full_name='otg.FlowIpv4.fragment_offset', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_to_live', full_name='otg.FlowIpv4.time_to_live', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='otg.FlowIpv4.protocol', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header_checksum', full_name='otg.FlowIpv4.header_checksum', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='src', full_name='otg.FlowIpv4.src', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dst', full_name='otg.FlowIpv4.dst', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_version', full_name='otg.FlowIpv4._version',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_header_length', full_name='otg.FlowIpv4._header_length',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_priority', full_name='otg.FlowIpv4._priority',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_total_length', full_name='otg.FlowIpv4._total_length',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_identification', full_name='otg.FlowIpv4._identification',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_reserved', full_name='otg.FlowIpv4._reserved',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_dont_fragment', full_name='otg.FlowIpv4._dont_fragment',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_more_fragments', full_name='otg.FlowIpv4._more_fragments',
      index=7, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_fragment_offset', full_name='otg.FlowIpv4._fragment_offset',
      index=8, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_time_to_live', full_name='otg.FlowIpv4._time_to_live',
      index=9, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_protocol', full_name='otg.FlowIpv4._protocol',
      index=10, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_header_checksum', full_name='otg.FlowIpv4._header_checksum',
      index=11, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_src', full_name='otg.FlowIpv4._src',
      index=12, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_dst', full_name='otg.FlowIpv4._dst',
      index=13, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=31113,
  serialized_end=32131,
)


_FLOWIPV4PRIORITY_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.FlowIpv4Priority.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FLOWIPV4PRIORITY_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32335,
  serialized_end=32396,
)

_FLOWIPV4PRIORITY = _descriptor.Descriptor(
  name='FlowIpv4Priority',
  full_name='otg.FlowIpv4Priority',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.FlowIpv4Priority.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw', full_name='otg.FlowIpv4Priority.raw', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tos', full_name='otg.FlowIpv4Priority.tos', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dscp', full_name='otg.FlowIpv4Priority.dscp', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FLOWIPV4PRIORITY_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.FlowIpv4Priority._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_raw', full_name='otg.FlowIpv4Priority._raw',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_tos', full_name='otg.FlowIpv4Priority._tos',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_dscp', full_name='otg.FlowIpv4Priority._dscp',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=32134,
  serialized_end=32432,
)


_FLOWIPV4DSCP = _descriptor.Descriptor(
  name='FlowIpv4Dscp',
  full_name='otg.FlowIpv4Dscp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='phb', full_name='otg.FlowIpv4Dscp.phb', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ecn', full_name='otg.FlowIpv4Dscp.ecn', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_phb', full_name='otg.FlowIpv4Dscp._phb',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ecn', full_name='otg.FlowIpv4Dscp._ecn',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=32434,
  serialized_end=32558,
)


_FLOWIPV4TOS = _descriptor.Descriptor(
  name='FlowIpv4Tos',
  full_name='otg.FlowIpv4Tos',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='precedence', full_name='otg.FlowIpv4Tos.precedence', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delay', full_name='otg.FlowIpv4Tos.delay', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='throughput', full_name='otg.FlowIpv4Tos.throughput', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reliability', full_name='otg.FlowIpv4Tos.reliability', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='monetary', full_name='otg.FlowIpv4Tos.monetary', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unused', full_name='otg.FlowIpv4Tos.unused', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_precedence', full_name='otg.FlowIpv4Tos._precedence',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_delay', full_name='otg.FlowIpv4Tos._delay',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_throughput', full_name='otg.FlowIpv4Tos._throughput',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_reliability', full_name='otg.FlowIpv4Tos._reliability',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_monetary', full_name='otg.FlowIpv4Tos._monetary',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_unused', full_name='otg.FlowIpv4Tos._unused',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=32561,
  serialized_end=32994,
)


_FLOWIPV6 = _descriptor.Descriptor(
  name='FlowIpv6',
  full_name='otg.FlowIpv6',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='otg.FlowIpv6.version', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic_class', full_name='otg.FlowIpv6.traffic_class', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flow_label', full_name='otg.FlowIpv6.flow_label', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload_length', full_name='otg.FlowIpv6.payload_length', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_header', full_name='otg.FlowIpv6.next_header', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hop_limit', full_name='otg.FlowIpv6.hop_limit', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='src', full_name='otg.FlowIpv6.src', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dst', full_name='otg.FlowIpv6.dst', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_version', full_name='otg.FlowIpv6._version',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_traffic_class', full_name='otg.FlowIpv6._traffic_class',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_flow_label', full_name='otg.FlowIpv6._flow_label',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_payload_length', full_name='otg.FlowIpv6._payload_length',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_next_header', full_name='otg.FlowIpv6._next_header',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_hop_limit', full_name='otg.FlowIpv6._hop_limit',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_src', full_name='otg.FlowIpv6._src',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_dst', full_name='otg.FlowIpv6._dst',
      index=7, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=32997,
  serialized_end=33548,
)


_FLOWPFCPAUSE = _descriptor.Descriptor(
  name='FlowPfcPause',
  full_name='otg.FlowPfcPause',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dst', full_name='otg.FlowPfcPause.dst', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='src', full_name='otg.FlowPfcPause.src', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ether_type', full_name='otg.FlowPfcPause.ether_type', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='control_op_code', full_name='otg.FlowPfcPause.control_op_code', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='class_enable_vector', full_name='otg.FlowPfcPause.class_enable_vector', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pause_class_0', full_name='otg.FlowPfcPause.pause_class_0', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pause_class_1', full_name='otg.FlowPfcPause.pause_class_1', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pause_class_2', full_name='otg.FlowPfcPause.pause_class_2', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pause_class_3', full_name='otg.FlowPfcPause.pause_class_3', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pause_class_4', full_name='otg.FlowPfcPause.pause_class_4', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pause_class_5', full_name='otg.FlowPfcPause.pause_class_5', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pause_class_6', full_name='otg.FlowPfcPause.pause_class_6', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pause_class_7', full_name='otg.FlowPfcPause.pause_class_7', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_dst', full_name='otg.FlowPfcPause._dst',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_src', full_name='otg.FlowPfcPause._src',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ether_type', full_name='otg.FlowPfcPause._ether_type',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_control_op_code', full_name='otg.FlowPfcPause._control_op_code',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_class_enable_vector', full_name='otg.FlowPfcPause._class_enable_vector',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_pause_class_0', full_name='otg.FlowPfcPause._pause_class_0',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_pause_class_1', full_name='otg.FlowPfcPause._pause_class_1',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_pause_class_2', full_name='otg.FlowPfcPause._pause_class_2',
      index=7, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_pause_class_3', full_name='otg.FlowPfcPause._pause_class_3',
      index=8, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_pause_class_4', full_name='otg.FlowPfcPause._pause_class_4',
      index=9, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_pause_class_5', full_name='otg.FlowPfcPause._pause_class_5',
      index=10, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_pause_class_6', full_name='otg.FlowPfcPause._pause_class_6',
      index=11, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_pause_class_7', full_name='otg.FlowPfcPause._pause_class_7',
      index=12, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=33551,
  serialized_end=34604,
)


_FLOWETHERNETPAUSE = _descriptor.Descriptor(
  name='FlowEthernetPause',
  full_name='otg.FlowEthernetPause',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dst', full_name='otg.FlowEthernetPause.dst', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='src', full_name='otg.FlowEthernetPause.src', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ether_type', full_name='otg.FlowEthernetPause.ether_type', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='control_op_code', full_name='otg.FlowEthernetPause.control_op_code', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='otg.FlowEthernetPause.time', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_dst', full_name='otg.FlowEthernetPause._dst',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_src', full_name='otg.FlowEthernetPause._src',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ether_type', full_name='otg.FlowEthernetPause._ether_type',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_control_op_code', full_name='otg.FlowEthernetPause._control_op_code',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_time', full_name='otg.FlowEthernetPause._time',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=34607,
  serialized_end=34983,
)


_FLOWTCP = _descriptor.Descriptor(
  name='FlowTcp',
  full_name='otg.FlowTcp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='src_port', full_name='otg.FlowTcp.src_port', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dst_port', full_name='otg.FlowTcp.dst_port', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seq_num', full_name='otg.FlowTcp.seq_num', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ack_num', full_name='otg.FlowTcp.ack_num', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_offset', full_name='otg.FlowTcp.data_offset', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ecn_ns', full_name='otg.FlowTcp.ecn_ns', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ecn_cwr', full_name='otg.FlowTcp.ecn_cwr', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ecn_echo', full_name='otg.FlowTcp.ecn_echo', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ctl_urg', full_name='otg.FlowTcp.ctl_urg', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ctl_ack', full_name='otg.FlowTcp.ctl_ack', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ctl_psh', full_name='otg.FlowTcp.ctl_psh', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ctl_rst', full_name='otg.FlowTcp.ctl_rst', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ctl_syn', full_name='otg.FlowTcp.ctl_syn', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ctl_fin', full_name='otg.FlowTcp.ctl_fin', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='window', full_name='otg.FlowTcp.window', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_src_port', full_name='otg.FlowTcp._src_port',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_dst_port', full_name='otg.FlowTcp._dst_port',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_seq_num', full_name='otg.FlowTcp._seq_num',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ack_num', full_name='otg.FlowTcp._ack_num',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_data_offset', full_name='otg.FlowTcp._data_offset',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ecn_ns', full_name='otg.FlowTcp._ecn_ns',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ecn_cwr', full_name='otg.FlowTcp._ecn_cwr',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ecn_echo', full_name='otg.FlowTcp._ecn_echo',
      index=7, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ctl_urg', full_name='otg.FlowTcp._ctl_urg',
      index=8, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ctl_ack', full_name='otg.FlowTcp._ctl_ack',
      index=9, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ctl_psh', full_name='otg.FlowTcp._ctl_psh',
      index=10, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ctl_rst', full_name='otg.FlowTcp._ctl_rst',
      index=11, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ctl_syn', full_name='otg.FlowTcp._ctl_syn',
      index=12, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ctl_fin', full_name='otg.FlowTcp._ctl_fin',
      index=13, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_window', full_name='otg.FlowTcp._window',
      index=14, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=34986,
  serialized_end=35926,
)


_FLOWUDP = _descriptor.Descriptor(
  name='FlowUdp',
  full_name='otg.FlowUdp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='src_port', full_name='otg.FlowUdp.src_port', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dst_port', full_name='otg.FlowUdp.dst_port', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length', full_name='otg.FlowUdp.length', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checksum', full_name='otg.FlowUdp.checksum', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_src_port', full_name='otg.FlowUdp._src_port',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_dst_port', full_name='otg.FlowUdp._dst_port',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_length', full_name='otg.FlowUdp._length',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_checksum', full_name='otg.FlowUdp._checksum',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=35929,
  serialized_end=36190,
)


_FLOWGRE = _descriptor.Descriptor(
  name='FlowGre',
  full_name='otg.FlowGre',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='checksum_present', full_name='otg.FlowGre.checksum_present', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reserved0', full_name='otg.FlowGre.reserved0', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='otg.FlowGre.version', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='otg.FlowGre.protocol', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checksum', full_name='otg.FlowGre.checksum', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reserved1', full_name='otg.FlowGre.reserved1', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_checksum_present', full_name='otg.FlowGre._checksum_present',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_reserved0', full_name='otg.FlowGre._reserved0',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_version', full_name='otg.FlowGre._version',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_protocol', full_name='otg.FlowGre._protocol',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_checksum', full_name='otg.FlowGre._checksum',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_reserved1', full_name='otg.FlowGre._reserved1',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=36193,
  serialized_end=36618,
)


_FLOWGTPV1 = _descriptor.Descriptor(
  name='FlowGtpv1',
  full_name='otg.FlowGtpv1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='otg.FlowGtpv1.version', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol_type', full_name='otg.FlowGtpv1.protocol_type', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reserved', full_name='otg.FlowGtpv1.reserved', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='e_flag', full_name='otg.FlowGtpv1.e_flag', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s_flag', full_name='otg.FlowGtpv1.s_flag', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pn_flag', full_name='otg.FlowGtpv1.pn_flag', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_type', full_name='otg.FlowGtpv1.message_type', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_length', full_name='otg.FlowGtpv1.message_length', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='teid', full_name='otg.FlowGtpv1.teid', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='squence_number', full_name='otg.FlowGtpv1.squence_number', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='n_pdu_number', full_name='otg.FlowGtpv1.n_pdu_number', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_extension_header_type', full_name='otg.FlowGtpv1.next_extension_header_type', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extension_headers', full_name='otg.FlowGtpv1.extension_headers', index=12,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_version', full_name='otg.FlowGtpv1._version',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_protocol_type', full_name='otg.FlowGtpv1._protocol_type',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_reserved', full_name='otg.FlowGtpv1._reserved',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_e_flag', full_name='otg.FlowGtpv1._e_flag',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_s_flag', full_name='otg.FlowGtpv1._s_flag',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_pn_flag', full_name='otg.FlowGtpv1._pn_flag',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_message_type', full_name='otg.FlowGtpv1._message_type',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_message_length', full_name='otg.FlowGtpv1._message_length',
      index=7, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_teid', full_name='otg.FlowGtpv1._teid',
      index=8, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_squence_number', full_name='otg.FlowGtpv1._squence_number',
      index=9, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_n_pdu_number', full_name='otg.FlowGtpv1._n_pdu_number',
      index=10, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_next_extension_header_type', full_name='otg.FlowGtpv1._next_extension_header_type',
      index=11, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=36621,
  serialized_end=37573,
)


_FLOWGTPEXTENSION = _descriptor.Descriptor(
  name='FlowGtpExtension',
  full_name='otg.FlowGtpExtension',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='extension_length', full_name='otg.FlowGtpExtension.extension_length', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contents', full_name='otg.FlowGtpExtension.contents', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_extension_header', full_name='otg.FlowGtpExtension.next_extension_header', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_extension_length', full_name='otg.FlowGtpExtension._extension_length',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_contents', full_name='otg.FlowGtpExtension._contents',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_next_extension_header', full_name='otg.FlowGtpExtension._next_extension_header',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=37576,
  serialized_end=37876,
)


_FLOWGTPV2 = _descriptor.Descriptor(
  name='FlowGtpv2',
  full_name='otg.FlowGtpv2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='otg.FlowGtpv2.version', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='piggybacking_flag', full_name='otg.FlowGtpv2.piggybacking_flag', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='teid_flag', full_name='otg.FlowGtpv2.teid_flag', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spare1', full_name='otg.FlowGtpv2.spare1', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_type', full_name='otg.FlowGtpv2.message_type', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_length', full_name='otg.FlowGtpv2.message_length', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='teid', full_name='otg.FlowGtpv2.teid', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sequence_number', full_name='otg.FlowGtpv2.sequence_number', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spare2', full_name='otg.FlowGtpv2.spare2', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_version', full_name='otg.FlowGtpv2._version',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_piggybacking_flag', full_name='otg.FlowGtpv2._piggybacking_flag',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_teid_flag', full_name='otg.FlowGtpv2._teid_flag',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_spare1', full_name='otg.FlowGtpv2._spare1',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_message_type', full_name='otg.FlowGtpv2._message_type',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_message_length', full_name='otg.FlowGtpv2._message_length',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_teid', full_name='otg.FlowGtpv2._teid',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_sequence_number', full_name='otg.FlowGtpv2._sequence_number',
      index=7, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_spare2', full_name='otg.FlowGtpv2._spare2',
      index=8, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=37879,
  serialized_end=38542,
)


_FLOWARP = _descriptor.Descriptor(
  name='FlowArp',
  full_name='otg.FlowArp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hardware_type', full_name='otg.FlowArp.hardware_type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol_type', full_name='otg.FlowArp.protocol_type', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hardware_length', full_name='otg.FlowArp.hardware_length', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol_length', full_name='otg.FlowArp.protocol_length', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation', full_name='otg.FlowArp.operation', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sender_hardware_addr', full_name='otg.FlowArp.sender_hardware_addr', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sender_protocol_addr', full_name='otg.FlowArp.sender_protocol_addr', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_hardware_addr', full_name='otg.FlowArp.target_hardware_addr', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_protocol_addr', full_name='otg.FlowArp.target_protocol_addr', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_hardware_type', full_name='otg.FlowArp._hardware_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_protocol_type', full_name='otg.FlowArp._protocol_type',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_hardware_length', full_name='otg.FlowArp._hardware_length',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_protocol_length', full_name='otg.FlowArp._protocol_length',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_operation', full_name='otg.FlowArp._operation',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_sender_hardware_addr', full_name='otg.FlowArp._sender_hardware_addr',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_sender_protocol_addr', full_name='otg.FlowArp._sender_protocol_addr',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_target_hardware_addr', full_name='otg.FlowArp._target_hardware_addr',
      index=7, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_target_protocol_addr', full_name='otg.FlowArp._target_protocol_addr',
      index=8, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=38545,
  serialized_end=39346,
)


_FLOWICMP_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.FlowIcmp.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FLOWICMP_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=39447,
  serialized_end=39490,
)

_FLOWICMP = _descriptor.Descriptor(
  name='FlowIcmp',
  full_name='otg.FlowIcmp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.FlowIcmp.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='echo', full_name='otg.FlowIcmp.echo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FLOWICMP_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.FlowIcmp._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_echo', full_name='otg.FlowIcmp._echo',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=39349,
  serialized_end=39510,
)


_FLOWICMPECHO = _descriptor.Descriptor(
  name='FlowIcmpEcho',
  full_name='otg.FlowIcmpEcho',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='otg.FlowIcmpEcho.type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='otg.FlowIcmpEcho.code', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checksum', full_name='otg.FlowIcmpEcho.checksum', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='identifier', full_name='otg.FlowIcmpEcho.identifier', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sequence_number', full_name='otg.FlowIcmpEcho.sequence_number', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_type', full_name='otg.FlowIcmpEcho._type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_code', full_name='otg.FlowIcmpEcho._code',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_checksum', full_name='otg.FlowIcmpEcho._checksum',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_identifier', full_name='otg.FlowIcmpEcho._identifier',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_sequence_number', full_name='otg.FlowIcmpEcho._sequence_number',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=39513,
  serialized_end=39879,
)


_FLOWICMPV6_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.FlowIcmpv6.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FLOWICMPV6_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=39447,
  serialized_end=39490,
)

_FLOWICMPV6 = _descriptor.Descriptor(
  name='FlowIcmpv6',
  full_name='otg.FlowIcmpv6',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.FlowIcmpv6.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='echo', full_name='otg.FlowIcmpv6.echo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FLOWICMPV6_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.FlowIcmpv6._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_echo', full_name='otg.FlowIcmpv6._echo',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=39882,
  serialized_end=40049,
)


_FLOWICMPV6ECHO = _descriptor.Descriptor(
  name='FlowIcmpv6Echo',
  full_name='otg.FlowIcmpv6Echo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='otg.FlowIcmpv6Echo.type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='otg.FlowIcmpv6Echo.code', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='identifier', full_name='otg.FlowIcmpv6Echo.identifier', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sequence_number', full_name='otg.FlowIcmpv6Echo.sequence_number', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checksum', full_name='otg.FlowIcmpv6Echo.checksum', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_type', full_name='otg.FlowIcmpv6Echo._type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_code', full_name='otg.FlowIcmpv6Echo._code',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_identifier', full_name='otg.FlowIcmpv6Echo._identifier',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_sequence_number', full_name='otg.FlowIcmpv6Echo._sequence_number',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_checksum', full_name='otg.FlowIcmpv6Echo._checksum',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=40052,
  serialized_end=40430,
)


_FLOWPPP = _descriptor.Descriptor(
  name='FlowPpp',
  full_name='otg.FlowPpp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='otg.FlowPpp.address', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='control', full_name='otg.FlowPpp.control', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol_type', full_name='otg.FlowPpp.protocol_type', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_address', full_name='otg.FlowPpp._address',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_control', full_name='otg.FlowPpp._control',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_protocol_type', full_name='otg.FlowPpp._protocol_type',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=40433,
  serialized_end=40645,
)


_FLOWIGMPV1 = _descriptor.Descriptor(
  name='FlowIgmpv1',
  full_name='otg.FlowIgmpv1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='otg.FlowIgmpv1.version', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='otg.FlowIgmpv1.type', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unused', full_name='otg.FlowIgmpv1.unused', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checksum', full_name='otg.FlowIgmpv1.checksum', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_address', full_name='otg.FlowIgmpv1.group_address', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_version', full_name='otg.FlowIgmpv1._version',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_type', full_name='otg.FlowIgmpv1._type',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_unused', full_name='otg.FlowIgmpv1._unused',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_checksum', full_name='otg.FlowIgmpv1._checksum',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_group_address', full_name='otg.FlowIgmpv1._group_address',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=40648,
  serialized_end=40993,
)


_FLOWSIZE_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.FlowSize.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FLOWSIZE_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=41166,
  serialized_end=41237,
)

_FLOWSIZE = _descriptor.Descriptor(
  name='FlowSize',
  full_name='otg.FlowSize',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.FlowSize.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fixed', full_name='otg.FlowSize.fixed', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.FlowSize.increment', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='random', full_name='otg.FlowSize.random', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FLOWSIZE_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.FlowSize._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_fixed', full_name='otg.FlowSize._fixed',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.FlowSize._increment',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_random', full_name='otg.FlowSize._random',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=40996,
  serialized_end=41283,
)


_FLOWSIZEINCREMENT = _descriptor.Descriptor(
  name='FlowSizeIncrement',
  full_name='otg.FlowSizeIncrement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.FlowSizeIncrement.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end', full_name='otg.FlowSizeIncrement.end', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.FlowSizeIncrement.step', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.FlowSizeIncrement._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_end', full_name='otg.FlowSizeIncrement._end',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.FlowSizeIncrement._step',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=41285,
  serialized_end=41388,
)


_FLOWSIZERANDOM = _descriptor.Descriptor(
  name='FlowSizeRandom',
  full_name='otg.FlowSizeRandom',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min', full_name='otg.FlowSizeRandom.min', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max', full_name='otg.FlowSizeRandom.max', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_min', full_name='otg.FlowSizeRandom._min',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_max', full_name='otg.FlowSizeRandom._max',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=41390,
  serialized_end=41458,
)


_FLOWRATE_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.FlowRate.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FLOWRATE_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=41639,
  serialized_end=41736,
)

_FLOWRATE = _descriptor.Descriptor(
  name='FlowRate',
  full_name='otg.FlowRate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.FlowRate.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pps', full_name='otg.FlowRate.pps', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bps', full_name='otg.FlowRate.bps', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kbps', full_name='otg.FlowRate.kbps', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mbps', full_name='otg.FlowRate.mbps', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gbps', full_name='otg.FlowRate.gbps', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percentage', full_name='otg.FlowRate.percentage', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FLOWRATE_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.FlowRate._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_pps', full_name='otg.FlowRate._pps',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_bps', full_name='otg.FlowRate._bps',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_kbps', full_name='otg.FlowRate._kbps',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_mbps', full_name='otg.FlowRate._mbps',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_gbps', full_name='otg.FlowRate._gbps',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_percentage', full_name='otg.FlowRate._percentage',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=41461,
  serialized_end=41805,
)


_FLOWDURATION_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.FlowDuration.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FLOWDURATION_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=42060,
  serialized_end=42158,
)

_FLOWDURATION = _descriptor.Descriptor(
  name='FlowDuration',
  full_name='otg.FlowDuration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.FlowDuration.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fixed_packets', full_name='otg.FlowDuration.fixed_packets', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fixed_seconds', full_name='otg.FlowDuration.fixed_seconds', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='burst', full_name='otg.FlowDuration.burst', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='continuous', full_name='otg.FlowDuration.continuous', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FLOWDURATION_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.FlowDuration._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_fixed_packets', full_name='otg.FlowDuration._fixed_packets',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_fixed_seconds', full_name='otg.FlowDuration._fixed_seconds',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_burst', full_name='otg.FlowDuration._burst',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_continuous', full_name='otg.FlowDuration._continuous',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=41808,
  serialized_end=42230,
)


_FLOWCONTINUOUS = _descriptor.Descriptor(
  name='FlowContinuous',
  full_name='otg.FlowContinuous',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gap', full_name='otg.FlowContinuous.gap', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delay', full_name='otg.FlowContinuous.delay', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_gap', full_name='otg.FlowContinuous._gap',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_delay', full_name='otg.FlowContinuous._delay',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=42232,
  serialized_end=42320,
)


_FLOWDELAY_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.FlowDelay.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FLOWDELAY_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=42458,
  serialized_end=42537,
)

_FLOWDELAY = _descriptor.Descriptor(
  name='FlowDelay',
  full_name='otg.FlowDelay',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.FlowDelay.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes', full_name='otg.FlowDelay.bytes', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nanoseconds', full_name='otg.FlowDelay.nanoseconds', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='microseconds', full_name='otg.FlowDelay.microseconds', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FLOWDELAY_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.FlowDelay._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_bytes', full_name='otg.FlowDelay._bytes',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_nanoseconds', full_name='otg.FlowDelay._nanoseconds',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_microseconds', full_name='otg.FlowDelay._microseconds',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=42323,
  serialized_end=42591,
)


_FLOWFIXEDPACKETS = _descriptor.Descriptor(
  name='FlowFixedPackets',
  full_name='otg.FlowFixedPackets',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='packets', full_name='otg.FlowFixedPackets.packets', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gap', full_name='otg.FlowFixedPackets.gap', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delay', full_name='otg.FlowFixedPackets.delay', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_packets', full_name='otg.FlowFixedPackets._packets',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_gap', full_name='otg.FlowFixedPackets._gap',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_delay', full_name='otg.FlowFixedPackets._delay',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=42593,
  serialized_end=42717,
)


_FLOWFIXEDSECONDS = _descriptor.Descriptor(
  name='FlowFixedSeconds',
  full_name='otg.FlowFixedSeconds',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='seconds', full_name='otg.FlowFixedSeconds.seconds', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gap', full_name='otg.FlowFixedSeconds.gap', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delay', full_name='otg.FlowFixedSeconds.delay', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_seconds', full_name='otg.FlowFixedSeconds._seconds',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_gap', full_name='otg.FlowFixedSeconds._gap',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_delay', full_name='otg.FlowFixedSeconds._delay',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=42719,
  serialized_end=42843,
)


_FLOWBURST = _descriptor.Descriptor(
  name='FlowBurst',
  full_name='otg.FlowBurst',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bursts', full_name='otg.FlowBurst.bursts', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packets', full_name='otg.FlowBurst.packets', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gap', full_name='otg.FlowBurst.gap', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inter_burst_gap', full_name='otg.FlowBurst.inter_burst_gap', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_bursts', full_name='otg.FlowBurst._bursts',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_packets', full_name='otg.FlowBurst._packets',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_gap', full_name='otg.FlowBurst._gap',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_inter_burst_gap', full_name='otg.FlowBurst._inter_burst_gap',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=42846,
  serialized_end=43031,
)


_FLOWDURATIONINTERBURSTGAP_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.FlowDurationInterBurstGap.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FLOWDURATIONINTERBURSTGAP_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=42458,
  serialized_end=42537,
)

_FLOWDURATIONINTERBURSTGAP = _descriptor.Descriptor(
  name='FlowDurationInterBurstGap',
  full_name='otg.FlowDurationInterBurstGap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.FlowDurationInterBurstGap.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes', full_name='otg.FlowDurationInterBurstGap.bytes', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nanoseconds', full_name='otg.FlowDurationInterBurstGap.nanoseconds', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='microseconds', full_name='otg.FlowDurationInterBurstGap.microseconds', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FLOWDURATIONINTERBURSTGAP_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.FlowDurationInterBurstGap._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_bytes', full_name='otg.FlowDurationInterBurstGap._bytes',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_nanoseconds', full_name='otg.FlowDurationInterBurstGap._nanoseconds',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_microseconds', full_name='otg.FlowDurationInterBurstGap._microseconds',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=43034,
  serialized_end=43334,
)


_FLOWMETRICS = _descriptor.Descriptor(
  name='FlowMetrics',
  full_name='otg.FlowMetrics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enable', full_name='otg.FlowMetrics.enable', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loss', full_name='otg.FlowMetrics.loss', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamps', full_name='otg.FlowMetrics.timestamps', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latency', full_name='otg.FlowMetrics.latency', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_enable', full_name='otg.FlowMetrics._enable',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_loss', full_name='otg.FlowMetrics._loss',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_timestamps', full_name='otg.FlowMetrics._timestamps',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_latency', full_name='otg.FlowMetrics._latency',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=43337,
  serialized_end=43509,
)


_FLOWLATENCYMETRICS_MODE = _descriptor.Descriptor(
  name='Mode',
  full_name='otg.FlowLatencyMetrics.Mode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FLOWLATENCYMETRICS_MODE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=43609,
  serialized_end=43676,
)

_FLOWLATENCYMETRICS = _descriptor.Descriptor(
  name='FlowLatencyMetrics',
  full_name='otg.FlowLatencyMetrics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enable', full_name='otg.FlowLatencyMetrics.enable', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='otg.FlowLatencyMetrics.mode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FLOWLATENCYMETRICS_MODE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_enable', full_name='otg.FlowLatencyMetrics._enable',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_mode', full_name='otg.FlowLatencyMetrics._mode',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=43512,
  serialized_end=43696,
)


_EVENT = _descriptor.Descriptor(
  name='Event',
  full_name='otg.Event',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enable', full_name='otg.Event.enable', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link', full_name='otg.Event.link', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rx_rate_threshold', full_name='otg.Event.rx_rate_threshold', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_advertise_withdraw', full_name='otg.Event.route_advertise_withdraw', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_enable', full_name='otg.Event._enable',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_link', full_name='otg.Event._link',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_rx_rate_threshold', full_name='otg.Event._rx_rate_threshold',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_route_advertise_withdraw', full_name='otg.Event._route_advertise_withdraw',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=43699,
  serialized_end=43965,
)


_EVENTRXRATETHRESHOLD = _descriptor.Descriptor(
  name='EventRxRateThreshold',
  full_name='otg.EventRxRateThreshold',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enable', full_name='otg.EventRxRateThreshold.enable', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='threshold', full_name='otg.EventRxRateThreshold.threshold', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_enable', full_name='otg.EventRxRateThreshold._enable',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_threshold', full_name='otg.EventRxRateThreshold._threshold',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=43967,
  serialized_end=44059,
)


_EVENTLINK = _descriptor.Descriptor(
  name='EventLink',
  full_name='otg.EventLink',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enable', full_name='otg.EventLink.enable', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_enable', full_name='otg.EventLink._enable',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=44061,
  serialized_end=44104,
)


_EVENTROUTEADVERTISEWITHDRAW = _descriptor.Descriptor(
  name='EventRouteAdvertiseWithdraw',
  full_name='otg.EventRouteAdvertiseWithdraw',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enable', full_name='otg.EventRouteAdvertiseWithdraw.enable', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_enable', full_name='otg.EventRouteAdvertiseWithdraw._enable',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=44106,
  serialized_end=44167,
)


_EVENTREQUEST_TYPE = _descriptor.Descriptor(
  name='Type',
  full_name='otg.EventRequest.Type',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EVENTREQUEST_TYPE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=44246,
  serialized_end=44415,
)

_EVENTREQUEST = _descriptor.Descriptor(
  name='EventRequest',
  full_name='otg.EventRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='otg.EventRequest.type', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='otg.EventRequest.source', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_EVENTREQUEST_TYPE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=44170,
  serialized_end=44415,
)


_EVENTSUBSCRIPTION = _descriptor.Descriptor(
  name='EventSubscription',
  full_name='otg.EventSubscription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='events', full_name='otg.EventSubscription.events', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='callbackurl', full_name='otg.EventSubscription.callbackurl', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_events', full_name='otg.EventSubscription._events',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_callbackurl', full_name='otg.EventSubscription._callbackurl',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=44417,
  serialized_end=44529,
)


_RESPONSEERROR = _descriptor.Descriptor(
  name='ResponseError',
  full_name='otg.ResponseError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='errors', full_name='otg.ResponseError.errors', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=44531,
  serialized_end=44562,
)


_RESPONSEWARNING = _descriptor.Descriptor(
  name='ResponseWarning',
  full_name='otg.ResponseWarning',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='warnings', full_name='otg.ResponseWarning.warnings', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=44564,
  serialized_end=44599,
)


_LINKSTATE_STATE = _descriptor.Descriptor(
  name='State',
  full_name='otg.LinkState.State',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LINKSTATE_STATE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=44676,
  serialized_end=44726,
)

_LINKSTATE = _descriptor.Descriptor(
  name='LinkState',
  full_name='otg.LinkState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port_names', full_name='otg.LinkState.port_names', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='otg.LinkState.state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LINKSTATE_STATE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=44601,
  serialized_end=44726,
)


_TRANSMITSTATE_STATE = _descriptor.Descriptor(
  name='State',
  full_name='otg.TransmitState.State',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TRANSMITSTATE_STATE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=44812,
  serialized_end=44876,
)

_TRANSMITSTATE = _descriptor.Descriptor(
  name='TransmitState',
  full_name='otg.TransmitState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flow_names', full_name='otg.TransmitState.flow_names', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='otg.TransmitState.state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TRANSMITSTATE_STATE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=44729,
  serialized_end=44876,
)


_CAPTURESTATE_STATE = _descriptor.Descriptor(
  name='State',
  full_name='otg.CaptureState.State',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CAPTURESTATE_STATE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=44960,
  serialized_end=45013,
)

_CAPTURESTATE = _descriptor.Descriptor(
  name='CaptureState',
  full_name='otg.CaptureState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port_names', full_name='otg.CaptureState.port_names', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='otg.CaptureState.state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CAPTURESTATE_STATE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=44879,
  serialized_end=45013,
)


_FLOWSUPDATE_PROPERTYNAMES = _descriptor.Descriptor(
  name='PropertyNames',
  full_name='otg.FlowsUpdate.PropertyNames',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FLOWSUPDATE_PROPERTYNAMES_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45118,
  serialized_end=45178,
)

_FLOWSUPDATE = _descriptor.Descriptor(
  name='FlowsUpdate',
  full_name='otg.FlowsUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='property_names', full_name='otg.FlowsUpdate.property_names', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flows', full_name='otg.FlowsUpdate.flows', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FLOWSUPDATE_PROPERTYNAMES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45016,
  serialized_end=45178,
)


_ROUTESTATE_STATE = _descriptor.Descriptor(
  name='State',
  full_name='otg.RouteState.State',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ROUTESTATE_STATE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45253,
  serialized_end=45314,
)

_ROUTESTATE = _descriptor.Descriptor(
  name='RouteState',
  full_name='otg.RouteState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='names', full_name='otg.RouteState.names', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='otg.RouteState.state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ROUTESTATE_STATE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45181,
  serialized_end=45314,
)


_PINGREQUEST = _descriptor.Descriptor(
  name='PingRequest',
  full_name='otg.PingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='endpoints', full_name='otg.PingRequest.endpoints', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45316,
  serialized_end=45359,
)


_PROTOCOLSTATE_STATE = _descriptor.Descriptor(
  name='State',
  full_name='otg.ProtocolState.State',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PROTOCOLSTATE_STATE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=44960,
  serialized_end=45013,
)

_PROTOCOLSTATE = _descriptor.Descriptor(
  name='ProtocolState',
  full_name='otg.ProtocolState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='otg.ProtocolState.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PROTOCOLSTATE_STATE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45361,
  serialized_end=45477,
)


_PING_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.Ping.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PING_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45600,
  serialized_end=45653,
)

_PING = _descriptor.Descriptor(
  name='Ping',
  full_name='otg.Ping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.Ping.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv4', full_name='otg.Ping.ipv4', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv6', full_name='otg.Ping.ipv6', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PING_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.Ping._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ipv4', full_name='otg.Ping._ipv4',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ipv6', full_name='otg.Ping._ipv6',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=45480,
  serialized_end=45682,
)


_PINGIPV4 = _descriptor.Descriptor(
  name='PingIpv4',
  full_name='otg.PingIpv4',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='src_name', full_name='otg.PingIpv4.src_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dst_ip', full_name='otg.PingIpv4.dst_ip', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_src_name', full_name='otg.PingIpv4._src_name',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_dst_ip', full_name='otg.PingIpv4._dst_ip',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=45684,
  serialized_end=45762,
)


_PINGIPV6 = _descriptor.Descriptor(
  name='PingIpv6',
  full_name='otg.PingIpv6',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='src_name', full_name='otg.PingIpv6.src_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dst_ip', full_name='otg.PingIpv6.dst_ip', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_src_name', full_name='otg.PingIpv6._src_name',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_dst_ip', full_name='otg.PingIpv6._dst_ip',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=45764,
  serialized_end=45842,
)


_PINGRESPONSE = _descriptor.Descriptor(
  name='PingResponse',
  full_name='otg.PingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='responses', full_name='otg.PingResponse.responses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45844,
  serialized_end=45892,
)


_RESPONSE_RESULT = _descriptor.Descriptor(
  name='Result',
  full_name='otg.Response.Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RESPONSE_RESULT_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45999,
  serialized_end=46058,
)

_RESPONSE = _descriptor.Descriptor(
  name='Response',
  full_name='otg.Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='src_name', full_name='otg.Response.src_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dst_ip', full_name='otg.Response.dst_ip', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result', full_name='otg.Response.result', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RESPONSE_RESULT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_src_name', full_name='otg.Response._src_name',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_dst_ip', full_name='otg.Response._dst_ip',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_result', full_name='otg.Response._result',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=45895,
  serialized_end=46093,
)


_METRICSREQUEST_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.MetricsRequest.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _METRICSREQUEST_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46392,
  serialized_end=46477,
)

_METRICSREQUEST = _descriptor.Descriptor(
  name='MetricsRequest',
  full_name='otg.MetricsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.MetricsRequest.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='otg.MetricsRequest.port', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flow', full_name='otg.MetricsRequest.flow', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bgpv4', full_name='otg.MetricsRequest.bgpv4', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bgpv6', full_name='otg.MetricsRequest.bgpv6', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isis', full_name='otg.MetricsRequest.isis', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_METRICSREQUEST_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.MetricsRequest._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_port', full_name='otg.MetricsRequest._port',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_flow', full_name='otg.MetricsRequest._flow',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_bgpv4', full_name='otg.MetricsRequest._bgpv4',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_bgpv6', full_name='otg.MetricsRequest._bgpv6',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_isis', full_name='otg.MetricsRequest._isis',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=46096,
  serialized_end=46535,
)


_METRICSRESPONSE_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.MetricsResponse.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _METRICSRESPONSE_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46811,
  serialized_end=46936,
)

_METRICSRESPONSE = _descriptor.Descriptor(
  name='MetricsResponse',
  full_name='otg.MetricsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.MetricsResponse.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_metrics', full_name='otg.MetricsResponse.port_metrics', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flow_metrics', full_name='otg.MetricsResponse.flow_metrics', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bgpv4_metrics', full_name='otg.MetricsResponse.bgpv4_metrics', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bgpv6_metrics', full_name='otg.MetricsResponse.bgpv6_metrics', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isis_metrics', full_name='otg.MetricsResponse.isis_metrics', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_METRICSRESPONSE_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.MetricsResponse._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=46538,
  serialized_end=46947,
)


_PORTMETRICSREQUEST_COLUMNNAMES = _descriptor.Descriptor(
  name='ColumnNames',
  full_name='otg.PortMetricsRequest.ColumnNames',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PORTMETRICSREQUEST_COLUMNNAMES_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47057,
  serialized_end=47283,
)

_PORTMETRICSREQUEST = _descriptor.Descriptor(
  name='PortMetricsRequest',
  full_name='otg.PortMetricsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port_names', full_name='otg.PortMetricsRequest.port_names', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='column_names', full_name='otg.PortMetricsRequest.column_names', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PORTMETRICSREQUEST_COLUMNNAMES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46950,
  serialized_end=47283,
)


_PORTMETRIC_LINK = _descriptor.Descriptor(
  name='Link',
  full_name='otg.PortMetric.Link',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PORTMETRIC_LINK_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47648,
  serialized_end=47697,
)

_PORTMETRIC_CAPTURE = _descriptor.Descriptor(
  name='Capture',
  full_name='otg.PortMetric.Capture',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PORTMETRIC_CAPTURE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47699,
  serialized_end=47759,
)

_PORTMETRIC = _descriptor.Descriptor(
  name='PortMetric',
  full_name='otg.PortMetric',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='otg.PortMetric.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location', full_name='otg.PortMetric.location', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link', full_name='otg.PortMetric.link', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='capture', full_name='otg.PortMetric.capture', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frames_tx', full_name='otg.PortMetric.frames_tx', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frames_rx', full_name='otg.PortMetric.frames_rx', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_tx', full_name='otg.PortMetric.bytes_tx', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_rx', full_name='otg.PortMetric.bytes_rx', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frames_tx_rate', full_name='otg.PortMetric.frames_tx_rate', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frames_rx_rate', full_name='otg.PortMetric.frames_rx_rate', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_tx_rate', full_name='otg.PortMetric.bytes_tx_rate', index=10,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_rx_rate', full_name='otg.PortMetric.bytes_rx_rate', index=11,
      number=12, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PORTMETRIC_LINK, _PORTMETRIC_CAPTURE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_name', full_name='otg.PortMetric._name',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_location', full_name='otg.PortMetric._location',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_link', full_name='otg.PortMetric._link',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_capture', full_name='otg.PortMetric._capture',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_frames_tx', full_name='otg.PortMetric._frames_tx',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_frames_rx', full_name='otg.PortMetric._frames_rx',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_bytes_tx', full_name='otg.PortMetric._bytes_tx',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_bytes_rx', full_name='otg.PortMetric._bytes_rx',
      index=7, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_frames_tx_rate', full_name='otg.PortMetric._frames_tx_rate',
      index=8, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_frames_rx_rate', full_name='otg.PortMetric._frames_rx_rate',
      index=9, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_bytes_tx_rate', full_name='otg.PortMetric._bytes_tx_rate',
      index=10, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_bytes_rx_rate', full_name='otg.PortMetric._bytes_rx_rate',
      index=11, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=47286,
  serialized_end=47930,
)


_FLOWMETRICSREQUEST_METRICNAMES = _descriptor.Descriptor(
  name='MetricNames',
  full_name='otg.FlowMetricsRequest.MetricNames',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FLOWMETRICSREQUEST_METRICNAMES_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=48097,
  serialized_end=48248,
)

_FLOWMETRICSREQUEST = _descriptor.Descriptor(
  name='FlowMetricsRequest',
  full_name='otg.FlowMetricsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flow_names', full_name='otg.FlowMetricsRequest.flow_names', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_groups', full_name='otg.FlowMetricsRequest.metric_groups', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_names', full_name='otg.FlowMetricsRequest.metric_names', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FLOWMETRICSREQUEST_METRICNAMES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_metric_groups', full_name='otg.FlowMetricsRequest._metric_groups',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=47933,
  serialized_end=48266,
)


_FLOWMETRICGROUPREQUEST_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.FlowMetricGroupRequest.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FLOWMETRICGROUPREQUEST_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=48390,
  serialized_end=48448,
)

_FLOWMETRICGROUPREQUEST = _descriptor.Descriptor(
  name='FlowMetricGroupRequest',
  full_name='otg.FlowMetricGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.FlowMetricGroupRequest.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ingress', full_name='otg.FlowMetricGroupRequest.ingress', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='egress', full_name='otg.FlowMetricGroupRequest.egress', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FLOWMETRICGROUPREQUEST_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.FlowMetricGroupRequest._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=48269,
  serialized_end=48459,
)


_FLOWMETRIC_TRANSMIT = _descriptor.Descriptor(
  name='Transmit',
  full_name='otg.FlowMetric.Transmit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FLOWMETRIC_TRANSMIT_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=48898,
  serialized_end=48971,
)

_FLOWMETRIC = _descriptor.Descriptor(
  name='FlowMetric',
  full_name='otg.FlowMetric',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='otg.FlowMetric.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_tx', full_name='otg.FlowMetric.port_tx', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_rx', full_name='otg.FlowMetric.port_rx', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_groups', full_name='otg.FlowMetric.metric_groups', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transmit', full_name='otg.FlowMetric.transmit', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frames_tx', full_name='otg.FlowMetric.frames_tx', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frames_rx', full_name='otg.FlowMetric.frames_rx', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_tx', full_name='otg.FlowMetric.bytes_tx', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_rx', full_name='otg.FlowMetric.bytes_rx', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frames_tx_rate', full_name='otg.FlowMetric.frames_tx_rate', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frames_rx_rate', full_name='otg.FlowMetric.frames_rx_rate', index=10,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loss', full_name='otg.FlowMetric.loss', index=11,
      number=12, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamps', full_name='otg.FlowMetric.timestamps', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latency', full_name='otg.FlowMetric.latency', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FLOWMETRIC_TRANSMIT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_name', full_name='otg.FlowMetric._name',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_port_tx', full_name='otg.FlowMetric._port_tx',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_port_rx', full_name='otg.FlowMetric._port_rx',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_transmit', full_name='otg.FlowMetric._transmit',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_frames_tx', full_name='otg.FlowMetric._frames_tx',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_frames_rx', full_name='otg.FlowMetric._frames_rx',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_bytes_tx', full_name='otg.FlowMetric._bytes_tx',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_bytes_rx', full_name='otg.FlowMetric._bytes_rx',
      index=7, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_frames_tx_rate', full_name='otg.FlowMetric._frames_tx_rate',
      index=8, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_frames_rx_rate', full_name='otg.FlowMetric._frames_rx_rate',
      index=9, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_loss', full_name='otg.FlowMetric._loss',
      index=10, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_timestamps', full_name='otg.FlowMetric._timestamps',
      index=11, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_latency', full_name='otg.FlowMetric._latency',
      index=12, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=48462,
  serialized_end=49145,
)


_FLOWMETRICGROUP = _descriptor.Descriptor(
  name='FlowMetricGroup',
  full_name='otg.FlowMetricGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='otg.FlowMetricGroup.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.FlowMetricGroup.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_name', full_name='otg.FlowMetricGroup._name',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.FlowMetricGroup._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=49147,
  serialized_end=49222,
)


_METRICTIMESTAMP = _descriptor.Descriptor(
  name='MetricTimestamp',
  full_name='otg.MetricTimestamp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='first_timestamp_ns', full_name='otg.MetricTimestamp.first_timestamp_ns', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_timestamp_ns', full_name='otg.MetricTimestamp.last_timestamp_ns', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_first_timestamp_ns', full_name='otg.MetricTimestamp._first_timestamp_ns',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_last_timestamp_ns', full_name='otg.MetricTimestamp._last_timestamp_ns',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=49224,
  serialized_end=49351,
)


_METRICLATENCY = _descriptor.Descriptor(
  name='MetricLatency',
  full_name='otg.MetricLatency',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='minimum_ns', full_name='otg.MetricLatency.minimum_ns', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maximum_ns', full_name='otg.MetricLatency.maximum_ns', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='average_ns', full_name='otg.MetricLatency.average_ns', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_minimum_ns', full_name='otg.MetricLatency._minimum_ns',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_maximum_ns', full_name='otg.MetricLatency._maximum_ns',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_average_ns', full_name='otg.MetricLatency._average_ns',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=49354,
  serialized_end=49489,
)


_BGPV4METRICSREQUEST_COLUMNNAMES = _descriptor.Descriptor(
  name='ColumnNames',
  full_name='otg.Bgpv4MetricsRequest.ColumnNames',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BGPV4METRICSREQUEST_COLUMNNAMES_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=49601,
  serialized_end=49957,
)

_BGPV4METRICSREQUEST = _descriptor.Descriptor(
  name='Bgpv4MetricsRequest',
  full_name='otg.Bgpv4MetricsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer_names', full_name='otg.Bgpv4MetricsRequest.peer_names', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='column_names', full_name='otg.Bgpv4MetricsRequest.column_names', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BGPV4METRICSREQUEST_COLUMNNAMES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=49492,
  serialized_end=49957,
)


_BGPV4METRIC_SESSIONSTATE = _descriptor.Descriptor(
  name='SessionState',
  full_name='otg.Bgpv4Metric.SessionState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BGPV4METRIC_SESSIONSTATE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=50473,
  serialized_end=50530,
)

_BGPV4METRIC = _descriptor.Descriptor(
  name='Bgpv4Metric',
  full_name='otg.Bgpv4Metric',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='otg.Bgpv4Metric.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_state', full_name='otg.Bgpv4Metric.session_state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_flap_count', full_name='otg.Bgpv4Metric.session_flap_count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routes_advertised', full_name='otg.Bgpv4Metric.routes_advertised', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routes_received', full_name='otg.Bgpv4Metric.routes_received', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_withdraws_sent', full_name='otg.Bgpv4Metric.route_withdraws_sent', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_withdraws_received', full_name='otg.Bgpv4Metric.route_withdraws_received', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updates_sent', full_name='otg.Bgpv4Metric.updates_sent', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updates_received', full_name='otg.Bgpv4Metric.updates_received', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='opens_sent', full_name='otg.Bgpv4Metric.opens_sent', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='opens_received', full_name='otg.Bgpv4Metric.opens_received', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keepalives_sent', full_name='otg.Bgpv4Metric.keepalives_sent', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keepalives_received', full_name='otg.Bgpv4Metric.keepalives_received', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notifications_sent', full_name='otg.Bgpv4Metric.notifications_sent', index=13,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notifications_received', full_name='otg.Bgpv4Metric.notifications_received', index=14,
      number=15, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BGPV4METRIC_SESSIONSTATE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_name', full_name='otg.Bgpv4Metric._name',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_session_state', full_name='otg.Bgpv4Metric._session_state',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_session_flap_count', full_name='otg.Bgpv4Metric._session_flap_count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_routes_advertised', full_name='otg.Bgpv4Metric._routes_advertised',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_routes_received', full_name='otg.Bgpv4Metric._routes_received',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_route_withdraws_sent', full_name='otg.Bgpv4Metric._route_withdraws_sent',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_route_withdraws_received', full_name='otg.Bgpv4Metric._route_withdraws_received',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_updates_sent', full_name='otg.Bgpv4Metric._updates_sent',
      index=7, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_updates_received', full_name='otg.Bgpv4Metric._updates_received',
      index=8, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_opens_sent', full_name='otg.Bgpv4Metric._opens_sent',
      index=9, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_opens_received', full_name='otg.Bgpv4Metric._opens_received',
      index=10, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_keepalives_sent', full_name='otg.Bgpv4Metric._keepalives_sent',
      index=11, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_keepalives_received', full_name='otg.Bgpv4Metric._keepalives_received',
      index=12, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_notifications_sent', full_name='otg.Bgpv4Metric._notifications_sent',
      index=13, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_notifications_received', full_name='otg.Bgpv4Metric._notifications_received',
      index=14, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=49960,
  serialized_end=50842,
)


_BGPV6METRICSREQUEST_COLUMNNAMES = _descriptor.Descriptor(
  name='ColumnNames',
  full_name='otg.Bgpv6MetricsRequest.ColumnNames',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BGPV6METRICSREQUEST_COLUMNNAMES_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=49601,
  serialized_end=49957,
)

_BGPV6METRICSREQUEST = _descriptor.Descriptor(
  name='Bgpv6MetricsRequest',
  full_name='otg.Bgpv6MetricsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer_names', full_name='otg.Bgpv6MetricsRequest.peer_names', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='column_names', full_name='otg.Bgpv6MetricsRequest.column_names', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BGPV6METRICSREQUEST_COLUMNNAMES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=50845,
  serialized_end=51310,
)


_BGPV6METRIC_SESSIONSTATE = _descriptor.Descriptor(
  name='SessionState',
  full_name='otg.Bgpv6Metric.SessionState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BGPV6METRIC_SESSIONSTATE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=50473,
  serialized_end=50530,
)

_BGPV6METRIC = _descriptor.Descriptor(
  name='Bgpv6Metric',
  full_name='otg.Bgpv6Metric',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='otg.Bgpv6Metric.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_state', full_name='otg.Bgpv6Metric.session_state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_flap_count', full_name='otg.Bgpv6Metric.session_flap_count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routes_advertised', full_name='otg.Bgpv6Metric.routes_advertised', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routes_received', full_name='otg.Bgpv6Metric.routes_received', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_withdraws_sent', full_name='otg.Bgpv6Metric.route_withdraws_sent', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_withdraws_received', full_name='otg.Bgpv6Metric.route_withdraws_received', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updates_sent', full_name='otg.Bgpv6Metric.updates_sent', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updates_received', full_name='otg.Bgpv6Metric.updates_received', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='opens_sent', full_name='otg.Bgpv6Metric.opens_sent', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='opens_received', full_name='otg.Bgpv6Metric.opens_received', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keepalives_sent', full_name='otg.Bgpv6Metric.keepalives_sent', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keepalives_received', full_name='otg.Bgpv6Metric.keepalives_received', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notifications_sent', full_name='otg.Bgpv6Metric.notifications_sent', index=13,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notifications_received', full_name='otg.Bgpv6Metric.notifications_received', index=14,
      number=15, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BGPV6METRIC_SESSIONSTATE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_name', full_name='otg.Bgpv6Metric._name',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_session_state', full_name='otg.Bgpv6Metric._session_state',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_session_flap_count', full_name='otg.Bgpv6Metric._session_flap_count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_routes_advertised', full_name='otg.Bgpv6Metric._routes_advertised',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_routes_received', full_name='otg.Bgpv6Metric._routes_received',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_route_withdraws_sent', full_name='otg.Bgpv6Metric._route_withdraws_sent',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_route_withdraws_received', full_name='otg.Bgpv6Metric._route_withdraws_received',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_updates_sent', full_name='otg.Bgpv6Metric._updates_sent',
      index=7, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_updates_received', full_name='otg.Bgpv6Metric._updates_received',
      index=8, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_opens_sent', full_name='otg.Bgpv6Metric._opens_sent',
      index=9, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_opens_received', full_name='otg.Bgpv6Metric._opens_received',
      index=10, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_keepalives_sent', full_name='otg.Bgpv6Metric._keepalives_sent',
      index=11, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_keepalives_received', full_name='otg.Bgpv6Metric._keepalives_received',
      index=12, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_notifications_sent', full_name='otg.Bgpv6Metric._notifications_sent',
      index=13, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_notifications_received', full_name='otg.Bgpv6Metric._notifications_received',
      index=14, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=51313,
  serialized_end=52195,
)


_ISISMETRICSREQUEST_COLUMNNAMES = _descriptor.Descriptor(
  name='ColumnNames',
  full_name='otg.IsisMetricsRequest.ColumnNames',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ISISMETRICSREQUEST_COLUMNNAMES_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52307,
  serialized_end=52984,
)

_ISISMETRICSREQUEST = _descriptor.Descriptor(
  name='IsisMetricsRequest',
  full_name='otg.IsisMetricsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='router_names', full_name='otg.IsisMetricsRequest.router_names', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='column_names', full_name='otg.IsisMetricsRequest.column_names', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ISISMETRICSREQUEST_COLUMNNAMES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52198,
  serialized_end=52984,
)


_ISISMETRIC = _descriptor.Descriptor(
  name='IsisMetric',
  full_name='otg.IsisMetric',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='otg.IsisMetric.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='l1_sessions_up', full_name='otg.IsisMetric.l1_sessions_up', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='l1_session_flap', full_name='otg.IsisMetric.l1_session_flap', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='l1_broadcast_hellos_sent', full_name='otg.IsisMetric.l1_broadcast_hellos_sent', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='l1_broadcast_hellos_received', full_name='otg.IsisMetric.l1_broadcast_hellos_received', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='l1_point_to_point_hellos_sent', full_name='otg.IsisMetric.l1_point_to_point_hellos_sent', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='l1_point_to_point_hellos_received', full_name='otg.IsisMetric.l1_point_to_point_hellos_received', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='l1_database_size', full_name='otg.IsisMetric.l1_database_size', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='l1_psnp_sent', full_name='otg.IsisMetric.l1_psnp_sent', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='l1_psnp_received', full_name='otg.IsisMetric.l1_psnp_received', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='l1_csnp_sent', full_name='otg.IsisMetric.l1_csnp_sent', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='l1_csnp_received', full_name='otg.IsisMetric.l1_csnp_received', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='l1_lsp_sent', full_name='otg.IsisMetric.l1_lsp_sent', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='l1_lsp_received', full_name='otg.IsisMetric.l1_lsp_received', index=13,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='l2_sessions_up', full_name='otg.IsisMetric.l2_sessions_up', index=14,
      number=15, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='l2_session_flap', full_name='otg.IsisMetric.l2_session_flap', index=15,
      number=16, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='l2_broadcast_hellos_sent', full_name='otg.IsisMetric.l2_broadcast_hellos_sent', index=16,
      number=17, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='l2_broadcast_hellos_received', full_name='otg.IsisMetric.l2_broadcast_hellos_received', index=17,
      number=18, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='l2_point_to_point_hellos_sent', full_name='otg.IsisMetric.l2_point_to_point_hellos_sent', index=18,
      number=19, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='l2_point_to_point_hellos_received', full_name='otg.IsisMetric.l2_point_to_point_hellos_received', index=19,
      number=20, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='l2_database_size', full_name='otg.IsisMetric.l2_database_size', index=20,
      number=21, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='l2_psnp_sent', full_name='otg.IsisMetric.l2_psnp_sent', index=21,
      number=22, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='l2_psnp_received', full_name='otg.IsisMetric.l2_psnp_received', index=22,
      number=23, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='l2_csnp_sent', full_name='otg.IsisMetric.l2_csnp_sent', index=23,
      number=24, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='l2_csnp_received', full_name='otg.IsisMetric.l2_csnp_received', index=24,
      number=25, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='l2_lsp_sent', full_name='otg.IsisMetric.l2_lsp_sent', index=25,
      number=26, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='l2_lsp_received', full_name='otg.IsisMetric.l2_lsp_received', index=26,
      number=27, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_name', full_name='otg.IsisMetric._name',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_l1_sessions_up', full_name='otg.IsisMetric._l1_sessions_up',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_l1_session_flap', full_name='otg.IsisMetric._l1_session_flap',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_l1_broadcast_hellos_sent', full_name='otg.IsisMetric._l1_broadcast_hellos_sent',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_l1_broadcast_hellos_received', full_name='otg.IsisMetric._l1_broadcast_hellos_received',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_l1_point_to_point_hellos_sent', full_name='otg.IsisMetric._l1_point_to_point_hellos_sent',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_l1_point_to_point_hellos_received', full_name='otg.IsisMetric._l1_point_to_point_hellos_received',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_l1_database_size', full_name='otg.IsisMetric._l1_database_size',
      index=7, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_l1_psnp_sent', full_name='otg.IsisMetric._l1_psnp_sent',
      index=8, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_l1_psnp_received', full_name='otg.IsisMetric._l1_psnp_received',
      index=9, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_l1_csnp_sent', full_name='otg.IsisMetric._l1_csnp_sent',
      index=10, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_l1_csnp_received', full_name='otg.IsisMetric._l1_csnp_received',
      index=11, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_l1_lsp_sent', full_name='otg.IsisMetric._l1_lsp_sent',
      index=12, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_l1_lsp_received', full_name='otg.IsisMetric._l1_lsp_received',
      index=13, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_l2_sessions_up', full_name='otg.IsisMetric._l2_sessions_up',
      index=14, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_l2_session_flap', full_name='otg.IsisMetric._l2_session_flap',
      index=15, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_l2_broadcast_hellos_sent', full_name='otg.IsisMetric._l2_broadcast_hellos_sent',
      index=16, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_l2_broadcast_hellos_received', full_name='otg.IsisMetric._l2_broadcast_hellos_received',
      index=17, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_l2_point_to_point_hellos_sent', full_name='otg.IsisMetric._l2_point_to_point_hellos_sent',
      index=18, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_l2_point_to_point_hellos_received', full_name='otg.IsisMetric._l2_point_to_point_hellos_received',
      index=19, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_l2_database_size', full_name='otg.IsisMetric._l2_database_size',
      index=20, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_l2_psnp_sent', full_name='otg.IsisMetric._l2_psnp_sent',
      index=21, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_l2_psnp_received', full_name='otg.IsisMetric._l2_psnp_received',
      index=22, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_l2_csnp_sent', full_name='otg.IsisMetric._l2_csnp_sent',
      index=23, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_l2_csnp_received', full_name='otg.IsisMetric._l2_csnp_received',
      index=24, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_l2_lsp_sent', full_name='otg.IsisMetric._l2_lsp_sent',
      index=25, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_l2_lsp_received', full_name='otg.IsisMetric._l2_lsp_received',
      index=26, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=52987,
  serialized_end=54511,
)


_STATESREQUEST_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.StatesRequest.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STATESREQUEST_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54704,
  serialized_end=54777,
)

_STATESREQUEST = _descriptor.Descriptor(
  name='StatesRequest',
  full_name='otg.StatesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.StatesRequest.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv4_neighbors', full_name='otg.StatesRequest.ipv4_neighbors', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv6_neighbors', full_name='otg.StatesRequest.ipv6_neighbors', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STATESREQUEST_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.StatesRequest._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ipv4_neighbors', full_name='otg.StatesRequest._ipv4_neighbors',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_ipv6_neighbors', full_name='otg.StatesRequest._ipv6_neighbors',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=54514,
  serialized_end=54826,
)


_STATESRESPONSE_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.StatesResponse.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STATESRESPONSE_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54704,
  serialized_end=54777,
)

_STATESRESPONSE = _descriptor.Descriptor(
  name='StatesResponse',
  full_name='otg.StatesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.StatesResponse.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv4_neighbors', full_name='otg.StatesResponse.ipv4_neighbors', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv6_neighbors', full_name='otg.StatesResponse.ipv6_neighbors', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STATESRESPONSE_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.StatesResponse._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=54829,
  serialized_end=55079,
)


_NEIGHBORSV4STATESREQUEST = _descriptor.Descriptor(
  name='Neighborsv4StatesRequest',
  full_name='otg.Neighborsv4StatesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ethernet_names', full_name='otg.Neighborsv4StatesRequest.ethernet_names', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55081,
  serialized_end=55131,
)


_NEIGHBORSV4STATE = _descriptor.Descriptor(
  name='Neighborsv4State',
  full_name='otg.Neighborsv4State',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ethernet_name', full_name='otg.Neighborsv4State.ethernet_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv4_address', full_name='otg.Neighborsv4State.ipv4_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link_layer_address', full_name='otg.Neighborsv4State.link_layer_address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_link_layer_address', full_name='otg.Neighborsv4State._link_layer_address',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=55133,
  serialized_end=55252,
)


_NEIGHBORSV6STATESREQUEST = _descriptor.Descriptor(
  name='Neighborsv6StatesRequest',
  full_name='otg.Neighborsv6StatesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ethernet_names', full_name='otg.Neighborsv6StatesRequest.ethernet_names', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55254,
  serialized_end=55304,
)


_NEIGHBORSV6STATE = _descriptor.Descriptor(
  name='Neighborsv6State',
  full_name='otg.Neighborsv6State',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ethernet_name', full_name='otg.Neighborsv6State.ethernet_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv6_address', full_name='otg.Neighborsv6State.ipv6_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link_layer_address', full_name='otg.Neighborsv6State.link_layer_address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_link_layer_address', full_name='otg.Neighborsv6State._link_layer_address',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=55306,
  serialized_end=55425,
)


_CAPTUREREQUEST = _descriptor.Descriptor(
  name='CaptureRequest',
  full_name='otg.CaptureRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port_name', full_name='otg.CaptureRequest.port_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55427,
  serialized_end=55462,
)


_PATTERNFLOWETHERNETDSTCOUNTER = _descriptor.Descriptor(
  name='PatternFlowEthernetDstCounter',
  full_name='otg.PatternFlowEthernetDstCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowEthernetDstCounter.start', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowEthernetDstCounter.step', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowEthernetDstCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowEthernetDstCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowEthernetDstCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowEthernetDstCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=55464,
  serialized_end=55583,
)


_PATTERNFLOWETHERNETDST_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowEthernetDst.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWETHERNETDST_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWETHERNETDST = _descriptor.Descriptor(
  name='PatternFlowEthernetDst',
  full_name='otg.PatternFlowEthernetDst',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowEthernetDst.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowEthernetDst.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowEthernetDst.values', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowEthernetDst.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowEthernetDst.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowEthernetDst.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWETHERNETDST_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowEthernetDst._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowEthernetDst._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowEthernetDst._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowEthernetDst._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowEthernetDst._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=55586,
  serialized_end=56009,
)


_PATTERNFLOWETHERNETSRCCOUNTER = _descriptor.Descriptor(
  name='PatternFlowEthernetSrcCounter',
  full_name='otg.PatternFlowEthernetSrcCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowEthernetSrcCounter.start', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowEthernetSrcCounter.step', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowEthernetSrcCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowEthernetSrcCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowEthernetSrcCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowEthernetSrcCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=56011,
  serialized_end=56130,
)


_PATTERNFLOWETHERNETSRC_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowEthernetSrc.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWETHERNETSRC_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWETHERNETSRC = _descriptor.Descriptor(
  name='PatternFlowEthernetSrc',
  full_name='otg.PatternFlowEthernetSrc',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowEthernetSrc.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowEthernetSrc.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowEthernetSrc.values', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowEthernetSrc.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowEthernetSrc.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowEthernetSrc.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWETHERNETSRC_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowEthernetSrc._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowEthernetSrc._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowEthernetSrc._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowEthernetSrc._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowEthernetSrc._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=56133,
  serialized_end=56556,
)


_PATTERNFLOWETHERNETETHERTYPECOUNTER = _descriptor.Descriptor(
  name='PatternFlowEthernetEtherTypeCounter',
  full_name='otg.PatternFlowEthernetEtherTypeCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowEthernetEtherTypeCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowEthernetEtherTypeCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowEthernetEtherTypeCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowEthernetEtherTypeCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowEthernetEtherTypeCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowEthernetEtherTypeCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=56558,
  serialized_end=56683,
)


_PATTERNFLOWETHERNETETHERTYPE_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowEthernetEtherType.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWETHERNETETHERTYPE_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57045,
  serialized_end=57141,
)

_PATTERNFLOWETHERNETETHERTYPE_AUTO = _descriptor.Descriptor(
  name='Auto',
  full_name='otg.PatternFlowEthernetEtherType.Auto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWETHERNETETHERTYPE_AUTO_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57143,
  serialized_end=57184,
)

_PATTERNFLOWETHERNETETHERTYPE = _descriptor.Descriptor(
  name='PatternFlowEthernetEtherType',
  full_name='otg.PatternFlowEthernetEtherType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowEthernetEtherType.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowEthernetEtherType.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowEthernetEtherType.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto', full_name='otg.PatternFlowEthernetEtherType.auto', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowEthernetEtherType.metric_group', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowEthernetEtherType.increment', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowEthernetEtherType.decrement', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWETHERNETETHERTYPE_CHOICE, _PATTERNFLOWETHERNETETHERTYPE_AUTO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowEthernetEtherType._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowEthernetEtherType._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_auto', full_name='otg.PatternFlowEthernetEtherType._auto',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowEthernetEtherType._metric_group',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowEthernetEtherType._increment',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowEthernetEtherType._decrement',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=56686,
  serialized_end=57259,
)


_PATTERNFLOWETHERNETPFCQUEUECOUNTER = _descriptor.Descriptor(
  name='PatternFlowEthernetPfcQueueCounter',
  full_name='otg.PatternFlowEthernetPfcQueueCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowEthernetPfcQueueCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowEthernetPfcQueueCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowEthernetPfcQueueCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowEthernetPfcQueueCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowEthernetPfcQueueCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowEthernetPfcQueueCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=57261,
  serialized_end=57385,
)


_PATTERNFLOWETHERNETPFCQUEUE_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowEthernetPfcQueue.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWETHERNETPFCQUEUE_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWETHERNETPFCQUEUE = _descriptor.Descriptor(
  name='PatternFlowEthernetPfcQueue',
  full_name='otg.PatternFlowEthernetPfcQueue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowEthernetPfcQueue.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowEthernetPfcQueue.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowEthernetPfcQueue.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowEthernetPfcQueue.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowEthernetPfcQueue.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowEthernetPfcQueue.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWETHERNETPFCQUEUE_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowEthernetPfcQueue._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowEthernetPfcQueue._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowEthernetPfcQueue._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowEthernetPfcQueue._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowEthernetPfcQueue._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=57388,
  serialized_end=57831,
)


_PATTERNFLOWVLANPRIORITYCOUNTER = _descriptor.Descriptor(
  name='PatternFlowVlanPriorityCounter',
  full_name='otg.PatternFlowVlanPriorityCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowVlanPriorityCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowVlanPriorityCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowVlanPriorityCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowVlanPriorityCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowVlanPriorityCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowVlanPriorityCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=57833,
  serialized_end=57953,
)


_PATTERNFLOWVLANPRIORITY_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowVlanPriority.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWVLANPRIORITY_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWVLANPRIORITY = _descriptor.Descriptor(
  name='PatternFlowVlanPriority',
  full_name='otg.PatternFlowVlanPriority',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowVlanPriority.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowVlanPriority.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowVlanPriority.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowVlanPriority.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowVlanPriority.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowVlanPriority.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWVLANPRIORITY_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowVlanPriority._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowVlanPriority._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowVlanPriority._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowVlanPriority._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowVlanPriority._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=57956,
  serialized_end=58383,
)


_PATTERNFLOWVLANCFICOUNTER = _descriptor.Descriptor(
  name='PatternFlowVlanCfiCounter',
  full_name='otg.PatternFlowVlanCfiCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowVlanCfiCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowVlanCfiCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowVlanCfiCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowVlanCfiCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowVlanCfiCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowVlanCfiCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=58385,
  serialized_end=58500,
)


_PATTERNFLOWVLANCFI_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowVlanCfi.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWVLANCFI_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWVLANCFI = _descriptor.Descriptor(
  name='PatternFlowVlanCfi',
  full_name='otg.PatternFlowVlanCfi',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowVlanCfi.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowVlanCfi.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowVlanCfi.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowVlanCfi.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowVlanCfi.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowVlanCfi.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWVLANCFI_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowVlanCfi._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowVlanCfi._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowVlanCfi._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowVlanCfi._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowVlanCfi._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=58503,
  serialized_end=58910,
)


_PATTERNFLOWVLANIDCOUNTER = _descriptor.Descriptor(
  name='PatternFlowVlanIdCounter',
  full_name='otg.PatternFlowVlanIdCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowVlanIdCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowVlanIdCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowVlanIdCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowVlanIdCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowVlanIdCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowVlanIdCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=58912,
  serialized_end=59026,
)


_PATTERNFLOWVLANID_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowVlanId.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWVLANID_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWVLANID = _descriptor.Descriptor(
  name='PatternFlowVlanId',
  full_name='otg.PatternFlowVlanId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowVlanId.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowVlanId.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowVlanId.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowVlanId.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowVlanId.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowVlanId.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWVLANID_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowVlanId._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowVlanId._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowVlanId._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowVlanId._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowVlanId._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=59029,
  serialized_end=59432,
)


_PATTERNFLOWVLANTPIDCOUNTER = _descriptor.Descriptor(
  name='PatternFlowVlanTpidCounter',
  full_name='otg.PatternFlowVlanTpidCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowVlanTpidCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowVlanTpidCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowVlanTpidCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowVlanTpidCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowVlanTpidCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowVlanTpidCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=59434,
  serialized_end=59550,
)


_PATTERNFLOWVLANTPID_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowVlanTpid.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWVLANTPID_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWVLANTPID = _descriptor.Descriptor(
  name='PatternFlowVlanTpid',
  full_name='otg.PatternFlowVlanTpid',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowVlanTpid.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowVlanTpid.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowVlanTpid.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowVlanTpid.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowVlanTpid.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowVlanTpid.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWVLANTPID_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowVlanTpid._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowVlanTpid._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowVlanTpid._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowVlanTpid._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowVlanTpid._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=59553,
  serialized_end=59964,
)


_PATTERNFLOWVXLANFLAGSCOUNTER = _descriptor.Descriptor(
  name='PatternFlowVxlanFlagsCounter',
  full_name='otg.PatternFlowVxlanFlagsCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowVxlanFlagsCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowVxlanFlagsCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowVxlanFlagsCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowVxlanFlagsCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowVxlanFlagsCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowVxlanFlagsCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=59966,
  serialized_end=60084,
)


_PATTERNFLOWVXLANFLAGS_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowVxlanFlags.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWVXLANFLAGS_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWVXLANFLAGS = _descriptor.Descriptor(
  name='PatternFlowVxlanFlags',
  full_name='otg.PatternFlowVxlanFlags',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowVxlanFlags.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowVxlanFlags.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowVxlanFlags.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowVxlanFlags.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowVxlanFlags.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowVxlanFlags.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWVXLANFLAGS_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowVxlanFlags._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowVxlanFlags._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowVxlanFlags._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowVxlanFlags._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowVxlanFlags._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=60087,
  serialized_end=60506,
)


_PATTERNFLOWVXLANRESERVED0COUNTER = _descriptor.Descriptor(
  name='PatternFlowVxlanReserved0Counter',
  full_name='otg.PatternFlowVxlanReserved0Counter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowVxlanReserved0Counter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowVxlanReserved0Counter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowVxlanReserved0Counter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowVxlanReserved0Counter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowVxlanReserved0Counter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowVxlanReserved0Counter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=60508,
  serialized_end=60630,
)


_PATTERNFLOWVXLANRESERVED0_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowVxlanReserved0.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWVXLANRESERVED0_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWVXLANRESERVED0 = _descriptor.Descriptor(
  name='PatternFlowVxlanReserved0',
  full_name='otg.PatternFlowVxlanReserved0',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowVxlanReserved0.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowVxlanReserved0.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowVxlanReserved0.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowVxlanReserved0.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowVxlanReserved0.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowVxlanReserved0.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWVXLANRESERVED0_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowVxlanReserved0._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowVxlanReserved0._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowVxlanReserved0._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowVxlanReserved0._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowVxlanReserved0._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=60633,
  serialized_end=61068,
)


_PATTERNFLOWVXLANVNICOUNTER = _descriptor.Descriptor(
  name='PatternFlowVxlanVniCounter',
  full_name='otg.PatternFlowVxlanVniCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowVxlanVniCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowVxlanVniCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowVxlanVniCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowVxlanVniCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowVxlanVniCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowVxlanVniCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=61070,
  serialized_end=61186,
)


_PATTERNFLOWVXLANVNI_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowVxlanVni.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWVXLANVNI_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWVXLANVNI = _descriptor.Descriptor(
  name='PatternFlowVxlanVni',
  full_name='otg.PatternFlowVxlanVni',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowVxlanVni.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowVxlanVni.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowVxlanVni.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowVxlanVni.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowVxlanVni.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowVxlanVni.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWVXLANVNI_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowVxlanVni._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowVxlanVni._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowVxlanVni._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowVxlanVni._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowVxlanVni._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=61189,
  serialized_end=61600,
)


_PATTERNFLOWVXLANRESERVED1COUNTER = _descriptor.Descriptor(
  name='PatternFlowVxlanReserved1Counter',
  full_name='otg.PatternFlowVxlanReserved1Counter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowVxlanReserved1Counter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowVxlanReserved1Counter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowVxlanReserved1Counter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowVxlanReserved1Counter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowVxlanReserved1Counter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowVxlanReserved1Counter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=61602,
  serialized_end=61724,
)


_PATTERNFLOWVXLANRESERVED1_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowVxlanReserved1.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWVXLANRESERVED1_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWVXLANRESERVED1 = _descriptor.Descriptor(
  name='PatternFlowVxlanReserved1',
  full_name='otg.PatternFlowVxlanReserved1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowVxlanReserved1.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowVxlanReserved1.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowVxlanReserved1.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowVxlanReserved1.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowVxlanReserved1.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowVxlanReserved1.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWVXLANRESERVED1_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowVxlanReserved1._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowVxlanReserved1._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowVxlanReserved1._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowVxlanReserved1._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowVxlanReserved1._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=61727,
  serialized_end=62162,
)


_PATTERNFLOWIPV4VERSIONCOUNTER = _descriptor.Descriptor(
  name='PatternFlowIpv4VersionCounter',
  full_name='otg.PatternFlowIpv4VersionCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIpv4VersionCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIpv4VersionCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIpv4VersionCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIpv4VersionCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIpv4VersionCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIpv4VersionCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=62164,
  serialized_end=62283,
)


_PATTERNFLOWIPV4VERSION_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIpv4Version.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIPV4VERSION_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWIPV4VERSION = _descriptor.Descriptor(
  name='PatternFlowIpv4Version',
  full_name='otg.PatternFlowIpv4Version',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIpv4Version.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIpv4Version.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIpv4Version.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIpv4Version.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIpv4Version.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIpv4Version.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWIPV4VERSION_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIpv4Version._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIpv4Version._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIpv4Version._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIpv4Version._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIpv4Version._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=62286,
  serialized_end=62709,
)


_PATTERNFLOWIPV4HEADERLENGTHCOUNTER = _descriptor.Descriptor(
  name='PatternFlowIpv4HeaderLengthCounter',
  full_name='otg.PatternFlowIpv4HeaderLengthCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIpv4HeaderLengthCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIpv4HeaderLengthCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIpv4HeaderLengthCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIpv4HeaderLengthCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIpv4HeaderLengthCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIpv4HeaderLengthCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=62711,
  serialized_end=62835,
)


_PATTERNFLOWIPV4HEADERLENGTH_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIpv4HeaderLength.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIPV4HEADERLENGTH_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57045,
  serialized_end=57141,
)

_PATTERNFLOWIPV4HEADERLENGTH_AUTO = _descriptor.Descriptor(
  name='Auto',
  full_name='otg.PatternFlowIpv4HeaderLength.Auto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIPV4HEADERLENGTH_AUTO_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57143,
  serialized_end=57184,
)

_PATTERNFLOWIPV4HEADERLENGTH = _descriptor.Descriptor(
  name='PatternFlowIpv4HeaderLength',
  full_name='otg.PatternFlowIpv4HeaderLength',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIpv4HeaderLength.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIpv4HeaderLength.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIpv4HeaderLength.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto', full_name='otg.PatternFlowIpv4HeaderLength.auto', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIpv4HeaderLength.metric_group', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIpv4HeaderLength.increment', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIpv4HeaderLength.decrement', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWIPV4HEADERLENGTH_CHOICE, _PATTERNFLOWIPV4HEADERLENGTH_AUTO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIpv4HeaderLength._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIpv4HeaderLength._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_auto', full_name='otg.PatternFlowIpv4HeaderLength._auto',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIpv4HeaderLength._metric_group',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIpv4HeaderLength._increment',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIpv4HeaderLength._decrement',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=62838,
  serialized_end=63406,
)


_PATTERNFLOWIPV4TOTALLENGTHCOUNTER = _descriptor.Descriptor(
  name='PatternFlowIpv4TotalLengthCounter',
  full_name='otg.PatternFlowIpv4TotalLengthCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIpv4TotalLengthCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIpv4TotalLengthCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIpv4TotalLengthCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIpv4TotalLengthCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIpv4TotalLengthCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIpv4TotalLengthCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=63408,
  serialized_end=63531,
)


_PATTERNFLOWIPV4TOTALLENGTH_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIpv4TotalLength.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIPV4TOTALLENGTH_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57045,
  serialized_end=57141,
)

_PATTERNFLOWIPV4TOTALLENGTH_AUTO = _descriptor.Descriptor(
  name='Auto',
  full_name='otg.PatternFlowIpv4TotalLength.Auto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIPV4TOTALLENGTH_AUTO_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57143,
  serialized_end=57184,
)

_PATTERNFLOWIPV4TOTALLENGTH = _descriptor.Descriptor(
  name='PatternFlowIpv4TotalLength',
  full_name='otg.PatternFlowIpv4TotalLength',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIpv4TotalLength.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIpv4TotalLength.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIpv4TotalLength.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto', full_name='otg.PatternFlowIpv4TotalLength.auto', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIpv4TotalLength.metric_group', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIpv4TotalLength.increment', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIpv4TotalLength.decrement', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWIPV4TOTALLENGTH_CHOICE, _PATTERNFLOWIPV4TOTALLENGTH_AUTO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIpv4TotalLength._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIpv4TotalLength._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_auto', full_name='otg.PatternFlowIpv4TotalLength._auto',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIpv4TotalLength._metric_group',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIpv4TotalLength._increment',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIpv4TotalLength._decrement',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=63534,
  serialized_end=64097,
)


_PATTERNFLOWIPV4IDENTIFICATIONCOUNTER = _descriptor.Descriptor(
  name='PatternFlowIpv4IdentificationCounter',
  full_name='otg.PatternFlowIpv4IdentificationCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIpv4IdentificationCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIpv4IdentificationCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIpv4IdentificationCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIpv4IdentificationCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIpv4IdentificationCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIpv4IdentificationCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=64099,
  serialized_end=64225,
)


_PATTERNFLOWIPV4IDENTIFICATION_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIpv4Identification.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIPV4IDENTIFICATION_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWIPV4IDENTIFICATION = _descriptor.Descriptor(
  name='PatternFlowIpv4Identification',
  full_name='otg.PatternFlowIpv4Identification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIpv4Identification.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIpv4Identification.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIpv4Identification.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIpv4Identification.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIpv4Identification.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIpv4Identification.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWIPV4IDENTIFICATION_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIpv4Identification._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIpv4Identification._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIpv4Identification._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIpv4Identification._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIpv4Identification._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=64228,
  serialized_end=64679,
)


_PATTERNFLOWIPV4RESERVEDCOUNTER = _descriptor.Descriptor(
  name='PatternFlowIpv4ReservedCounter',
  full_name='otg.PatternFlowIpv4ReservedCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIpv4ReservedCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIpv4ReservedCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIpv4ReservedCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIpv4ReservedCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIpv4ReservedCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIpv4ReservedCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=64681,
  serialized_end=64801,
)


_PATTERNFLOWIPV4RESERVED_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIpv4Reserved.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIPV4RESERVED_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWIPV4RESERVED = _descriptor.Descriptor(
  name='PatternFlowIpv4Reserved',
  full_name='otg.PatternFlowIpv4Reserved',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIpv4Reserved.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIpv4Reserved.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIpv4Reserved.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIpv4Reserved.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIpv4Reserved.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIpv4Reserved.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWIPV4RESERVED_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIpv4Reserved._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIpv4Reserved._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIpv4Reserved._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIpv4Reserved._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIpv4Reserved._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=64804,
  serialized_end=65231,
)


_PATTERNFLOWIPV4DONTFRAGMENTCOUNTER = _descriptor.Descriptor(
  name='PatternFlowIpv4DontFragmentCounter',
  full_name='otg.PatternFlowIpv4DontFragmentCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIpv4DontFragmentCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIpv4DontFragmentCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIpv4DontFragmentCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIpv4DontFragmentCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIpv4DontFragmentCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIpv4DontFragmentCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=65233,
  serialized_end=65357,
)


_PATTERNFLOWIPV4DONTFRAGMENT_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIpv4DontFragment.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIPV4DONTFRAGMENT_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWIPV4DONTFRAGMENT = _descriptor.Descriptor(
  name='PatternFlowIpv4DontFragment',
  full_name='otg.PatternFlowIpv4DontFragment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIpv4DontFragment.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIpv4DontFragment.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIpv4DontFragment.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIpv4DontFragment.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIpv4DontFragment.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIpv4DontFragment.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWIPV4DONTFRAGMENT_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIpv4DontFragment._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIpv4DontFragment._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIpv4DontFragment._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIpv4DontFragment._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIpv4DontFragment._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=65360,
  serialized_end=65803,
)


_PATTERNFLOWIPV4MOREFRAGMENTSCOUNTER = _descriptor.Descriptor(
  name='PatternFlowIpv4MoreFragmentsCounter',
  full_name='otg.PatternFlowIpv4MoreFragmentsCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIpv4MoreFragmentsCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIpv4MoreFragmentsCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIpv4MoreFragmentsCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIpv4MoreFragmentsCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIpv4MoreFragmentsCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIpv4MoreFragmentsCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=65805,
  serialized_end=65930,
)


_PATTERNFLOWIPV4MOREFRAGMENTS_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIpv4MoreFragments.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIPV4MOREFRAGMENTS_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWIPV4MOREFRAGMENTS = _descriptor.Descriptor(
  name='PatternFlowIpv4MoreFragments',
  full_name='otg.PatternFlowIpv4MoreFragments',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIpv4MoreFragments.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIpv4MoreFragments.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIpv4MoreFragments.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIpv4MoreFragments.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIpv4MoreFragments.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIpv4MoreFragments.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWIPV4MOREFRAGMENTS_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIpv4MoreFragments._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIpv4MoreFragments._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIpv4MoreFragments._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIpv4MoreFragments._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIpv4MoreFragments._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=65933,
  serialized_end=66380,
)


_PATTERNFLOWIPV4FRAGMENTOFFSETCOUNTER = _descriptor.Descriptor(
  name='PatternFlowIpv4FragmentOffsetCounter',
  full_name='otg.PatternFlowIpv4FragmentOffsetCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIpv4FragmentOffsetCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIpv4FragmentOffsetCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIpv4FragmentOffsetCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIpv4FragmentOffsetCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIpv4FragmentOffsetCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIpv4FragmentOffsetCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=66382,
  serialized_end=66508,
)


_PATTERNFLOWIPV4FRAGMENTOFFSET_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIpv4FragmentOffset.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIPV4FRAGMENTOFFSET_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWIPV4FRAGMENTOFFSET = _descriptor.Descriptor(
  name='PatternFlowIpv4FragmentOffset',
  full_name='otg.PatternFlowIpv4FragmentOffset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIpv4FragmentOffset.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIpv4FragmentOffset.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIpv4FragmentOffset.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIpv4FragmentOffset.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIpv4FragmentOffset.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIpv4FragmentOffset.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWIPV4FRAGMENTOFFSET_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIpv4FragmentOffset._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIpv4FragmentOffset._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIpv4FragmentOffset._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIpv4FragmentOffset._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIpv4FragmentOffset._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=66511,
  serialized_end=66962,
)


_PATTERNFLOWIPV4TIMETOLIVECOUNTER = _descriptor.Descriptor(
  name='PatternFlowIpv4TimeToLiveCounter',
  full_name='otg.PatternFlowIpv4TimeToLiveCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIpv4TimeToLiveCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIpv4TimeToLiveCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIpv4TimeToLiveCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIpv4TimeToLiveCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIpv4TimeToLiveCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIpv4TimeToLiveCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=66964,
  serialized_end=67086,
)


_PATTERNFLOWIPV4TIMETOLIVE_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIpv4TimeToLive.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIPV4TIMETOLIVE_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWIPV4TIMETOLIVE = _descriptor.Descriptor(
  name='PatternFlowIpv4TimeToLive',
  full_name='otg.PatternFlowIpv4TimeToLive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIpv4TimeToLive.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIpv4TimeToLive.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIpv4TimeToLive.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIpv4TimeToLive.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIpv4TimeToLive.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIpv4TimeToLive.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWIPV4TIMETOLIVE_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIpv4TimeToLive._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIpv4TimeToLive._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIpv4TimeToLive._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIpv4TimeToLive._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIpv4TimeToLive._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=67089,
  serialized_end=67524,
)


_PATTERNFLOWIPV4PROTOCOLCOUNTER = _descriptor.Descriptor(
  name='PatternFlowIpv4ProtocolCounter',
  full_name='otg.PatternFlowIpv4ProtocolCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIpv4ProtocolCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIpv4ProtocolCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIpv4ProtocolCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIpv4ProtocolCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIpv4ProtocolCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIpv4ProtocolCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=67526,
  serialized_end=67646,
)


_PATTERNFLOWIPV4PROTOCOL_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIpv4Protocol.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIPV4PROTOCOL_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57045,
  serialized_end=57141,
)

_PATTERNFLOWIPV4PROTOCOL_AUTO = _descriptor.Descriptor(
  name='Auto',
  full_name='otg.PatternFlowIpv4Protocol.Auto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIPV4PROTOCOL_AUTO_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57143,
  serialized_end=57184,
)

_PATTERNFLOWIPV4PROTOCOL = _descriptor.Descriptor(
  name='PatternFlowIpv4Protocol',
  full_name='otg.PatternFlowIpv4Protocol',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIpv4Protocol.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIpv4Protocol.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIpv4Protocol.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto', full_name='otg.PatternFlowIpv4Protocol.auto', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIpv4Protocol.metric_group', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIpv4Protocol.increment', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIpv4Protocol.decrement', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWIPV4PROTOCOL_CHOICE, _PATTERNFLOWIPV4PROTOCOL_AUTO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIpv4Protocol._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIpv4Protocol._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_auto', full_name='otg.PatternFlowIpv4Protocol._auto',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIpv4Protocol._metric_group',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIpv4Protocol._increment',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIpv4Protocol._decrement',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=67649,
  serialized_end=68197,
)


_PATTERNFLOWIPV4HEADERCHECKSUM_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIpv4HeaderChecksum.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIPV4HEADERCHECKSUM_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68398,
  serialized_end=68458,
)

_PATTERNFLOWIPV4HEADERCHECKSUM_GENERATED = _descriptor.Descriptor(
  name='Generated',
  full_name='otg.PatternFlowIpv4HeaderChecksum.Generated',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIPV4HEADERCHECKSUM_GENERATED_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68460,
  serialized_end=68515,
)

_PATTERNFLOWIPV4HEADERCHECKSUM = _descriptor.Descriptor(
  name='PatternFlowIpv4HeaderChecksum',
  full_name='otg.PatternFlowIpv4HeaderChecksum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIpv4HeaderChecksum.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='generated', full_name='otg.PatternFlowIpv4HeaderChecksum.generated', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom', full_name='otg.PatternFlowIpv4HeaderChecksum.custom', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWIPV4HEADERCHECKSUM_CHOICE, _PATTERNFLOWIPV4HEADERCHECKSUM_GENERATED, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIpv4HeaderChecksum._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_generated', full_name='otg.PatternFlowIpv4HeaderChecksum._generated',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_custom', full_name='otg.PatternFlowIpv4HeaderChecksum._custom',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=68200,
  serialized_end=68551,
)


_PATTERNFLOWIPV4SRCCOUNTER = _descriptor.Descriptor(
  name='PatternFlowIpv4SrcCounter',
  full_name='otg.PatternFlowIpv4SrcCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIpv4SrcCounter.start', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIpv4SrcCounter.step', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIpv4SrcCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIpv4SrcCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIpv4SrcCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIpv4SrcCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=68553,
  serialized_end=68668,
)


_PATTERNFLOWIPV4SRC_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIpv4Src.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIPV4SRC_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWIPV4SRC = _descriptor.Descriptor(
  name='PatternFlowIpv4Src',
  full_name='otg.PatternFlowIpv4Src',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIpv4Src.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIpv4Src.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIpv4Src.values', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIpv4Src.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIpv4Src.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIpv4Src.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWIPV4SRC_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIpv4Src._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIpv4Src._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIpv4Src._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIpv4Src._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIpv4Src._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=68671,
  serialized_end=69078,
)


_PATTERNFLOWIPV4DSTCOUNTER = _descriptor.Descriptor(
  name='PatternFlowIpv4DstCounter',
  full_name='otg.PatternFlowIpv4DstCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIpv4DstCounter.start', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIpv4DstCounter.step', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIpv4DstCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIpv4DstCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIpv4DstCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIpv4DstCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=69080,
  serialized_end=69195,
)


_PATTERNFLOWIPV4DST_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIpv4Dst.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIPV4DST_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWIPV4DST = _descriptor.Descriptor(
  name='PatternFlowIpv4Dst',
  full_name='otg.PatternFlowIpv4Dst',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIpv4Dst.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIpv4Dst.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIpv4Dst.values', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIpv4Dst.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIpv4Dst.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIpv4Dst.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWIPV4DST_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIpv4Dst._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIpv4Dst._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIpv4Dst._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIpv4Dst._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIpv4Dst._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=69198,
  serialized_end=69605,
)


_PATTERNFLOWIPV4PRIORITYRAWCOUNTER = _descriptor.Descriptor(
  name='PatternFlowIpv4PriorityRawCounter',
  full_name='otg.PatternFlowIpv4PriorityRawCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIpv4PriorityRawCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIpv4PriorityRawCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIpv4PriorityRawCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIpv4PriorityRawCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIpv4PriorityRawCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIpv4PriorityRawCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=69607,
  serialized_end=69730,
)


_PATTERNFLOWIPV4PRIORITYRAW_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIpv4PriorityRaw.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIPV4PRIORITYRAW_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWIPV4PRIORITYRAW = _descriptor.Descriptor(
  name='PatternFlowIpv4PriorityRaw',
  full_name='otg.PatternFlowIpv4PriorityRaw',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIpv4PriorityRaw.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIpv4PriorityRaw.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIpv4PriorityRaw.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIpv4PriorityRaw.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIpv4PriorityRaw.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIpv4PriorityRaw.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWIPV4PRIORITYRAW_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIpv4PriorityRaw._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIpv4PriorityRaw._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIpv4PriorityRaw._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIpv4PriorityRaw._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIpv4PriorityRaw._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=69733,
  serialized_end=70172,
)


_PATTERNFLOWIPV4DSCPPHBCOUNTER = _descriptor.Descriptor(
  name='PatternFlowIpv4DscpPhbCounter',
  full_name='otg.PatternFlowIpv4DscpPhbCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIpv4DscpPhbCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIpv4DscpPhbCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIpv4DscpPhbCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIpv4DscpPhbCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIpv4DscpPhbCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIpv4DscpPhbCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=70174,
  serialized_end=70293,
)


_PATTERNFLOWIPV4DSCPPHB_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIpv4DscpPhb.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIPV4DSCPPHB_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWIPV4DSCPPHB = _descriptor.Descriptor(
  name='PatternFlowIpv4DscpPhb',
  full_name='otg.PatternFlowIpv4DscpPhb',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIpv4DscpPhb.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIpv4DscpPhb.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIpv4DscpPhb.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIpv4DscpPhb.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIpv4DscpPhb.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIpv4DscpPhb.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWIPV4DSCPPHB_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIpv4DscpPhb._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIpv4DscpPhb._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIpv4DscpPhb._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIpv4DscpPhb._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIpv4DscpPhb._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=70296,
  serialized_end=70719,
)


_PATTERNFLOWIPV4DSCPECNCOUNTER = _descriptor.Descriptor(
  name='PatternFlowIpv4DscpEcnCounter',
  full_name='otg.PatternFlowIpv4DscpEcnCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIpv4DscpEcnCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIpv4DscpEcnCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIpv4DscpEcnCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIpv4DscpEcnCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIpv4DscpEcnCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIpv4DscpEcnCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=70721,
  serialized_end=70840,
)


_PATTERNFLOWIPV4DSCPECN_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIpv4DscpEcn.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIPV4DSCPECN_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWIPV4DSCPECN = _descriptor.Descriptor(
  name='PatternFlowIpv4DscpEcn',
  full_name='otg.PatternFlowIpv4DscpEcn',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIpv4DscpEcn.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIpv4DscpEcn.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIpv4DscpEcn.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIpv4DscpEcn.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIpv4DscpEcn.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIpv4DscpEcn.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWIPV4DSCPECN_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIpv4DscpEcn._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIpv4DscpEcn._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIpv4DscpEcn._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIpv4DscpEcn._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIpv4DscpEcn._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=70843,
  serialized_end=71266,
)


_PATTERNFLOWIPV4TOSPRECEDENCECOUNTER = _descriptor.Descriptor(
  name='PatternFlowIpv4TosPrecedenceCounter',
  full_name='otg.PatternFlowIpv4TosPrecedenceCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIpv4TosPrecedenceCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIpv4TosPrecedenceCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIpv4TosPrecedenceCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIpv4TosPrecedenceCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIpv4TosPrecedenceCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIpv4TosPrecedenceCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=71268,
  serialized_end=71393,
)


_PATTERNFLOWIPV4TOSPRECEDENCE_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIpv4TosPrecedence.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIPV4TOSPRECEDENCE_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWIPV4TOSPRECEDENCE = _descriptor.Descriptor(
  name='PatternFlowIpv4TosPrecedence',
  full_name='otg.PatternFlowIpv4TosPrecedence',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIpv4TosPrecedence.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIpv4TosPrecedence.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIpv4TosPrecedence.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIpv4TosPrecedence.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIpv4TosPrecedence.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIpv4TosPrecedence.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWIPV4TOSPRECEDENCE_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIpv4TosPrecedence._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIpv4TosPrecedence._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIpv4TosPrecedence._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIpv4TosPrecedence._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIpv4TosPrecedence._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=71396,
  serialized_end=71843,
)


_PATTERNFLOWIPV4TOSDELAYCOUNTER = _descriptor.Descriptor(
  name='PatternFlowIpv4TosDelayCounter',
  full_name='otg.PatternFlowIpv4TosDelayCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIpv4TosDelayCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIpv4TosDelayCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIpv4TosDelayCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIpv4TosDelayCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIpv4TosDelayCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIpv4TosDelayCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=71845,
  serialized_end=71965,
)


_PATTERNFLOWIPV4TOSDELAY_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIpv4TosDelay.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIPV4TOSDELAY_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWIPV4TOSDELAY = _descriptor.Descriptor(
  name='PatternFlowIpv4TosDelay',
  full_name='otg.PatternFlowIpv4TosDelay',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIpv4TosDelay.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIpv4TosDelay.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIpv4TosDelay.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIpv4TosDelay.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIpv4TosDelay.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIpv4TosDelay.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWIPV4TOSDELAY_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIpv4TosDelay._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIpv4TosDelay._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIpv4TosDelay._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIpv4TosDelay._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIpv4TosDelay._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=71968,
  serialized_end=72395,
)


_PATTERNFLOWIPV4TOSTHROUGHPUTCOUNTER = _descriptor.Descriptor(
  name='PatternFlowIpv4TosThroughputCounter',
  full_name='otg.PatternFlowIpv4TosThroughputCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIpv4TosThroughputCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIpv4TosThroughputCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIpv4TosThroughputCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIpv4TosThroughputCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIpv4TosThroughputCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIpv4TosThroughputCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=72397,
  serialized_end=72522,
)


_PATTERNFLOWIPV4TOSTHROUGHPUT_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIpv4TosThroughput.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIPV4TOSTHROUGHPUT_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWIPV4TOSTHROUGHPUT = _descriptor.Descriptor(
  name='PatternFlowIpv4TosThroughput',
  full_name='otg.PatternFlowIpv4TosThroughput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIpv4TosThroughput.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIpv4TosThroughput.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIpv4TosThroughput.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIpv4TosThroughput.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIpv4TosThroughput.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIpv4TosThroughput.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWIPV4TOSTHROUGHPUT_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIpv4TosThroughput._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIpv4TosThroughput._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIpv4TosThroughput._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIpv4TosThroughput._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIpv4TosThroughput._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=72525,
  serialized_end=72972,
)


_PATTERNFLOWIPV4TOSRELIABILITYCOUNTER = _descriptor.Descriptor(
  name='PatternFlowIpv4TosReliabilityCounter',
  full_name='otg.PatternFlowIpv4TosReliabilityCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIpv4TosReliabilityCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIpv4TosReliabilityCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIpv4TosReliabilityCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIpv4TosReliabilityCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIpv4TosReliabilityCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIpv4TosReliabilityCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=72974,
  serialized_end=73100,
)


_PATTERNFLOWIPV4TOSRELIABILITY_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIpv4TosReliability.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIPV4TOSRELIABILITY_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWIPV4TOSRELIABILITY = _descriptor.Descriptor(
  name='PatternFlowIpv4TosReliability',
  full_name='otg.PatternFlowIpv4TosReliability',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIpv4TosReliability.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIpv4TosReliability.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIpv4TosReliability.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIpv4TosReliability.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIpv4TosReliability.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIpv4TosReliability.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWIPV4TOSRELIABILITY_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIpv4TosReliability._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIpv4TosReliability._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIpv4TosReliability._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIpv4TosReliability._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIpv4TosReliability._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=73103,
  serialized_end=73554,
)


_PATTERNFLOWIPV4TOSMONETARYCOUNTER = _descriptor.Descriptor(
  name='PatternFlowIpv4TosMonetaryCounter',
  full_name='otg.PatternFlowIpv4TosMonetaryCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIpv4TosMonetaryCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIpv4TosMonetaryCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIpv4TosMonetaryCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIpv4TosMonetaryCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIpv4TosMonetaryCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIpv4TosMonetaryCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=73556,
  serialized_end=73679,
)


_PATTERNFLOWIPV4TOSMONETARY_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIpv4TosMonetary.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIPV4TOSMONETARY_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWIPV4TOSMONETARY = _descriptor.Descriptor(
  name='PatternFlowIpv4TosMonetary',
  full_name='otg.PatternFlowIpv4TosMonetary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIpv4TosMonetary.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIpv4TosMonetary.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIpv4TosMonetary.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIpv4TosMonetary.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIpv4TosMonetary.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIpv4TosMonetary.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWIPV4TOSMONETARY_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIpv4TosMonetary._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIpv4TosMonetary._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIpv4TosMonetary._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIpv4TosMonetary._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIpv4TosMonetary._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=73682,
  serialized_end=74121,
)


_PATTERNFLOWIPV4TOSUNUSEDCOUNTER = _descriptor.Descriptor(
  name='PatternFlowIpv4TosUnusedCounter',
  full_name='otg.PatternFlowIpv4TosUnusedCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIpv4TosUnusedCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIpv4TosUnusedCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIpv4TosUnusedCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIpv4TosUnusedCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIpv4TosUnusedCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIpv4TosUnusedCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=74123,
  serialized_end=74244,
)


_PATTERNFLOWIPV4TOSUNUSED_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIpv4TosUnused.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIPV4TOSUNUSED_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWIPV4TOSUNUSED = _descriptor.Descriptor(
  name='PatternFlowIpv4TosUnused',
  full_name='otg.PatternFlowIpv4TosUnused',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIpv4TosUnused.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIpv4TosUnused.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIpv4TosUnused.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIpv4TosUnused.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIpv4TosUnused.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIpv4TosUnused.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWIPV4TOSUNUSED_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIpv4TosUnused._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIpv4TosUnused._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIpv4TosUnused._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIpv4TosUnused._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIpv4TosUnused._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=74247,
  serialized_end=74678,
)


_PATTERNFLOWIPV6VERSIONCOUNTER = _descriptor.Descriptor(
  name='PatternFlowIpv6VersionCounter',
  full_name='otg.PatternFlowIpv6VersionCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIpv6VersionCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIpv6VersionCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIpv6VersionCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIpv6VersionCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIpv6VersionCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIpv6VersionCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=74680,
  serialized_end=74799,
)


_PATTERNFLOWIPV6VERSION_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIpv6Version.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIPV6VERSION_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWIPV6VERSION = _descriptor.Descriptor(
  name='PatternFlowIpv6Version',
  full_name='otg.PatternFlowIpv6Version',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIpv6Version.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIpv6Version.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIpv6Version.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIpv6Version.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIpv6Version.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIpv6Version.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWIPV6VERSION_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIpv6Version._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIpv6Version._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIpv6Version._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIpv6Version._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIpv6Version._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=74802,
  serialized_end=75225,
)


_PATTERNFLOWIPV6TRAFFICCLASSCOUNTER = _descriptor.Descriptor(
  name='PatternFlowIpv6TrafficClassCounter',
  full_name='otg.PatternFlowIpv6TrafficClassCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIpv6TrafficClassCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIpv6TrafficClassCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIpv6TrafficClassCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIpv6TrafficClassCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIpv6TrafficClassCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIpv6TrafficClassCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=75227,
  serialized_end=75351,
)


_PATTERNFLOWIPV6TRAFFICCLASS_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIpv6TrafficClass.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIPV6TRAFFICCLASS_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWIPV6TRAFFICCLASS = _descriptor.Descriptor(
  name='PatternFlowIpv6TrafficClass',
  full_name='otg.PatternFlowIpv6TrafficClass',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIpv6TrafficClass.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIpv6TrafficClass.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIpv6TrafficClass.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIpv6TrafficClass.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIpv6TrafficClass.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIpv6TrafficClass.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWIPV6TRAFFICCLASS_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIpv6TrafficClass._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIpv6TrafficClass._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIpv6TrafficClass._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIpv6TrafficClass._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIpv6TrafficClass._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=75354,
  serialized_end=75797,
)


_PATTERNFLOWIPV6FLOWLABELCOUNTER = _descriptor.Descriptor(
  name='PatternFlowIpv6FlowLabelCounter',
  full_name='otg.PatternFlowIpv6FlowLabelCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIpv6FlowLabelCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIpv6FlowLabelCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIpv6FlowLabelCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIpv6FlowLabelCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIpv6FlowLabelCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIpv6FlowLabelCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=75799,
  serialized_end=75920,
)


_PATTERNFLOWIPV6FLOWLABEL_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIpv6FlowLabel.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIPV6FLOWLABEL_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWIPV6FLOWLABEL = _descriptor.Descriptor(
  name='PatternFlowIpv6FlowLabel',
  full_name='otg.PatternFlowIpv6FlowLabel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIpv6FlowLabel.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIpv6FlowLabel.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIpv6FlowLabel.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIpv6FlowLabel.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIpv6FlowLabel.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIpv6FlowLabel.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWIPV6FLOWLABEL_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIpv6FlowLabel._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIpv6FlowLabel._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIpv6FlowLabel._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIpv6FlowLabel._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIpv6FlowLabel._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=75923,
  serialized_end=76354,
)


_PATTERNFLOWIPV6PAYLOADLENGTHCOUNTER = _descriptor.Descriptor(
  name='PatternFlowIpv6PayloadLengthCounter',
  full_name='otg.PatternFlowIpv6PayloadLengthCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIpv6PayloadLengthCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIpv6PayloadLengthCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIpv6PayloadLengthCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIpv6PayloadLengthCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIpv6PayloadLengthCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIpv6PayloadLengthCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=76356,
  serialized_end=76481,
)


_PATTERNFLOWIPV6PAYLOADLENGTH_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIpv6PayloadLength.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIPV6PAYLOADLENGTH_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57045,
  serialized_end=57141,
)

_PATTERNFLOWIPV6PAYLOADLENGTH_AUTO = _descriptor.Descriptor(
  name='Auto',
  full_name='otg.PatternFlowIpv6PayloadLength.Auto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIPV6PAYLOADLENGTH_AUTO_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57143,
  serialized_end=57184,
)

_PATTERNFLOWIPV6PAYLOADLENGTH = _descriptor.Descriptor(
  name='PatternFlowIpv6PayloadLength',
  full_name='otg.PatternFlowIpv6PayloadLength',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIpv6PayloadLength.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIpv6PayloadLength.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIpv6PayloadLength.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto', full_name='otg.PatternFlowIpv6PayloadLength.auto', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIpv6PayloadLength.metric_group', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIpv6PayloadLength.increment', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIpv6PayloadLength.decrement', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWIPV6PAYLOADLENGTH_CHOICE, _PATTERNFLOWIPV6PAYLOADLENGTH_AUTO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIpv6PayloadLength._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIpv6PayloadLength._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_auto', full_name='otg.PatternFlowIpv6PayloadLength._auto',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIpv6PayloadLength._metric_group',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIpv6PayloadLength._increment',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIpv6PayloadLength._decrement',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=76484,
  serialized_end=77057,
)


_PATTERNFLOWIPV6NEXTHEADERCOUNTER = _descriptor.Descriptor(
  name='PatternFlowIpv6NextHeaderCounter',
  full_name='otg.PatternFlowIpv6NextHeaderCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIpv6NextHeaderCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIpv6NextHeaderCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIpv6NextHeaderCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIpv6NextHeaderCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIpv6NextHeaderCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIpv6NextHeaderCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=77059,
  serialized_end=77181,
)


_PATTERNFLOWIPV6NEXTHEADER_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIpv6NextHeader.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIPV6NEXTHEADER_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWIPV6NEXTHEADER = _descriptor.Descriptor(
  name='PatternFlowIpv6NextHeader',
  full_name='otg.PatternFlowIpv6NextHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIpv6NextHeader.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIpv6NextHeader.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIpv6NextHeader.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIpv6NextHeader.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIpv6NextHeader.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIpv6NextHeader.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWIPV6NEXTHEADER_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIpv6NextHeader._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIpv6NextHeader._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIpv6NextHeader._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIpv6NextHeader._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIpv6NextHeader._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=77184,
  serialized_end=77619,
)


_PATTERNFLOWIPV6HOPLIMITCOUNTER = _descriptor.Descriptor(
  name='PatternFlowIpv6HopLimitCounter',
  full_name='otg.PatternFlowIpv6HopLimitCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIpv6HopLimitCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIpv6HopLimitCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIpv6HopLimitCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIpv6HopLimitCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIpv6HopLimitCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIpv6HopLimitCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=77621,
  serialized_end=77741,
)


_PATTERNFLOWIPV6HOPLIMIT_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIpv6HopLimit.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIPV6HOPLIMIT_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWIPV6HOPLIMIT = _descriptor.Descriptor(
  name='PatternFlowIpv6HopLimit',
  full_name='otg.PatternFlowIpv6HopLimit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIpv6HopLimit.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIpv6HopLimit.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIpv6HopLimit.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIpv6HopLimit.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIpv6HopLimit.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIpv6HopLimit.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWIPV6HOPLIMIT_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIpv6HopLimit._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIpv6HopLimit._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIpv6HopLimit._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIpv6HopLimit._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIpv6HopLimit._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=77744,
  serialized_end=78171,
)


_PATTERNFLOWIPV6SRCCOUNTER = _descriptor.Descriptor(
  name='PatternFlowIpv6SrcCounter',
  full_name='otg.PatternFlowIpv6SrcCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIpv6SrcCounter.start', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIpv6SrcCounter.step', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIpv6SrcCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIpv6SrcCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIpv6SrcCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIpv6SrcCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=78173,
  serialized_end=78288,
)


_PATTERNFLOWIPV6SRC_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIpv6Src.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIPV6SRC_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWIPV6SRC = _descriptor.Descriptor(
  name='PatternFlowIpv6Src',
  full_name='otg.PatternFlowIpv6Src',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIpv6Src.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIpv6Src.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIpv6Src.values', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIpv6Src.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIpv6Src.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIpv6Src.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWIPV6SRC_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIpv6Src._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIpv6Src._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIpv6Src._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIpv6Src._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIpv6Src._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=78291,
  serialized_end=78698,
)


_PATTERNFLOWIPV6DSTCOUNTER = _descriptor.Descriptor(
  name='PatternFlowIpv6DstCounter',
  full_name='otg.PatternFlowIpv6DstCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIpv6DstCounter.start', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIpv6DstCounter.step', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIpv6DstCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIpv6DstCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIpv6DstCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIpv6DstCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=78700,
  serialized_end=78815,
)


_PATTERNFLOWIPV6DST_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIpv6Dst.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIPV6DST_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWIPV6DST = _descriptor.Descriptor(
  name='PatternFlowIpv6Dst',
  full_name='otg.PatternFlowIpv6Dst',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIpv6Dst.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIpv6Dst.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIpv6Dst.values', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIpv6Dst.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIpv6Dst.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIpv6Dst.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWIPV6DST_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIpv6Dst._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIpv6Dst._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIpv6Dst._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIpv6Dst._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIpv6Dst._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=78818,
  serialized_end=79225,
)


_PATTERNFLOWPFCPAUSEDSTCOUNTER = _descriptor.Descriptor(
  name='PatternFlowPfcPauseDstCounter',
  full_name='otg.PatternFlowPfcPauseDstCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowPfcPauseDstCounter.start', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowPfcPauseDstCounter.step', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowPfcPauseDstCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowPfcPauseDstCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowPfcPauseDstCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowPfcPauseDstCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=79227,
  serialized_end=79346,
)


_PATTERNFLOWPFCPAUSEDST_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowPfcPauseDst.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWPFCPAUSEDST_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWPFCPAUSEDST = _descriptor.Descriptor(
  name='PatternFlowPfcPauseDst',
  full_name='otg.PatternFlowPfcPauseDst',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowPfcPauseDst.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowPfcPauseDst.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowPfcPauseDst.values', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowPfcPauseDst.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowPfcPauseDst.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowPfcPauseDst.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWPFCPAUSEDST_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowPfcPauseDst._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowPfcPauseDst._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowPfcPauseDst._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowPfcPauseDst._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowPfcPauseDst._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=79349,
  serialized_end=79772,
)


_PATTERNFLOWPFCPAUSESRCCOUNTER = _descriptor.Descriptor(
  name='PatternFlowPfcPauseSrcCounter',
  full_name='otg.PatternFlowPfcPauseSrcCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowPfcPauseSrcCounter.start', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowPfcPauseSrcCounter.step', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowPfcPauseSrcCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowPfcPauseSrcCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowPfcPauseSrcCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowPfcPauseSrcCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=79774,
  serialized_end=79893,
)


_PATTERNFLOWPFCPAUSESRC_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowPfcPauseSrc.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWPFCPAUSESRC_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWPFCPAUSESRC = _descriptor.Descriptor(
  name='PatternFlowPfcPauseSrc',
  full_name='otg.PatternFlowPfcPauseSrc',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowPfcPauseSrc.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowPfcPauseSrc.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowPfcPauseSrc.values', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowPfcPauseSrc.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowPfcPauseSrc.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowPfcPauseSrc.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWPFCPAUSESRC_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowPfcPauseSrc._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowPfcPauseSrc._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowPfcPauseSrc._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowPfcPauseSrc._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowPfcPauseSrc._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=79896,
  serialized_end=80319,
)


_PATTERNFLOWPFCPAUSEETHERTYPECOUNTER = _descriptor.Descriptor(
  name='PatternFlowPfcPauseEtherTypeCounter',
  full_name='otg.PatternFlowPfcPauseEtherTypeCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowPfcPauseEtherTypeCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowPfcPauseEtherTypeCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowPfcPauseEtherTypeCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowPfcPauseEtherTypeCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowPfcPauseEtherTypeCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowPfcPauseEtherTypeCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=80321,
  serialized_end=80446,
)


_PATTERNFLOWPFCPAUSEETHERTYPE_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowPfcPauseEtherType.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWPFCPAUSEETHERTYPE_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWPFCPAUSEETHERTYPE = _descriptor.Descriptor(
  name='PatternFlowPfcPauseEtherType',
  full_name='otg.PatternFlowPfcPauseEtherType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowPfcPauseEtherType.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowPfcPauseEtherType.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowPfcPauseEtherType.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowPfcPauseEtherType.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowPfcPauseEtherType.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowPfcPauseEtherType.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWPFCPAUSEETHERTYPE_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowPfcPauseEtherType._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowPfcPauseEtherType._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowPfcPauseEtherType._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowPfcPauseEtherType._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowPfcPauseEtherType._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=80449,
  serialized_end=80896,
)


_PATTERNFLOWPFCPAUSECONTROLOPCODECOUNTER = _descriptor.Descriptor(
  name='PatternFlowPfcPauseControlOpCodeCounter',
  full_name='otg.PatternFlowPfcPauseControlOpCodeCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowPfcPauseControlOpCodeCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowPfcPauseControlOpCodeCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowPfcPauseControlOpCodeCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowPfcPauseControlOpCodeCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowPfcPauseControlOpCodeCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowPfcPauseControlOpCodeCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=80899,
  serialized_end=81028,
)


_PATTERNFLOWPFCPAUSECONTROLOPCODE_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowPfcPauseControlOpCode.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWPFCPAUSECONTROLOPCODE_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWPFCPAUSECONTROLOPCODE = _descriptor.Descriptor(
  name='PatternFlowPfcPauseControlOpCode',
  full_name='otg.PatternFlowPfcPauseControlOpCode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowPfcPauseControlOpCode.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowPfcPauseControlOpCode.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowPfcPauseControlOpCode.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowPfcPauseControlOpCode.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowPfcPauseControlOpCode.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowPfcPauseControlOpCode.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWPFCPAUSECONTROLOPCODE_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowPfcPauseControlOpCode._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowPfcPauseControlOpCode._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowPfcPauseControlOpCode._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowPfcPauseControlOpCode._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowPfcPauseControlOpCode._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=81031,
  serialized_end=81494,
)


_PATTERNFLOWPFCPAUSECLASSENABLEVECTORCOUNTER = _descriptor.Descriptor(
  name='PatternFlowPfcPauseClassEnableVectorCounter',
  full_name='otg.PatternFlowPfcPauseClassEnableVectorCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowPfcPauseClassEnableVectorCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowPfcPauseClassEnableVectorCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowPfcPauseClassEnableVectorCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowPfcPauseClassEnableVectorCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowPfcPauseClassEnableVectorCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowPfcPauseClassEnableVectorCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=81497,
  serialized_end=81630,
)


_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowPfcPauseClassEnableVector.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR = _descriptor.Descriptor(
  name='PatternFlowPfcPauseClassEnableVector',
  full_name='otg.PatternFlowPfcPauseClassEnableVector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowPfcPauseClassEnableVector.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowPfcPauseClassEnableVector.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowPfcPauseClassEnableVector.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowPfcPauseClassEnableVector.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowPfcPauseClassEnableVector.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowPfcPauseClassEnableVector.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowPfcPauseClassEnableVector._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowPfcPauseClassEnableVector._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowPfcPauseClassEnableVector._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowPfcPauseClassEnableVector._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowPfcPauseClassEnableVector._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=81633,
  serialized_end=82112,
)


_PATTERNFLOWPFCPAUSEPAUSECLASS0COUNTER = _descriptor.Descriptor(
  name='PatternFlowPfcPausePauseClass0Counter',
  full_name='otg.PatternFlowPfcPausePauseClass0Counter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowPfcPausePauseClass0Counter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowPfcPausePauseClass0Counter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowPfcPausePauseClass0Counter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowPfcPausePauseClass0Counter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowPfcPausePauseClass0Counter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowPfcPausePauseClass0Counter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=82114,
  serialized_end=82241,
)


_PATTERNFLOWPFCPAUSEPAUSECLASS0_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowPfcPausePauseClass0.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWPFCPAUSEPAUSECLASS0_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWPFCPAUSEPAUSECLASS0 = _descriptor.Descriptor(
  name='PatternFlowPfcPausePauseClass0',
  full_name='otg.PatternFlowPfcPausePauseClass0',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowPfcPausePauseClass0.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowPfcPausePauseClass0.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowPfcPausePauseClass0.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowPfcPausePauseClass0.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowPfcPausePauseClass0.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowPfcPausePauseClass0.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWPFCPAUSEPAUSECLASS0_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowPfcPausePauseClass0._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowPfcPausePauseClass0._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowPfcPausePauseClass0._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowPfcPausePauseClass0._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowPfcPausePauseClass0._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=82244,
  serialized_end=82699,
)


_PATTERNFLOWPFCPAUSEPAUSECLASS1COUNTER = _descriptor.Descriptor(
  name='PatternFlowPfcPausePauseClass1Counter',
  full_name='otg.PatternFlowPfcPausePauseClass1Counter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowPfcPausePauseClass1Counter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowPfcPausePauseClass1Counter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowPfcPausePauseClass1Counter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowPfcPausePauseClass1Counter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowPfcPausePauseClass1Counter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowPfcPausePauseClass1Counter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=82701,
  serialized_end=82828,
)


_PATTERNFLOWPFCPAUSEPAUSECLASS1_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowPfcPausePauseClass1.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWPFCPAUSEPAUSECLASS1_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWPFCPAUSEPAUSECLASS1 = _descriptor.Descriptor(
  name='PatternFlowPfcPausePauseClass1',
  full_name='otg.PatternFlowPfcPausePauseClass1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowPfcPausePauseClass1.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowPfcPausePauseClass1.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowPfcPausePauseClass1.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowPfcPausePauseClass1.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowPfcPausePauseClass1.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowPfcPausePauseClass1.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWPFCPAUSEPAUSECLASS1_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowPfcPausePauseClass1._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowPfcPausePauseClass1._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowPfcPausePauseClass1._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowPfcPausePauseClass1._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowPfcPausePauseClass1._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=82831,
  serialized_end=83286,
)


_PATTERNFLOWPFCPAUSEPAUSECLASS2COUNTER = _descriptor.Descriptor(
  name='PatternFlowPfcPausePauseClass2Counter',
  full_name='otg.PatternFlowPfcPausePauseClass2Counter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowPfcPausePauseClass2Counter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowPfcPausePauseClass2Counter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowPfcPausePauseClass2Counter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowPfcPausePauseClass2Counter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowPfcPausePauseClass2Counter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowPfcPausePauseClass2Counter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=83288,
  serialized_end=83415,
)


_PATTERNFLOWPFCPAUSEPAUSECLASS2_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowPfcPausePauseClass2.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWPFCPAUSEPAUSECLASS2_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWPFCPAUSEPAUSECLASS2 = _descriptor.Descriptor(
  name='PatternFlowPfcPausePauseClass2',
  full_name='otg.PatternFlowPfcPausePauseClass2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowPfcPausePauseClass2.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowPfcPausePauseClass2.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowPfcPausePauseClass2.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowPfcPausePauseClass2.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowPfcPausePauseClass2.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowPfcPausePauseClass2.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWPFCPAUSEPAUSECLASS2_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowPfcPausePauseClass2._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowPfcPausePauseClass2._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowPfcPausePauseClass2._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowPfcPausePauseClass2._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowPfcPausePauseClass2._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=83418,
  serialized_end=83873,
)


_PATTERNFLOWPFCPAUSEPAUSECLASS3COUNTER = _descriptor.Descriptor(
  name='PatternFlowPfcPausePauseClass3Counter',
  full_name='otg.PatternFlowPfcPausePauseClass3Counter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowPfcPausePauseClass3Counter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowPfcPausePauseClass3Counter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowPfcPausePauseClass3Counter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowPfcPausePauseClass3Counter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowPfcPausePauseClass3Counter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowPfcPausePauseClass3Counter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=83875,
  serialized_end=84002,
)


_PATTERNFLOWPFCPAUSEPAUSECLASS3_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowPfcPausePauseClass3.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWPFCPAUSEPAUSECLASS3_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWPFCPAUSEPAUSECLASS3 = _descriptor.Descriptor(
  name='PatternFlowPfcPausePauseClass3',
  full_name='otg.PatternFlowPfcPausePauseClass3',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowPfcPausePauseClass3.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowPfcPausePauseClass3.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowPfcPausePauseClass3.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowPfcPausePauseClass3.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowPfcPausePauseClass3.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowPfcPausePauseClass3.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWPFCPAUSEPAUSECLASS3_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowPfcPausePauseClass3._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowPfcPausePauseClass3._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowPfcPausePauseClass3._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowPfcPausePauseClass3._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowPfcPausePauseClass3._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=84005,
  serialized_end=84460,
)


_PATTERNFLOWPFCPAUSEPAUSECLASS4COUNTER = _descriptor.Descriptor(
  name='PatternFlowPfcPausePauseClass4Counter',
  full_name='otg.PatternFlowPfcPausePauseClass4Counter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowPfcPausePauseClass4Counter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowPfcPausePauseClass4Counter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowPfcPausePauseClass4Counter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowPfcPausePauseClass4Counter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowPfcPausePauseClass4Counter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowPfcPausePauseClass4Counter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=84462,
  serialized_end=84589,
)


_PATTERNFLOWPFCPAUSEPAUSECLASS4_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowPfcPausePauseClass4.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWPFCPAUSEPAUSECLASS4_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWPFCPAUSEPAUSECLASS4 = _descriptor.Descriptor(
  name='PatternFlowPfcPausePauseClass4',
  full_name='otg.PatternFlowPfcPausePauseClass4',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowPfcPausePauseClass4.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowPfcPausePauseClass4.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowPfcPausePauseClass4.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowPfcPausePauseClass4.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowPfcPausePauseClass4.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowPfcPausePauseClass4.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWPFCPAUSEPAUSECLASS4_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowPfcPausePauseClass4._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowPfcPausePauseClass4._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowPfcPausePauseClass4._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowPfcPausePauseClass4._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowPfcPausePauseClass4._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=84592,
  serialized_end=85047,
)


_PATTERNFLOWPFCPAUSEPAUSECLASS5COUNTER = _descriptor.Descriptor(
  name='PatternFlowPfcPausePauseClass5Counter',
  full_name='otg.PatternFlowPfcPausePauseClass5Counter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowPfcPausePauseClass5Counter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowPfcPausePauseClass5Counter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowPfcPausePauseClass5Counter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowPfcPausePauseClass5Counter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowPfcPausePauseClass5Counter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowPfcPausePauseClass5Counter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=85049,
  serialized_end=85176,
)


_PATTERNFLOWPFCPAUSEPAUSECLASS5_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowPfcPausePauseClass5.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWPFCPAUSEPAUSECLASS5_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWPFCPAUSEPAUSECLASS5 = _descriptor.Descriptor(
  name='PatternFlowPfcPausePauseClass5',
  full_name='otg.PatternFlowPfcPausePauseClass5',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowPfcPausePauseClass5.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowPfcPausePauseClass5.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowPfcPausePauseClass5.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowPfcPausePauseClass5.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowPfcPausePauseClass5.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowPfcPausePauseClass5.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWPFCPAUSEPAUSECLASS5_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowPfcPausePauseClass5._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowPfcPausePauseClass5._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowPfcPausePauseClass5._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowPfcPausePauseClass5._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowPfcPausePauseClass5._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=85179,
  serialized_end=85634,
)


_PATTERNFLOWPFCPAUSEPAUSECLASS6COUNTER = _descriptor.Descriptor(
  name='PatternFlowPfcPausePauseClass6Counter',
  full_name='otg.PatternFlowPfcPausePauseClass6Counter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowPfcPausePauseClass6Counter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowPfcPausePauseClass6Counter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowPfcPausePauseClass6Counter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowPfcPausePauseClass6Counter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowPfcPausePauseClass6Counter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowPfcPausePauseClass6Counter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=85636,
  serialized_end=85763,
)


_PATTERNFLOWPFCPAUSEPAUSECLASS6_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowPfcPausePauseClass6.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWPFCPAUSEPAUSECLASS6_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWPFCPAUSEPAUSECLASS6 = _descriptor.Descriptor(
  name='PatternFlowPfcPausePauseClass6',
  full_name='otg.PatternFlowPfcPausePauseClass6',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowPfcPausePauseClass6.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowPfcPausePauseClass6.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowPfcPausePauseClass6.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowPfcPausePauseClass6.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowPfcPausePauseClass6.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowPfcPausePauseClass6.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWPFCPAUSEPAUSECLASS6_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowPfcPausePauseClass6._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowPfcPausePauseClass6._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowPfcPausePauseClass6._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowPfcPausePauseClass6._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowPfcPausePauseClass6._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=85766,
  serialized_end=86221,
)


_PATTERNFLOWPFCPAUSEPAUSECLASS7COUNTER = _descriptor.Descriptor(
  name='PatternFlowPfcPausePauseClass7Counter',
  full_name='otg.PatternFlowPfcPausePauseClass7Counter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowPfcPausePauseClass7Counter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowPfcPausePauseClass7Counter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowPfcPausePauseClass7Counter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowPfcPausePauseClass7Counter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowPfcPausePauseClass7Counter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowPfcPausePauseClass7Counter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=86223,
  serialized_end=86350,
)


_PATTERNFLOWPFCPAUSEPAUSECLASS7_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowPfcPausePauseClass7.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWPFCPAUSEPAUSECLASS7_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWPFCPAUSEPAUSECLASS7 = _descriptor.Descriptor(
  name='PatternFlowPfcPausePauseClass7',
  full_name='otg.PatternFlowPfcPausePauseClass7',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowPfcPausePauseClass7.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowPfcPausePauseClass7.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowPfcPausePauseClass7.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowPfcPausePauseClass7.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowPfcPausePauseClass7.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowPfcPausePauseClass7.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWPFCPAUSEPAUSECLASS7_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowPfcPausePauseClass7._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowPfcPausePauseClass7._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowPfcPausePauseClass7._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowPfcPausePauseClass7._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowPfcPausePauseClass7._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=86353,
  serialized_end=86808,
)


_PATTERNFLOWETHERNETPAUSEDSTCOUNTER = _descriptor.Descriptor(
  name='PatternFlowEthernetPauseDstCounter',
  full_name='otg.PatternFlowEthernetPauseDstCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowEthernetPauseDstCounter.start', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowEthernetPauseDstCounter.step', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowEthernetPauseDstCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowEthernetPauseDstCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowEthernetPauseDstCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowEthernetPauseDstCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=86810,
  serialized_end=86934,
)


_PATTERNFLOWETHERNETPAUSEDST_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowEthernetPauseDst.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWETHERNETPAUSEDST_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWETHERNETPAUSEDST = _descriptor.Descriptor(
  name='PatternFlowEthernetPauseDst',
  full_name='otg.PatternFlowEthernetPauseDst',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowEthernetPauseDst.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowEthernetPauseDst.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowEthernetPauseDst.values', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowEthernetPauseDst.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowEthernetPauseDst.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowEthernetPauseDst.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWETHERNETPAUSEDST_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowEthernetPauseDst._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowEthernetPauseDst._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowEthernetPauseDst._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowEthernetPauseDst._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowEthernetPauseDst._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=86937,
  serialized_end=87380,
)


_PATTERNFLOWETHERNETPAUSESRCCOUNTER = _descriptor.Descriptor(
  name='PatternFlowEthernetPauseSrcCounter',
  full_name='otg.PatternFlowEthernetPauseSrcCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowEthernetPauseSrcCounter.start', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowEthernetPauseSrcCounter.step', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowEthernetPauseSrcCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowEthernetPauseSrcCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowEthernetPauseSrcCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowEthernetPauseSrcCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=87382,
  serialized_end=87506,
)


_PATTERNFLOWETHERNETPAUSESRC_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowEthernetPauseSrc.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWETHERNETPAUSESRC_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWETHERNETPAUSESRC = _descriptor.Descriptor(
  name='PatternFlowEthernetPauseSrc',
  full_name='otg.PatternFlowEthernetPauseSrc',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowEthernetPauseSrc.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowEthernetPauseSrc.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowEthernetPauseSrc.values', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowEthernetPauseSrc.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowEthernetPauseSrc.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowEthernetPauseSrc.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWETHERNETPAUSESRC_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowEthernetPauseSrc._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowEthernetPauseSrc._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowEthernetPauseSrc._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowEthernetPauseSrc._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowEthernetPauseSrc._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=87509,
  serialized_end=87952,
)


_PATTERNFLOWETHERNETPAUSEETHERTYPECOUNTER = _descriptor.Descriptor(
  name='PatternFlowEthernetPauseEtherTypeCounter',
  full_name='otg.PatternFlowEthernetPauseEtherTypeCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowEthernetPauseEtherTypeCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowEthernetPauseEtherTypeCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowEthernetPauseEtherTypeCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowEthernetPauseEtherTypeCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowEthernetPauseEtherTypeCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowEthernetPauseEtherTypeCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=87955,
  serialized_end=88085,
)


_PATTERNFLOWETHERNETPAUSEETHERTYPE_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowEthernetPauseEtherType.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWETHERNETPAUSEETHERTYPE_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWETHERNETPAUSEETHERTYPE = _descriptor.Descriptor(
  name='PatternFlowEthernetPauseEtherType',
  full_name='otg.PatternFlowEthernetPauseEtherType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowEthernetPauseEtherType.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowEthernetPauseEtherType.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowEthernetPauseEtherType.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowEthernetPauseEtherType.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowEthernetPauseEtherType.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowEthernetPauseEtherType.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWETHERNETPAUSEETHERTYPE_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowEthernetPauseEtherType._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowEthernetPauseEtherType._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowEthernetPauseEtherType._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowEthernetPauseEtherType._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowEthernetPauseEtherType._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=88088,
  serialized_end=88555,
)


_PATTERNFLOWETHERNETPAUSECONTROLOPCODECOUNTER = _descriptor.Descriptor(
  name='PatternFlowEthernetPauseControlOpCodeCounter',
  full_name='otg.PatternFlowEthernetPauseControlOpCodeCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowEthernetPauseControlOpCodeCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowEthernetPauseControlOpCodeCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowEthernetPauseControlOpCodeCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowEthernetPauseControlOpCodeCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowEthernetPauseControlOpCodeCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowEthernetPauseControlOpCodeCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=88558,
  serialized_end=88692,
)


_PATTERNFLOWETHERNETPAUSECONTROLOPCODE_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowEthernetPauseControlOpCode.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWETHERNETPAUSECONTROLOPCODE_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWETHERNETPAUSECONTROLOPCODE = _descriptor.Descriptor(
  name='PatternFlowEthernetPauseControlOpCode',
  full_name='otg.PatternFlowEthernetPauseControlOpCode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowEthernetPauseControlOpCode.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowEthernetPauseControlOpCode.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowEthernetPauseControlOpCode.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowEthernetPauseControlOpCode.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowEthernetPauseControlOpCode.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowEthernetPauseControlOpCode.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWETHERNETPAUSECONTROLOPCODE_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowEthernetPauseControlOpCode._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowEthernetPauseControlOpCode._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowEthernetPauseControlOpCode._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowEthernetPauseControlOpCode._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowEthernetPauseControlOpCode._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=88695,
  serialized_end=89178,
)


_PATTERNFLOWETHERNETPAUSETIMECOUNTER = _descriptor.Descriptor(
  name='PatternFlowEthernetPauseTimeCounter',
  full_name='otg.PatternFlowEthernetPauseTimeCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowEthernetPauseTimeCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowEthernetPauseTimeCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowEthernetPauseTimeCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowEthernetPauseTimeCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowEthernetPauseTimeCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowEthernetPauseTimeCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=89180,
  serialized_end=89305,
)


_PATTERNFLOWETHERNETPAUSETIME_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowEthernetPauseTime.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWETHERNETPAUSETIME_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWETHERNETPAUSETIME = _descriptor.Descriptor(
  name='PatternFlowEthernetPauseTime',
  full_name='otg.PatternFlowEthernetPauseTime',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowEthernetPauseTime.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowEthernetPauseTime.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowEthernetPauseTime.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowEthernetPauseTime.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowEthernetPauseTime.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowEthernetPauseTime.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWETHERNETPAUSETIME_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowEthernetPauseTime._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowEthernetPauseTime._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowEthernetPauseTime._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowEthernetPauseTime._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowEthernetPauseTime._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=89308,
  serialized_end=89755,
)


_PATTERNFLOWTCPSRCPORTCOUNTER = _descriptor.Descriptor(
  name='PatternFlowTcpSrcPortCounter',
  full_name='otg.PatternFlowTcpSrcPortCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowTcpSrcPortCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowTcpSrcPortCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowTcpSrcPortCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowTcpSrcPortCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowTcpSrcPortCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowTcpSrcPortCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=89757,
  serialized_end=89875,
)


_PATTERNFLOWTCPSRCPORT_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowTcpSrcPort.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWTCPSRCPORT_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWTCPSRCPORT = _descriptor.Descriptor(
  name='PatternFlowTcpSrcPort',
  full_name='otg.PatternFlowTcpSrcPort',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowTcpSrcPort.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowTcpSrcPort.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowTcpSrcPort.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowTcpSrcPort.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowTcpSrcPort.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowTcpSrcPort.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWTCPSRCPORT_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowTcpSrcPort._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowTcpSrcPort._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowTcpSrcPort._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowTcpSrcPort._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowTcpSrcPort._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=89878,
  serialized_end=90297,
)


_PATTERNFLOWTCPDSTPORTCOUNTER = _descriptor.Descriptor(
  name='PatternFlowTcpDstPortCounter',
  full_name='otg.PatternFlowTcpDstPortCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowTcpDstPortCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowTcpDstPortCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowTcpDstPortCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowTcpDstPortCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowTcpDstPortCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowTcpDstPortCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=90299,
  serialized_end=90417,
)


_PATTERNFLOWTCPDSTPORT_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowTcpDstPort.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWTCPDSTPORT_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWTCPDSTPORT = _descriptor.Descriptor(
  name='PatternFlowTcpDstPort',
  full_name='otg.PatternFlowTcpDstPort',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowTcpDstPort.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowTcpDstPort.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowTcpDstPort.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowTcpDstPort.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowTcpDstPort.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowTcpDstPort.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWTCPDSTPORT_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowTcpDstPort._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowTcpDstPort._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowTcpDstPort._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowTcpDstPort._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowTcpDstPort._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=90420,
  serialized_end=90839,
)


_PATTERNFLOWTCPSEQNUMCOUNTER = _descriptor.Descriptor(
  name='PatternFlowTcpSeqNumCounter',
  full_name='otg.PatternFlowTcpSeqNumCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowTcpSeqNumCounter.start', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowTcpSeqNumCounter.step', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowTcpSeqNumCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowTcpSeqNumCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowTcpSeqNumCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowTcpSeqNumCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=90841,
  serialized_end=90958,
)


_PATTERNFLOWTCPSEQNUM_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowTcpSeqNum.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWTCPSEQNUM_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWTCPSEQNUM = _descriptor.Descriptor(
  name='PatternFlowTcpSeqNum',
  full_name='otg.PatternFlowTcpSeqNum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowTcpSeqNum.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowTcpSeqNum.value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowTcpSeqNum.values', index=2,
      number=3, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowTcpSeqNum.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowTcpSeqNum.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowTcpSeqNum.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWTCPSEQNUM_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowTcpSeqNum._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowTcpSeqNum._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowTcpSeqNum._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowTcpSeqNum._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowTcpSeqNum._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=90961,
  serialized_end=91376,
)


_PATTERNFLOWTCPACKNUMCOUNTER = _descriptor.Descriptor(
  name='PatternFlowTcpAckNumCounter',
  full_name='otg.PatternFlowTcpAckNumCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowTcpAckNumCounter.start', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowTcpAckNumCounter.step', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowTcpAckNumCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowTcpAckNumCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowTcpAckNumCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowTcpAckNumCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=91378,
  serialized_end=91495,
)


_PATTERNFLOWTCPACKNUM_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowTcpAckNum.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWTCPACKNUM_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWTCPACKNUM = _descriptor.Descriptor(
  name='PatternFlowTcpAckNum',
  full_name='otg.PatternFlowTcpAckNum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowTcpAckNum.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowTcpAckNum.value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowTcpAckNum.values', index=2,
      number=3, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowTcpAckNum.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowTcpAckNum.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowTcpAckNum.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWTCPACKNUM_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowTcpAckNum._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowTcpAckNum._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowTcpAckNum._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowTcpAckNum._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowTcpAckNum._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=91498,
  serialized_end=91913,
)


_PATTERNFLOWTCPDATAOFFSETCOUNTER = _descriptor.Descriptor(
  name='PatternFlowTcpDataOffsetCounter',
  full_name='otg.PatternFlowTcpDataOffsetCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowTcpDataOffsetCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowTcpDataOffsetCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowTcpDataOffsetCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowTcpDataOffsetCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowTcpDataOffsetCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowTcpDataOffsetCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=91915,
  serialized_end=92036,
)


_PATTERNFLOWTCPDATAOFFSET_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowTcpDataOffset.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWTCPDATAOFFSET_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWTCPDATAOFFSET = _descriptor.Descriptor(
  name='PatternFlowTcpDataOffset',
  full_name='otg.PatternFlowTcpDataOffset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowTcpDataOffset.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowTcpDataOffset.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowTcpDataOffset.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowTcpDataOffset.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowTcpDataOffset.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowTcpDataOffset.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWTCPDATAOFFSET_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowTcpDataOffset._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowTcpDataOffset._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowTcpDataOffset._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowTcpDataOffset._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowTcpDataOffset._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=92039,
  serialized_end=92470,
)


_PATTERNFLOWTCPECNNSCOUNTER = _descriptor.Descriptor(
  name='PatternFlowTcpEcnNsCounter',
  full_name='otg.PatternFlowTcpEcnNsCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowTcpEcnNsCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowTcpEcnNsCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowTcpEcnNsCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowTcpEcnNsCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowTcpEcnNsCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowTcpEcnNsCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=92472,
  serialized_end=92588,
)


_PATTERNFLOWTCPECNNS_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowTcpEcnNs.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWTCPECNNS_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWTCPECNNS = _descriptor.Descriptor(
  name='PatternFlowTcpEcnNs',
  full_name='otg.PatternFlowTcpEcnNs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowTcpEcnNs.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowTcpEcnNs.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowTcpEcnNs.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowTcpEcnNs.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowTcpEcnNs.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowTcpEcnNs.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWTCPECNNS_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowTcpEcnNs._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowTcpEcnNs._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowTcpEcnNs._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowTcpEcnNs._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowTcpEcnNs._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=92591,
  serialized_end=93002,
)


_PATTERNFLOWTCPECNCWRCOUNTER = _descriptor.Descriptor(
  name='PatternFlowTcpEcnCwrCounter',
  full_name='otg.PatternFlowTcpEcnCwrCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowTcpEcnCwrCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowTcpEcnCwrCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowTcpEcnCwrCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowTcpEcnCwrCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowTcpEcnCwrCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowTcpEcnCwrCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=93004,
  serialized_end=93121,
)


_PATTERNFLOWTCPECNCWR_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowTcpEcnCwr.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWTCPECNCWR_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWTCPECNCWR = _descriptor.Descriptor(
  name='PatternFlowTcpEcnCwr',
  full_name='otg.PatternFlowTcpEcnCwr',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowTcpEcnCwr.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowTcpEcnCwr.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowTcpEcnCwr.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowTcpEcnCwr.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowTcpEcnCwr.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowTcpEcnCwr.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWTCPECNCWR_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowTcpEcnCwr._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowTcpEcnCwr._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowTcpEcnCwr._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowTcpEcnCwr._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowTcpEcnCwr._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=93124,
  serialized_end=93539,
)


_PATTERNFLOWTCPECNECHOCOUNTER = _descriptor.Descriptor(
  name='PatternFlowTcpEcnEchoCounter',
  full_name='otg.PatternFlowTcpEcnEchoCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowTcpEcnEchoCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowTcpEcnEchoCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowTcpEcnEchoCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowTcpEcnEchoCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowTcpEcnEchoCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowTcpEcnEchoCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=93541,
  serialized_end=93659,
)


_PATTERNFLOWTCPECNECHO_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowTcpEcnEcho.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWTCPECNECHO_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWTCPECNECHO = _descriptor.Descriptor(
  name='PatternFlowTcpEcnEcho',
  full_name='otg.PatternFlowTcpEcnEcho',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowTcpEcnEcho.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowTcpEcnEcho.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowTcpEcnEcho.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowTcpEcnEcho.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowTcpEcnEcho.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowTcpEcnEcho.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWTCPECNECHO_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowTcpEcnEcho._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowTcpEcnEcho._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowTcpEcnEcho._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowTcpEcnEcho._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowTcpEcnEcho._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=93662,
  serialized_end=94081,
)


_PATTERNFLOWTCPCTLURGCOUNTER = _descriptor.Descriptor(
  name='PatternFlowTcpCtlUrgCounter',
  full_name='otg.PatternFlowTcpCtlUrgCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowTcpCtlUrgCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowTcpCtlUrgCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowTcpCtlUrgCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowTcpCtlUrgCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowTcpCtlUrgCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowTcpCtlUrgCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=94083,
  serialized_end=94200,
)


_PATTERNFLOWTCPCTLURG_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowTcpCtlUrg.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWTCPCTLURG_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWTCPCTLURG = _descriptor.Descriptor(
  name='PatternFlowTcpCtlUrg',
  full_name='otg.PatternFlowTcpCtlUrg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowTcpCtlUrg.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowTcpCtlUrg.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowTcpCtlUrg.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowTcpCtlUrg.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowTcpCtlUrg.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowTcpCtlUrg.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWTCPCTLURG_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowTcpCtlUrg._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowTcpCtlUrg._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowTcpCtlUrg._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowTcpCtlUrg._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowTcpCtlUrg._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=94203,
  serialized_end=94618,
)


_PATTERNFLOWTCPCTLACKCOUNTER = _descriptor.Descriptor(
  name='PatternFlowTcpCtlAckCounter',
  full_name='otg.PatternFlowTcpCtlAckCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowTcpCtlAckCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowTcpCtlAckCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowTcpCtlAckCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowTcpCtlAckCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowTcpCtlAckCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowTcpCtlAckCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=94620,
  serialized_end=94737,
)


_PATTERNFLOWTCPCTLACK_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowTcpCtlAck.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWTCPCTLACK_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWTCPCTLACK = _descriptor.Descriptor(
  name='PatternFlowTcpCtlAck',
  full_name='otg.PatternFlowTcpCtlAck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowTcpCtlAck.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowTcpCtlAck.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowTcpCtlAck.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowTcpCtlAck.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowTcpCtlAck.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowTcpCtlAck.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWTCPCTLACK_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowTcpCtlAck._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowTcpCtlAck._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowTcpCtlAck._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowTcpCtlAck._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowTcpCtlAck._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=94740,
  serialized_end=95155,
)


_PATTERNFLOWTCPCTLPSHCOUNTER = _descriptor.Descriptor(
  name='PatternFlowTcpCtlPshCounter',
  full_name='otg.PatternFlowTcpCtlPshCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowTcpCtlPshCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowTcpCtlPshCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowTcpCtlPshCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowTcpCtlPshCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowTcpCtlPshCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowTcpCtlPshCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=95157,
  serialized_end=95274,
)


_PATTERNFLOWTCPCTLPSH_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowTcpCtlPsh.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWTCPCTLPSH_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWTCPCTLPSH = _descriptor.Descriptor(
  name='PatternFlowTcpCtlPsh',
  full_name='otg.PatternFlowTcpCtlPsh',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowTcpCtlPsh.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowTcpCtlPsh.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowTcpCtlPsh.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowTcpCtlPsh.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowTcpCtlPsh.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowTcpCtlPsh.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWTCPCTLPSH_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowTcpCtlPsh._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowTcpCtlPsh._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowTcpCtlPsh._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowTcpCtlPsh._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowTcpCtlPsh._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=95277,
  serialized_end=95692,
)


_PATTERNFLOWTCPCTLRSTCOUNTER = _descriptor.Descriptor(
  name='PatternFlowTcpCtlRstCounter',
  full_name='otg.PatternFlowTcpCtlRstCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowTcpCtlRstCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowTcpCtlRstCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowTcpCtlRstCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowTcpCtlRstCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowTcpCtlRstCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowTcpCtlRstCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=95694,
  serialized_end=95811,
)


_PATTERNFLOWTCPCTLRST_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowTcpCtlRst.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWTCPCTLRST_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWTCPCTLRST = _descriptor.Descriptor(
  name='PatternFlowTcpCtlRst',
  full_name='otg.PatternFlowTcpCtlRst',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowTcpCtlRst.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowTcpCtlRst.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowTcpCtlRst.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowTcpCtlRst.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowTcpCtlRst.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowTcpCtlRst.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWTCPCTLRST_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowTcpCtlRst._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowTcpCtlRst._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowTcpCtlRst._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowTcpCtlRst._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowTcpCtlRst._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=95814,
  serialized_end=96229,
)


_PATTERNFLOWTCPCTLSYNCOUNTER = _descriptor.Descriptor(
  name='PatternFlowTcpCtlSynCounter',
  full_name='otg.PatternFlowTcpCtlSynCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowTcpCtlSynCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowTcpCtlSynCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowTcpCtlSynCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowTcpCtlSynCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowTcpCtlSynCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowTcpCtlSynCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=96231,
  serialized_end=96348,
)


_PATTERNFLOWTCPCTLSYN_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowTcpCtlSyn.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWTCPCTLSYN_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWTCPCTLSYN = _descriptor.Descriptor(
  name='PatternFlowTcpCtlSyn',
  full_name='otg.PatternFlowTcpCtlSyn',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowTcpCtlSyn.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowTcpCtlSyn.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowTcpCtlSyn.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowTcpCtlSyn.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowTcpCtlSyn.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowTcpCtlSyn.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWTCPCTLSYN_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowTcpCtlSyn._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowTcpCtlSyn._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowTcpCtlSyn._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowTcpCtlSyn._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowTcpCtlSyn._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=96351,
  serialized_end=96766,
)


_PATTERNFLOWTCPCTLFINCOUNTER = _descriptor.Descriptor(
  name='PatternFlowTcpCtlFinCounter',
  full_name='otg.PatternFlowTcpCtlFinCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowTcpCtlFinCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowTcpCtlFinCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowTcpCtlFinCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowTcpCtlFinCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowTcpCtlFinCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowTcpCtlFinCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=96768,
  serialized_end=96885,
)


_PATTERNFLOWTCPCTLFIN_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowTcpCtlFin.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWTCPCTLFIN_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWTCPCTLFIN = _descriptor.Descriptor(
  name='PatternFlowTcpCtlFin',
  full_name='otg.PatternFlowTcpCtlFin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowTcpCtlFin.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowTcpCtlFin.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowTcpCtlFin.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowTcpCtlFin.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowTcpCtlFin.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowTcpCtlFin.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWTCPCTLFIN_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowTcpCtlFin._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowTcpCtlFin._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowTcpCtlFin._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowTcpCtlFin._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowTcpCtlFin._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=96888,
  serialized_end=97303,
)


_PATTERNFLOWTCPWINDOWCOUNTER = _descriptor.Descriptor(
  name='PatternFlowTcpWindowCounter',
  full_name='otg.PatternFlowTcpWindowCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowTcpWindowCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowTcpWindowCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowTcpWindowCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowTcpWindowCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowTcpWindowCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowTcpWindowCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=97305,
  serialized_end=97422,
)


_PATTERNFLOWTCPWINDOW_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowTcpWindow.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWTCPWINDOW_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWTCPWINDOW = _descriptor.Descriptor(
  name='PatternFlowTcpWindow',
  full_name='otg.PatternFlowTcpWindow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowTcpWindow.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowTcpWindow.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowTcpWindow.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowTcpWindow.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowTcpWindow.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowTcpWindow.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWTCPWINDOW_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowTcpWindow._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowTcpWindow._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowTcpWindow._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowTcpWindow._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowTcpWindow._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=97425,
  serialized_end=97840,
)


_PATTERNFLOWUDPSRCPORTCOUNTER = _descriptor.Descriptor(
  name='PatternFlowUdpSrcPortCounter',
  full_name='otg.PatternFlowUdpSrcPortCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowUdpSrcPortCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowUdpSrcPortCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowUdpSrcPortCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowUdpSrcPortCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowUdpSrcPortCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowUdpSrcPortCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=97842,
  serialized_end=97960,
)


_PATTERNFLOWUDPSRCPORT_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowUdpSrcPort.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWUDPSRCPORT_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWUDPSRCPORT = _descriptor.Descriptor(
  name='PatternFlowUdpSrcPort',
  full_name='otg.PatternFlowUdpSrcPort',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowUdpSrcPort.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowUdpSrcPort.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowUdpSrcPort.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowUdpSrcPort.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowUdpSrcPort.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowUdpSrcPort.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWUDPSRCPORT_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowUdpSrcPort._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowUdpSrcPort._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowUdpSrcPort._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowUdpSrcPort._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowUdpSrcPort._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=97963,
  serialized_end=98382,
)


_PATTERNFLOWUDPDSTPORTCOUNTER = _descriptor.Descriptor(
  name='PatternFlowUdpDstPortCounter',
  full_name='otg.PatternFlowUdpDstPortCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowUdpDstPortCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowUdpDstPortCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowUdpDstPortCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowUdpDstPortCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowUdpDstPortCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowUdpDstPortCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=98384,
  serialized_end=98502,
)


_PATTERNFLOWUDPDSTPORT_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowUdpDstPort.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWUDPDSTPORT_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWUDPDSTPORT = _descriptor.Descriptor(
  name='PatternFlowUdpDstPort',
  full_name='otg.PatternFlowUdpDstPort',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowUdpDstPort.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowUdpDstPort.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowUdpDstPort.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowUdpDstPort.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowUdpDstPort.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowUdpDstPort.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWUDPDSTPORT_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowUdpDstPort._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowUdpDstPort._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowUdpDstPort._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowUdpDstPort._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowUdpDstPort._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=98505,
  serialized_end=98924,
)


_PATTERNFLOWUDPLENGTHCOUNTER = _descriptor.Descriptor(
  name='PatternFlowUdpLengthCounter',
  full_name='otg.PatternFlowUdpLengthCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowUdpLengthCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowUdpLengthCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowUdpLengthCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowUdpLengthCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowUdpLengthCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowUdpLengthCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=98926,
  serialized_end=99043,
)


_PATTERNFLOWUDPLENGTH_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowUdpLength.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWUDPLENGTH_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWUDPLENGTH = _descriptor.Descriptor(
  name='PatternFlowUdpLength',
  full_name='otg.PatternFlowUdpLength',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowUdpLength.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowUdpLength.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowUdpLength.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowUdpLength.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowUdpLength.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowUdpLength.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWUDPLENGTH_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowUdpLength._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowUdpLength._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowUdpLength._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowUdpLength._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowUdpLength._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=99046,
  serialized_end=99461,
)


_PATTERNFLOWUDPCHECKSUM_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowUdpChecksum.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWUDPCHECKSUM_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68398,
  serialized_end=68458,
)

_PATTERNFLOWUDPCHECKSUM_GENERATED = _descriptor.Descriptor(
  name='Generated',
  full_name='otg.PatternFlowUdpChecksum.Generated',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWUDPCHECKSUM_GENERATED_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68460,
  serialized_end=68515,
)

_PATTERNFLOWUDPCHECKSUM = _descriptor.Descriptor(
  name='PatternFlowUdpChecksum',
  full_name='otg.PatternFlowUdpChecksum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowUdpChecksum.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='generated', full_name='otg.PatternFlowUdpChecksum.generated', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom', full_name='otg.PatternFlowUdpChecksum.custom', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWUDPCHECKSUM_CHOICE, _PATTERNFLOWUDPCHECKSUM_GENERATED, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowUdpChecksum._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_generated', full_name='otg.PatternFlowUdpChecksum._generated',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_custom', full_name='otg.PatternFlowUdpChecksum._custom',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=99464,
  serialized_end=99794,
)


_PATTERNFLOWGRECHECKSUMPRESENTCOUNTER = _descriptor.Descriptor(
  name='PatternFlowGreChecksumPresentCounter',
  full_name='otg.PatternFlowGreChecksumPresentCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowGreChecksumPresentCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowGreChecksumPresentCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowGreChecksumPresentCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowGreChecksumPresentCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowGreChecksumPresentCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowGreChecksumPresentCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=99796,
  serialized_end=99922,
)


_PATTERNFLOWGRECHECKSUMPRESENT_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowGreChecksumPresent.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWGRECHECKSUMPRESENT_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWGRECHECKSUMPRESENT = _descriptor.Descriptor(
  name='PatternFlowGreChecksumPresent',
  full_name='otg.PatternFlowGreChecksumPresent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowGreChecksumPresent.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowGreChecksumPresent.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowGreChecksumPresent.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowGreChecksumPresent.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowGreChecksumPresent.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowGreChecksumPresent.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWGRECHECKSUMPRESENT_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowGreChecksumPresent._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowGreChecksumPresent._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowGreChecksumPresent._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowGreChecksumPresent._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowGreChecksumPresent._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=99925,
  serialized_end=100376,
)


_PATTERNFLOWGRERESERVED0COUNTER = _descriptor.Descriptor(
  name='PatternFlowGreReserved0Counter',
  full_name='otg.PatternFlowGreReserved0Counter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowGreReserved0Counter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowGreReserved0Counter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowGreReserved0Counter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowGreReserved0Counter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowGreReserved0Counter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowGreReserved0Counter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=100378,
  serialized_end=100498,
)


_PATTERNFLOWGRERESERVED0_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowGreReserved0.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWGRERESERVED0_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWGRERESERVED0 = _descriptor.Descriptor(
  name='PatternFlowGreReserved0',
  full_name='otg.PatternFlowGreReserved0',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowGreReserved0.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowGreReserved0.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowGreReserved0.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowGreReserved0.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowGreReserved0.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowGreReserved0.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWGRERESERVED0_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowGreReserved0._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowGreReserved0._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowGreReserved0._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowGreReserved0._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowGreReserved0._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=100501,
  serialized_end=100928,
)


_PATTERNFLOWGREVERSIONCOUNTER = _descriptor.Descriptor(
  name='PatternFlowGreVersionCounter',
  full_name='otg.PatternFlowGreVersionCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowGreVersionCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowGreVersionCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowGreVersionCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowGreVersionCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowGreVersionCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowGreVersionCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=100930,
  serialized_end=101048,
)


_PATTERNFLOWGREVERSION_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowGreVersion.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWGREVERSION_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWGREVERSION = _descriptor.Descriptor(
  name='PatternFlowGreVersion',
  full_name='otg.PatternFlowGreVersion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowGreVersion.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowGreVersion.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowGreVersion.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowGreVersion.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowGreVersion.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowGreVersion.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWGREVERSION_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowGreVersion._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowGreVersion._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowGreVersion._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowGreVersion._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowGreVersion._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=101051,
  serialized_end=101470,
)


_PATTERNFLOWGREPROTOCOLCOUNTER = _descriptor.Descriptor(
  name='PatternFlowGreProtocolCounter',
  full_name='otg.PatternFlowGreProtocolCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowGreProtocolCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowGreProtocolCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowGreProtocolCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowGreProtocolCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowGreProtocolCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowGreProtocolCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=101472,
  serialized_end=101591,
)


_PATTERNFLOWGREPROTOCOL_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowGreProtocol.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWGREPROTOCOL_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWGREPROTOCOL = _descriptor.Descriptor(
  name='PatternFlowGreProtocol',
  full_name='otg.PatternFlowGreProtocol',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowGreProtocol.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowGreProtocol.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowGreProtocol.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowGreProtocol.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowGreProtocol.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowGreProtocol.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWGREPROTOCOL_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowGreProtocol._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowGreProtocol._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowGreProtocol._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowGreProtocol._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowGreProtocol._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=101594,
  serialized_end=102017,
)


_PATTERNFLOWGRECHECKSUM_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowGreChecksum.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWGRECHECKSUM_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68398,
  serialized_end=68458,
)

_PATTERNFLOWGRECHECKSUM_GENERATED = _descriptor.Descriptor(
  name='Generated',
  full_name='otg.PatternFlowGreChecksum.Generated',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWGRECHECKSUM_GENERATED_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68460,
  serialized_end=68515,
)

_PATTERNFLOWGRECHECKSUM = _descriptor.Descriptor(
  name='PatternFlowGreChecksum',
  full_name='otg.PatternFlowGreChecksum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowGreChecksum.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='generated', full_name='otg.PatternFlowGreChecksum.generated', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom', full_name='otg.PatternFlowGreChecksum.custom', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWGRECHECKSUM_CHOICE, _PATTERNFLOWGRECHECKSUM_GENERATED, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowGreChecksum._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_generated', full_name='otg.PatternFlowGreChecksum._generated',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_custom', full_name='otg.PatternFlowGreChecksum._custom',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=102020,
  serialized_end=102350,
)


_PATTERNFLOWGRERESERVED1COUNTER = _descriptor.Descriptor(
  name='PatternFlowGreReserved1Counter',
  full_name='otg.PatternFlowGreReserved1Counter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowGreReserved1Counter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowGreReserved1Counter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowGreReserved1Counter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowGreReserved1Counter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowGreReserved1Counter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowGreReserved1Counter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=102352,
  serialized_end=102472,
)


_PATTERNFLOWGRERESERVED1_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowGreReserved1.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWGRERESERVED1_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWGRERESERVED1 = _descriptor.Descriptor(
  name='PatternFlowGreReserved1',
  full_name='otg.PatternFlowGreReserved1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowGreReserved1.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowGreReserved1.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowGreReserved1.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowGreReserved1.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowGreReserved1.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowGreReserved1.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWGRERESERVED1_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowGreReserved1._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowGreReserved1._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowGreReserved1._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowGreReserved1._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowGreReserved1._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=102475,
  serialized_end=102902,
)


_PATTERNFLOWGTPV1VERSIONCOUNTER = _descriptor.Descriptor(
  name='PatternFlowGtpv1VersionCounter',
  full_name='otg.PatternFlowGtpv1VersionCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowGtpv1VersionCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowGtpv1VersionCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowGtpv1VersionCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowGtpv1VersionCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowGtpv1VersionCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowGtpv1VersionCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=102904,
  serialized_end=103024,
)


_PATTERNFLOWGTPV1VERSION_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowGtpv1Version.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWGTPV1VERSION_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWGTPV1VERSION = _descriptor.Descriptor(
  name='PatternFlowGtpv1Version',
  full_name='otg.PatternFlowGtpv1Version',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowGtpv1Version.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowGtpv1Version.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowGtpv1Version.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowGtpv1Version.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowGtpv1Version.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowGtpv1Version.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWGTPV1VERSION_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowGtpv1Version._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowGtpv1Version._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowGtpv1Version._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowGtpv1Version._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowGtpv1Version._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=103027,
  serialized_end=103454,
)


_PATTERNFLOWGTPV1PROTOCOLTYPECOUNTER = _descriptor.Descriptor(
  name='PatternFlowGtpv1ProtocolTypeCounter',
  full_name='otg.PatternFlowGtpv1ProtocolTypeCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowGtpv1ProtocolTypeCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowGtpv1ProtocolTypeCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowGtpv1ProtocolTypeCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowGtpv1ProtocolTypeCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowGtpv1ProtocolTypeCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowGtpv1ProtocolTypeCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=103456,
  serialized_end=103581,
)


_PATTERNFLOWGTPV1PROTOCOLTYPE_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowGtpv1ProtocolType.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWGTPV1PROTOCOLTYPE_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWGTPV1PROTOCOLTYPE = _descriptor.Descriptor(
  name='PatternFlowGtpv1ProtocolType',
  full_name='otg.PatternFlowGtpv1ProtocolType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowGtpv1ProtocolType.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowGtpv1ProtocolType.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowGtpv1ProtocolType.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowGtpv1ProtocolType.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowGtpv1ProtocolType.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowGtpv1ProtocolType.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWGTPV1PROTOCOLTYPE_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowGtpv1ProtocolType._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowGtpv1ProtocolType._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowGtpv1ProtocolType._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowGtpv1ProtocolType._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowGtpv1ProtocolType._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=103584,
  serialized_end=104031,
)


_PATTERNFLOWGTPV1RESERVEDCOUNTER = _descriptor.Descriptor(
  name='PatternFlowGtpv1ReservedCounter',
  full_name='otg.PatternFlowGtpv1ReservedCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowGtpv1ReservedCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowGtpv1ReservedCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowGtpv1ReservedCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowGtpv1ReservedCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowGtpv1ReservedCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowGtpv1ReservedCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=104033,
  serialized_end=104154,
)


_PATTERNFLOWGTPV1RESERVED_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowGtpv1Reserved.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWGTPV1RESERVED_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWGTPV1RESERVED = _descriptor.Descriptor(
  name='PatternFlowGtpv1Reserved',
  full_name='otg.PatternFlowGtpv1Reserved',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowGtpv1Reserved.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowGtpv1Reserved.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowGtpv1Reserved.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowGtpv1Reserved.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowGtpv1Reserved.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowGtpv1Reserved.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWGTPV1RESERVED_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowGtpv1Reserved._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowGtpv1Reserved._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowGtpv1Reserved._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowGtpv1Reserved._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowGtpv1Reserved._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=104157,
  serialized_end=104588,
)


_PATTERNFLOWGTPV1EFLAGCOUNTER = _descriptor.Descriptor(
  name='PatternFlowGtpv1EFlagCounter',
  full_name='otg.PatternFlowGtpv1EFlagCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowGtpv1EFlagCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowGtpv1EFlagCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowGtpv1EFlagCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowGtpv1EFlagCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowGtpv1EFlagCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowGtpv1EFlagCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=104590,
  serialized_end=104708,
)


_PATTERNFLOWGTPV1EFLAG_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowGtpv1EFlag.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWGTPV1EFLAG_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWGTPV1EFLAG = _descriptor.Descriptor(
  name='PatternFlowGtpv1EFlag',
  full_name='otg.PatternFlowGtpv1EFlag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowGtpv1EFlag.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowGtpv1EFlag.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowGtpv1EFlag.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowGtpv1EFlag.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowGtpv1EFlag.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowGtpv1EFlag.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWGTPV1EFLAG_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowGtpv1EFlag._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowGtpv1EFlag._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowGtpv1EFlag._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowGtpv1EFlag._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowGtpv1EFlag._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=104711,
  serialized_end=105130,
)


_PATTERNFLOWGTPV1SFLAGCOUNTER = _descriptor.Descriptor(
  name='PatternFlowGtpv1SFlagCounter',
  full_name='otg.PatternFlowGtpv1SFlagCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowGtpv1SFlagCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowGtpv1SFlagCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowGtpv1SFlagCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowGtpv1SFlagCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowGtpv1SFlagCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowGtpv1SFlagCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=105132,
  serialized_end=105250,
)


_PATTERNFLOWGTPV1SFLAG_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowGtpv1SFlag.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWGTPV1SFLAG_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWGTPV1SFLAG = _descriptor.Descriptor(
  name='PatternFlowGtpv1SFlag',
  full_name='otg.PatternFlowGtpv1SFlag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowGtpv1SFlag.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowGtpv1SFlag.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowGtpv1SFlag.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowGtpv1SFlag.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowGtpv1SFlag.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowGtpv1SFlag.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWGTPV1SFLAG_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowGtpv1SFlag._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowGtpv1SFlag._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowGtpv1SFlag._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowGtpv1SFlag._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowGtpv1SFlag._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=105253,
  serialized_end=105672,
)


_PATTERNFLOWGTPV1PNFLAGCOUNTER = _descriptor.Descriptor(
  name='PatternFlowGtpv1PnFlagCounter',
  full_name='otg.PatternFlowGtpv1PnFlagCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowGtpv1PnFlagCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowGtpv1PnFlagCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowGtpv1PnFlagCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowGtpv1PnFlagCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowGtpv1PnFlagCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowGtpv1PnFlagCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=105674,
  serialized_end=105793,
)


_PATTERNFLOWGTPV1PNFLAG_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowGtpv1PnFlag.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWGTPV1PNFLAG_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWGTPV1PNFLAG = _descriptor.Descriptor(
  name='PatternFlowGtpv1PnFlag',
  full_name='otg.PatternFlowGtpv1PnFlag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowGtpv1PnFlag.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowGtpv1PnFlag.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowGtpv1PnFlag.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowGtpv1PnFlag.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowGtpv1PnFlag.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowGtpv1PnFlag.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWGTPV1PNFLAG_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowGtpv1PnFlag._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowGtpv1PnFlag._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowGtpv1PnFlag._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowGtpv1PnFlag._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowGtpv1PnFlag._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=105796,
  serialized_end=106219,
)


_PATTERNFLOWGTPV1MESSAGETYPECOUNTER = _descriptor.Descriptor(
  name='PatternFlowGtpv1MessageTypeCounter',
  full_name='otg.PatternFlowGtpv1MessageTypeCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowGtpv1MessageTypeCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowGtpv1MessageTypeCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowGtpv1MessageTypeCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowGtpv1MessageTypeCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowGtpv1MessageTypeCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowGtpv1MessageTypeCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=106221,
  serialized_end=106345,
)


_PATTERNFLOWGTPV1MESSAGETYPE_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowGtpv1MessageType.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWGTPV1MESSAGETYPE_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWGTPV1MESSAGETYPE = _descriptor.Descriptor(
  name='PatternFlowGtpv1MessageType',
  full_name='otg.PatternFlowGtpv1MessageType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowGtpv1MessageType.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowGtpv1MessageType.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowGtpv1MessageType.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowGtpv1MessageType.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowGtpv1MessageType.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowGtpv1MessageType.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWGTPV1MESSAGETYPE_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowGtpv1MessageType._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowGtpv1MessageType._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowGtpv1MessageType._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowGtpv1MessageType._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowGtpv1MessageType._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=106348,
  serialized_end=106791,
)


_PATTERNFLOWGTPV1MESSAGELENGTHCOUNTER = _descriptor.Descriptor(
  name='PatternFlowGtpv1MessageLengthCounter',
  full_name='otg.PatternFlowGtpv1MessageLengthCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowGtpv1MessageLengthCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowGtpv1MessageLengthCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowGtpv1MessageLengthCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowGtpv1MessageLengthCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowGtpv1MessageLengthCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowGtpv1MessageLengthCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=106793,
  serialized_end=106919,
)


_PATTERNFLOWGTPV1MESSAGELENGTH_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowGtpv1MessageLength.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWGTPV1MESSAGELENGTH_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWGTPV1MESSAGELENGTH = _descriptor.Descriptor(
  name='PatternFlowGtpv1MessageLength',
  full_name='otg.PatternFlowGtpv1MessageLength',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowGtpv1MessageLength.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowGtpv1MessageLength.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowGtpv1MessageLength.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowGtpv1MessageLength.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowGtpv1MessageLength.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowGtpv1MessageLength.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWGTPV1MESSAGELENGTH_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowGtpv1MessageLength._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowGtpv1MessageLength._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowGtpv1MessageLength._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowGtpv1MessageLength._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowGtpv1MessageLength._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=106922,
  serialized_end=107373,
)


_PATTERNFLOWGTPV1TEIDCOUNTER = _descriptor.Descriptor(
  name='PatternFlowGtpv1TeidCounter',
  full_name='otg.PatternFlowGtpv1TeidCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowGtpv1TeidCounter.start', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowGtpv1TeidCounter.step', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowGtpv1TeidCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowGtpv1TeidCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowGtpv1TeidCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowGtpv1TeidCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=107375,
  serialized_end=107492,
)


_PATTERNFLOWGTPV1TEID_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowGtpv1Teid.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWGTPV1TEID_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWGTPV1TEID = _descriptor.Descriptor(
  name='PatternFlowGtpv1Teid',
  full_name='otg.PatternFlowGtpv1Teid',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowGtpv1Teid.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowGtpv1Teid.value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowGtpv1Teid.values', index=2,
      number=3, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowGtpv1Teid.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowGtpv1Teid.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowGtpv1Teid.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWGTPV1TEID_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowGtpv1Teid._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowGtpv1Teid._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowGtpv1Teid._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowGtpv1Teid._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowGtpv1Teid._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=107495,
  serialized_end=107910,
)


_PATTERNFLOWGTPV1SQUENCENUMBERCOUNTER = _descriptor.Descriptor(
  name='PatternFlowGtpv1SquenceNumberCounter',
  full_name='otg.PatternFlowGtpv1SquenceNumberCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowGtpv1SquenceNumberCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowGtpv1SquenceNumberCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowGtpv1SquenceNumberCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowGtpv1SquenceNumberCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowGtpv1SquenceNumberCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowGtpv1SquenceNumberCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=107912,
  serialized_end=108038,
)


_PATTERNFLOWGTPV1SQUENCENUMBER_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowGtpv1SquenceNumber.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWGTPV1SQUENCENUMBER_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWGTPV1SQUENCENUMBER = _descriptor.Descriptor(
  name='PatternFlowGtpv1SquenceNumber',
  full_name='otg.PatternFlowGtpv1SquenceNumber',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowGtpv1SquenceNumber.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowGtpv1SquenceNumber.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowGtpv1SquenceNumber.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowGtpv1SquenceNumber.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowGtpv1SquenceNumber.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowGtpv1SquenceNumber.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWGTPV1SQUENCENUMBER_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowGtpv1SquenceNumber._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowGtpv1SquenceNumber._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowGtpv1SquenceNumber._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowGtpv1SquenceNumber._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowGtpv1SquenceNumber._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=108041,
  serialized_end=108492,
)


_PATTERNFLOWGTPV1NPDUNUMBERCOUNTER = _descriptor.Descriptor(
  name='PatternFlowGtpv1NPduNumberCounter',
  full_name='otg.PatternFlowGtpv1NPduNumberCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowGtpv1NPduNumberCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowGtpv1NPduNumberCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowGtpv1NPduNumberCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowGtpv1NPduNumberCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowGtpv1NPduNumberCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowGtpv1NPduNumberCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=108494,
  serialized_end=108617,
)


_PATTERNFLOWGTPV1NPDUNUMBER_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowGtpv1NPduNumber.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWGTPV1NPDUNUMBER_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWGTPV1NPDUNUMBER = _descriptor.Descriptor(
  name='PatternFlowGtpv1NPduNumber',
  full_name='otg.PatternFlowGtpv1NPduNumber',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowGtpv1NPduNumber.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowGtpv1NPduNumber.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowGtpv1NPduNumber.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowGtpv1NPduNumber.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowGtpv1NPduNumber.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowGtpv1NPduNumber.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWGTPV1NPDUNUMBER_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowGtpv1NPduNumber._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowGtpv1NPduNumber._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowGtpv1NPduNumber._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowGtpv1NPduNumber._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowGtpv1NPduNumber._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=108620,
  serialized_end=109059,
)


_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPECOUNTER = _descriptor.Descriptor(
  name='PatternFlowGtpv1NextExtensionHeaderTypeCounter',
  full_name='otg.PatternFlowGtpv1NextExtensionHeaderTypeCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowGtpv1NextExtensionHeaderTypeCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowGtpv1NextExtensionHeaderTypeCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowGtpv1NextExtensionHeaderTypeCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowGtpv1NextExtensionHeaderTypeCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowGtpv1NextExtensionHeaderTypeCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowGtpv1NextExtensionHeaderTypeCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=109062,
  serialized_end=109198,
)


_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowGtpv1NextExtensionHeaderType.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE = _descriptor.Descriptor(
  name='PatternFlowGtpv1NextExtensionHeaderType',
  full_name='otg.PatternFlowGtpv1NextExtensionHeaderType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowGtpv1NextExtensionHeaderType.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowGtpv1NextExtensionHeaderType.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowGtpv1NextExtensionHeaderType.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowGtpv1NextExtensionHeaderType.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowGtpv1NextExtensionHeaderType.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowGtpv1NextExtensionHeaderType.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowGtpv1NextExtensionHeaderType._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowGtpv1NextExtensionHeaderType._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowGtpv1NextExtensionHeaderType._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowGtpv1NextExtensionHeaderType._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowGtpv1NextExtensionHeaderType._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=109201,
  serialized_end=109692,
)


_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHCOUNTER = _descriptor.Descriptor(
  name='PatternFlowGtpExtensionExtensionLengthCounter',
  full_name='otg.PatternFlowGtpExtensionExtensionLengthCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowGtpExtensionExtensionLengthCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowGtpExtensionExtensionLengthCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowGtpExtensionExtensionLengthCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowGtpExtensionExtensionLengthCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowGtpExtensionExtensionLengthCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowGtpExtensionExtensionLengthCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=109695,
  serialized_end=109830,
)


_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowGtpExtensionExtensionLength.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH = _descriptor.Descriptor(
  name='PatternFlowGtpExtensionExtensionLength',
  full_name='otg.PatternFlowGtpExtensionExtensionLength',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowGtpExtensionExtensionLength.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowGtpExtensionExtensionLength.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowGtpExtensionExtensionLength.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowGtpExtensionExtensionLength.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowGtpExtensionExtensionLength.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowGtpExtensionExtensionLength.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowGtpExtensionExtensionLength._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowGtpExtensionExtensionLength._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowGtpExtensionExtensionLength._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowGtpExtensionExtensionLength._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowGtpExtensionExtensionLength._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=109833,
  serialized_end=110320,
)


_PATTERNFLOWGTPEXTENSIONCONTENTSCOUNTER = _descriptor.Descriptor(
  name='PatternFlowGtpExtensionContentsCounter',
  full_name='otg.PatternFlowGtpExtensionContentsCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowGtpExtensionContentsCounter.start', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowGtpExtensionContentsCounter.step', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowGtpExtensionContentsCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowGtpExtensionContentsCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowGtpExtensionContentsCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowGtpExtensionContentsCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=110323,
  serialized_end=110451,
)


_PATTERNFLOWGTPEXTENSIONCONTENTS_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowGtpExtensionContents.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWGTPEXTENSIONCONTENTS_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWGTPEXTENSIONCONTENTS = _descriptor.Descriptor(
  name='PatternFlowGtpExtensionContents',
  full_name='otg.PatternFlowGtpExtensionContents',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowGtpExtensionContents.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowGtpExtensionContents.value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowGtpExtensionContents.values', index=2,
      number=3, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowGtpExtensionContents.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowGtpExtensionContents.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowGtpExtensionContents.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWGTPEXTENSIONCONTENTS_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowGtpExtensionContents._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowGtpExtensionContents._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowGtpExtensionContents._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowGtpExtensionContents._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowGtpExtensionContents._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=110454,
  serialized_end=110913,
)


_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERCOUNTER = _descriptor.Descriptor(
  name='PatternFlowGtpExtensionNextExtensionHeaderCounter',
  full_name='otg.PatternFlowGtpExtensionNextExtensionHeaderCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowGtpExtensionNextExtensionHeaderCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowGtpExtensionNextExtensionHeaderCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowGtpExtensionNextExtensionHeaderCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowGtpExtensionNextExtensionHeaderCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowGtpExtensionNextExtensionHeaderCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowGtpExtensionNextExtensionHeaderCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=110916,
  serialized_end=111055,
)


_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowGtpExtensionNextExtensionHeader.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER = _descriptor.Descriptor(
  name='PatternFlowGtpExtensionNextExtensionHeader',
  full_name='otg.PatternFlowGtpExtensionNextExtensionHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowGtpExtensionNextExtensionHeader.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowGtpExtensionNextExtensionHeader.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowGtpExtensionNextExtensionHeader.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowGtpExtensionNextExtensionHeader.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowGtpExtensionNextExtensionHeader.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowGtpExtensionNextExtensionHeader.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowGtpExtensionNextExtensionHeader._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowGtpExtensionNextExtensionHeader._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowGtpExtensionNextExtensionHeader._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowGtpExtensionNextExtensionHeader._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowGtpExtensionNextExtensionHeader._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=111058,
  serialized_end=111561,
)


_PATTERNFLOWGTPV2VERSIONCOUNTER = _descriptor.Descriptor(
  name='PatternFlowGtpv2VersionCounter',
  full_name='otg.PatternFlowGtpv2VersionCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowGtpv2VersionCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowGtpv2VersionCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowGtpv2VersionCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowGtpv2VersionCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowGtpv2VersionCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowGtpv2VersionCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=111563,
  serialized_end=111683,
)


_PATTERNFLOWGTPV2VERSION_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowGtpv2Version.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWGTPV2VERSION_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWGTPV2VERSION = _descriptor.Descriptor(
  name='PatternFlowGtpv2Version',
  full_name='otg.PatternFlowGtpv2Version',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowGtpv2Version.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowGtpv2Version.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowGtpv2Version.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowGtpv2Version.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowGtpv2Version.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowGtpv2Version.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWGTPV2VERSION_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowGtpv2Version._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowGtpv2Version._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowGtpv2Version._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowGtpv2Version._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowGtpv2Version._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=111686,
  serialized_end=112113,
)


_PATTERNFLOWGTPV2PIGGYBACKINGFLAGCOUNTER = _descriptor.Descriptor(
  name='PatternFlowGtpv2PiggybackingFlagCounter',
  full_name='otg.PatternFlowGtpv2PiggybackingFlagCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowGtpv2PiggybackingFlagCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowGtpv2PiggybackingFlagCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowGtpv2PiggybackingFlagCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowGtpv2PiggybackingFlagCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowGtpv2PiggybackingFlagCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowGtpv2PiggybackingFlagCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=112116,
  serialized_end=112245,
)


_PATTERNFLOWGTPV2PIGGYBACKINGFLAG_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowGtpv2PiggybackingFlag.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWGTPV2PIGGYBACKINGFLAG_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWGTPV2PIGGYBACKINGFLAG = _descriptor.Descriptor(
  name='PatternFlowGtpv2PiggybackingFlag',
  full_name='otg.PatternFlowGtpv2PiggybackingFlag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowGtpv2PiggybackingFlag.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowGtpv2PiggybackingFlag.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowGtpv2PiggybackingFlag.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowGtpv2PiggybackingFlag.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowGtpv2PiggybackingFlag.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowGtpv2PiggybackingFlag.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWGTPV2PIGGYBACKINGFLAG_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowGtpv2PiggybackingFlag._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowGtpv2PiggybackingFlag._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowGtpv2PiggybackingFlag._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowGtpv2PiggybackingFlag._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowGtpv2PiggybackingFlag._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=112248,
  serialized_end=112711,
)


_PATTERNFLOWGTPV2TEIDFLAGCOUNTER = _descriptor.Descriptor(
  name='PatternFlowGtpv2TeidFlagCounter',
  full_name='otg.PatternFlowGtpv2TeidFlagCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowGtpv2TeidFlagCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowGtpv2TeidFlagCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowGtpv2TeidFlagCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowGtpv2TeidFlagCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowGtpv2TeidFlagCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowGtpv2TeidFlagCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=112713,
  serialized_end=112834,
)


_PATTERNFLOWGTPV2TEIDFLAG_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowGtpv2TeidFlag.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWGTPV2TEIDFLAG_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWGTPV2TEIDFLAG = _descriptor.Descriptor(
  name='PatternFlowGtpv2TeidFlag',
  full_name='otg.PatternFlowGtpv2TeidFlag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowGtpv2TeidFlag.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowGtpv2TeidFlag.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowGtpv2TeidFlag.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowGtpv2TeidFlag.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowGtpv2TeidFlag.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowGtpv2TeidFlag.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWGTPV2TEIDFLAG_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowGtpv2TeidFlag._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowGtpv2TeidFlag._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowGtpv2TeidFlag._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowGtpv2TeidFlag._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowGtpv2TeidFlag._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=112837,
  serialized_end=113268,
)


_PATTERNFLOWGTPV2SPARE1COUNTER = _descriptor.Descriptor(
  name='PatternFlowGtpv2Spare1Counter',
  full_name='otg.PatternFlowGtpv2Spare1Counter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowGtpv2Spare1Counter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowGtpv2Spare1Counter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowGtpv2Spare1Counter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowGtpv2Spare1Counter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowGtpv2Spare1Counter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowGtpv2Spare1Counter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=113270,
  serialized_end=113389,
)


_PATTERNFLOWGTPV2SPARE1_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowGtpv2Spare1.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWGTPV2SPARE1_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWGTPV2SPARE1 = _descriptor.Descriptor(
  name='PatternFlowGtpv2Spare1',
  full_name='otg.PatternFlowGtpv2Spare1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowGtpv2Spare1.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowGtpv2Spare1.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowGtpv2Spare1.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowGtpv2Spare1.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowGtpv2Spare1.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowGtpv2Spare1.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWGTPV2SPARE1_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowGtpv2Spare1._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowGtpv2Spare1._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowGtpv2Spare1._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowGtpv2Spare1._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowGtpv2Spare1._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=113392,
  serialized_end=113815,
)


_PATTERNFLOWGTPV2MESSAGETYPECOUNTER = _descriptor.Descriptor(
  name='PatternFlowGtpv2MessageTypeCounter',
  full_name='otg.PatternFlowGtpv2MessageTypeCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowGtpv2MessageTypeCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowGtpv2MessageTypeCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowGtpv2MessageTypeCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowGtpv2MessageTypeCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowGtpv2MessageTypeCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowGtpv2MessageTypeCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=113817,
  serialized_end=113941,
)


_PATTERNFLOWGTPV2MESSAGETYPE_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowGtpv2MessageType.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWGTPV2MESSAGETYPE_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWGTPV2MESSAGETYPE = _descriptor.Descriptor(
  name='PatternFlowGtpv2MessageType',
  full_name='otg.PatternFlowGtpv2MessageType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowGtpv2MessageType.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowGtpv2MessageType.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowGtpv2MessageType.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowGtpv2MessageType.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowGtpv2MessageType.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowGtpv2MessageType.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWGTPV2MESSAGETYPE_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowGtpv2MessageType._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowGtpv2MessageType._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowGtpv2MessageType._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowGtpv2MessageType._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowGtpv2MessageType._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=113944,
  serialized_end=114387,
)


_PATTERNFLOWGTPV2MESSAGELENGTHCOUNTER = _descriptor.Descriptor(
  name='PatternFlowGtpv2MessageLengthCounter',
  full_name='otg.PatternFlowGtpv2MessageLengthCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowGtpv2MessageLengthCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowGtpv2MessageLengthCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowGtpv2MessageLengthCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowGtpv2MessageLengthCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowGtpv2MessageLengthCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowGtpv2MessageLengthCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=114389,
  serialized_end=114515,
)


_PATTERNFLOWGTPV2MESSAGELENGTH_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowGtpv2MessageLength.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWGTPV2MESSAGELENGTH_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWGTPV2MESSAGELENGTH = _descriptor.Descriptor(
  name='PatternFlowGtpv2MessageLength',
  full_name='otg.PatternFlowGtpv2MessageLength',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowGtpv2MessageLength.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowGtpv2MessageLength.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowGtpv2MessageLength.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowGtpv2MessageLength.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowGtpv2MessageLength.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowGtpv2MessageLength.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWGTPV2MESSAGELENGTH_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowGtpv2MessageLength._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowGtpv2MessageLength._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowGtpv2MessageLength._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowGtpv2MessageLength._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowGtpv2MessageLength._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=114518,
  serialized_end=114969,
)


_PATTERNFLOWGTPV2TEIDCOUNTER = _descriptor.Descriptor(
  name='PatternFlowGtpv2TeidCounter',
  full_name='otg.PatternFlowGtpv2TeidCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowGtpv2TeidCounter.start', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowGtpv2TeidCounter.step', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowGtpv2TeidCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowGtpv2TeidCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowGtpv2TeidCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowGtpv2TeidCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=114971,
  serialized_end=115088,
)


_PATTERNFLOWGTPV2TEID_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowGtpv2Teid.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWGTPV2TEID_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWGTPV2TEID = _descriptor.Descriptor(
  name='PatternFlowGtpv2Teid',
  full_name='otg.PatternFlowGtpv2Teid',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowGtpv2Teid.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowGtpv2Teid.value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowGtpv2Teid.values', index=2,
      number=3, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowGtpv2Teid.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowGtpv2Teid.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowGtpv2Teid.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWGTPV2TEID_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowGtpv2Teid._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowGtpv2Teid._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowGtpv2Teid._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowGtpv2Teid._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowGtpv2Teid._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=115091,
  serialized_end=115506,
)


_PATTERNFLOWGTPV2SEQUENCENUMBERCOUNTER = _descriptor.Descriptor(
  name='PatternFlowGtpv2SequenceNumberCounter',
  full_name='otg.PatternFlowGtpv2SequenceNumberCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowGtpv2SequenceNumberCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowGtpv2SequenceNumberCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowGtpv2SequenceNumberCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowGtpv2SequenceNumberCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowGtpv2SequenceNumberCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowGtpv2SequenceNumberCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=115508,
  serialized_end=115635,
)


_PATTERNFLOWGTPV2SEQUENCENUMBER_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowGtpv2SequenceNumber.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWGTPV2SEQUENCENUMBER_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWGTPV2SEQUENCENUMBER = _descriptor.Descriptor(
  name='PatternFlowGtpv2SequenceNumber',
  full_name='otg.PatternFlowGtpv2SequenceNumber',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowGtpv2SequenceNumber.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowGtpv2SequenceNumber.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowGtpv2SequenceNumber.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowGtpv2SequenceNumber.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowGtpv2SequenceNumber.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowGtpv2SequenceNumber.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWGTPV2SEQUENCENUMBER_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowGtpv2SequenceNumber._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowGtpv2SequenceNumber._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowGtpv2SequenceNumber._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowGtpv2SequenceNumber._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowGtpv2SequenceNumber._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=115638,
  serialized_end=116093,
)


_PATTERNFLOWGTPV2SPARE2COUNTER = _descriptor.Descriptor(
  name='PatternFlowGtpv2Spare2Counter',
  full_name='otg.PatternFlowGtpv2Spare2Counter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowGtpv2Spare2Counter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowGtpv2Spare2Counter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowGtpv2Spare2Counter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowGtpv2Spare2Counter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowGtpv2Spare2Counter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowGtpv2Spare2Counter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=116095,
  serialized_end=116214,
)


_PATTERNFLOWGTPV2SPARE2_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowGtpv2Spare2.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWGTPV2SPARE2_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWGTPV2SPARE2 = _descriptor.Descriptor(
  name='PatternFlowGtpv2Spare2',
  full_name='otg.PatternFlowGtpv2Spare2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowGtpv2Spare2.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowGtpv2Spare2.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowGtpv2Spare2.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowGtpv2Spare2.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowGtpv2Spare2.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowGtpv2Spare2.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWGTPV2SPARE2_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowGtpv2Spare2._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowGtpv2Spare2._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowGtpv2Spare2._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowGtpv2Spare2._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowGtpv2Spare2._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=116217,
  serialized_end=116640,
)


_PATTERNFLOWARPHARDWARETYPECOUNTER = _descriptor.Descriptor(
  name='PatternFlowArpHardwareTypeCounter',
  full_name='otg.PatternFlowArpHardwareTypeCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowArpHardwareTypeCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowArpHardwareTypeCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowArpHardwareTypeCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowArpHardwareTypeCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowArpHardwareTypeCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowArpHardwareTypeCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=116642,
  serialized_end=116765,
)


_PATTERNFLOWARPHARDWARETYPE_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowArpHardwareType.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWARPHARDWARETYPE_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWARPHARDWARETYPE = _descriptor.Descriptor(
  name='PatternFlowArpHardwareType',
  full_name='otg.PatternFlowArpHardwareType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowArpHardwareType.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowArpHardwareType.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowArpHardwareType.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowArpHardwareType.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowArpHardwareType.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowArpHardwareType.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWARPHARDWARETYPE_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowArpHardwareType._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowArpHardwareType._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowArpHardwareType._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowArpHardwareType._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowArpHardwareType._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=116768,
  serialized_end=117207,
)


_PATTERNFLOWARPPROTOCOLTYPECOUNTER = _descriptor.Descriptor(
  name='PatternFlowArpProtocolTypeCounter',
  full_name='otg.PatternFlowArpProtocolTypeCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowArpProtocolTypeCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowArpProtocolTypeCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowArpProtocolTypeCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowArpProtocolTypeCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowArpProtocolTypeCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowArpProtocolTypeCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=117209,
  serialized_end=117332,
)


_PATTERNFLOWARPPROTOCOLTYPE_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowArpProtocolType.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWARPPROTOCOLTYPE_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWARPPROTOCOLTYPE = _descriptor.Descriptor(
  name='PatternFlowArpProtocolType',
  full_name='otg.PatternFlowArpProtocolType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowArpProtocolType.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowArpProtocolType.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowArpProtocolType.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowArpProtocolType.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowArpProtocolType.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowArpProtocolType.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWARPPROTOCOLTYPE_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowArpProtocolType._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowArpProtocolType._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowArpProtocolType._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowArpProtocolType._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowArpProtocolType._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=117335,
  serialized_end=117774,
)


_PATTERNFLOWARPHARDWARELENGTHCOUNTER = _descriptor.Descriptor(
  name='PatternFlowArpHardwareLengthCounter',
  full_name='otg.PatternFlowArpHardwareLengthCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowArpHardwareLengthCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowArpHardwareLengthCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowArpHardwareLengthCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowArpHardwareLengthCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowArpHardwareLengthCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowArpHardwareLengthCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=117776,
  serialized_end=117901,
)


_PATTERNFLOWARPHARDWARELENGTH_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowArpHardwareLength.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWARPHARDWARELENGTH_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWARPHARDWARELENGTH = _descriptor.Descriptor(
  name='PatternFlowArpHardwareLength',
  full_name='otg.PatternFlowArpHardwareLength',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowArpHardwareLength.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowArpHardwareLength.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowArpHardwareLength.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowArpHardwareLength.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowArpHardwareLength.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowArpHardwareLength.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWARPHARDWARELENGTH_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowArpHardwareLength._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowArpHardwareLength._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowArpHardwareLength._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowArpHardwareLength._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowArpHardwareLength._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=117904,
  serialized_end=118351,
)


_PATTERNFLOWARPPROTOCOLLENGTHCOUNTER = _descriptor.Descriptor(
  name='PatternFlowArpProtocolLengthCounter',
  full_name='otg.PatternFlowArpProtocolLengthCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowArpProtocolLengthCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowArpProtocolLengthCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowArpProtocolLengthCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowArpProtocolLengthCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowArpProtocolLengthCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowArpProtocolLengthCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=118353,
  serialized_end=118478,
)


_PATTERNFLOWARPPROTOCOLLENGTH_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowArpProtocolLength.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWARPPROTOCOLLENGTH_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWARPPROTOCOLLENGTH = _descriptor.Descriptor(
  name='PatternFlowArpProtocolLength',
  full_name='otg.PatternFlowArpProtocolLength',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowArpProtocolLength.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowArpProtocolLength.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowArpProtocolLength.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowArpProtocolLength.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowArpProtocolLength.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowArpProtocolLength.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWARPPROTOCOLLENGTH_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowArpProtocolLength._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowArpProtocolLength._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowArpProtocolLength._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowArpProtocolLength._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowArpProtocolLength._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=118481,
  serialized_end=118928,
)


_PATTERNFLOWARPOPERATIONCOUNTER = _descriptor.Descriptor(
  name='PatternFlowArpOperationCounter',
  full_name='otg.PatternFlowArpOperationCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowArpOperationCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowArpOperationCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowArpOperationCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowArpOperationCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowArpOperationCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowArpOperationCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=118930,
  serialized_end=119050,
)


_PATTERNFLOWARPOPERATION_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowArpOperation.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWARPOPERATION_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWARPOPERATION = _descriptor.Descriptor(
  name='PatternFlowArpOperation',
  full_name='otg.PatternFlowArpOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowArpOperation.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowArpOperation.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowArpOperation.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowArpOperation.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowArpOperation.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowArpOperation.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWARPOPERATION_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowArpOperation._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowArpOperation._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowArpOperation._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowArpOperation._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowArpOperation._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=119053,
  serialized_end=119480,
)


_PATTERNFLOWARPSENDERHARDWAREADDRCOUNTER = _descriptor.Descriptor(
  name='PatternFlowArpSenderHardwareAddrCounter',
  full_name='otg.PatternFlowArpSenderHardwareAddrCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowArpSenderHardwareAddrCounter.start', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowArpSenderHardwareAddrCounter.step', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowArpSenderHardwareAddrCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowArpSenderHardwareAddrCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowArpSenderHardwareAddrCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowArpSenderHardwareAddrCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=119483,
  serialized_end=119612,
)


_PATTERNFLOWARPSENDERHARDWAREADDR_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowArpSenderHardwareAddr.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWARPSENDERHARDWAREADDR_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWARPSENDERHARDWAREADDR = _descriptor.Descriptor(
  name='PatternFlowArpSenderHardwareAddr',
  full_name='otg.PatternFlowArpSenderHardwareAddr',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowArpSenderHardwareAddr.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowArpSenderHardwareAddr.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowArpSenderHardwareAddr.values', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowArpSenderHardwareAddr.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowArpSenderHardwareAddr.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowArpSenderHardwareAddr.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWARPSENDERHARDWAREADDR_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowArpSenderHardwareAddr._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowArpSenderHardwareAddr._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowArpSenderHardwareAddr._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowArpSenderHardwareAddr._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowArpSenderHardwareAddr._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=119615,
  serialized_end=120078,
)


_PATTERNFLOWARPSENDERPROTOCOLADDRCOUNTER = _descriptor.Descriptor(
  name='PatternFlowArpSenderProtocolAddrCounter',
  full_name='otg.PatternFlowArpSenderProtocolAddrCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowArpSenderProtocolAddrCounter.start', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowArpSenderProtocolAddrCounter.step', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowArpSenderProtocolAddrCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowArpSenderProtocolAddrCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowArpSenderProtocolAddrCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowArpSenderProtocolAddrCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=120081,
  serialized_end=120210,
)


_PATTERNFLOWARPSENDERPROTOCOLADDR_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowArpSenderProtocolAddr.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWARPSENDERPROTOCOLADDR_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWARPSENDERPROTOCOLADDR = _descriptor.Descriptor(
  name='PatternFlowArpSenderProtocolAddr',
  full_name='otg.PatternFlowArpSenderProtocolAddr',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowArpSenderProtocolAddr.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowArpSenderProtocolAddr.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowArpSenderProtocolAddr.values', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowArpSenderProtocolAddr.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowArpSenderProtocolAddr.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowArpSenderProtocolAddr.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWARPSENDERPROTOCOLADDR_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowArpSenderProtocolAddr._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowArpSenderProtocolAddr._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowArpSenderProtocolAddr._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowArpSenderProtocolAddr._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowArpSenderProtocolAddr._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=120213,
  serialized_end=120676,
)


_PATTERNFLOWARPTARGETHARDWAREADDRCOUNTER = _descriptor.Descriptor(
  name='PatternFlowArpTargetHardwareAddrCounter',
  full_name='otg.PatternFlowArpTargetHardwareAddrCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowArpTargetHardwareAddrCounter.start', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowArpTargetHardwareAddrCounter.step', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowArpTargetHardwareAddrCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowArpTargetHardwareAddrCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowArpTargetHardwareAddrCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowArpTargetHardwareAddrCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=120679,
  serialized_end=120808,
)


_PATTERNFLOWARPTARGETHARDWAREADDR_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowArpTargetHardwareAddr.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWARPTARGETHARDWAREADDR_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWARPTARGETHARDWAREADDR = _descriptor.Descriptor(
  name='PatternFlowArpTargetHardwareAddr',
  full_name='otg.PatternFlowArpTargetHardwareAddr',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowArpTargetHardwareAddr.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowArpTargetHardwareAddr.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowArpTargetHardwareAddr.values', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowArpTargetHardwareAddr.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowArpTargetHardwareAddr.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowArpTargetHardwareAddr.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWARPTARGETHARDWAREADDR_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowArpTargetHardwareAddr._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowArpTargetHardwareAddr._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowArpTargetHardwareAddr._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowArpTargetHardwareAddr._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowArpTargetHardwareAddr._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=120811,
  serialized_end=121274,
)


_PATTERNFLOWARPTARGETPROTOCOLADDRCOUNTER = _descriptor.Descriptor(
  name='PatternFlowArpTargetProtocolAddrCounter',
  full_name='otg.PatternFlowArpTargetProtocolAddrCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowArpTargetProtocolAddrCounter.start', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowArpTargetProtocolAddrCounter.step', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowArpTargetProtocolAddrCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowArpTargetProtocolAddrCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowArpTargetProtocolAddrCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowArpTargetProtocolAddrCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=121277,
  serialized_end=121406,
)


_PATTERNFLOWARPTARGETPROTOCOLADDR_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowArpTargetProtocolAddr.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWARPTARGETPROTOCOLADDR_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWARPTARGETPROTOCOLADDR = _descriptor.Descriptor(
  name='PatternFlowArpTargetProtocolAddr',
  full_name='otg.PatternFlowArpTargetProtocolAddr',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowArpTargetProtocolAddr.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowArpTargetProtocolAddr.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowArpTargetProtocolAddr.values', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowArpTargetProtocolAddr.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowArpTargetProtocolAddr.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowArpTargetProtocolAddr.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWARPTARGETPROTOCOLADDR_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowArpTargetProtocolAddr._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowArpTargetProtocolAddr._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowArpTargetProtocolAddr._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowArpTargetProtocolAddr._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowArpTargetProtocolAddr._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=121409,
  serialized_end=121872,
)


_PATTERNFLOWICMPECHOTYPECOUNTER = _descriptor.Descriptor(
  name='PatternFlowIcmpEchoTypeCounter',
  full_name='otg.PatternFlowIcmpEchoTypeCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIcmpEchoTypeCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIcmpEchoTypeCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIcmpEchoTypeCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIcmpEchoTypeCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIcmpEchoTypeCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIcmpEchoTypeCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=121874,
  serialized_end=121994,
)


_PATTERNFLOWICMPECHOTYPE_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIcmpEchoType.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWICMPECHOTYPE_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWICMPECHOTYPE = _descriptor.Descriptor(
  name='PatternFlowIcmpEchoType',
  full_name='otg.PatternFlowIcmpEchoType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIcmpEchoType.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIcmpEchoType.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIcmpEchoType.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIcmpEchoType.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIcmpEchoType.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIcmpEchoType.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWICMPECHOTYPE_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIcmpEchoType._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIcmpEchoType._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIcmpEchoType._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIcmpEchoType._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIcmpEchoType._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=121997,
  serialized_end=122424,
)


_PATTERNFLOWICMPECHOCODECOUNTER = _descriptor.Descriptor(
  name='PatternFlowIcmpEchoCodeCounter',
  full_name='otg.PatternFlowIcmpEchoCodeCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIcmpEchoCodeCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIcmpEchoCodeCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIcmpEchoCodeCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIcmpEchoCodeCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIcmpEchoCodeCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIcmpEchoCodeCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=122426,
  serialized_end=122546,
)


_PATTERNFLOWICMPECHOCODE_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIcmpEchoCode.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWICMPECHOCODE_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWICMPECHOCODE = _descriptor.Descriptor(
  name='PatternFlowIcmpEchoCode',
  full_name='otg.PatternFlowIcmpEchoCode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIcmpEchoCode.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIcmpEchoCode.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIcmpEchoCode.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIcmpEchoCode.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIcmpEchoCode.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIcmpEchoCode.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWICMPECHOCODE_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIcmpEchoCode._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIcmpEchoCode._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIcmpEchoCode._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIcmpEchoCode._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIcmpEchoCode._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=122549,
  serialized_end=122976,
)


_PATTERNFLOWICMPECHOCHECKSUM_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIcmpEchoChecksum.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWICMPECHOCHECKSUM_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68398,
  serialized_end=68458,
)

_PATTERNFLOWICMPECHOCHECKSUM_GENERATED = _descriptor.Descriptor(
  name='Generated',
  full_name='otg.PatternFlowIcmpEchoChecksum.Generated',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWICMPECHOCHECKSUM_GENERATED_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68460,
  serialized_end=68515,
)

_PATTERNFLOWICMPECHOCHECKSUM = _descriptor.Descriptor(
  name='PatternFlowIcmpEchoChecksum',
  full_name='otg.PatternFlowIcmpEchoChecksum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIcmpEchoChecksum.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='generated', full_name='otg.PatternFlowIcmpEchoChecksum.generated', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom', full_name='otg.PatternFlowIcmpEchoChecksum.custom', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWICMPECHOCHECKSUM_CHOICE, _PATTERNFLOWICMPECHOCHECKSUM_GENERATED, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIcmpEchoChecksum._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_generated', full_name='otg.PatternFlowIcmpEchoChecksum._generated',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_custom', full_name='otg.PatternFlowIcmpEchoChecksum._custom',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=122979,
  serialized_end=123324,
)


_PATTERNFLOWICMPECHOIDENTIFIERCOUNTER = _descriptor.Descriptor(
  name='PatternFlowIcmpEchoIdentifierCounter',
  full_name='otg.PatternFlowIcmpEchoIdentifierCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIcmpEchoIdentifierCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIcmpEchoIdentifierCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIcmpEchoIdentifierCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIcmpEchoIdentifierCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIcmpEchoIdentifierCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIcmpEchoIdentifierCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=123326,
  serialized_end=123452,
)


_PATTERNFLOWICMPECHOIDENTIFIER_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIcmpEchoIdentifier.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWICMPECHOIDENTIFIER_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWICMPECHOIDENTIFIER = _descriptor.Descriptor(
  name='PatternFlowIcmpEchoIdentifier',
  full_name='otg.PatternFlowIcmpEchoIdentifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIcmpEchoIdentifier.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIcmpEchoIdentifier.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIcmpEchoIdentifier.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIcmpEchoIdentifier.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIcmpEchoIdentifier.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIcmpEchoIdentifier.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWICMPECHOIDENTIFIER_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIcmpEchoIdentifier._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIcmpEchoIdentifier._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIcmpEchoIdentifier._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIcmpEchoIdentifier._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIcmpEchoIdentifier._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=123455,
  serialized_end=123906,
)


_PATTERNFLOWICMPECHOSEQUENCENUMBERCOUNTER = _descriptor.Descriptor(
  name='PatternFlowIcmpEchoSequenceNumberCounter',
  full_name='otg.PatternFlowIcmpEchoSequenceNumberCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIcmpEchoSequenceNumberCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIcmpEchoSequenceNumberCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIcmpEchoSequenceNumberCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIcmpEchoSequenceNumberCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIcmpEchoSequenceNumberCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIcmpEchoSequenceNumberCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=123909,
  serialized_end=124039,
)


_PATTERNFLOWICMPECHOSEQUENCENUMBER_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIcmpEchoSequenceNumber.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWICMPECHOSEQUENCENUMBER_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWICMPECHOSEQUENCENUMBER = _descriptor.Descriptor(
  name='PatternFlowIcmpEchoSequenceNumber',
  full_name='otg.PatternFlowIcmpEchoSequenceNumber',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIcmpEchoSequenceNumber.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIcmpEchoSequenceNumber.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIcmpEchoSequenceNumber.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIcmpEchoSequenceNumber.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIcmpEchoSequenceNumber.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIcmpEchoSequenceNumber.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWICMPECHOSEQUENCENUMBER_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIcmpEchoSequenceNumber._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIcmpEchoSequenceNumber._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIcmpEchoSequenceNumber._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIcmpEchoSequenceNumber._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIcmpEchoSequenceNumber._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=124042,
  serialized_end=124509,
)


_PATTERNFLOWICMPCOMMONCHECKSUM_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIcmpCommonChecksum.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWICMPCOMMONCHECKSUM_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68398,
  serialized_end=68458,
)

_PATTERNFLOWICMPCOMMONCHECKSUM_GENERATED = _descriptor.Descriptor(
  name='Generated',
  full_name='otg.PatternFlowIcmpCommonChecksum.Generated',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWICMPCOMMONCHECKSUM_GENERATED_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68460,
  serialized_end=68515,
)

_PATTERNFLOWICMPCOMMONCHECKSUM = _descriptor.Descriptor(
  name='PatternFlowIcmpCommonChecksum',
  full_name='otg.PatternFlowIcmpCommonChecksum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIcmpCommonChecksum.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='generated', full_name='otg.PatternFlowIcmpCommonChecksum.generated', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom', full_name='otg.PatternFlowIcmpCommonChecksum.custom', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWICMPCOMMONCHECKSUM_CHOICE, _PATTERNFLOWICMPCOMMONCHECKSUM_GENERATED, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIcmpCommonChecksum._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_generated', full_name='otg.PatternFlowIcmpCommonChecksum._generated',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_custom', full_name='otg.PatternFlowIcmpCommonChecksum._custom',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=124512,
  serialized_end=124863,
)


_PATTERNFLOWICMPNEXTFIELDSIDENTIFIERCOUNTER = _descriptor.Descriptor(
  name='PatternFlowIcmpNextFieldsIdentifierCounter',
  full_name='otg.PatternFlowIcmpNextFieldsIdentifierCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIcmpNextFieldsIdentifierCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIcmpNextFieldsIdentifierCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIcmpNextFieldsIdentifierCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIcmpNextFieldsIdentifierCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIcmpNextFieldsIdentifierCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIcmpNextFieldsIdentifierCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=124866,
  serialized_end=124998,
)


_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIcmpNextFieldsIdentifier.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER = _descriptor.Descriptor(
  name='PatternFlowIcmpNextFieldsIdentifier',
  full_name='otg.PatternFlowIcmpNextFieldsIdentifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIcmpNextFieldsIdentifier.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIcmpNextFieldsIdentifier.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIcmpNextFieldsIdentifier.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIcmpNextFieldsIdentifier.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIcmpNextFieldsIdentifier.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIcmpNextFieldsIdentifier.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIcmpNextFieldsIdentifier._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIcmpNextFieldsIdentifier._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIcmpNextFieldsIdentifier._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIcmpNextFieldsIdentifier._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIcmpNextFieldsIdentifier._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=125001,
  serialized_end=125476,
)


_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERCOUNTER = _descriptor.Descriptor(
  name='PatternFlowIcmpNextFieldsSequenceNumberCounter',
  full_name='otg.PatternFlowIcmpNextFieldsSequenceNumberCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIcmpNextFieldsSequenceNumberCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIcmpNextFieldsSequenceNumberCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIcmpNextFieldsSequenceNumberCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIcmpNextFieldsSequenceNumberCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIcmpNextFieldsSequenceNumberCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIcmpNextFieldsSequenceNumberCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=125479,
  serialized_end=125615,
)


_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIcmpNextFieldsSequenceNumber.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER = _descriptor.Descriptor(
  name='PatternFlowIcmpNextFieldsSequenceNumber',
  full_name='otg.PatternFlowIcmpNextFieldsSequenceNumber',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIcmpNextFieldsSequenceNumber.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIcmpNextFieldsSequenceNumber.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIcmpNextFieldsSequenceNumber.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIcmpNextFieldsSequenceNumber.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIcmpNextFieldsSequenceNumber.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIcmpNextFieldsSequenceNumber.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIcmpNextFieldsSequenceNumber._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIcmpNextFieldsSequenceNumber._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIcmpNextFieldsSequenceNumber._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIcmpNextFieldsSequenceNumber._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIcmpNextFieldsSequenceNumber._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=125618,
  serialized_end=126109,
)


_PATTERNFLOWICMPV6ECHOTYPECOUNTER = _descriptor.Descriptor(
  name='PatternFlowIcmpv6EchoTypeCounter',
  full_name='otg.PatternFlowIcmpv6EchoTypeCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIcmpv6EchoTypeCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIcmpv6EchoTypeCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIcmpv6EchoTypeCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIcmpv6EchoTypeCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIcmpv6EchoTypeCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIcmpv6EchoTypeCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=126111,
  serialized_end=126233,
)


_PATTERNFLOWICMPV6ECHOTYPE_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIcmpv6EchoType.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWICMPV6ECHOTYPE_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWICMPV6ECHOTYPE = _descriptor.Descriptor(
  name='PatternFlowIcmpv6EchoType',
  full_name='otg.PatternFlowIcmpv6EchoType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIcmpv6EchoType.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIcmpv6EchoType.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIcmpv6EchoType.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIcmpv6EchoType.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIcmpv6EchoType.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIcmpv6EchoType.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWICMPV6ECHOTYPE_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIcmpv6EchoType._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIcmpv6EchoType._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIcmpv6EchoType._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIcmpv6EchoType._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIcmpv6EchoType._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=126236,
  serialized_end=126671,
)


_PATTERNFLOWICMPV6ECHOCODECOUNTER = _descriptor.Descriptor(
  name='PatternFlowIcmpv6EchoCodeCounter',
  full_name='otg.PatternFlowIcmpv6EchoCodeCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIcmpv6EchoCodeCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIcmpv6EchoCodeCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIcmpv6EchoCodeCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIcmpv6EchoCodeCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIcmpv6EchoCodeCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIcmpv6EchoCodeCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=126673,
  serialized_end=126795,
)


_PATTERNFLOWICMPV6ECHOCODE_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIcmpv6EchoCode.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWICMPV6ECHOCODE_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWICMPV6ECHOCODE = _descriptor.Descriptor(
  name='PatternFlowIcmpv6EchoCode',
  full_name='otg.PatternFlowIcmpv6EchoCode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIcmpv6EchoCode.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIcmpv6EchoCode.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIcmpv6EchoCode.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIcmpv6EchoCode.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIcmpv6EchoCode.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIcmpv6EchoCode.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWICMPV6ECHOCODE_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIcmpv6EchoCode._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIcmpv6EchoCode._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIcmpv6EchoCode._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIcmpv6EchoCode._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIcmpv6EchoCode._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=126798,
  serialized_end=127233,
)


_PATTERNFLOWICMPV6ECHOIDENTIFIERCOUNTER = _descriptor.Descriptor(
  name='PatternFlowIcmpv6EchoIdentifierCounter',
  full_name='otg.PatternFlowIcmpv6EchoIdentifierCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIcmpv6EchoIdentifierCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIcmpv6EchoIdentifierCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIcmpv6EchoIdentifierCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIcmpv6EchoIdentifierCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIcmpv6EchoIdentifierCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIcmpv6EchoIdentifierCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=127236,
  serialized_end=127364,
)


_PATTERNFLOWICMPV6ECHOIDENTIFIER_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIcmpv6EchoIdentifier.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWICMPV6ECHOIDENTIFIER_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWICMPV6ECHOIDENTIFIER = _descriptor.Descriptor(
  name='PatternFlowIcmpv6EchoIdentifier',
  full_name='otg.PatternFlowIcmpv6EchoIdentifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIcmpv6EchoIdentifier.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIcmpv6EchoIdentifier.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIcmpv6EchoIdentifier.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIcmpv6EchoIdentifier.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIcmpv6EchoIdentifier.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIcmpv6EchoIdentifier.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWICMPV6ECHOIDENTIFIER_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIcmpv6EchoIdentifier._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIcmpv6EchoIdentifier._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIcmpv6EchoIdentifier._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIcmpv6EchoIdentifier._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIcmpv6EchoIdentifier._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=127367,
  serialized_end=127826,
)


_PATTERNFLOWICMPV6ECHOSEQUENCENUMBERCOUNTER = _descriptor.Descriptor(
  name='PatternFlowIcmpv6EchoSequenceNumberCounter',
  full_name='otg.PatternFlowIcmpv6EchoSequenceNumberCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIcmpv6EchoSequenceNumberCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIcmpv6EchoSequenceNumberCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIcmpv6EchoSequenceNumberCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIcmpv6EchoSequenceNumberCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIcmpv6EchoSequenceNumberCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIcmpv6EchoSequenceNumberCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=127829,
  serialized_end=127961,
)


_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIcmpv6EchoSequenceNumber.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER = _descriptor.Descriptor(
  name='PatternFlowIcmpv6EchoSequenceNumber',
  full_name='otg.PatternFlowIcmpv6EchoSequenceNumber',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIcmpv6EchoSequenceNumber.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIcmpv6EchoSequenceNumber.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIcmpv6EchoSequenceNumber.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIcmpv6EchoSequenceNumber.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIcmpv6EchoSequenceNumber.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIcmpv6EchoSequenceNumber.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIcmpv6EchoSequenceNumber._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIcmpv6EchoSequenceNumber._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIcmpv6EchoSequenceNumber._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIcmpv6EchoSequenceNumber._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIcmpv6EchoSequenceNumber._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=127964,
  serialized_end=128439,
)


_PATTERNFLOWICMPV6ECHOCHECKSUM_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIcmpv6EchoChecksum.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWICMPV6ECHOCHECKSUM_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68398,
  serialized_end=68458,
)

_PATTERNFLOWICMPV6ECHOCHECKSUM_GENERATED = _descriptor.Descriptor(
  name='Generated',
  full_name='otg.PatternFlowIcmpv6EchoChecksum.Generated',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWICMPV6ECHOCHECKSUM_GENERATED_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68460,
  serialized_end=68515,
)

_PATTERNFLOWICMPV6ECHOCHECKSUM = _descriptor.Descriptor(
  name='PatternFlowIcmpv6EchoChecksum',
  full_name='otg.PatternFlowIcmpv6EchoChecksum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIcmpv6EchoChecksum.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='generated', full_name='otg.PatternFlowIcmpv6EchoChecksum.generated', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom', full_name='otg.PatternFlowIcmpv6EchoChecksum.custom', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWICMPV6ECHOCHECKSUM_CHOICE, _PATTERNFLOWICMPV6ECHOCHECKSUM_GENERATED, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIcmpv6EchoChecksum._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_generated', full_name='otg.PatternFlowIcmpv6EchoChecksum._generated',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_custom', full_name='otg.PatternFlowIcmpv6EchoChecksum._custom',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=128442,
  serialized_end=128793,
)


_PATTERNFLOWICMPV6COMMONCHECKSUM_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIcmpv6CommonChecksum.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWICMPV6COMMONCHECKSUM_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68398,
  serialized_end=68458,
)

_PATTERNFLOWICMPV6COMMONCHECKSUM_GENERATED = _descriptor.Descriptor(
  name='Generated',
  full_name='otg.PatternFlowIcmpv6CommonChecksum.Generated',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWICMPV6COMMONCHECKSUM_GENERATED_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68460,
  serialized_end=68515,
)

_PATTERNFLOWICMPV6COMMONCHECKSUM = _descriptor.Descriptor(
  name='PatternFlowIcmpv6CommonChecksum',
  full_name='otg.PatternFlowIcmpv6CommonChecksum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIcmpv6CommonChecksum.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='generated', full_name='otg.PatternFlowIcmpv6CommonChecksum.generated', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom', full_name='otg.PatternFlowIcmpv6CommonChecksum.custom', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWICMPV6COMMONCHECKSUM_CHOICE, _PATTERNFLOWICMPV6COMMONCHECKSUM_GENERATED, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIcmpv6CommonChecksum._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_generated', full_name='otg.PatternFlowIcmpv6CommonChecksum._generated',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_custom', full_name='otg.PatternFlowIcmpv6CommonChecksum._custom',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=128796,
  serialized_end=129153,
)


_PATTERNFLOWPPPADDRESSCOUNTER = _descriptor.Descriptor(
  name='PatternFlowPppAddressCounter',
  full_name='otg.PatternFlowPppAddressCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowPppAddressCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowPppAddressCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowPppAddressCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowPppAddressCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowPppAddressCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowPppAddressCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=129155,
  serialized_end=129273,
)


_PATTERNFLOWPPPADDRESS_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowPppAddress.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWPPPADDRESS_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWPPPADDRESS = _descriptor.Descriptor(
  name='PatternFlowPppAddress',
  full_name='otg.PatternFlowPppAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowPppAddress.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowPppAddress.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowPppAddress.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowPppAddress.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowPppAddress.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowPppAddress.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWPPPADDRESS_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowPppAddress._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowPppAddress._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowPppAddress._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowPppAddress._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowPppAddress._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=129276,
  serialized_end=129695,
)


_PATTERNFLOWPPPCONTROLCOUNTER = _descriptor.Descriptor(
  name='PatternFlowPppControlCounter',
  full_name='otg.PatternFlowPppControlCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowPppControlCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowPppControlCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowPppControlCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowPppControlCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowPppControlCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowPppControlCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=129697,
  serialized_end=129815,
)


_PATTERNFLOWPPPCONTROL_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowPppControl.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWPPPCONTROL_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWPPPCONTROL = _descriptor.Descriptor(
  name='PatternFlowPppControl',
  full_name='otg.PatternFlowPppControl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowPppControl.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowPppControl.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowPppControl.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowPppControl.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowPppControl.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowPppControl.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWPPPCONTROL_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowPppControl._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowPppControl._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowPppControl._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowPppControl._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowPppControl._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=129818,
  serialized_end=130237,
)


_PATTERNFLOWPPPPROTOCOLTYPECOUNTER = _descriptor.Descriptor(
  name='PatternFlowPppProtocolTypeCounter',
  full_name='otg.PatternFlowPppProtocolTypeCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowPppProtocolTypeCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowPppProtocolTypeCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowPppProtocolTypeCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowPppProtocolTypeCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowPppProtocolTypeCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowPppProtocolTypeCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=130239,
  serialized_end=130362,
)


_PATTERNFLOWPPPPROTOCOLTYPE_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowPppProtocolType.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWPPPPROTOCOLTYPE_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57045,
  serialized_end=57141,
)

_PATTERNFLOWPPPPROTOCOLTYPE_AUTO = _descriptor.Descriptor(
  name='Auto',
  full_name='otg.PatternFlowPppProtocolType.Auto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWPPPPROTOCOLTYPE_AUTO_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57143,
  serialized_end=57184,
)

_PATTERNFLOWPPPPROTOCOLTYPE = _descriptor.Descriptor(
  name='PatternFlowPppProtocolType',
  full_name='otg.PatternFlowPppProtocolType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowPppProtocolType.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowPppProtocolType.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowPppProtocolType.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto', full_name='otg.PatternFlowPppProtocolType.auto', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowPppProtocolType.metric_group', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowPppProtocolType.increment', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowPppProtocolType.decrement', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWPPPPROTOCOLTYPE_CHOICE, _PATTERNFLOWPPPPROTOCOLTYPE_AUTO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowPppProtocolType._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowPppProtocolType._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_auto', full_name='otg.PatternFlowPppProtocolType._auto',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowPppProtocolType._metric_group',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowPppProtocolType._increment',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowPppProtocolType._decrement',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=130365,
  serialized_end=130928,
)


_PATTERNFLOWIGMPV1VERSIONCOUNTER = _descriptor.Descriptor(
  name='PatternFlowIgmpv1VersionCounter',
  full_name='otg.PatternFlowIgmpv1VersionCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIgmpv1VersionCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIgmpv1VersionCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIgmpv1VersionCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIgmpv1VersionCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIgmpv1VersionCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIgmpv1VersionCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=130930,
  serialized_end=131051,
)


_PATTERNFLOWIGMPV1VERSION_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIgmpv1Version.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIGMPV1VERSION_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWIGMPV1VERSION = _descriptor.Descriptor(
  name='PatternFlowIgmpv1Version',
  full_name='otg.PatternFlowIgmpv1Version',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIgmpv1Version.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIgmpv1Version.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIgmpv1Version.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIgmpv1Version.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIgmpv1Version.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIgmpv1Version.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWIGMPV1VERSION_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIgmpv1Version._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIgmpv1Version._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIgmpv1Version._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIgmpv1Version._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIgmpv1Version._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=131054,
  serialized_end=131485,
)


_PATTERNFLOWIGMPV1TYPECOUNTER = _descriptor.Descriptor(
  name='PatternFlowIgmpv1TypeCounter',
  full_name='otg.PatternFlowIgmpv1TypeCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIgmpv1TypeCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIgmpv1TypeCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIgmpv1TypeCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIgmpv1TypeCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIgmpv1TypeCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIgmpv1TypeCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=131487,
  serialized_end=131605,
)


_PATTERNFLOWIGMPV1TYPE_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIgmpv1Type.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIGMPV1TYPE_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWIGMPV1TYPE = _descriptor.Descriptor(
  name='PatternFlowIgmpv1Type',
  full_name='otg.PatternFlowIgmpv1Type',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIgmpv1Type.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIgmpv1Type.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIgmpv1Type.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIgmpv1Type.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIgmpv1Type.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIgmpv1Type.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWIGMPV1TYPE_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIgmpv1Type._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIgmpv1Type._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIgmpv1Type._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIgmpv1Type._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIgmpv1Type._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=131608,
  serialized_end=132027,
)


_PATTERNFLOWIGMPV1UNUSEDCOUNTER = _descriptor.Descriptor(
  name='PatternFlowIgmpv1UnusedCounter',
  full_name='otg.PatternFlowIgmpv1UnusedCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIgmpv1UnusedCounter.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIgmpv1UnusedCounter.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIgmpv1UnusedCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIgmpv1UnusedCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIgmpv1UnusedCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIgmpv1UnusedCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=132029,
  serialized_end=132149,
)


_PATTERNFLOWIGMPV1UNUSED_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIgmpv1Unused.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIGMPV1UNUSED_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWIGMPV1UNUSED = _descriptor.Descriptor(
  name='PatternFlowIgmpv1Unused',
  full_name='otg.PatternFlowIgmpv1Unused',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIgmpv1Unused.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIgmpv1Unused.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIgmpv1Unused.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIgmpv1Unused.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIgmpv1Unused.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIgmpv1Unused.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWIGMPV1UNUSED_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIgmpv1Unused._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIgmpv1Unused._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIgmpv1Unused._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIgmpv1Unused._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIgmpv1Unused._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=132152,
  serialized_end=132579,
)


_PATTERNFLOWIGMPV1CHECKSUM_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIgmpv1Checksum.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIGMPV1CHECKSUM_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68398,
  serialized_end=68458,
)

_PATTERNFLOWIGMPV1CHECKSUM_GENERATED = _descriptor.Descriptor(
  name='Generated',
  full_name='otg.PatternFlowIgmpv1Checksum.Generated',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIGMPV1CHECKSUM_GENERATED_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68460,
  serialized_end=68515,
)

_PATTERNFLOWIGMPV1CHECKSUM = _descriptor.Descriptor(
  name='PatternFlowIgmpv1Checksum',
  full_name='otg.PatternFlowIgmpv1Checksum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIgmpv1Checksum.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='generated', full_name='otg.PatternFlowIgmpv1Checksum.generated', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom', full_name='otg.PatternFlowIgmpv1Checksum.custom', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWIGMPV1CHECKSUM_CHOICE, _PATTERNFLOWIGMPV1CHECKSUM_GENERATED, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIgmpv1Checksum._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_generated', full_name='otg.PatternFlowIgmpv1Checksum._generated',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_custom', full_name='otg.PatternFlowIgmpv1Checksum._custom',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=132582,
  serialized_end=132921,
)


_PATTERNFLOWIGMPV1GROUPADDRESSCOUNTER = _descriptor.Descriptor(
  name='PatternFlowIgmpv1GroupAddressCounter',
  full_name='otg.PatternFlowIgmpv1GroupAddressCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='otg.PatternFlowIgmpv1GroupAddressCounter.start', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='otg.PatternFlowIgmpv1GroupAddressCounter.step', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='otg.PatternFlowIgmpv1GroupAddressCounter.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_start', full_name='otg.PatternFlowIgmpv1GroupAddressCounter._start',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_step', full_name='otg.PatternFlowIgmpv1GroupAddressCounter._step',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_count', full_name='otg.PatternFlowIgmpv1GroupAddressCounter._count',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=132923,
  serialized_end=133049,
)


_PATTERNFLOWIGMPV1GROUPADDRESS_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='otg.PatternFlowIgmpv1GroupAddress.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATTERNFLOWIGMPV1GROUPADDRESS_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55857,
  serialized_end=55943,
)

_PATTERNFLOWIGMPV1GROUPADDRESS = _descriptor.Descriptor(
  name='PatternFlowIgmpv1GroupAddress',
  full_name='otg.PatternFlowIgmpv1GroupAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='otg.PatternFlowIgmpv1GroupAddress.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='otg.PatternFlowIgmpv1GroupAddress.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='otg.PatternFlowIgmpv1GroupAddress.values', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_group', full_name='otg.PatternFlowIgmpv1GroupAddress.metric_group', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='otg.PatternFlowIgmpv1GroupAddress.increment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decrement', full_name='otg.PatternFlowIgmpv1GroupAddress.decrement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATTERNFLOWIGMPV1GROUPADDRESS_CHOICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='otg.PatternFlowIgmpv1GroupAddress._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_value', full_name='otg.PatternFlowIgmpv1GroupAddress._value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_metric_group', full_name='otg.PatternFlowIgmpv1GroupAddress._metric_group',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='otg.PatternFlowIgmpv1GroupAddress._increment',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_decrement', full_name='otg.PatternFlowIgmpv1GroupAddress._decrement',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=133052,
  serialized_end=133503,
)


_SUCCESS = _descriptor.Descriptor(
  name='Success',
  full_name='otg.Success',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='response_warning', full_name='otg.Success.response_warning', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=133505,
  serialized_end=133562,
)


_BADREQUEST = _descriptor.Descriptor(
  name='BadRequest',
  full_name='otg.BadRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='response_error', full_name='otg.BadRequest.response_error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=133564,
  serialized_end=133620,
)


_INTERNALSERVERERROR = _descriptor.Descriptor(
  name='InternalServerError',
  full_name='otg.InternalServerError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='response_error', full_name='otg.InternalServerError.response_error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=133622,
  serialized_end=133687,
)


_SETCONFIGREQUEST = _descriptor.Descriptor(
  name='SetConfigRequest',
  full_name='otg.SetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='otg.SetConfigRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=133689,
  serialized_end=133736,
)


_SETCONFIGRESPONSE = _descriptor.Descriptor(
  name='SetConfigResponse',
  full_name='otg.SetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status_code_200', full_name='otg.SetConfigResponse.status_code_200', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_code_400', full_name='otg.SetConfigResponse.status_code_400', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_code_500', full_name='otg.SetConfigResponse.status_code_500', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_status_code_200', full_name='otg.SetConfigResponse._status_code_200',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_status_code_400', full_name='otg.SetConfigResponse._status_code_400',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_status_code_500', full_name='otg.SetConfigResponse._status_code_500',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=133739,
  serialized_end=133970,
)


_GETCONFIGRESPONSE = _descriptor.Descriptor(
  name='GetConfigResponse',
  full_name='otg.GetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status_code_200', full_name='otg.GetConfigResponse.status_code_200', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_code_400', full_name='otg.GetConfigResponse.status_code_400', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_code_500', full_name='otg.GetConfigResponse.status_code_500', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_status_code_200', full_name='otg.GetConfigResponse._status_code_200',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_status_code_400', full_name='otg.GetConfigResponse._status_code_400',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_status_code_500', full_name='otg.GetConfigResponse._status_code_500',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=133973,
  serialized_end=134195,
)


_SETTRANSMITSTATEREQUEST = _descriptor.Descriptor(
  name='SetTransmitStateRequest',
  full_name='otg.SetTransmitStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transmit_state', full_name='otg.SetTransmitStateRequest.transmit_state', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=134197,
  serialized_end=134266,
)


_SETTRANSMITSTATERESPONSE = _descriptor.Descriptor(
  name='SetTransmitStateResponse',
  full_name='otg.SetTransmitStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status_code_200', full_name='otg.SetTransmitStateResponse.status_code_200', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_code_400', full_name='otg.SetTransmitStateResponse.status_code_400', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_code_500', full_name='otg.SetTransmitStateResponse.status_code_500', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_status_code_200', full_name='otg.SetTransmitStateResponse._status_code_200',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_status_code_400', full_name='otg.SetTransmitStateResponse._status_code_400',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_status_code_500', full_name='otg.SetTransmitStateResponse._status_code_500',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=134269,
  serialized_end=134507,
)


_SETLINKSTATEREQUEST = _descriptor.Descriptor(
  name='SetLinkStateRequest',
  full_name='otg.SetLinkStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='link_state', full_name='otg.SetLinkStateRequest.link_state', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=134509,
  serialized_end=134566,
)


_SETLINKSTATERESPONSE = _descriptor.Descriptor(
  name='SetLinkStateResponse',
  full_name='otg.SetLinkStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status_code_200', full_name='otg.SetLinkStateResponse.status_code_200', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_code_400', full_name='otg.SetLinkStateResponse.status_code_400', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_code_500', full_name='otg.SetLinkStateResponse.status_code_500', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_status_code_200', full_name='otg.SetLinkStateResponse._status_code_200',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_status_code_400', full_name='otg.SetLinkStateResponse._status_code_400',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_status_code_500', full_name='otg.SetLinkStateResponse._status_code_500',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=134569,
  serialized_end=134803,
)


_SETCAPTURESTATEREQUEST = _descriptor.Descriptor(
  name='SetCaptureStateRequest',
  full_name='otg.SetCaptureStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='capture_state', full_name='otg.SetCaptureStateRequest.capture_state', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=134805,
  serialized_end=134871,
)


_SETCAPTURESTATERESPONSE = _descriptor.Descriptor(
  name='SetCaptureStateResponse',
  full_name='otg.SetCaptureStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status_code_200', full_name='otg.SetCaptureStateResponse.status_code_200', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_code_400', full_name='otg.SetCaptureStateResponse.status_code_400', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_code_500', full_name='otg.SetCaptureStateResponse.status_code_500', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_status_code_200', full_name='otg.SetCaptureStateResponse._status_code_200',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_status_code_400', full_name='otg.SetCaptureStateResponse._status_code_400',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_status_code_500', full_name='otg.SetCaptureStateResponse._status_code_500',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=134874,
  serialized_end=135111,
)


_UPDATEFLOWSREQUEST = _descriptor.Descriptor(
  name='UpdateFlowsRequest',
  full_name='otg.UpdateFlowsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flows_update', full_name='otg.UpdateFlowsRequest.flows_update', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=135113,
  serialized_end=135173,
)


_UPDATEFLOWSRESPONSE = _descriptor.Descriptor(
  name='UpdateFlowsResponse',
  full_name='otg.UpdateFlowsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status_code_200', full_name='otg.UpdateFlowsResponse.status_code_200', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_code_400', full_name='otg.UpdateFlowsResponse.status_code_400', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_code_500', full_name='otg.UpdateFlowsResponse.status_code_500', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_status_code_200', full_name='otg.UpdateFlowsResponse._status_code_200',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_status_code_400', full_name='otg.UpdateFlowsResponse._status_code_400',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_status_code_500', full_name='otg.UpdateFlowsResponse._status_code_500',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=135176,
  serialized_end=135400,
)


_SETROUTESTATEREQUEST = _descriptor.Descriptor(
  name='SetRouteStateRequest',
  full_name='otg.SetRouteStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='route_state', full_name='otg.SetRouteStateRequest.route_state', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=135402,
  serialized_end=135462,
)


_SETROUTESTATERESPONSE = _descriptor.Descriptor(
  name='SetRouteStateResponse',
  full_name='otg.SetRouteStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status_code_200', full_name='otg.SetRouteStateResponse.status_code_200', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_code_400', full_name='otg.SetRouteStateResponse.status_code_400', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_code_500', full_name='otg.SetRouteStateResponse.status_code_500', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_status_code_200', full_name='otg.SetRouteStateResponse._status_code_200',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_status_code_400', full_name='otg.SetRouteStateResponse._status_code_400',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_status_code_500', full_name='otg.SetRouteStateResponse._status_code_500',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=135465,
  serialized_end=135700,
)


_SENDPINGREQUEST = _descriptor.Descriptor(
  name='SendPingRequest',
  full_name='otg.SendPingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ping_request', full_name='otg.SendPingRequest.ping_request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=135702,
  serialized_end=135759,
)


_SENDPINGRESPONSE = _descriptor.Descriptor(
  name='SendPingResponse',
  full_name='otg.SendPingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status_code_200', full_name='otg.SendPingResponse.status_code_200', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_code_400', full_name='otg.SendPingResponse.status_code_400', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_code_500', full_name='otg.SendPingResponse.status_code_500', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_status_code_200', full_name='otg.SendPingResponse._status_code_200',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_status_code_400', full_name='otg.SendPingResponse._status_code_400',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_status_code_500', full_name='otg.SendPingResponse._status_code_500',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=135762,
  serialized_end=135989,
)


_SETPROTOCOLSTATEREQUEST = _descriptor.Descriptor(
  name='SetProtocolStateRequest',
  full_name='otg.SetProtocolStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='protocol_state', full_name='otg.SetProtocolStateRequest.protocol_state', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=135991,
  serialized_end=136060,
)


_SETPROTOCOLSTATERESPONSE = _descriptor.Descriptor(
  name='SetProtocolStateResponse',
  full_name='otg.SetProtocolStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status_code_200', full_name='otg.SetProtocolStateResponse.status_code_200', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_code_400', full_name='otg.SetProtocolStateResponse.status_code_400', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_code_500', full_name='otg.SetProtocolStateResponse.status_code_500', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_status_code_200', full_name='otg.SetProtocolStateResponse._status_code_200',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_status_code_400', full_name='otg.SetProtocolStateResponse._status_code_400',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_status_code_500', full_name='otg.SetProtocolStateResponse._status_code_500',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=136063,
  serialized_end=136301,
)


_GETMETRICSREQUEST = _descriptor.Descriptor(
  name='GetMetricsRequest',
  full_name='otg.GetMetricsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metrics_request', full_name='otg.GetMetricsRequest.metrics_request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=136303,
  serialized_end=136368,
)


_GETMETRICSRESPONSE = _descriptor.Descriptor(
  name='GetMetricsResponse',
  full_name='otg.GetMetricsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status_code_200', full_name='otg.GetMetricsResponse.status_code_200', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_code_400', full_name='otg.GetMetricsResponse.status_code_400', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_code_500', full_name='otg.GetMetricsResponse.status_code_500', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_status_code_200', full_name='otg.GetMetricsResponse._status_code_200',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_status_code_400', full_name='otg.GetMetricsResponse._status_code_400',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_status_code_500', full_name='otg.GetMetricsResponse._status_code_500',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=136371,
  serialized_end=136603,
)


_GETSTATESREQUEST = _descriptor.Descriptor(
  name='GetStatesRequest',
  full_name='otg.GetStatesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='states_request', full_name='otg.GetStatesRequest.states_request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=136605,
  serialized_end=136667,
)


_GETSTATESRESPONSE = _descriptor.Descriptor(
  name='GetStatesResponse',
  full_name='otg.GetStatesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status_code_200', full_name='otg.GetStatesResponse.status_code_200', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_code_400', full_name='otg.GetStatesResponse.status_code_400', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_code_500', full_name='otg.GetStatesResponse.status_code_500', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_status_code_200', full_name='otg.GetStatesResponse._status_code_200',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_status_code_400', full_name='otg.GetStatesResponse._status_code_400',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_status_code_500', full_name='otg.GetStatesResponse._status_code_500',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=136670,
  serialized_end=136900,
)


_GETCAPTUREREQUEST = _descriptor.Descriptor(
  name='GetCaptureRequest',
  full_name='otg.GetCaptureRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='capture_request', full_name='otg.GetCaptureRequest.capture_request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=136902,
  serialized_end=136967,
)


_GETCAPTURERESPONSE = _descriptor.Descriptor(
  name='GetCaptureResponse',
  full_name='otg.GetCaptureResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status_code_200', full_name='otg.GetCaptureResponse.status_code_200', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_code_400', full_name='otg.GetCaptureResponse.status_code_400', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_code_500', full_name='otg.GetCaptureResponse.status_code_500', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_status_code_200', full_name='otg.GetCaptureResponse._status_code_200',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_status_code_400', full_name='otg.GetCaptureResponse._status_code_400',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_status_code_500', full_name='otg.GetCaptureResponse._status_code_500',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=136970,
  serialized_end=137180,
)

_CONFIG.fields_by_name['ports'].message_type = _PORT
_CONFIG.fields_by_name['lags'].message_type = _LAG
_CONFIG.fields_by_name['layer1'].message_type = _LAYER1
_CONFIG.fields_by_name['captures'].message_type = _CAPTURE
_CONFIG.fields_by_name['devices'].message_type = _DEVICE
_CONFIG.fields_by_name['flows'].message_type = _FLOW
_CONFIG.fields_by_name['events'].message_type = _EVENT
_CONFIG.fields_by_name['options'].message_type = _CONFIGOPTIONS
_CONFIG.oneofs_by_name['_events'].fields.append(
  _CONFIG.fields_by_name['events'])
_CONFIG.fields_by_name['events'].containing_oneof = _CONFIG.oneofs_by_name['_events']
_CONFIG.oneofs_by_name['_options'].fields.append(
  _CONFIG.fields_by_name['options'])
_CONFIG.fields_by_name['options'].containing_oneof = _CONFIG.oneofs_by_name['_options']
_CONFIGOPTIONS.fields_by_name['port_options'].message_type = _PORTOPTIONS
_CONFIGOPTIONS.oneofs_by_name['_port_options'].fields.append(
  _CONFIGOPTIONS.fields_by_name['port_options'])
_CONFIGOPTIONS.fields_by_name['port_options'].containing_oneof = _CONFIGOPTIONS.oneofs_by_name['_port_options']
_PORT.oneofs_by_name['_location'].fields.append(
  _PORT.fields_by_name['location'])
_PORT.fields_by_name['location'].containing_oneof = _PORT.oneofs_by_name['_location']
_PORTOPTIONS.oneofs_by_name['_location_preemption'].fields.append(
  _PORTOPTIONS.fields_by_name['location_preemption'])
_PORTOPTIONS.fields_by_name['location_preemption'].containing_oneof = _PORTOPTIONS.oneofs_by_name['_location_preemption']
_LAG.fields_by_name['ports'].message_type = _LAGPORT
_LAGPORT.fields_by_name['protocol'].message_type = _LAGPROTOCOL
_LAGPORT.fields_by_name['ethernet'].message_type = _DEVICEETHERNETBASE
_LAGPROTOCOL_CHOICE.containing_type = _LAGPROTOCOL
_LAGPROTOCOL_CHOICE_ENUM.containing_type = _LAGPROTOCOL_CHOICE
_LAGPROTOCOL.fields_by_name['choice'].enum_type = _LAGPROTOCOL_CHOICE_ENUM
_LAGPROTOCOL.fields_by_name['lacp'].message_type = _LAGLACP
_LAGPROTOCOL.fields_by_name['static'].message_type = _LAGSTATIC
_LAGPROTOCOL.oneofs_by_name['_choice'].fields.append(
  _LAGPROTOCOL.fields_by_name['choice'])
_LAGPROTOCOL.fields_by_name['choice'].containing_oneof = _LAGPROTOCOL.oneofs_by_name['_choice']
_LAGPROTOCOL.oneofs_by_name['_lacp'].fields.append(
  _LAGPROTOCOL.fields_by_name['lacp'])
_LAGPROTOCOL.fields_by_name['lacp'].containing_oneof = _LAGPROTOCOL.oneofs_by_name['_lacp']
_LAGPROTOCOL.oneofs_by_name['_static'].fields.append(
  _LAGPROTOCOL.fields_by_name['static'])
_LAGPROTOCOL.fields_by_name['static'].containing_oneof = _LAGPROTOCOL.oneofs_by_name['_static']
_LAGSTATIC.oneofs_by_name['_lag_id'].fields.append(
  _LAGSTATIC.fields_by_name['lag_id'])
_LAGSTATIC.fields_by_name['lag_id'].containing_oneof = _LAGSTATIC.oneofs_by_name['_lag_id']
_LAGLACP_ACTORACTIVITY.containing_type = _LAGLACP
_LAGLACP_ACTORACTIVITY_ENUM.containing_type = _LAGLACP_ACTORACTIVITY
_LAGLACP.fields_by_name['actor_activity'].enum_type = _LAGLACP_ACTORACTIVITY_ENUM
_LAGLACP.oneofs_by_name['_actor_key'].fields.append(
  _LAGLACP.fields_by_name['actor_key'])
_LAGLACP.fields_by_name['actor_key'].containing_oneof = _LAGLACP.oneofs_by_name['_actor_key']
_LAGLACP.oneofs_by_name['_actor_port_number'].fields.append(
  _LAGLACP.fields_by_name['actor_port_number'])
_LAGLACP.fields_by_name['actor_port_number'].containing_oneof = _LAGLACP.oneofs_by_name['_actor_port_number']
_LAGLACP.oneofs_by_name['_actor_port_priority'].fields.append(
  _LAGLACP.fields_by_name['actor_port_priority'])
_LAGLACP.fields_by_name['actor_port_priority'].containing_oneof = _LAGLACP.oneofs_by_name['_actor_port_priority']
_LAGLACP.oneofs_by_name['_actor_system_id'].fields.append(
  _LAGLACP.fields_by_name['actor_system_id'])
_LAGLACP.fields_by_name['actor_system_id'].containing_oneof = _LAGLACP.oneofs_by_name['_actor_system_id']
_LAGLACP.oneofs_by_name['_actor_system_priority'].fields.append(
  _LAGLACP.fields_by_name['actor_system_priority'])
_LAGLACP.fields_by_name['actor_system_priority'].containing_oneof = _LAGLACP.oneofs_by_name['_actor_system_priority']
_LAGLACP.oneofs_by_name['_lacpdu_periodic_time_interval'].fields.append(
  _LAGLACP.fields_by_name['lacpdu_periodic_time_interval'])
_LAGLACP.fields_by_name['lacpdu_periodic_time_interval'].containing_oneof = _LAGLACP.oneofs_by_name['_lacpdu_periodic_time_interval']
_LAGLACP.oneofs_by_name['_lacpdu_timeout'].fields.append(
  _LAGLACP.fields_by_name['lacpdu_timeout'])
_LAGLACP.fields_by_name['lacpdu_timeout'].containing_oneof = _LAGLACP.oneofs_by_name['_lacpdu_timeout']
_LAGLACP.oneofs_by_name['_actor_activity'].fields.append(
  _LAGLACP.fields_by_name['actor_activity'])
_LAGLACP.fields_by_name['actor_activity'].containing_oneof = _LAGLACP.oneofs_by_name['_actor_activity']
_DEVICEETHERNETBASE.fields_by_name['vlans'].message_type = _DEVICEVLAN
_DEVICEETHERNETBASE.oneofs_by_name['_mtu'].fields.append(
  _DEVICEETHERNETBASE.fields_by_name['mtu'])
_DEVICEETHERNETBASE.fields_by_name['mtu'].containing_oneof = _DEVICEETHERNETBASE.oneofs_by_name['_mtu']
_DEVICEETHERNET.fields_by_name['ipv4_addresses'].message_type = _DEVICEIPV4
_DEVICEETHERNET.fields_by_name['ipv6_addresses'].message_type = _DEVICEIPV6
_DEVICEETHERNET.fields_by_name['vlans'].message_type = _DEVICEVLAN
_DEVICEETHERNET.oneofs_by_name['_mtu'].fields.append(
  _DEVICEETHERNET.fields_by_name['mtu'])
_DEVICEETHERNET.fields_by_name['mtu'].containing_oneof = _DEVICEETHERNET.oneofs_by_name['_mtu']
_DEVICEVLAN_TPID.containing_type = _DEVICEVLAN
_DEVICEVLAN_TPID_ENUM.containing_type = _DEVICEVLAN_TPID
_DEVICEVLAN.fields_by_name['tpid'].enum_type = _DEVICEVLAN_TPID_ENUM
_DEVICEVLAN.oneofs_by_name['_tpid'].fields.append(
  _DEVICEVLAN.fields_by_name['tpid'])
_DEVICEVLAN.fields_by_name['tpid'].containing_oneof = _DEVICEVLAN.oneofs_by_name['_tpid']
_DEVICEVLAN.oneofs_by_name['_priority'].fields.append(
  _DEVICEVLAN.fields_by_name['priority'])
_DEVICEVLAN.fields_by_name['priority'].containing_oneof = _DEVICEVLAN.oneofs_by_name['_priority']
_DEVICEVLAN.oneofs_by_name['_id'].fields.append(
  _DEVICEVLAN.fields_by_name['id'])
_DEVICEVLAN.fields_by_name['id'].containing_oneof = _DEVICEVLAN.oneofs_by_name['_id']
_DEVICEIPV4.oneofs_by_name['_prefix'].fields.append(
  _DEVICEIPV4.fields_by_name['prefix'])
_DEVICEIPV4.fields_by_name['prefix'].containing_oneof = _DEVICEIPV4.oneofs_by_name['_prefix']
_DEVICEIPV4LOOPBACK.oneofs_by_name['_address'].fields.append(
  _DEVICEIPV4LOOPBACK.fields_by_name['address'])
_DEVICEIPV4LOOPBACK.fields_by_name['address'].containing_oneof = _DEVICEIPV4LOOPBACK.oneofs_by_name['_address']
_DEVICEIPV6.oneofs_by_name['_prefix'].fields.append(
  _DEVICEIPV6.fields_by_name['prefix'])
_DEVICEIPV6.fields_by_name['prefix'].containing_oneof = _DEVICEIPV6.oneofs_by_name['_prefix']
_DEVICEIPV6LOOPBACK.oneofs_by_name['_address'].fields.append(
  _DEVICEIPV6LOOPBACK.fields_by_name['address'])
_DEVICEIPV6LOOPBACK.fields_by_name['address'].containing_oneof = _DEVICEIPV6LOOPBACK.oneofs_by_name['_address']
_LAYER1_SPEED.containing_type = _LAYER1
_LAYER1_SPEED_ENUM.containing_type = _LAYER1_SPEED
_LAYER1_MEDIA.containing_type = _LAYER1
_LAYER1_MEDIA_ENUM.containing_type = _LAYER1_MEDIA
_LAYER1.fields_by_name['speed'].enum_type = _LAYER1_SPEED_ENUM
_LAYER1.fields_by_name['media'].enum_type = _LAYER1_MEDIA_ENUM
_LAYER1.fields_by_name['auto_negotiation'].message_type = _LAYER1AUTONEGOTIATION
_LAYER1.fields_by_name['flow_control'].message_type = _LAYER1FLOWCONTROL
_LAYER1.oneofs_by_name['_speed'].fields.append(
  _LAYER1.fields_by_name['speed'])
_LAYER1.fields_by_name['speed'].containing_oneof = _LAYER1.oneofs_by_name['_speed']
_LAYER1.oneofs_by_name['_media'].fields.append(
  _LAYER1.fields_by_name['media'])
_LAYER1.fields_by_name['media'].containing_oneof = _LAYER1.oneofs_by_name['_media']
_LAYER1.oneofs_by_name['_promiscuous'].fields.append(
  _LAYER1.fields_by_name['promiscuous'])
_LAYER1.fields_by_name['promiscuous'].containing_oneof = _LAYER1.oneofs_by_name['_promiscuous']
_LAYER1.oneofs_by_name['_mtu'].fields.append(
  _LAYER1.fields_by_name['mtu'])
_LAYER1.fields_by_name['mtu'].containing_oneof = _LAYER1.oneofs_by_name['_mtu']
_LAYER1.oneofs_by_name['_ieee_media_defaults'].fields.append(
  _LAYER1.fields_by_name['ieee_media_defaults'])
_LAYER1.fields_by_name['ieee_media_defaults'].containing_oneof = _LAYER1.oneofs_by_name['_ieee_media_defaults']
_LAYER1.oneofs_by_name['_auto_negotiate'].fields.append(
  _LAYER1.fields_by_name['auto_negotiate'])
_LAYER1.fields_by_name['auto_negotiate'].containing_oneof = _LAYER1.oneofs_by_name['_auto_negotiate']
_LAYER1.oneofs_by_name['_auto_negotiation'].fields.append(
  _LAYER1.fields_by_name['auto_negotiation'])
_LAYER1.fields_by_name['auto_negotiation'].containing_oneof = _LAYER1.oneofs_by_name['_auto_negotiation']
_LAYER1.oneofs_by_name['_flow_control'].fields.append(
  _LAYER1.fields_by_name['flow_control'])
_LAYER1.fields_by_name['flow_control'].containing_oneof = _LAYER1.oneofs_by_name['_flow_control']
_LAYER1AUTONEGOTIATION.oneofs_by_name['_advertise_1000_mbps'].fields.append(
  _LAYER1AUTONEGOTIATION.fields_by_name['advertise_1000_mbps'])
_LAYER1AUTONEGOTIATION.fields_by_name['advertise_1000_mbps'].containing_oneof = _LAYER1AUTONEGOTIATION.oneofs_by_name['_advertise_1000_mbps']
_LAYER1AUTONEGOTIATION.oneofs_by_name['_advertise_100_fd_mbps'].fields.append(
  _LAYER1AUTONEGOTIATION.fields_by_name['advertise_100_fd_mbps'])
_LAYER1AUTONEGOTIATION.fields_by_name['advertise_100_fd_mbps'].containing_oneof = _LAYER1AUTONEGOTIATION.oneofs_by_name['_advertise_100_fd_mbps']
_LAYER1AUTONEGOTIATION.oneofs_by_name['_advertise_100_hd_mbps'].fields.append(
  _LAYER1AUTONEGOTIATION.fields_by_name['advertise_100_hd_mbps'])
_LAYER1AUTONEGOTIATION.fields_by_name['advertise_100_hd_mbps'].containing_oneof = _LAYER1AUTONEGOTIATION.oneofs_by_name['_advertise_100_hd_mbps']
_LAYER1AUTONEGOTIATION.oneofs_by_name['_advertise_10_fd_mbps'].fields.append(
  _LAYER1AUTONEGOTIATION.fields_by_name['advertise_10_fd_mbps'])
_LAYER1AUTONEGOTIATION.fields_by_name['advertise_10_fd_mbps'].containing_oneof = _LAYER1AUTONEGOTIATION.oneofs_by_name['_advertise_10_fd_mbps']
_LAYER1AUTONEGOTIATION.oneofs_by_name['_advertise_10_hd_mbps'].fields.append(
  _LAYER1AUTONEGOTIATION.fields_by_name['advertise_10_hd_mbps'])
_LAYER1AUTONEGOTIATION.fields_by_name['advertise_10_hd_mbps'].containing_oneof = _LAYER1AUTONEGOTIATION.oneofs_by_name['_advertise_10_hd_mbps']
_LAYER1AUTONEGOTIATION.oneofs_by_name['_link_training'].fields.append(
  _LAYER1AUTONEGOTIATION.fields_by_name['link_training'])
_LAYER1AUTONEGOTIATION.fields_by_name['link_training'].containing_oneof = _LAYER1AUTONEGOTIATION.oneofs_by_name['_link_training']
_LAYER1AUTONEGOTIATION.oneofs_by_name['_rs_fec'].fields.append(
  _LAYER1AUTONEGOTIATION.fields_by_name['rs_fec'])
_LAYER1AUTONEGOTIATION.fields_by_name['rs_fec'].containing_oneof = _LAYER1AUTONEGOTIATION.oneofs_by_name['_rs_fec']
_LAYER1FLOWCONTROL_CHOICE.containing_type = _LAYER1FLOWCONTROL
_LAYER1FLOWCONTROL_CHOICE_ENUM.containing_type = _LAYER1FLOWCONTROL_CHOICE
_LAYER1FLOWCONTROL.fields_by_name['choice'].enum_type = _LAYER1FLOWCONTROL_CHOICE_ENUM
_LAYER1FLOWCONTROL.fields_by_name['ieee_802_1qbb'].message_type = _LAYER1IEEE8021QBB
_LAYER1FLOWCONTROL.fields_by_name['ieee_802_3x'].message_type = _LAYER1IEEE8023X
_LAYER1FLOWCONTROL.oneofs_by_name['_directed_address'].fields.append(
  _LAYER1FLOWCONTROL.fields_by_name['directed_address'])
_LAYER1FLOWCONTROL.fields_by_name['directed_address'].containing_oneof = _LAYER1FLOWCONTROL.oneofs_by_name['_directed_address']
_LAYER1FLOWCONTROL.oneofs_by_name['_choice'].fields.append(
  _LAYER1FLOWCONTROL.fields_by_name['choice'])
_LAYER1FLOWCONTROL.fields_by_name['choice'].containing_oneof = _LAYER1FLOWCONTROL.oneofs_by_name['_choice']
_LAYER1FLOWCONTROL.oneofs_by_name['_ieee_802_1qbb'].fields.append(
  _LAYER1FLOWCONTROL.fields_by_name['ieee_802_1qbb'])
_LAYER1FLOWCONTROL.fields_by_name['ieee_802_1qbb'].containing_oneof = _LAYER1FLOWCONTROL.oneofs_by_name['_ieee_802_1qbb']
_LAYER1FLOWCONTROL.oneofs_by_name['_ieee_802_3x'].fields.append(
  _LAYER1FLOWCONTROL.fields_by_name['ieee_802_3x'])
_LAYER1FLOWCONTROL.fields_by_name['ieee_802_3x'].containing_oneof = _LAYER1FLOWCONTROL.oneofs_by_name['_ieee_802_3x']
_LAYER1IEEE8021QBB.oneofs_by_name['_pfc_delay'].fields.append(
  _LAYER1IEEE8021QBB.fields_by_name['pfc_delay'])
_LAYER1IEEE8021QBB.fields_by_name['pfc_delay'].containing_oneof = _LAYER1IEEE8021QBB.oneofs_by_name['_pfc_delay']
_LAYER1IEEE8021QBB.oneofs_by_name['_pfc_class_0'].fields.append(
  _LAYER1IEEE8021QBB.fields_by_name['pfc_class_0'])
_LAYER1IEEE8021QBB.fields_by_name['pfc_class_0'].containing_oneof = _LAYER1IEEE8021QBB.oneofs_by_name['_pfc_class_0']
_LAYER1IEEE8021QBB.oneofs_by_name['_pfc_class_1'].fields.append(
  _LAYER1IEEE8021QBB.fields_by_name['pfc_class_1'])
_LAYER1IEEE8021QBB.fields_by_name['pfc_class_1'].containing_oneof = _LAYER1IEEE8021QBB.oneofs_by_name['_pfc_class_1']
_LAYER1IEEE8021QBB.oneofs_by_name['_pfc_class_2'].fields.append(
  _LAYER1IEEE8021QBB.fields_by_name['pfc_class_2'])
_LAYER1IEEE8021QBB.fields_by_name['pfc_class_2'].containing_oneof = _LAYER1IEEE8021QBB.oneofs_by_name['_pfc_class_2']
_LAYER1IEEE8021QBB.oneofs_by_name['_pfc_class_3'].fields.append(
  _LAYER1IEEE8021QBB.fields_by_name['pfc_class_3'])
_LAYER1IEEE8021QBB.fields_by_name['pfc_class_3'].containing_oneof = _LAYER1IEEE8021QBB.oneofs_by_name['_pfc_class_3']
_LAYER1IEEE8021QBB.oneofs_by_name['_pfc_class_4'].fields.append(
  _LAYER1IEEE8021QBB.fields_by_name['pfc_class_4'])
_LAYER1IEEE8021QBB.fields_by_name['pfc_class_4'].containing_oneof = _LAYER1IEEE8021QBB.oneofs_by_name['_pfc_class_4']
_LAYER1IEEE8021QBB.oneofs_by_name['_pfc_class_5'].fields.append(
  _LAYER1IEEE8021QBB.fields_by_name['pfc_class_5'])
_LAYER1IEEE8021QBB.fields_by_name['pfc_class_5'].containing_oneof = _LAYER1IEEE8021QBB.oneofs_by_name['_pfc_class_5']
_LAYER1IEEE8021QBB.oneofs_by_name['_pfc_class_6'].fields.append(
  _LAYER1IEEE8021QBB.fields_by_name['pfc_class_6'])
_LAYER1IEEE8021QBB.fields_by_name['pfc_class_6'].containing_oneof = _LAYER1IEEE8021QBB.oneofs_by_name['_pfc_class_6']
_LAYER1IEEE8021QBB.oneofs_by_name['_pfc_class_7'].fields.append(
  _LAYER1IEEE8021QBB.fields_by_name['pfc_class_7'])
_LAYER1IEEE8021QBB.fields_by_name['pfc_class_7'].containing_oneof = _LAYER1IEEE8021QBB.oneofs_by_name['_pfc_class_7']
_CAPTURE_FORMAT.containing_type = _CAPTURE
_CAPTURE_FORMAT_ENUM.containing_type = _CAPTURE_FORMAT
_CAPTURE.fields_by_name['filters'].message_type = _CAPTUREFILTER
_CAPTURE.fields_by_name['format'].enum_type = _CAPTURE_FORMAT_ENUM
_CAPTURE.oneofs_by_name['_overwrite'].fields.append(
  _CAPTURE.fields_by_name['overwrite'])
_CAPTURE.fields_by_name['overwrite'].containing_oneof = _CAPTURE.oneofs_by_name['_overwrite']
_CAPTURE.oneofs_by_name['_packet_size'].fields.append(
  _CAPTURE.fields_by_name['packet_size'])
_CAPTURE.fields_by_name['packet_size'].containing_oneof = _CAPTURE.oneofs_by_name['_packet_size']
_CAPTURE.oneofs_by_name['_format'].fields.append(
  _CAPTURE.fields_by_name['format'])
_CAPTURE.fields_by_name['format'].containing_oneof = _CAPTURE.oneofs_by_name['_format']
_CAPTUREFILTER_CHOICE.containing_type = _CAPTUREFILTER
_CAPTUREFILTER_CHOICE_ENUM.containing_type = _CAPTUREFILTER_CHOICE
_CAPTUREFILTER.fields_by_name['choice'].enum_type = _CAPTUREFILTER_CHOICE_ENUM
_CAPTUREFILTER.fields_by_name['custom'].message_type = _CAPTURECUSTOM
_CAPTUREFILTER.fields_by_name['ethernet'].message_type = _CAPTUREETHERNET
_CAPTUREFILTER.fields_by_name['vlan'].message_type = _CAPTUREVLAN
_CAPTUREFILTER.fields_by_name['ipv4'].message_type = _CAPTUREIPV4
_CAPTUREFILTER.fields_by_name['ipv6'].message_type = _CAPTUREIPV6
_CAPTUREFILTER.oneofs_by_name['_choice'].fields.append(
  _CAPTUREFILTER.fields_by_name['choice'])
_CAPTUREFILTER.fields_by_name['choice'].containing_oneof = _CAPTUREFILTER.oneofs_by_name['_choice']
_CAPTUREFILTER.oneofs_by_name['_custom'].fields.append(
  _CAPTUREFILTER.fields_by_name['custom'])
_CAPTUREFILTER.fields_by_name['custom'].containing_oneof = _CAPTUREFILTER.oneofs_by_name['_custom']
_CAPTUREFILTER.oneofs_by_name['_ethernet'].fields.append(
  _CAPTUREFILTER.fields_by_name['ethernet'])
_CAPTUREFILTER.fields_by_name['ethernet'].containing_oneof = _CAPTUREFILTER.oneofs_by_name['_ethernet']
_CAPTUREFILTER.oneofs_by_name['_vlan'].fields.append(
  _CAPTUREFILTER.fields_by_name['vlan'])
_CAPTUREFILTER.fields_by_name['vlan'].containing_oneof = _CAPTUREFILTER.oneofs_by_name['_vlan']
_CAPTUREFILTER.oneofs_by_name['_ipv4'].fields.append(
  _CAPTUREFILTER.fields_by_name['ipv4'])
_CAPTUREFILTER.fields_by_name['ipv4'].containing_oneof = _CAPTUREFILTER.oneofs_by_name['_ipv4']
_CAPTUREFILTER.oneofs_by_name['_ipv6'].fields.append(
  _CAPTUREFILTER.fields_by_name['ipv6'])
_CAPTUREFILTER.fields_by_name['ipv6'].containing_oneof = _CAPTUREFILTER.oneofs_by_name['_ipv6']
_CAPTURECUSTOM.oneofs_by_name['_offset'].fields.append(
  _CAPTURECUSTOM.fields_by_name['offset'])
_CAPTURECUSTOM.fields_by_name['offset'].containing_oneof = _CAPTURECUSTOM.oneofs_by_name['_offset']
_CAPTURECUSTOM.oneofs_by_name['_bit_length'].fields.append(
  _CAPTURECUSTOM.fields_by_name['bit_length'])
_CAPTURECUSTOM.fields_by_name['bit_length'].containing_oneof = _CAPTURECUSTOM.oneofs_by_name['_bit_length']
_CAPTURECUSTOM.oneofs_by_name['_value'].fields.append(
  _CAPTURECUSTOM.fields_by_name['value'])
_CAPTURECUSTOM.fields_by_name['value'].containing_oneof = _CAPTURECUSTOM.oneofs_by_name['_value']
_CAPTURECUSTOM.oneofs_by_name['_mask'].fields.append(
  _CAPTURECUSTOM.fields_by_name['mask'])
_CAPTURECUSTOM.fields_by_name['mask'].containing_oneof = _CAPTURECUSTOM.oneofs_by_name['_mask']
_CAPTURECUSTOM.oneofs_by_name['_negate'].fields.append(
  _CAPTURECUSTOM.fields_by_name['negate'])
_CAPTURECUSTOM.fields_by_name['negate'].containing_oneof = _CAPTURECUSTOM.oneofs_by_name['_negate']
_CAPTUREFIELD.oneofs_by_name['_value'].fields.append(
  _CAPTUREFIELD.fields_by_name['value'])
_CAPTUREFIELD.fields_by_name['value'].containing_oneof = _CAPTUREFIELD.oneofs_by_name['_value']
_CAPTUREFIELD.oneofs_by_name['_mask'].fields.append(
  _CAPTUREFIELD.fields_by_name['mask'])
_CAPTUREFIELD.fields_by_name['mask'].containing_oneof = _CAPTUREFIELD.oneofs_by_name['_mask']
_CAPTUREFIELD.oneofs_by_name['_negate'].fields.append(
  _CAPTUREFIELD.fields_by_name['negate'])
_CAPTUREFIELD.fields_by_name['negate'].containing_oneof = _CAPTUREFIELD.oneofs_by_name['_negate']
_CAPTUREETHERNET.fields_by_name['src'].message_type = _CAPTUREFIELD
_CAPTUREETHERNET.fields_by_name['dst'].message_type = _CAPTUREFIELD
_CAPTUREETHERNET.fields_by_name['ether_type'].message_type = _CAPTUREFIELD
_CAPTUREETHERNET.fields_by_name['pfc_queue'].message_type = _CAPTUREFIELD
_CAPTUREETHERNET.oneofs_by_name['_src'].fields.append(
  _CAPTUREETHERNET.fields_by_name['src'])
_CAPTUREETHERNET.fields_by_name['src'].containing_oneof = _CAPTUREETHERNET.oneofs_by_name['_src']
_CAPTUREETHERNET.oneofs_by_name['_dst'].fields.append(
  _CAPTUREETHERNET.fields_by_name['dst'])
_CAPTUREETHERNET.fields_by_name['dst'].containing_oneof = _CAPTUREETHERNET.oneofs_by_name['_dst']
_CAPTUREETHERNET.oneofs_by_name['_ether_type'].fields.append(
  _CAPTUREETHERNET.fields_by_name['ether_type'])
_CAPTUREETHERNET.fields_by_name['ether_type'].containing_oneof = _CAPTUREETHERNET.oneofs_by_name['_ether_type']
_CAPTUREETHERNET.oneofs_by_name['_pfc_queue'].fields.append(
  _CAPTUREETHERNET.fields_by_name['pfc_queue'])
_CAPTUREETHERNET.fields_by_name['pfc_queue'].containing_oneof = _CAPTUREETHERNET.oneofs_by_name['_pfc_queue']
_CAPTUREVLAN.fields_by_name['priority'].message_type = _CAPTUREFIELD
_CAPTUREVLAN.fields_by_name['cfi'].message_type = _CAPTUREFIELD
_CAPTUREVLAN.fields_by_name['id'].message_type = _CAPTUREFIELD
_CAPTUREVLAN.fields_by_name['protocol'].message_type = _CAPTUREFIELD
_CAPTUREVLAN.oneofs_by_name['_priority'].fields.append(
  _CAPTUREVLAN.fields_by_name['priority'])
_CAPTUREVLAN.fields_by_name['priority'].containing_oneof = _CAPTUREVLAN.oneofs_by_name['_priority']
_CAPTUREVLAN.oneofs_by_name['_cfi'].fields.append(
  _CAPTUREVLAN.fields_by_name['cfi'])
_CAPTUREVLAN.fields_by_name['cfi'].containing_oneof = _CAPTUREVLAN.oneofs_by_name['_cfi']
_CAPTUREVLAN.oneofs_by_name['_id'].fields.append(
  _CAPTUREVLAN.fields_by_name['id'])
_CAPTUREVLAN.fields_by_name['id'].containing_oneof = _CAPTUREVLAN.oneofs_by_name['_id']
_CAPTUREVLAN.oneofs_by_name['_protocol'].fields.append(
  _CAPTUREVLAN.fields_by_name['protocol'])
_CAPTUREVLAN.fields_by_name['protocol'].containing_oneof = _CAPTUREVLAN.oneofs_by_name['_protocol']
_CAPTUREIPV4.fields_by_name['version'].message_type = _CAPTUREFIELD
_CAPTUREIPV4.fields_by_name['header_length'].message_type = _CAPTUREFIELD
_CAPTUREIPV4.fields_by_name['priority'].message_type = _CAPTUREFIELD
_CAPTUREIPV4.fields_by_name['total_length'].message_type = _CAPTUREFIELD
_CAPTUREIPV4.fields_by_name['identification'].message_type = _CAPTUREFIELD
_CAPTUREIPV4.fields_by_name['reserved'].message_type = _CAPTUREFIELD
_CAPTUREIPV4.fields_by_name['dont_fragment'].message_type = _CAPTUREFIELD
_CAPTUREIPV4.fields_by_name['more_fragments'].message_type = _CAPTUREFIELD
_CAPTUREIPV4.fields_by_name['fragment_offset'].message_type = _CAPTUREFIELD
_CAPTUREIPV4.fields_by_name['time_to_live'].message_type = _CAPTUREFIELD
_CAPTUREIPV4.fields_by_name['protocol'].message_type = _CAPTUREFIELD
_CAPTUREIPV4.fields_by_name['header_checksum'].message_type = _CAPTUREFIELD
_CAPTUREIPV4.fields_by_name['src'].message_type = _CAPTUREFIELD
_CAPTUREIPV4.fields_by_name['dst'].message_type = _CAPTUREFIELD
_CAPTUREIPV4.oneofs_by_name['_version'].fields.append(
  _CAPTUREIPV4.fields_by_name['version'])
_CAPTUREIPV4.fields_by_name['version'].containing_oneof = _CAPTUREIPV4.oneofs_by_name['_version']
_CAPTUREIPV4.oneofs_by_name['_header_length'].fields.append(
  _CAPTUREIPV4.fields_by_name['header_length'])
_CAPTUREIPV4.fields_by_name['header_length'].containing_oneof = _CAPTUREIPV4.oneofs_by_name['_header_length']
_CAPTUREIPV4.oneofs_by_name['_priority'].fields.append(
  _CAPTUREIPV4.fields_by_name['priority'])
_CAPTUREIPV4.fields_by_name['priority'].containing_oneof = _CAPTUREIPV4.oneofs_by_name['_priority']
_CAPTUREIPV4.oneofs_by_name['_total_length'].fields.append(
  _CAPTUREIPV4.fields_by_name['total_length'])
_CAPTUREIPV4.fields_by_name['total_length'].containing_oneof = _CAPTUREIPV4.oneofs_by_name['_total_length']
_CAPTUREIPV4.oneofs_by_name['_identification'].fields.append(
  _CAPTUREIPV4.fields_by_name['identification'])
_CAPTUREIPV4.fields_by_name['identification'].containing_oneof = _CAPTUREIPV4.oneofs_by_name['_identification']
_CAPTUREIPV4.oneofs_by_name['_reserved'].fields.append(
  _CAPTUREIPV4.fields_by_name['reserved'])
_CAPTUREIPV4.fields_by_name['reserved'].containing_oneof = _CAPTUREIPV4.oneofs_by_name['_reserved']
_CAPTUREIPV4.oneofs_by_name['_dont_fragment'].fields.append(
  _CAPTUREIPV4.fields_by_name['dont_fragment'])
_CAPTUREIPV4.fields_by_name['dont_fragment'].containing_oneof = _CAPTUREIPV4.oneofs_by_name['_dont_fragment']
_CAPTUREIPV4.oneofs_by_name['_more_fragments'].fields.append(
  _CAPTUREIPV4.fields_by_name['more_fragments'])
_CAPTUREIPV4.fields_by_name['more_fragments'].containing_oneof = _CAPTUREIPV4.oneofs_by_name['_more_fragments']
_CAPTUREIPV4.oneofs_by_name['_fragment_offset'].fields.append(
  _CAPTUREIPV4.fields_by_name['fragment_offset'])
_CAPTUREIPV4.fields_by_name['fragment_offset'].containing_oneof = _CAPTUREIPV4.oneofs_by_name['_fragment_offset']
_CAPTUREIPV4.oneofs_by_name['_time_to_live'].fields.append(
  _CAPTUREIPV4.fields_by_name['time_to_live'])
_CAPTUREIPV4.fields_by_name['time_to_live'].containing_oneof = _CAPTUREIPV4.oneofs_by_name['_time_to_live']
_CAPTUREIPV4.oneofs_by_name['_protocol'].fields.append(
  _CAPTUREIPV4.fields_by_name['protocol'])
_CAPTUREIPV4.fields_by_name['protocol'].containing_oneof = _CAPTUREIPV4.oneofs_by_name['_protocol']
_CAPTUREIPV4.oneofs_by_name['_header_checksum'].fields.append(
  _CAPTUREIPV4.fields_by_name['header_checksum'])
_CAPTUREIPV4.fields_by_name['header_checksum'].containing_oneof = _CAPTUREIPV4.oneofs_by_name['_header_checksum']
_CAPTUREIPV4.oneofs_by_name['_src'].fields.append(
  _CAPTUREIPV4.fields_by_name['src'])
_CAPTUREIPV4.fields_by_name['src'].containing_oneof = _CAPTUREIPV4.oneofs_by_name['_src']
_CAPTUREIPV4.oneofs_by_name['_dst'].fields.append(
  _CAPTUREIPV4.fields_by_name['dst'])
_CAPTUREIPV4.fields_by_name['dst'].containing_oneof = _CAPTUREIPV4.oneofs_by_name['_dst']
_CAPTUREIPV6.fields_by_name['version'].message_type = _CAPTUREFIELD
_CAPTUREIPV6.fields_by_name['traffic_class'].message_type = _CAPTUREFIELD
_CAPTUREIPV6.fields_by_name['flow_label'].message_type = _CAPTUREFIELD
_CAPTUREIPV6.fields_by_name['payload_length'].message_type = _CAPTUREFIELD
_CAPTUREIPV6.fields_by_name['next_header'].message_type = _CAPTUREFIELD
_CAPTUREIPV6.fields_by_name['hop_limit'].message_type = _CAPTUREFIELD
_CAPTUREIPV6.fields_by_name['src'].message_type = _CAPTUREFIELD
_CAPTUREIPV6.fields_by_name['dst'].message_type = _CAPTUREFIELD
_CAPTUREIPV6.oneofs_by_name['_version'].fields.append(
  _CAPTUREIPV6.fields_by_name['version'])
_CAPTUREIPV6.fields_by_name['version'].containing_oneof = _CAPTUREIPV6.oneofs_by_name['_version']
_CAPTUREIPV6.oneofs_by_name['_traffic_class'].fields.append(
  _CAPTUREIPV6.fields_by_name['traffic_class'])
_CAPTUREIPV6.fields_by_name['traffic_class'].containing_oneof = _CAPTUREIPV6.oneofs_by_name['_traffic_class']
_CAPTUREIPV6.oneofs_by_name['_flow_label'].fields.append(
  _CAPTUREIPV6.fields_by_name['flow_label'])
_CAPTUREIPV6.fields_by_name['flow_label'].containing_oneof = _CAPTUREIPV6.oneofs_by_name['_flow_label']
_CAPTUREIPV6.oneofs_by_name['_payload_length'].fields.append(
  _CAPTUREIPV6.fields_by_name['payload_length'])
_CAPTUREIPV6.fields_by_name['payload_length'].containing_oneof = _CAPTUREIPV6.oneofs_by_name['_payload_length']
_CAPTUREIPV6.oneofs_by_name['_next_header'].fields.append(
  _CAPTUREIPV6.fields_by_name['next_header'])
_CAPTUREIPV6.fields_by_name['next_header'].containing_oneof = _CAPTUREIPV6.oneofs_by_name['_next_header']
_CAPTUREIPV6.oneofs_by_name['_hop_limit'].fields.append(
  _CAPTUREIPV6.fields_by_name['hop_limit'])
_CAPTUREIPV6.fields_by_name['hop_limit'].containing_oneof = _CAPTUREIPV6.oneofs_by_name['_hop_limit']
_CAPTUREIPV6.oneofs_by_name['_src'].fields.append(
  _CAPTUREIPV6.fields_by_name['src'])
_CAPTUREIPV6.fields_by_name['src'].containing_oneof = _CAPTUREIPV6.oneofs_by_name['_src']
_CAPTUREIPV6.oneofs_by_name['_dst'].fields.append(
  _CAPTUREIPV6.fields_by_name['dst'])
_CAPTUREIPV6.fields_by_name['dst'].containing_oneof = _CAPTUREIPV6.oneofs_by_name['_dst']
_DEVICE.fields_by_name['ethernets'].message_type = _DEVICEETHERNET
_DEVICE.fields_by_name['ipv4_loopbacks'].message_type = _DEVICEIPV4LOOPBACK
_DEVICE.fields_by_name['ipv6_loopbacks'].message_type = _DEVICEIPV6LOOPBACK
_DEVICE.fields_by_name['isis'].message_type = _DEVICEISISROUTER
_DEVICE.fields_by_name['bgp'].message_type = _DEVICEBGPROUTER
_DEVICE.oneofs_by_name['_isis'].fields.append(
  _DEVICE.fields_by_name['isis'])
_DEVICE.fields_by_name['isis'].containing_oneof = _DEVICE.oneofs_by_name['_isis']
_DEVICE.oneofs_by_name['_bgp'].fields.append(
  _DEVICE.fields_by_name['bgp'])
_DEVICE.fields_by_name['bgp'].containing_oneof = _DEVICE.oneofs_by_name['_bgp']
_DEVICEISISROUTER.fields_by_name['instance'].message_type = _DEVICEISISMULTIINSTANCE
_DEVICEISISROUTER.fields_by_name['interfaces'].message_type = _ISISINTERFACE
_DEVICEISISROUTER.fields_by_name['basic'].message_type = _ISISBASIC
_DEVICEISISROUTER.fields_by_name['advanced'].message_type = _ISISADVANCED
_DEVICEISISROUTER.fields_by_name['router_auth'].message_type = _ISISAUTHENTICATION
_DEVICEISISROUTER.fields_by_name['v4_routes'].message_type = _ISISV4ROUTERANGE
_DEVICEISISROUTER.fields_by_name['v6_routes'].message_type = _ISISV6ROUTERANGE
_DEVICEISISROUTER.oneofs_by_name['_instance'].fields.append(
  _DEVICEISISROUTER.fields_by_name['instance'])
_DEVICEISISROUTER.fields_by_name['instance'].containing_oneof = _DEVICEISISROUTER.oneofs_by_name['_instance']
_DEVICEISISROUTER.oneofs_by_name['_basic'].fields.append(
  _DEVICEISISROUTER.fields_by_name['basic'])
_DEVICEISISROUTER.fields_by_name['basic'].containing_oneof = _DEVICEISISROUTER.oneofs_by_name['_basic']
_DEVICEISISROUTER.oneofs_by_name['_advanced'].fields.append(
  _DEVICEISISROUTER.fields_by_name['advanced'])
_DEVICEISISROUTER.fields_by_name['advanced'].containing_oneof = _DEVICEISISROUTER.oneofs_by_name['_advanced']
_DEVICEISISROUTER.oneofs_by_name['_router_auth'].fields.append(
  _DEVICEISISROUTER.fields_by_name['router_auth'])
_DEVICEISISROUTER.fields_by_name['router_auth'].containing_oneof = _DEVICEISISROUTER.oneofs_by_name['_router_auth']
_DEVICEISISMULTIINSTANCE.oneofs_by_name['_iid'].fields.append(
  _DEVICEISISMULTIINSTANCE.fields_by_name['iid'])
_DEVICEISISMULTIINSTANCE.fields_by_name['iid'].containing_oneof = _DEVICEISISMULTIINSTANCE.oneofs_by_name['_iid']
_ISISINTERFACE_NETWORKTYPE.containing_type = _ISISINTERFACE
_ISISINTERFACE_NETWORKTYPE_ENUM.containing_type = _ISISINTERFACE_NETWORKTYPE
_ISISINTERFACE_LEVELTYPE.containing_type = _ISISINTERFACE
_ISISINTERFACE_LEVELTYPE_ENUM.containing_type = _ISISINTERFACE_LEVELTYPE
_ISISINTERFACE.fields_by_name['network_type'].enum_type = _ISISINTERFACE_NETWORKTYPE_ENUM
_ISISINTERFACE.fields_by_name['level_type'].enum_type = _ISISINTERFACE_LEVELTYPE_ENUM
_ISISINTERFACE.fields_by_name['l1_settings'].message_type = _ISISINTERFACELEVEL
_ISISINTERFACE.fields_by_name['l2_settings'].message_type = _ISISINTERFACELEVEL
_ISISINTERFACE.fields_by_name['multi_topology_ids'].message_type = _ISISMT
_ISISINTERFACE.fields_by_name['traffic_engineering'].message_type = _LINKSTATETE
_ISISINTERFACE.fields_by_name['authentication'].message_type = _ISISINTERFACEAUTHENTICATION
_ISISINTERFACE.fields_by_name['advanced'].message_type = _ISISINTERFACEADVANCED
_ISISINTERFACE.fields_by_name['link_protection'].message_type = _ISISINTERFACELINKPROTECTION
_ISISINTERFACE.oneofs_by_name['_metric'].fields.append(
  _ISISINTERFACE.fields_by_name['metric'])
_ISISINTERFACE.fields_by_name['metric'].containing_oneof = _ISISINTERFACE.oneofs_by_name['_metric']
_ISISINTERFACE.oneofs_by_name['_network_type'].fields.append(
  _ISISINTERFACE.fields_by_name['network_type'])
_ISISINTERFACE.fields_by_name['network_type'].containing_oneof = _ISISINTERFACE.oneofs_by_name['_network_type']
_ISISINTERFACE.oneofs_by_name['_level_type'].fields.append(
  _ISISINTERFACE.fields_by_name['level_type'])
_ISISINTERFACE.fields_by_name['level_type'].containing_oneof = _ISISINTERFACE.oneofs_by_name['_level_type']
_ISISINTERFACE.oneofs_by_name['_l1_settings'].fields.append(
  _ISISINTERFACE.fields_by_name['l1_settings'])
_ISISINTERFACE.fields_by_name['l1_settings'].containing_oneof = _ISISINTERFACE.oneofs_by_name['_l1_settings']
_ISISINTERFACE.oneofs_by_name['_l2_settings'].fields.append(
  _ISISINTERFACE.fields_by_name['l2_settings'])
_ISISINTERFACE.fields_by_name['l2_settings'].containing_oneof = _ISISINTERFACE.oneofs_by_name['_l2_settings']
_ISISINTERFACE.oneofs_by_name['_authentication'].fields.append(
  _ISISINTERFACE.fields_by_name['authentication'])
_ISISINTERFACE.fields_by_name['authentication'].containing_oneof = _ISISINTERFACE.oneofs_by_name['_authentication']
_ISISINTERFACE.oneofs_by_name['_advanced'].fields.append(
  _ISISINTERFACE.fields_by_name['advanced'])
_ISISINTERFACE.fields_by_name['advanced'].containing_oneof = _ISISINTERFACE.oneofs_by_name['_advanced']
_ISISINTERFACE.oneofs_by_name['_link_protection'].fields.append(
  _ISISINTERFACE.fields_by_name['link_protection'])
_ISISINTERFACE.fields_by_name['link_protection'].containing_oneof = _ISISINTERFACE.oneofs_by_name['_link_protection']
_ISISINTERFACELEVEL.oneofs_by_name['_priority'].fields.append(
  _ISISINTERFACELEVEL.fields_by_name['priority'])
_ISISINTERFACELEVEL.fields_by_name['priority'].containing_oneof = _ISISINTERFACELEVEL.oneofs_by_name['_priority']
_ISISINTERFACELEVEL.oneofs_by_name['_hello_interval'].fields.append(
  _ISISINTERFACELEVEL.fields_by_name['hello_interval'])
_ISISINTERFACELEVEL.fields_by_name['hello_interval'].containing_oneof = _ISISINTERFACELEVEL.oneofs_by_name['_hello_interval']
_ISISINTERFACELEVEL.oneofs_by_name['_dead_interval'].fields.append(
  _ISISINTERFACELEVEL.fields_by_name['dead_interval'])
_ISISINTERFACELEVEL.fields_by_name['dead_interval'].containing_oneof = _ISISINTERFACELEVEL.oneofs_by_name['_dead_interval']
_ISISMT.oneofs_by_name['_mt_id'].fields.append(
  _ISISMT.fields_by_name['mt_id'])
_ISISMT.fields_by_name['mt_id'].containing_oneof = _ISISMT.oneofs_by_name['_mt_id']
_ISISMT.oneofs_by_name['_link_metric'].fields.append(
  _ISISMT.fields_by_name['link_metric'])
_ISISMT.fields_by_name['link_metric'].containing_oneof = _ISISMT.oneofs_by_name['_link_metric']
_LINKSTATETE.fields_by_name['priority_bandwidths'].message_type = _LINKSTATEPRIORITYBANDWIDTHS
_LINKSTATETE.oneofs_by_name['_administrative_group'].fields.append(
  _LINKSTATETE.fields_by_name['administrative_group'])
_LINKSTATETE.fields_by_name['administrative_group'].containing_oneof = _LINKSTATETE.oneofs_by_name['_administrative_group']
_LINKSTATETE.oneofs_by_name['_metric_level'].fields.append(
  _LINKSTATETE.fields_by_name['metric_level'])
_LINKSTATETE.fields_by_name['metric_level'].containing_oneof = _LINKSTATETE.oneofs_by_name['_metric_level']
_LINKSTATETE.oneofs_by_name['_max_bandwith'].fields.append(
  _LINKSTATETE.fields_by_name['max_bandwith'])
_LINKSTATETE.fields_by_name['max_bandwith'].containing_oneof = _LINKSTATETE.oneofs_by_name['_max_bandwith']
_LINKSTATETE.oneofs_by_name['_max_reservable_bandwidth'].fields.append(
  _LINKSTATETE.fields_by_name['max_reservable_bandwidth'])
_LINKSTATETE.fields_by_name['max_reservable_bandwidth'].containing_oneof = _LINKSTATETE.oneofs_by_name['_max_reservable_bandwidth']
_LINKSTATETE.oneofs_by_name['_priority_bandwidths'].fields.append(
  _LINKSTATETE.fields_by_name['priority_bandwidths'])
_LINKSTATETE.fields_by_name['priority_bandwidths'].containing_oneof = _LINKSTATETE.oneofs_by_name['_priority_bandwidths']
_LINKSTATEPRIORITYBANDWIDTHS.oneofs_by_name['_pb0'].fields.append(
  _LINKSTATEPRIORITYBANDWIDTHS.fields_by_name['pb0'])
_LINKSTATEPRIORITYBANDWIDTHS.fields_by_name['pb0'].containing_oneof = _LINKSTATEPRIORITYBANDWIDTHS.oneofs_by_name['_pb0']
_LINKSTATEPRIORITYBANDWIDTHS.oneofs_by_name['_pb1'].fields.append(
  _LINKSTATEPRIORITYBANDWIDTHS.fields_by_name['pb1'])
_LINKSTATEPRIORITYBANDWIDTHS.fields_by_name['pb1'].containing_oneof = _LINKSTATEPRIORITYBANDWIDTHS.oneofs_by_name['_pb1']
_LINKSTATEPRIORITYBANDWIDTHS.oneofs_by_name['_pb2'].fields.append(
  _LINKSTATEPRIORITYBANDWIDTHS.fields_by_name['pb2'])
_LINKSTATEPRIORITYBANDWIDTHS.fields_by_name['pb2'].containing_oneof = _LINKSTATEPRIORITYBANDWIDTHS.oneofs_by_name['_pb2']
_LINKSTATEPRIORITYBANDWIDTHS.oneofs_by_name['_pb3'].fields.append(
  _LINKSTATEPRIORITYBANDWIDTHS.fields_by_name['pb3'])
_LINKSTATEPRIORITYBANDWIDTHS.fields_by_name['pb3'].containing_oneof = _LINKSTATEPRIORITYBANDWIDTHS.oneofs_by_name['_pb3']
_LINKSTATEPRIORITYBANDWIDTHS.oneofs_by_name['_pb4'].fields.append(
  _LINKSTATEPRIORITYBANDWIDTHS.fields_by_name['pb4'])
_LINKSTATEPRIORITYBANDWIDTHS.fields_by_name['pb4'].containing_oneof = _LINKSTATEPRIORITYBANDWIDTHS.oneofs_by_name['_pb4']
_LINKSTATEPRIORITYBANDWIDTHS.oneofs_by_name['_pb5'].fields.append(
  _LINKSTATEPRIORITYBANDWIDTHS.fields_by_name['pb5'])
_LINKSTATEPRIORITYBANDWIDTHS.fields_by_name['pb5'].containing_oneof = _LINKSTATEPRIORITYBANDWIDTHS.oneofs_by_name['_pb5']
_LINKSTATEPRIORITYBANDWIDTHS.oneofs_by_name['_pb6'].fields.append(
  _LINKSTATEPRIORITYBANDWIDTHS.fields_by_name['pb6'])
_LINKSTATEPRIORITYBANDWIDTHS.fields_by_name['pb6'].containing_oneof = _LINKSTATEPRIORITYBANDWIDTHS.oneofs_by_name['_pb6']
_LINKSTATEPRIORITYBANDWIDTHS.oneofs_by_name['_pb7'].fields.append(
  _LINKSTATEPRIORITYBANDWIDTHS.fields_by_name['pb7'])
_LINKSTATEPRIORITYBANDWIDTHS.fields_by_name['pb7'].containing_oneof = _LINKSTATEPRIORITYBANDWIDTHS.oneofs_by_name['_pb7']
_ISISINTERFACEAUTHENTICATION_AUTHTYPE.containing_type = _ISISINTERFACEAUTHENTICATION
_ISISINTERFACEAUTHENTICATION_AUTHTYPE_ENUM.containing_type = _ISISINTERFACEAUTHENTICATION_AUTHTYPE
_ISISINTERFACEAUTHENTICATION.fields_by_name['auth_type'].enum_type = _ISISINTERFACEAUTHENTICATION_AUTHTYPE_ENUM
_ISISINTERFACEAUTHENTICATION.oneofs_by_name['_md5'].fields.append(
  _ISISINTERFACEAUTHENTICATION.fields_by_name['md5'])
_ISISINTERFACEAUTHENTICATION.fields_by_name['md5'].containing_oneof = _ISISINTERFACEAUTHENTICATION.oneofs_by_name['_md5']
_ISISINTERFACEAUTHENTICATION.oneofs_by_name['_password'].fields.append(
  _ISISINTERFACEAUTHENTICATION.fields_by_name['password'])
_ISISINTERFACEAUTHENTICATION.fields_by_name['password'].containing_oneof = _ISISINTERFACEAUTHENTICATION.oneofs_by_name['_password']
_ISISINTERFACEADVANCED.oneofs_by_name['_auto_adjust_mtu'].fields.append(
  _ISISINTERFACEADVANCED.fields_by_name['auto_adjust_mtu'])
_ISISINTERFACEADVANCED.fields_by_name['auto_adjust_mtu'].containing_oneof = _ISISINTERFACEADVANCED.oneofs_by_name['_auto_adjust_mtu']
_ISISINTERFACEADVANCED.oneofs_by_name['_auto_adjust_area'].fields.append(
  _ISISINTERFACEADVANCED.fields_by_name['auto_adjust_area'])
_ISISINTERFACEADVANCED.fields_by_name['auto_adjust_area'].containing_oneof = _ISISINTERFACEADVANCED.oneofs_by_name['_auto_adjust_area']
_ISISINTERFACEADVANCED.oneofs_by_name['_auto_adjust_supported_protocols'].fields.append(
  _ISISINTERFACEADVANCED.fields_by_name['auto_adjust_supported_protocols'])
_ISISINTERFACEADVANCED.fields_by_name['auto_adjust_supported_protocols'].containing_oneof = _ISISINTERFACEADVANCED.oneofs_by_name['_auto_adjust_supported_protocols']
_ISISINTERFACEADVANCED.oneofs_by_name['_enable_3way_handshake'].fields.append(
  _ISISINTERFACEADVANCED.fields_by_name['enable_3way_handshake'])
_ISISINTERFACEADVANCED.fields_by_name['enable_3way_handshake'].containing_oneof = _ISISINTERFACEADVANCED.oneofs_by_name['_enable_3way_handshake']
_ISISINTERFACELINKPROTECTION.oneofs_by_name['_extra_traffic'].fields.append(
  _ISISINTERFACELINKPROTECTION.fields_by_name['extra_traffic'])
_ISISINTERFACELINKPROTECTION.fields_by_name['extra_traffic'].containing_oneof = _ISISINTERFACELINKPROTECTION.oneofs_by_name['_extra_traffic']
_ISISINTERFACELINKPROTECTION.oneofs_by_name['_unprotected'].fields.append(
  _ISISINTERFACELINKPROTECTION.fields_by_name['unprotected'])
_ISISINTERFACELINKPROTECTION.fields_by_name['unprotected'].containing_oneof = _ISISINTERFACELINKPROTECTION.oneofs_by_name['_unprotected']
_ISISINTERFACELINKPROTECTION.oneofs_by_name['_shared'].fields.append(
  _ISISINTERFACELINKPROTECTION.fields_by_name['shared'])
_ISISINTERFACELINKPROTECTION.fields_by_name['shared'].containing_oneof = _ISISINTERFACELINKPROTECTION.oneofs_by_name['_shared']
_ISISINTERFACELINKPROTECTION.oneofs_by_name['_dedicated_1_to_1'].fields.append(
  _ISISINTERFACELINKPROTECTION.fields_by_name['dedicated_1_to_1'])
_ISISINTERFACELINKPROTECTION.fields_by_name['dedicated_1_to_1'].containing_oneof = _ISISINTERFACELINKPROTECTION.oneofs_by_name['_dedicated_1_to_1']
_ISISINTERFACELINKPROTECTION.oneofs_by_name['_dedicated_1_plus_1'].fields.append(
  _ISISINTERFACELINKPROTECTION.fields_by_name['dedicated_1_plus_1'])
_ISISINTERFACELINKPROTECTION.fields_by_name['dedicated_1_plus_1'].containing_oneof = _ISISINTERFACELINKPROTECTION.oneofs_by_name['_dedicated_1_plus_1']
_ISISINTERFACELINKPROTECTION.oneofs_by_name['_enhanced'].fields.append(
  _ISISINTERFACELINKPROTECTION.fields_by_name['enhanced'])
_ISISINTERFACELINKPROTECTION.fields_by_name['enhanced'].containing_oneof = _ISISINTERFACELINKPROTECTION.oneofs_by_name['_enhanced']
_ISISINTERFACELINKPROTECTION.oneofs_by_name['_reserved_40'].fields.append(
  _ISISINTERFACELINKPROTECTION.fields_by_name['reserved_40'])
_ISISINTERFACELINKPROTECTION.fields_by_name['reserved_40'].containing_oneof = _ISISINTERFACELINKPROTECTION.oneofs_by_name['_reserved_40']
_ISISINTERFACELINKPROTECTION.oneofs_by_name['_reserved_80'].fields.append(
  _ISISINTERFACELINKPROTECTION.fields_by_name['reserved_80'])
_ISISINTERFACELINKPROTECTION.fields_by_name['reserved_80'].containing_oneof = _ISISINTERFACELINKPROTECTION.oneofs_by_name['_reserved_80']
_ISISBASIC.oneofs_by_name['_ipv4_te_router_id'].fields.append(
  _ISISBASIC.fields_by_name['ipv4_te_router_id'])
_ISISBASIC.fields_by_name['ipv4_te_router_id'].containing_oneof = _ISISBASIC.oneofs_by_name['_ipv4_te_router_id']
_ISISBASIC.oneofs_by_name['_hostname'].fields.append(
  _ISISBASIC.fields_by_name['hostname'])
_ISISBASIC.fields_by_name['hostname'].containing_oneof = _ISISBASIC.oneofs_by_name['_hostname']
_ISISBASIC.oneofs_by_name['_enable_wide_metric'].fields.append(
  _ISISBASIC.fields_by_name['enable_wide_metric'])
_ISISBASIC.fields_by_name['enable_wide_metric'].containing_oneof = _ISISBASIC.oneofs_by_name['_enable_wide_metric']
_ISISADVANCED.oneofs_by_name['_enable_hello_padding'].fields.append(
  _ISISADVANCED.fields_by_name['enable_hello_padding'])
_ISISADVANCED.fields_by_name['enable_hello_padding'].containing_oneof = _ISISADVANCED.oneofs_by_name['_enable_hello_padding']
_ISISADVANCED.oneofs_by_name['_max_area_addresses'].fields.append(
  _ISISADVANCED.fields_by_name['max_area_addresses'])
_ISISADVANCED.fields_by_name['max_area_addresses'].containing_oneof = _ISISADVANCED.oneofs_by_name['_max_area_addresses']
_ISISADVANCED.oneofs_by_name['_lsp_refresh_rate'].fields.append(
  _ISISADVANCED.fields_by_name['lsp_refresh_rate'])
_ISISADVANCED.fields_by_name['lsp_refresh_rate'].containing_oneof = _ISISADVANCED.oneofs_by_name['_lsp_refresh_rate']
_ISISADVANCED.oneofs_by_name['_lsp_lifetime'].fields.append(
  _ISISADVANCED.fields_by_name['lsp_lifetime'])
_ISISADVANCED.fields_by_name['lsp_lifetime'].containing_oneof = _ISISADVANCED.oneofs_by_name['_lsp_lifetime']
_ISISADVANCED.oneofs_by_name['_psnp_interval'].fields.append(
  _ISISADVANCED.fields_by_name['psnp_interval'])
_ISISADVANCED.fields_by_name['psnp_interval'].containing_oneof = _ISISADVANCED.oneofs_by_name['_psnp_interval']
_ISISADVANCED.oneofs_by_name['_csnp_interval'].fields.append(
  _ISISADVANCED.fields_by_name['csnp_interval'])
_ISISADVANCED.fields_by_name['csnp_interval'].containing_oneof = _ISISADVANCED.oneofs_by_name['_csnp_interval']
_ISISADVANCED.oneofs_by_name['_max_lsp_size'].fields.append(
  _ISISADVANCED.fields_by_name['max_lsp_size'])
_ISISADVANCED.fields_by_name['max_lsp_size'].containing_oneof = _ISISADVANCED.oneofs_by_name['_max_lsp_size']
_ISISADVANCED.oneofs_by_name['_lsp_mgroup_min_trans_interval'].fields.append(
  _ISISADVANCED.fields_by_name['lsp_mgroup_min_trans_interval'])
_ISISADVANCED.fields_by_name['lsp_mgroup_min_trans_interval'].containing_oneof = _ISISADVANCED.oneofs_by_name['_lsp_mgroup_min_trans_interval']
_ISISADVANCED.oneofs_by_name['_enable_attached_bit'].fields.append(
  _ISISADVANCED.fields_by_name['enable_attached_bit'])
_ISISADVANCED.fields_by_name['enable_attached_bit'].containing_oneof = _ISISADVANCED.oneofs_by_name['_enable_attached_bit']
_ISISAUTHENTICATION.fields_by_name['area_auth'].message_type = _ISISAUTHENTICATIONBASE
_ISISAUTHENTICATION.fields_by_name['domain_auth'].message_type = _ISISAUTHENTICATIONBASE
_ISISAUTHENTICATION.oneofs_by_name['_ignore_receive_md5'].fields.append(
  _ISISAUTHENTICATION.fields_by_name['ignore_receive_md5'])
_ISISAUTHENTICATION.fields_by_name['ignore_receive_md5'].containing_oneof = _ISISAUTHENTICATION.oneofs_by_name['_ignore_receive_md5']
_ISISAUTHENTICATION.oneofs_by_name['_area_auth'].fields.append(
  _ISISAUTHENTICATION.fields_by_name['area_auth'])
_ISISAUTHENTICATION.fields_by_name['area_auth'].containing_oneof = _ISISAUTHENTICATION.oneofs_by_name['_area_auth']
_ISISAUTHENTICATION.oneofs_by_name['_domain_auth'].fields.append(
  _ISISAUTHENTICATION.fields_by_name['domain_auth'])
_ISISAUTHENTICATION.fields_by_name['domain_auth'].containing_oneof = _ISISAUTHENTICATION.oneofs_by_name['_domain_auth']
_ISISAUTHENTICATIONBASE_AUTHTYPE.containing_type = _ISISAUTHENTICATIONBASE
_ISISAUTHENTICATIONBASE_AUTHTYPE_ENUM.containing_type = _ISISAUTHENTICATIONBASE_AUTHTYPE
_ISISAUTHENTICATIONBASE.fields_by_name['auth_type'].enum_type = _ISISAUTHENTICATIONBASE_AUTHTYPE_ENUM
_ISISAUTHENTICATIONBASE.oneofs_by_name['_md5'].fields.append(
  _ISISAUTHENTICATIONBASE.fields_by_name['md5'])
_ISISAUTHENTICATIONBASE.fields_by_name['md5'].containing_oneof = _ISISAUTHENTICATIONBASE.oneofs_by_name['_md5']
_ISISAUTHENTICATIONBASE.oneofs_by_name['_password'].fields.append(
  _ISISAUTHENTICATIONBASE.fields_by_name['password'])
_ISISAUTHENTICATIONBASE.fields_by_name['password'].containing_oneof = _ISISAUTHENTICATIONBASE.oneofs_by_name['_password']
_ISISV4ROUTERANGE_ORIGINTYPE.containing_type = _ISISV4ROUTERANGE
_ISISV4ROUTERANGE_ORIGINTYPE_ENUM.containing_type = _ISISV4ROUTERANGE_ORIGINTYPE
_ISISV4ROUTERANGE_REDISTRIBUTIONTYPE.containing_type = _ISISV4ROUTERANGE
_ISISV4ROUTERANGE_REDISTRIBUTIONTYPE_ENUM.containing_type = _ISISV4ROUTERANGE_REDISTRIBUTIONTYPE
_ISISV4ROUTERANGE.fields_by_name['addresses'].message_type = _V4ROUTEADDRESS
_ISISV4ROUTERANGE.fields_by_name['origin_type'].enum_type = _ISISV4ROUTERANGE_ORIGINTYPE_ENUM
_ISISV4ROUTERANGE.fields_by_name['redistribution_type'].enum_type = _ISISV4ROUTERANGE_REDISTRIBUTIONTYPE_ENUM
_ISISV4ROUTERANGE.oneofs_by_name['_link_metric'].fields.append(
  _ISISV4ROUTERANGE.fields_by_name['link_metric'])
_ISISV4ROUTERANGE.fields_by_name['link_metric'].containing_oneof = _ISISV4ROUTERANGE.oneofs_by_name['_link_metric']
_ISISV4ROUTERANGE.oneofs_by_name['_origin_type'].fields.append(
  _ISISV4ROUTERANGE.fields_by_name['origin_type'])
_ISISV4ROUTERANGE.fields_by_name['origin_type'].containing_oneof = _ISISV4ROUTERANGE.oneofs_by_name['_origin_type']
_ISISV4ROUTERANGE.oneofs_by_name['_redistribution_type'].fields.append(
  _ISISV4ROUTERANGE.fields_by_name['redistribution_type'])
_ISISV4ROUTERANGE.fields_by_name['redistribution_type'].containing_oneof = _ISISV4ROUTERANGE.oneofs_by_name['_redistribution_type']
_ISISV4ROUTERANGE.oneofs_by_name['_prefix_attr_enabled'].fields.append(
  _ISISV4ROUTERANGE.fields_by_name['prefix_attr_enabled'])
_ISISV4ROUTERANGE.fields_by_name['prefix_attr_enabled'].containing_oneof = _ISISV4ROUTERANGE.oneofs_by_name['_prefix_attr_enabled']
_ISISV4ROUTERANGE.oneofs_by_name['_x_flag'].fields.append(
  _ISISV4ROUTERANGE.fields_by_name['x_flag'])
_ISISV4ROUTERANGE.fields_by_name['x_flag'].containing_oneof = _ISISV4ROUTERANGE.oneofs_by_name['_x_flag']
_ISISV4ROUTERANGE.oneofs_by_name['_r_flag'].fields.append(
  _ISISV4ROUTERANGE.fields_by_name['r_flag'])
_ISISV4ROUTERANGE.fields_by_name['r_flag'].containing_oneof = _ISISV4ROUTERANGE.oneofs_by_name['_r_flag']
_ISISV4ROUTERANGE.oneofs_by_name['_n_flag'].fields.append(
  _ISISV4ROUTERANGE.fields_by_name['n_flag'])
_ISISV4ROUTERANGE.fields_by_name['n_flag'].containing_oneof = _ISISV4ROUTERANGE.oneofs_by_name['_n_flag']
_V4ROUTEADDRESS.oneofs_by_name['_prefix'].fields.append(
  _V4ROUTEADDRESS.fields_by_name['prefix'])
_V4ROUTEADDRESS.fields_by_name['prefix'].containing_oneof = _V4ROUTEADDRESS.oneofs_by_name['_prefix']
_V4ROUTEADDRESS.oneofs_by_name['_count'].fields.append(
  _V4ROUTEADDRESS.fields_by_name['count'])
_V4ROUTEADDRESS.fields_by_name['count'].containing_oneof = _V4ROUTEADDRESS.oneofs_by_name['_count']
_V4ROUTEADDRESS.oneofs_by_name['_step'].fields.append(
  _V4ROUTEADDRESS.fields_by_name['step'])
_V4ROUTEADDRESS.fields_by_name['step'].containing_oneof = _V4ROUTEADDRESS.oneofs_by_name['_step']
_V6ROUTEADDRESS.oneofs_by_name['_prefix'].fields.append(
  _V6ROUTEADDRESS.fields_by_name['prefix'])
_V6ROUTEADDRESS.fields_by_name['prefix'].containing_oneof = _V6ROUTEADDRESS.oneofs_by_name['_prefix']
_V6ROUTEADDRESS.oneofs_by_name['_count'].fields.append(
  _V6ROUTEADDRESS.fields_by_name['count'])
_V6ROUTEADDRESS.fields_by_name['count'].containing_oneof = _V6ROUTEADDRESS.oneofs_by_name['_count']
_V6ROUTEADDRESS.oneofs_by_name['_step'].fields.append(
  _V6ROUTEADDRESS.fields_by_name['step'])
_V6ROUTEADDRESS.fields_by_name['step'].containing_oneof = _V6ROUTEADDRESS.oneofs_by_name['_step']
_ISISV6ROUTERANGE_ORIGINTYPE.containing_type = _ISISV6ROUTERANGE
_ISISV6ROUTERANGE_ORIGINTYPE_ENUM.containing_type = _ISISV6ROUTERANGE_ORIGINTYPE
_ISISV6ROUTERANGE_REDISTRIBUTIONTYPE.containing_type = _ISISV6ROUTERANGE
_ISISV6ROUTERANGE_REDISTRIBUTIONTYPE_ENUM.containing_type = _ISISV6ROUTERANGE_REDISTRIBUTIONTYPE
_ISISV6ROUTERANGE.fields_by_name['addresses'].message_type = _V6ROUTEADDRESS
_ISISV6ROUTERANGE.fields_by_name['origin_type'].enum_type = _ISISV6ROUTERANGE_ORIGINTYPE_ENUM
_ISISV6ROUTERANGE.fields_by_name['redistribution_type'].enum_type = _ISISV6ROUTERANGE_REDISTRIBUTIONTYPE_ENUM
_ISISV6ROUTERANGE.oneofs_by_name['_link_metric'].fields.append(
  _ISISV6ROUTERANGE.fields_by_name['link_metric'])
_ISISV6ROUTERANGE.fields_by_name['link_metric'].containing_oneof = _ISISV6ROUTERANGE.oneofs_by_name['_link_metric']
_ISISV6ROUTERANGE.oneofs_by_name['_origin_type'].fields.append(
  _ISISV6ROUTERANGE.fields_by_name['origin_type'])
_ISISV6ROUTERANGE.fields_by_name['origin_type'].containing_oneof = _ISISV6ROUTERANGE.oneofs_by_name['_origin_type']
_ISISV6ROUTERANGE.oneofs_by_name['_redistribution_type'].fields.append(
  _ISISV6ROUTERANGE.fields_by_name['redistribution_type'])
_ISISV6ROUTERANGE.fields_by_name['redistribution_type'].containing_oneof = _ISISV6ROUTERANGE.oneofs_by_name['_redistribution_type']
_ISISV6ROUTERANGE.oneofs_by_name['_prefix_attr_enabled'].fields.append(
  _ISISV6ROUTERANGE.fields_by_name['prefix_attr_enabled'])
_ISISV6ROUTERANGE.fields_by_name['prefix_attr_enabled'].containing_oneof = _ISISV6ROUTERANGE.oneofs_by_name['_prefix_attr_enabled']
_ISISV6ROUTERANGE.oneofs_by_name['_x_flag'].fields.append(
  _ISISV6ROUTERANGE.fields_by_name['x_flag'])
_ISISV6ROUTERANGE.fields_by_name['x_flag'].containing_oneof = _ISISV6ROUTERANGE.oneofs_by_name['_x_flag']
_ISISV6ROUTERANGE.oneofs_by_name['_r_flag'].fields.append(
  _ISISV6ROUTERANGE.fields_by_name['r_flag'])
_ISISV6ROUTERANGE.fields_by_name['r_flag'].containing_oneof = _ISISV6ROUTERANGE.oneofs_by_name['_r_flag']
_ISISV6ROUTERANGE.oneofs_by_name['_n_flag'].fields.append(
  _ISISV6ROUTERANGE.fields_by_name['n_flag'])
_ISISV6ROUTERANGE.fields_by_name['n_flag'].containing_oneof = _ISISV6ROUTERANGE.oneofs_by_name['_n_flag']
_DEVICEBGPROUTER.fields_by_name['ipv4_interfaces'].message_type = _BGPV4INTERFACE
_DEVICEBGPROUTER.fields_by_name['ipv6_interfaces'].message_type = _BGPV6INTERFACE
_BGPV4PEER_ASTYPE.containing_type = _BGPV4PEER
_BGPV4PEER_ASTYPE_ENUM.containing_type = _BGPV4PEER_ASTYPE
_BGPV4PEER_ASNUMBERWIDTH.containing_type = _BGPV4PEER
_BGPV4PEER_ASNUMBERWIDTH_ENUM.containing_type = _BGPV4PEER_ASNUMBERWIDTH
_BGPV4PEER.fields_by_name['as_type'].enum_type = _BGPV4PEER_ASTYPE_ENUM
_BGPV4PEER.fields_by_name['as_number_width'].enum_type = _BGPV4PEER_ASNUMBERWIDTH_ENUM
_BGPV4PEER.fields_by_name['advanced'].message_type = _BGPADVANCED
_BGPV4PEER.fields_by_name['capability'].message_type = _BGPCAPABILITY
_BGPV4PEER.fields_by_name['v4_routes'].message_type = _BGPV4ROUTERANGE
_BGPV4PEER.fields_by_name['v6_routes'].message_type = _BGPV6ROUTERANGE
_BGPV4PEER.fields_by_name['v4_srte_policies'].message_type = _BGPSRTEV4POLICY
_BGPV4PEER.fields_by_name['v6_srte_policies'].message_type = _BGPSRTEV6POLICY
_BGPV4PEER.oneofs_by_name['_as_number_width'].fields.append(
  _BGPV4PEER.fields_by_name['as_number_width'])
_BGPV4PEER.fields_by_name['as_number_width'].containing_oneof = _BGPV4PEER.oneofs_by_name['_as_number_width']
_BGPV4PEER.oneofs_by_name['_advanced'].fields.append(
  _BGPV4PEER.fields_by_name['advanced'])
_BGPV4PEER.fields_by_name['advanced'].containing_oneof = _BGPV4PEER.oneofs_by_name['_advanced']
_BGPV4PEER.oneofs_by_name['_capability'].fields.append(
  _BGPV4PEER.fields_by_name['capability'])
_BGPV4PEER.fields_by_name['capability'].containing_oneof = _BGPV4PEER.oneofs_by_name['_capability']
_BGPV4INTERFACE.fields_by_name['peers'].message_type = _BGPV4PEER
_BGPADVANCED.oneofs_by_name['_hold_time_interval'].fields.append(
  _BGPADVANCED.fields_by_name['hold_time_interval'])
_BGPADVANCED.fields_by_name['hold_time_interval'].containing_oneof = _BGPADVANCED.oneofs_by_name['_hold_time_interval']
_BGPADVANCED.oneofs_by_name['_keep_alive_interval'].fields.append(
  _BGPADVANCED.fields_by_name['keep_alive_interval'])
_BGPADVANCED.fields_by_name['keep_alive_interval'].containing_oneof = _BGPADVANCED.oneofs_by_name['_keep_alive_interval']
_BGPADVANCED.oneofs_by_name['_update_interval'].fields.append(
  _BGPADVANCED.fields_by_name['update_interval'])
_BGPADVANCED.fields_by_name['update_interval'].containing_oneof = _BGPADVANCED.oneofs_by_name['_update_interval']
_BGPADVANCED.oneofs_by_name['_time_to_live'].fields.append(
  _BGPADVANCED.fields_by_name['time_to_live'])
_BGPADVANCED.fields_by_name['time_to_live'].containing_oneof = _BGPADVANCED.oneofs_by_name['_time_to_live']
_BGPADVANCED.oneofs_by_name['_md5_key'].fields.append(
  _BGPADVANCED.fields_by_name['md5_key'])
_BGPADVANCED.fields_by_name['md5_key'].containing_oneof = _BGPADVANCED.oneofs_by_name['_md5_key']
_BGPCAPABILITY.oneofs_by_name['_ipv4_unicast'].fields.append(
  _BGPCAPABILITY.fields_by_name['ipv4_unicast'])
_BGPCAPABILITY.fields_by_name['ipv4_unicast'].containing_oneof = _BGPCAPABILITY.oneofs_by_name['_ipv4_unicast']
_BGPCAPABILITY.oneofs_by_name['_ipv4_multicast'].fields.append(
  _BGPCAPABILITY.fields_by_name['ipv4_multicast'])
_BGPCAPABILITY.fields_by_name['ipv4_multicast'].containing_oneof = _BGPCAPABILITY.oneofs_by_name['_ipv4_multicast']
_BGPCAPABILITY.oneofs_by_name['_ipv6_unicast'].fields.append(
  _BGPCAPABILITY.fields_by_name['ipv6_unicast'])
_BGPCAPABILITY.fields_by_name['ipv6_unicast'].containing_oneof = _BGPCAPABILITY.oneofs_by_name['_ipv6_unicast']
_BGPCAPABILITY.oneofs_by_name['_ipv6_multicast'].fields.append(
  _BGPCAPABILITY.fields_by_name['ipv6_multicast'])
_BGPCAPABILITY.fields_by_name['ipv6_multicast'].containing_oneof = _BGPCAPABILITY.oneofs_by_name['_ipv6_multicast']
_BGPCAPABILITY.oneofs_by_name['_vpls'].fields.append(
  _BGPCAPABILITY.fields_by_name['vpls'])
_BGPCAPABILITY.fields_by_name['vpls'].containing_oneof = _BGPCAPABILITY.oneofs_by_name['_vpls']
_BGPCAPABILITY.oneofs_by_name['_route_refresh'].fields.append(
  _BGPCAPABILITY.fields_by_name['route_refresh'])
_BGPCAPABILITY.fields_by_name['route_refresh'].containing_oneof = _BGPCAPABILITY.oneofs_by_name['_route_refresh']
_BGPCAPABILITY.oneofs_by_name['_route_constraint'].fields.append(
  _BGPCAPABILITY.fields_by_name['route_constraint'])
_BGPCAPABILITY.fields_by_name['route_constraint'].containing_oneof = _BGPCAPABILITY.oneofs_by_name['_route_constraint']
_BGPCAPABILITY.oneofs_by_name['_link_state_non_vpn'].fields.append(
  _BGPCAPABILITY.fields_by_name['link_state_non_vpn'])
_BGPCAPABILITY.fields_by_name['link_state_non_vpn'].containing_oneof = _BGPCAPABILITY.oneofs_by_name['_link_state_non_vpn']
_BGPCAPABILITY.oneofs_by_name['_link_state_vpn'].fields.append(
  _BGPCAPABILITY.fields_by_name['link_state_vpn'])
_BGPCAPABILITY.fields_by_name['link_state_vpn'].containing_oneof = _BGPCAPABILITY.oneofs_by_name['_link_state_vpn']
_BGPCAPABILITY.oneofs_by_name['_evpn'].fields.append(
  _BGPCAPABILITY.fields_by_name['evpn'])
_BGPCAPABILITY.fields_by_name['evpn'].containing_oneof = _BGPCAPABILITY.oneofs_by_name['_evpn']
_BGPCAPABILITY.oneofs_by_name['_extended_next_hop_encoding'].fields.append(
  _BGPCAPABILITY.fields_by_name['extended_next_hop_encoding'])
_BGPCAPABILITY.fields_by_name['extended_next_hop_encoding'].containing_oneof = _BGPCAPABILITY.oneofs_by_name['_extended_next_hop_encoding']
_BGPCAPABILITY.oneofs_by_name['_ipv4_multicast_vpn'].fields.append(
  _BGPCAPABILITY.fields_by_name['ipv4_multicast_vpn'])
_BGPCAPABILITY.fields_by_name['ipv4_multicast_vpn'].containing_oneof = _BGPCAPABILITY.oneofs_by_name['_ipv4_multicast_vpn']
_BGPCAPABILITY.oneofs_by_name['_ipv4_mpls_vpn'].fields.append(
  _BGPCAPABILITY.fields_by_name['ipv4_mpls_vpn'])
_BGPCAPABILITY.fields_by_name['ipv4_mpls_vpn'].containing_oneof = _BGPCAPABILITY.oneofs_by_name['_ipv4_mpls_vpn']
_BGPCAPABILITY.oneofs_by_name['_ipv4_mdt'].fields.append(
  _BGPCAPABILITY.fields_by_name['ipv4_mdt'])
_BGPCAPABILITY.fields_by_name['ipv4_mdt'].containing_oneof = _BGPCAPABILITY.oneofs_by_name['_ipv4_mdt']
_BGPCAPABILITY.oneofs_by_name['_ipv4_multicast_mpls_vpn'].fields.append(
  _BGPCAPABILITY.fields_by_name['ipv4_multicast_mpls_vpn'])
_BGPCAPABILITY.fields_by_name['ipv4_multicast_mpls_vpn'].containing_oneof = _BGPCAPABILITY.oneofs_by_name['_ipv4_multicast_mpls_vpn']
_BGPCAPABILITY.oneofs_by_name['_ipv4_unicast_flow_spec'].fields.append(
  _BGPCAPABILITY.fields_by_name['ipv4_unicast_flow_spec'])
_BGPCAPABILITY.fields_by_name['ipv4_unicast_flow_spec'].containing_oneof = _BGPCAPABILITY.oneofs_by_name['_ipv4_unicast_flow_spec']
_BGPCAPABILITY.oneofs_by_name['_ipv4_sr_te_policy'].fields.append(
  _BGPCAPABILITY.fields_by_name['ipv4_sr_te_policy'])
_BGPCAPABILITY.fields_by_name['ipv4_sr_te_policy'].containing_oneof = _BGPCAPABILITY.oneofs_by_name['_ipv4_sr_te_policy']
_BGPCAPABILITY.oneofs_by_name['_ipv4_unicast_add_path'].fields.append(
  _BGPCAPABILITY.fields_by_name['ipv4_unicast_add_path'])
_BGPCAPABILITY.fields_by_name['ipv4_unicast_add_path'].containing_oneof = _BGPCAPABILITY.oneofs_by_name['_ipv4_unicast_add_path']
_BGPCAPABILITY.oneofs_by_name['_ipv6_multicast_vpn'].fields.append(
  _BGPCAPABILITY.fields_by_name['ipv6_multicast_vpn'])
_BGPCAPABILITY.fields_by_name['ipv6_multicast_vpn'].containing_oneof = _BGPCAPABILITY.oneofs_by_name['_ipv6_multicast_vpn']
_BGPCAPABILITY.oneofs_by_name['_ipv6_mpls_vpn'].fields.append(
  _BGPCAPABILITY.fields_by_name['ipv6_mpls_vpn'])
_BGPCAPABILITY.fields_by_name['ipv6_mpls_vpn'].containing_oneof = _BGPCAPABILITY.oneofs_by_name['_ipv6_mpls_vpn']
_BGPCAPABILITY.oneofs_by_name['_ipv6_mdt'].fields.append(
  _BGPCAPABILITY.fields_by_name['ipv6_mdt'])
_BGPCAPABILITY.fields_by_name['ipv6_mdt'].containing_oneof = _BGPCAPABILITY.oneofs_by_name['_ipv6_mdt']
_BGPCAPABILITY.oneofs_by_name['_ipv6_multicast_mpls_vpn'].fields.append(
  _BGPCAPABILITY.fields_by_name['ipv6_multicast_mpls_vpn'])
_BGPCAPABILITY.fields_by_name['ipv6_multicast_mpls_vpn'].containing_oneof = _BGPCAPABILITY.oneofs_by_name['_ipv6_multicast_mpls_vpn']
_BGPCAPABILITY.oneofs_by_name['_ipv6_unicast_flow_spec'].fields.append(
  _BGPCAPABILITY.fields_by_name['ipv6_unicast_flow_spec'])
_BGPCAPABILITY.fields_by_name['ipv6_unicast_flow_spec'].containing_oneof = _BGPCAPABILITY.oneofs_by_name['_ipv6_unicast_flow_spec']
_BGPCAPABILITY.oneofs_by_name['_ipv6_sr_te_policy'].fields.append(
  _BGPCAPABILITY.fields_by_name['ipv6_sr_te_policy'])
_BGPCAPABILITY.fields_by_name['ipv6_sr_te_policy'].containing_oneof = _BGPCAPABILITY.oneofs_by_name['_ipv6_sr_te_policy']
_BGPCAPABILITY.oneofs_by_name['_ipv6_unicast_add_path'].fields.append(
  _BGPCAPABILITY.fields_by_name['ipv6_unicast_add_path'])
_BGPCAPABILITY.fields_by_name['ipv6_unicast_add_path'].containing_oneof = _BGPCAPABILITY.oneofs_by_name['_ipv6_unicast_add_path']
_BGPV4ROUTERANGE_NEXTHOPMODE.containing_type = _BGPV4ROUTERANGE
_BGPV4ROUTERANGE_NEXTHOPMODE_ENUM.containing_type = _BGPV4ROUTERANGE_NEXTHOPMODE
_BGPV4ROUTERANGE_NEXTHOPADDRESSTYPE.containing_type = _BGPV4ROUTERANGE
_BGPV4ROUTERANGE_NEXTHOPADDRESSTYPE_ENUM.containing_type = _BGPV4ROUTERANGE_NEXTHOPADDRESSTYPE
_BGPV4ROUTERANGE.fields_by_name['addresses'].message_type = _V4ROUTEADDRESS
_BGPV4ROUTERANGE.fields_by_name['next_hop_mode'].enum_type = _BGPV4ROUTERANGE_NEXTHOPMODE_ENUM
_BGPV4ROUTERANGE.fields_by_name['next_hop_address_type'].enum_type = _BGPV4ROUTERANGE_NEXTHOPADDRESSTYPE_ENUM
_BGPV4ROUTERANGE.fields_by_name['advanced'].message_type = _BGPROUTEADVANCED
_BGPV4ROUTERANGE.fields_by_name['communities'].message_type = _BGPCOMMUNITY
_BGPV4ROUTERANGE.fields_by_name['as_path'].message_type = _BGPASPATH
_BGPV4ROUTERANGE.fields_by_name['add_path'].message_type = _BGPADDPATH
_BGPV4ROUTERANGE.oneofs_by_name['_next_hop_mode'].fields.append(
  _BGPV4ROUTERANGE.fields_by_name['next_hop_mode'])
_BGPV4ROUTERANGE.fields_by_name['next_hop_mode'].containing_oneof = _BGPV4ROUTERANGE.oneofs_by_name['_next_hop_mode']
_BGPV4ROUTERANGE.oneofs_by_name['_next_hop_address_type'].fields.append(
  _BGPV4ROUTERANGE.fields_by_name['next_hop_address_type'])
_BGPV4ROUTERANGE.fields_by_name['next_hop_address_type'].containing_oneof = _BGPV4ROUTERANGE.oneofs_by_name['_next_hop_address_type']
_BGPV4ROUTERANGE.oneofs_by_name['_next_hop_ipv4_address'].fields.append(
  _BGPV4ROUTERANGE.fields_by_name['next_hop_ipv4_address'])
_BGPV4ROUTERANGE.fields_by_name['next_hop_ipv4_address'].containing_oneof = _BGPV4ROUTERANGE.oneofs_by_name['_next_hop_ipv4_address']
_BGPV4ROUTERANGE.oneofs_by_name['_next_hop_ipv6_address'].fields.append(
  _BGPV4ROUTERANGE.fields_by_name['next_hop_ipv6_address'])
_BGPV4ROUTERANGE.fields_by_name['next_hop_ipv6_address'].containing_oneof = _BGPV4ROUTERANGE.oneofs_by_name['_next_hop_ipv6_address']
_BGPV4ROUTERANGE.oneofs_by_name['_advanced'].fields.append(
  _BGPV4ROUTERANGE.fields_by_name['advanced'])
_BGPV4ROUTERANGE.fields_by_name['advanced'].containing_oneof = _BGPV4ROUTERANGE.oneofs_by_name['_advanced']
_BGPV4ROUTERANGE.oneofs_by_name['_as_path'].fields.append(
  _BGPV4ROUTERANGE.fields_by_name['as_path'])
_BGPV4ROUTERANGE.fields_by_name['as_path'].containing_oneof = _BGPV4ROUTERANGE.oneofs_by_name['_as_path']
_BGPV4ROUTERANGE.oneofs_by_name['_add_path'].fields.append(
  _BGPV4ROUTERANGE.fields_by_name['add_path'])
_BGPV4ROUTERANGE.fields_by_name['add_path'].containing_oneof = _BGPV4ROUTERANGE.oneofs_by_name['_add_path']
_BGPROUTEADVANCED_ORIGIN.containing_type = _BGPROUTEADVANCED
_BGPROUTEADVANCED_ORIGIN_ENUM.containing_type = _BGPROUTEADVANCED_ORIGIN
_BGPROUTEADVANCED.fields_by_name['origin'].enum_type = _BGPROUTEADVANCED_ORIGIN_ENUM
_BGPROUTEADVANCED.oneofs_by_name['_multi_exit_discriminator'].fields.append(
  _BGPROUTEADVANCED.fields_by_name['multi_exit_discriminator'])
_BGPROUTEADVANCED.fields_by_name['multi_exit_discriminator'].containing_oneof = _BGPROUTEADVANCED.oneofs_by_name['_multi_exit_discriminator']
_BGPROUTEADVANCED.oneofs_by_name['_origin'].fields.append(
  _BGPROUTEADVANCED.fields_by_name['origin'])
_BGPROUTEADVANCED.fields_by_name['origin'].containing_oneof = _BGPROUTEADVANCED.oneofs_by_name['_origin']
_BGPCOMMUNITY_TYPE.containing_type = _BGPCOMMUNITY
_BGPCOMMUNITY_TYPE_ENUM.containing_type = _BGPCOMMUNITY_TYPE
_BGPCOMMUNITY.fields_by_name['type'].enum_type = _BGPCOMMUNITY_TYPE_ENUM
_BGPCOMMUNITY.oneofs_by_name['_type'].fields.append(
  _BGPCOMMUNITY.fields_by_name['type'])
_BGPCOMMUNITY.fields_by_name['type'].containing_oneof = _BGPCOMMUNITY.oneofs_by_name['_type']
_BGPCOMMUNITY.oneofs_by_name['_as_number'].fields.append(
  _BGPCOMMUNITY.fields_by_name['as_number'])
_BGPCOMMUNITY.fields_by_name['as_number'].containing_oneof = _BGPCOMMUNITY.oneofs_by_name['_as_number']
_BGPCOMMUNITY.oneofs_by_name['_as_custom'].fields.append(
  _BGPCOMMUNITY.fields_by_name['as_custom'])
_BGPCOMMUNITY.fields_by_name['as_custom'].containing_oneof = _BGPCOMMUNITY.oneofs_by_name['_as_custom']
_BGPASPATH_ASSETMODE.containing_type = _BGPASPATH
_BGPASPATH_ASSETMODE_ENUM.containing_type = _BGPASPATH_ASSETMODE
_BGPASPATH.fields_by_name['as_set_mode'].enum_type = _BGPASPATH_ASSETMODE_ENUM
_BGPASPATH.fields_by_name['segments'].message_type = _BGPASPATHSEGMENT
_BGPASPATH.oneofs_by_name['_as_set_mode'].fields.append(
  _BGPASPATH.fields_by_name['as_set_mode'])
_BGPASPATH.fields_by_name['as_set_mode'].containing_oneof = _BGPASPATH.oneofs_by_name['_as_set_mode']
_BGPASPATHSEGMENT_TYPE.containing_type = _BGPASPATHSEGMENT
_BGPASPATHSEGMENT_TYPE_ENUM.containing_type = _BGPASPATHSEGMENT_TYPE
_BGPASPATHSEGMENT.fields_by_name['type'].enum_type = _BGPASPATHSEGMENT_TYPE_ENUM
_BGPASPATHSEGMENT.oneofs_by_name['_type'].fields.append(
  _BGPASPATHSEGMENT.fields_by_name['type'])
_BGPASPATHSEGMENT.fields_by_name['type'].containing_oneof = _BGPASPATHSEGMENT.oneofs_by_name['_type']
_BGPADDPATH.oneofs_by_name['_path_id'].fields.append(
  _BGPADDPATH.fields_by_name['path_id'])
_BGPADDPATH.fields_by_name['path_id'].containing_oneof = _BGPADDPATH.oneofs_by_name['_path_id']
_BGPV6ROUTERANGE_NEXTHOPMODE.containing_type = _BGPV6ROUTERANGE
_BGPV6ROUTERANGE_NEXTHOPMODE_ENUM.containing_type = _BGPV6ROUTERANGE_NEXTHOPMODE
_BGPV6ROUTERANGE_NEXTHOPADDRESSTYPE.containing_type = _BGPV6ROUTERANGE
_BGPV6ROUTERANGE_NEXTHOPADDRESSTYPE_ENUM.containing_type = _BGPV6ROUTERANGE_NEXTHOPADDRESSTYPE
_BGPV6ROUTERANGE.fields_by_name['addresses'].message_type = _V6ROUTEADDRESS
_BGPV6ROUTERANGE.fields_by_name['next_hop_mode'].enum_type = _BGPV6ROUTERANGE_NEXTHOPMODE_ENUM
_BGPV6ROUTERANGE.fields_by_name['next_hop_address_type'].enum_type = _BGPV6ROUTERANGE_NEXTHOPADDRESSTYPE_ENUM
_BGPV6ROUTERANGE.fields_by_name['advanced'].message_type = _BGPROUTEADVANCED
_BGPV6ROUTERANGE.fields_by_name['communities'].message_type = _BGPCOMMUNITY
_BGPV6ROUTERANGE.fields_by_name['as_path'].message_type = _BGPASPATH
_BGPV6ROUTERANGE.fields_by_name['add_path'].message_type = _BGPADDPATH
_BGPV6ROUTERANGE.oneofs_by_name['_next_hop_mode'].fields.append(
  _BGPV6ROUTERANGE.fields_by_name['next_hop_mode'])
_BGPV6ROUTERANGE.fields_by_name['next_hop_mode'].containing_oneof = _BGPV6ROUTERANGE.oneofs_by_name['_next_hop_mode']
_BGPV6ROUTERANGE.oneofs_by_name['_next_hop_address_type'].fields.append(
  _BGPV6ROUTERANGE.fields_by_name['next_hop_address_type'])
_BGPV6ROUTERANGE.fields_by_name['next_hop_address_type'].containing_oneof = _BGPV6ROUTERANGE.oneofs_by_name['_next_hop_address_type']
_BGPV6ROUTERANGE.oneofs_by_name['_next_hop_ipv4_address'].fields.append(
  _BGPV6ROUTERANGE.fields_by_name['next_hop_ipv4_address'])
_BGPV6ROUTERANGE.fields_by_name['next_hop_ipv4_address'].containing_oneof = _BGPV6ROUTERANGE.oneofs_by_name['_next_hop_ipv4_address']
_BGPV6ROUTERANGE.oneofs_by_name['_next_hop_ipv6_address'].fields.append(
  _BGPV6ROUTERANGE.fields_by_name['next_hop_ipv6_address'])
_BGPV6ROUTERANGE.fields_by_name['next_hop_ipv6_address'].containing_oneof = _BGPV6ROUTERANGE.oneofs_by_name['_next_hop_ipv6_address']
_BGPV6ROUTERANGE.oneofs_by_name['_advanced'].fields.append(
  _BGPV6ROUTERANGE.fields_by_name['advanced'])
_BGPV6ROUTERANGE.fields_by_name['advanced'].containing_oneof = _BGPV6ROUTERANGE.oneofs_by_name['_advanced']
_BGPV6ROUTERANGE.oneofs_by_name['_as_path'].fields.append(
  _BGPV6ROUTERANGE.fields_by_name['as_path'])
_BGPV6ROUTERANGE.fields_by_name['as_path'].containing_oneof = _BGPV6ROUTERANGE.oneofs_by_name['_as_path']
_BGPV6ROUTERANGE.oneofs_by_name['_add_path'].fields.append(
  _BGPV6ROUTERANGE.fields_by_name['add_path'])
_BGPV6ROUTERANGE.fields_by_name['add_path'].containing_oneof = _BGPV6ROUTERANGE.oneofs_by_name['_add_path']
_BGPSRTEV4POLICY_NEXTHOPMODE.containing_type = _BGPSRTEV4POLICY
_BGPSRTEV4POLICY_NEXTHOPMODE_ENUM.containing_type = _BGPSRTEV4POLICY_NEXTHOPMODE
_BGPSRTEV4POLICY_NEXTHOPADDRESSTYPE.containing_type = _BGPSRTEV4POLICY
_BGPSRTEV4POLICY_NEXTHOPADDRESSTYPE_ENUM.containing_type = _BGPSRTEV4POLICY_NEXTHOPADDRESSTYPE
_BGPSRTEV4POLICY.fields_by_name['next_hop_mode'].enum_type = _BGPSRTEV4POLICY_NEXTHOPMODE_ENUM
_BGPSRTEV4POLICY.fields_by_name['next_hop_address_type'].enum_type = _BGPSRTEV4POLICY_NEXTHOPADDRESSTYPE_ENUM
_BGPSRTEV4POLICY.fields_by_name['advanced'].message_type = _BGPROUTEADVANCED
_BGPSRTEV4POLICY.fields_by_name['add_path'].message_type = _BGPADDPATH
_BGPSRTEV4POLICY.fields_by_name['as_path'].message_type = _BGPASPATH
_BGPSRTEV4POLICY.fields_by_name['communities'].message_type = _BGPCOMMUNITY
_BGPSRTEV4POLICY.fields_by_name['ext_communities'].message_type = _BGPEXTCOMMUNITY
_BGPSRTEV4POLICY.fields_by_name['tunnel_tlvs'].message_type = _BGPSRTEV4TUNNELTLV
_BGPSRTEV4POLICY.oneofs_by_name['_distinguisher'].fields.append(
  _BGPSRTEV4POLICY.fields_by_name['distinguisher'])
_BGPSRTEV4POLICY.fields_by_name['distinguisher'].containing_oneof = _BGPSRTEV4POLICY.oneofs_by_name['_distinguisher']
_BGPSRTEV4POLICY.oneofs_by_name['_color'].fields.append(
  _BGPSRTEV4POLICY.fields_by_name['color'])
_BGPSRTEV4POLICY.fields_by_name['color'].containing_oneof = _BGPSRTEV4POLICY.oneofs_by_name['_color']
_BGPSRTEV4POLICY.oneofs_by_name['_next_hop_mode'].fields.append(
  _BGPSRTEV4POLICY.fields_by_name['next_hop_mode'])
_BGPSRTEV4POLICY.fields_by_name['next_hop_mode'].containing_oneof = _BGPSRTEV4POLICY.oneofs_by_name['_next_hop_mode']
_BGPSRTEV4POLICY.oneofs_by_name['_next_hop_address_type'].fields.append(
  _BGPSRTEV4POLICY.fields_by_name['next_hop_address_type'])
_BGPSRTEV4POLICY.fields_by_name['next_hop_address_type'].containing_oneof = _BGPSRTEV4POLICY.oneofs_by_name['_next_hop_address_type']
_BGPSRTEV4POLICY.oneofs_by_name['_next_hop_ipv4_address'].fields.append(
  _BGPSRTEV4POLICY.fields_by_name['next_hop_ipv4_address'])
_BGPSRTEV4POLICY.fields_by_name['next_hop_ipv4_address'].containing_oneof = _BGPSRTEV4POLICY.oneofs_by_name['_next_hop_ipv4_address']
_BGPSRTEV4POLICY.oneofs_by_name['_next_hop_ipv6_address'].fields.append(
  _BGPSRTEV4POLICY.fields_by_name['next_hop_ipv6_address'])
_BGPSRTEV4POLICY.fields_by_name['next_hop_ipv6_address'].containing_oneof = _BGPSRTEV4POLICY.oneofs_by_name['_next_hop_ipv6_address']
_BGPSRTEV4POLICY.oneofs_by_name['_advanced'].fields.append(
  _BGPSRTEV4POLICY.fields_by_name['advanced'])
_BGPSRTEV4POLICY.fields_by_name['advanced'].containing_oneof = _BGPSRTEV4POLICY.oneofs_by_name['_advanced']
_BGPSRTEV4POLICY.oneofs_by_name['_add_path'].fields.append(
  _BGPSRTEV4POLICY.fields_by_name['add_path'])
_BGPSRTEV4POLICY.fields_by_name['add_path'].containing_oneof = _BGPSRTEV4POLICY.oneofs_by_name['_add_path']
_BGPSRTEV4POLICY.oneofs_by_name['_as_path'].fields.append(
  _BGPSRTEV4POLICY.fields_by_name['as_path'])
_BGPSRTEV4POLICY.fields_by_name['as_path'].containing_oneof = _BGPSRTEV4POLICY.oneofs_by_name['_as_path']
_BGPSRTEV4POLICY.oneofs_by_name['_active'].fields.append(
  _BGPSRTEV4POLICY.fields_by_name['active'])
_BGPSRTEV4POLICY.fields_by_name['active'].containing_oneof = _BGPSRTEV4POLICY.oneofs_by_name['_active']
_BGPEXTCOMMUNITY_TYPE.containing_type = _BGPEXTCOMMUNITY
_BGPEXTCOMMUNITY_TYPE_ENUM.containing_type = _BGPEXTCOMMUNITY_TYPE
_BGPEXTCOMMUNITY_SUBTYPE.containing_type = _BGPEXTCOMMUNITY
_BGPEXTCOMMUNITY_SUBTYPE_ENUM.containing_type = _BGPEXTCOMMUNITY_SUBTYPE
_BGPEXTCOMMUNITY.fields_by_name['type'].enum_type = _BGPEXTCOMMUNITY_TYPE_ENUM
_BGPEXTCOMMUNITY.fields_by_name['subtype'].enum_type = _BGPEXTCOMMUNITY_SUBTYPE_ENUM
_BGPEXTCOMMUNITY.oneofs_by_name['_type'].fields.append(
  _BGPEXTCOMMUNITY.fields_by_name['type'])
_BGPEXTCOMMUNITY.fields_by_name['type'].containing_oneof = _BGPEXTCOMMUNITY.oneofs_by_name['_type']
_BGPEXTCOMMUNITY.oneofs_by_name['_subtype'].fields.append(
  _BGPEXTCOMMUNITY.fields_by_name['subtype'])
_BGPEXTCOMMUNITY.fields_by_name['subtype'].containing_oneof = _BGPEXTCOMMUNITY.oneofs_by_name['_subtype']
_BGPEXTCOMMUNITY.oneofs_by_name['_value'].fields.append(
  _BGPEXTCOMMUNITY.fields_by_name['value'])
_BGPEXTCOMMUNITY.fields_by_name['value'].containing_oneof = _BGPEXTCOMMUNITY.oneofs_by_name['_value']
_BGPSRTEV4TUNNELTLV.fields_by_name['remote_endpoint_sub_tlv'].message_type = _BGPSRTEREMOTEENDPOINTSUBTLV
_BGPSRTEV4TUNNELTLV.fields_by_name['color_sub_tlv'].message_type = _BGPSRTECOLORSUBTLV
_BGPSRTEV4TUNNELTLV.fields_by_name['binding_sub_tlv'].message_type = _BGPSRTEBINDINGSUBTLV
_BGPSRTEV4TUNNELTLV.fields_by_name['preference_sub_tlv'].message_type = _BGPSRTEPREFERENCESUBTLV
_BGPSRTEV4TUNNELTLV.fields_by_name['policy_priority_sub_tlv'].message_type = _BGPSRTEPOLICYPRIORITYSUBTLV
_BGPSRTEV4TUNNELTLV.fields_by_name['policy_name_sub_tlv'].message_type = _BGPSRTEPOLICYNAMESUBTLV
_BGPSRTEV4TUNNELTLV.fields_by_name['explicit_null_label_policy_sub_tlv'].message_type = _BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV
_BGPSRTEV4TUNNELTLV.fields_by_name['segment_lists'].message_type = _BGPSRTESEGMENTLIST
_BGPSRTEV4TUNNELTLV.oneofs_by_name['_remote_endpoint_sub_tlv'].fields.append(
  _BGPSRTEV4TUNNELTLV.fields_by_name['remote_endpoint_sub_tlv'])
_BGPSRTEV4TUNNELTLV.fields_by_name['remote_endpoint_sub_tlv'].containing_oneof = _BGPSRTEV4TUNNELTLV.oneofs_by_name['_remote_endpoint_sub_tlv']
_BGPSRTEV4TUNNELTLV.oneofs_by_name['_color_sub_tlv'].fields.append(
  _BGPSRTEV4TUNNELTLV.fields_by_name['color_sub_tlv'])
_BGPSRTEV4TUNNELTLV.fields_by_name['color_sub_tlv'].containing_oneof = _BGPSRTEV4TUNNELTLV.oneofs_by_name['_color_sub_tlv']
_BGPSRTEV4TUNNELTLV.oneofs_by_name['_binding_sub_tlv'].fields.append(
  _BGPSRTEV4TUNNELTLV.fields_by_name['binding_sub_tlv'])
_BGPSRTEV4TUNNELTLV.fields_by_name['binding_sub_tlv'].containing_oneof = _BGPSRTEV4TUNNELTLV.oneofs_by_name['_binding_sub_tlv']
_BGPSRTEV4TUNNELTLV.oneofs_by_name['_preference_sub_tlv'].fields.append(
  _BGPSRTEV4TUNNELTLV.fields_by_name['preference_sub_tlv'])
_BGPSRTEV4TUNNELTLV.fields_by_name['preference_sub_tlv'].containing_oneof = _BGPSRTEV4TUNNELTLV.oneofs_by_name['_preference_sub_tlv']
_BGPSRTEV4TUNNELTLV.oneofs_by_name['_policy_priority_sub_tlv'].fields.append(
  _BGPSRTEV4TUNNELTLV.fields_by_name['policy_priority_sub_tlv'])
_BGPSRTEV4TUNNELTLV.fields_by_name['policy_priority_sub_tlv'].containing_oneof = _BGPSRTEV4TUNNELTLV.oneofs_by_name['_policy_priority_sub_tlv']
_BGPSRTEV4TUNNELTLV.oneofs_by_name['_policy_name_sub_tlv'].fields.append(
  _BGPSRTEV4TUNNELTLV.fields_by_name['policy_name_sub_tlv'])
_BGPSRTEV4TUNNELTLV.fields_by_name['policy_name_sub_tlv'].containing_oneof = _BGPSRTEV4TUNNELTLV.oneofs_by_name['_policy_name_sub_tlv']
_BGPSRTEV4TUNNELTLV.oneofs_by_name['_explicit_null_label_policy_sub_tlv'].fields.append(
  _BGPSRTEV4TUNNELTLV.fields_by_name['explicit_null_label_policy_sub_tlv'])
_BGPSRTEV4TUNNELTLV.fields_by_name['explicit_null_label_policy_sub_tlv'].containing_oneof = _BGPSRTEV4TUNNELTLV.oneofs_by_name['_explicit_null_label_policy_sub_tlv']
_BGPSRTEV4TUNNELTLV.oneofs_by_name['_active'].fields.append(
  _BGPSRTEV4TUNNELTLV.fields_by_name['active'])
_BGPSRTEV4TUNNELTLV.fields_by_name['active'].containing_oneof = _BGPSRTEV4TUNNELTLV.oneofs_by_name['_active']
_BGPSRTEREMOTEENDPOINTSUBTLV_ADDRESSFAMILY.containing_type = _BGPSRTEREMOTEENDPOINTSUBTLV
_BGPSRTEREMOTEENDPOINTSUBTLV_ADDRESSFAMILY_ENUM.containing_type = _BGPSRTEREMOTEENDPOINTSUBTLV_ADDRESSFAMILY
_BGPSRTEREMOTEENDPOINTSUBTLV.fields_by_name['address_family'].enum_type = _BGPSRTEREMOTEENDPOINTSUBTLV_ADDRESSFAMILY_ENUM
_BGPSRTEREMOTEENDPOINTSUBTLV.oneofs_by_name['_as_number'].fields.append(
  _BGPSRTEREMOTEENDPOINTSUBTLV.fields_by_name['as_number'])
_BGPSRTEREMOTEENDPOINTSUBTLV.fields_by_name['as_number'].containing_oneof = _BGPSRTEREMOTEENDPOINTSUBTLV.oneofs_by_name['_as_number']
_BGPSRTEREMOTEENDPOINTSUBTLV.oneofs_by_name['_address_family'].fields.append(
  _BGPSRTEREMOTEENDPOINTSUBTLV.fields_by_name['address_family'])
_BGPSRTEREMOTEENDPOINTSUBTLV.fields_by_name['address_family'].containing_oneof = _BGPSRTEREMOTEENDPOINTSUBTLV.oneofs_by_name['_address_family']
_BGPSRTEREMOTEENDPOINTSUBTLV.oneofs_by_name['_ipv4_address'].fields.append(
  _BGPSRTEREMOTEENDPOINTSUBTLV.fields_by_name['ipv4_address'])
_BGPSRTEREMOTEENDPOINTSUBTLV.fields_by_name['ipv4_address'].containing_oneof = _BGPSRTEREMOTEENDPOINTSUBTLV.oneofs_by_name['_ipv4_address']
_BGPSRTEREMOTEENDPOINTSUBTLV.oneofs_by_name['_ipv6_address'].fields.append(
  _BGPSRTEREMOTEENDPOINTSUBTLV.fields_by_name['ipv6_address'])
_BGPSRTEREMOTEENDPOINTSUBTLV.fields_by_name['ipv6_address'].containing_oneof = _BGPSRTEREMOTEENDPOINTSUBTLV.oneofs_by_name['_ipv6_address']
_BGPSRTECOLORSUBTLV.oneofs_by_name['_color'].fields.append(
  _BGPSRTECOLORSUBTLV.fields_by_name['color'])
_BGPSRTECOLORSUBTLV.fields_by_name['color'].containing_oneof = _BGPSRTECOLORSUBTLV.oneofs_by_name['_color']
_BGPSRTEBINDINGSUBTLV_BINDINGSIDTYPE.containing_type = _BGPSRTEBINDINGSUBTLV
_BGPSRTEBINDINGSUBTLV_BINDINGSIDTYPE_ENUM.containing_type = _BGPSRTEBINDINGSUBTLV_BINDINGSIDTYPE
_BGPSRTEBINDINGSUBTLV.fields_by_name['binding_sid_type'].enum_type = _BGPSRTEBINDINGSUBTLV_BINDINGSIDTYPE_ENUM
_BGPSRTEBINDINGSUBTLV.oneofs_by_name['_binding_sid_type'].fields.append(
  _BGPSRTEBINDINGSUBTLV.fields_by_name['binding_sid_type'])
_BGPSRTEBINDINGSUBTLV.fields_by_name['binding_sid_type'].containing_oneof = _BGPSRTEBINDINGSUBTLV.oneofs_by_name['_binding_sid_type']
_BGPSRTEBINDINGSUBTLV.oneofs_by_name['_four_octet_sid'].fields.append(
  _BGPSRTEBINDINGSUBTLV.fields_by_name['four_octet_sid'])
_BGPSRTEBINDINGSUBTLV.fields_by_name['four_octet_sid'].containing_oneof = _BGPSRTEBINDINGSUBTLV.oneofs_by_name['_four_octet_sid']
_BGPSRTEBINDINGSUBTLV.oneofs_by_name['_ipv6_sid'].fields.append(
  _BGPSRTEBINDINGSUBTLV.fields_by_name['ipv6_sid'])
_BGPSRTEBINDINGSUBTLV.fields_by_name['ipv6_sid'].containing_oneof = _BGPSRTEBINDINGSUBTLV.oneofs_by_name['_ipv6_sid']
_BGPSRTEBINDINGSUBTLV.oneofs_by_name['_s_flag'].fields.append(
  _BGPSRTEBINDINGSUBTLV.fields_by_name['s_flag'])
_BGPSRTEBINDINGSUBTLV.fields_by_name['s_flag'].containing_oneof = _BGPSRTEBINDINGSUBTLV.oneofs_by_name['_s_flag']
_BGPSRTEBINDINGSUBTLV.oneofs_by_name['_i_flag'].fields.append(
  _BGPSRTEBINDINGSUBTLV.fields_by_name['i_flag'])
_BGPSRTEBINDINGSUBTLV.fields_by_name['i_flag'].containing_oneof = _BGPSRTEBINDINGSUBTLV.oneofs_by_name['_i_flag']
_BGPSRTEPREFERENCESUBTLV.oneofs_by_name['_preference'].fields.append(
  _BGPSRTEPREFERENCESUBTLV.fields_by_name['preference'])
_BGPSRTEPREFERENCESUBTLV.fields_by_name['preference'].containing_oneof = _BGPSRTEPREFERENCESUBTLV.oneofs_by_name['_preference']
_BGPSRTEPOLICYPRIORITYSUBTLV.oneofs_by_name['_policy_priority'].fields.append(
  _BGPSRTEPOLICYPRIORITYSUBTLV.fields_by_name['policy_priority'])
_BGPSRTEPOLICYPRIORITYSUBTLV.fields_by_name['policy_priority'].containing_oneof = _BGPSRTEPOLICYPRIORITYSUBTLV.oneofs_by_name['_policy_priority']
_BGPSRTEPOLICYNAMESUBTLV.oneofs_by_name['_policy_name'].fields.append(
  _BGPSRTEPOLICYNAMESUBTLV.fields_by_name['policy_name'])
_BGPSRTEPOLICYNAMESUBTLV.fields_by_name['policy_name'].containing_oneof = _BGPSRTEPOLICYNAMESUBTLV.oneofs_by_name['_policy_name']
_BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV_EXPLICITNULLLABELPOLICY.containing_type = _BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV
_BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV_EXPLICITNULLLABELPOLICY_ENUM.containing_type = _BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV_EXPLICITNULLLABELPOLICY
_BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV.fields_by_name['explicit_null_label_policy'].enum_type = _BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV_EXPLICITNULLLABELPOLICY_ENUM
_BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV.oneofs_by_name['_explicit_null_label_policy'].fields.append(
  _BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV.fields_by_name['explicit_null_label_policy'])
_BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV.fields_by_name['explicit_null_label_policy'].containing_oneof = _BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV.oneofs_by_name['_explicit_null_label_policy']
_BGPSRTESEGMENTLIST.fields_by_name['segments'].message_type = _BGPSRTESEGMENT
_BGPSRTESEGMENTLIST.oneofs_by_name['_weight'].fields.append(
  _BGPSRTESEGMENTLIST.fields_by_name['weight'])
_BGPSRTESEGMENTLIST.fields_by_name['weight'].containing_oneof = _BGPSRTESEGMENTLIST.oneofs_by_name['_weight']
_BGPSRTESEGMENTLIST.oneofs_by_name['_active'].fields.append(
  _BGPSRTESEGMENTLIST.fields_by_name['active'])
_BGPSRTESEGMENTLIST.fields_by_name['active'].containing_oneof = _BGPSRTESEGMENTLIST.oneofs_by_name['_active']
_BGPSRTESEGMENT_SEGMENTTYPE.containing_type = _BGPSRTESEGMENT
_BGPSRTESEGMENT_SEGMENTTYPE_ENUM.containing_type = _BGPSRTESEGMENT_SEGMENTTYPE
_BGPSRTESEGMENT.fields_by_name['segment_type'].enum_type = _BGPSRTESEGMENT_SEGMENTTYPE_ENUM
_BGPSRTESEGMENT.fields_by_name['type_a'].message_type = _BGPSRTESEGMENTATYPESUBTLV
_BGPSRTESEGMENT.fields_by_name['type_b'].message_type = _BGPSRTESEGMENTBTYPESUBTLV
_BGPSRTESEGMENT.fields_by_name['type_c'].message_type = _BGPSRTESEGMENTCTYPESUBTLV
_BGPSRTESEGMENT.fields_by_name['type_d'].message_type = _BGPSRTESEGMENTDTYPESUBTLV
_BGPSRTESEGMENT.fields_by_name['type_e'].message_type = _BGPSRTESEGMENTETYPESUBTLV
_BGPSRTESEGMENT.fields_by_name['type_f'].message_type = _BGPSRTESEGMENTFTYPESUBTLV
_BGPSRTESEGMENT.fields_by_name['type_g'].message_type = _BGPSRTESEGMENTGTYPESUBTLV
_BGPSRTESEGMENT.fields_by_name['type_h'].message_type = _BGPSRTESEGMENTHTYPESUBTLV
_BGPSRTESEGMENT.fields_by_name['type_i'].message_type = _BGPSRTESEGMENTITYPESUBTLV
_BGPSRTESEGMENT.fields_by_name['type_j'].message_type = _BGPSRTESEGMENTJTYPESUBTLV
_BGPSRTESEGMENT.fields_by_name['type_k'].message_type = _BGPSRTESEGMENTKTYPESUBTLV
_BGPSRTESEGMENT.oneofs_by_name['_type_a'].fields.append(
  _BGPSRTESEGMENT.fields_by_name['type_a'])
_BGPSRTESEGMENT.fields_by_name['type_a'].containing_oneof = _BGPSRTESEGMENT.oneofs_by_name['_type_a']
_BGPSRTESEGMENT.oneofs_by_name['_type_b'].fields.append(
  _BGPSRTESEGMENT.fields_by_name['type_b'])
_BGPSRTESEGMENT.fields_by_name['type_b'].containing_oneof = _BGPSRTESEGMENT.oneofs_by_name['_type_b']
_BGPSRTESEGMENT.oneofs_by_name['_type_c'].fields.append(
  _BGPSRTESEGMENT.fields_by_name['type_c'])
_BGPSRTESEGMENT.fields_by_name['type_c'].containing_oneof = _BGPSRTESEGMENT.oneofs_by_name['_type_c']
_BGPSRTESEGMENT.oneofs_by_name['_type_d'].fields.append(
  _BGPSRTESEGMENT.fields_by_name['type_d'])
_BGPSRTESEGMENT.fields_by_name['type_d'].containing_oneof = _BGPSRTESEGMENT.oneofs_by_name['_type_d']
_BGPSRTESEGMENT.oneofs_by_name['_type_e'].fields.append(
  _BGPSRTESEGMENT.fields_by_name['type_e'])
_BGPSRTESEGMENT.fields_by_name['type_e'].containing_oneof = _BGPSRTESEGMENT.oneofs_by_name['_type_e']
_BGPSRTESEGMENT.oneofs_by_name['_type_f'].fields.append(
  _BGPSRTESEGMENT.fields_by_name['type_f'])
_BGPSRTESEGMENT.fields_by_name['type_f'].containing_oneof = _BGPSRTESEGMENT.oneofs_by_name['_type_f']
_BGPSRTESEGMENT.oneofs_by_name['_type_g'].fields.append(
  _BGPSRTESEGMENT.fields_by_name['type_g'])
_BGPSRTESEGMENT.fields_by_name['type_g'].containing_oneof = _BGPSRTESEGMENT.oneofs_by_name['_type_g']
_BGPSRTESEGMENT.oneofs_by_name['_type_h'].fields.append(
  _BGPSRTESEGMENT.fields_by_name['type_h'])
_BGPSRTESEGMENT.fields_by_name['type_h'].containing_oneof = _BGPSRTESEGMENT.oneofs_by_name['_type_h']
_BGPSRTESEGMENT.oneofs_by_name['_type_i'].fields.append(
  _BGPSRTESEGMENT.fields_by_name['type_i'])
_BGPSRTESEGMENT.fields_by_name['type_i'].containing_oneof = _BGPSRTESEGMENT.oneofs_by_name['_type_i']
_BGPSRTESEGMENT.oneofs_by_name['_type_j'].fields.append(
  _BGPSRTESEGMENT.fields_by_name['type_j'])
_BGPSRTESEGMENT.fields_by_name['type_j'].containing_oneof = _BGPSRTESEGMENT.oneofs_by_name['_type_j']
_BGPSRTESEGMENT.oneofs_by_name['_type_k'].fields.append(
  _BGPSRTESEGMENT.fields_by_name['type_k'])
_BGPSRTESEGMENT.fields_by_name['type_k'].containing_oneof = _BGPSRTESEGMENT.oneofs_by_name['_type_k']
_BGPSRTESEGMENT.oneofs_by_name['_active'].fields.append(
  _BGPSRTESEGMENT.fields_by_name['active'])
_BGPSRTESEGMENT.fields_by_name['active'].containing_oneof = _BGPSRTESEGMENT.oneofs_by_name['_active']
_BGPSRTESRMPLSSID.oneofs_by_name['_label'].fields.append(
  _BGPSRTESRMPLSSID.fields_by_name['label'])
_BGPSRTESRMPLSSID.fields_by_name['label'].containing_oneof = _BGPSRTESRMPLSSID.oneofs_by_name['_label']
_BGPSRTESRMPLSSID.oneofs_by_name['_tc'].fields.append(
  _BGPSRTESRMPLSSID.fields_by_name['tc'])
_BGPSRTESRMPLSSID.fields_by_name['tc'].containing_oneof = _BGPSRTESRMPLSSID.oneofs_by_name['_tc']
_BGPSRTESRMPLSSID.oneofs_by_name['_s_bit'].fields.append(
  _BGPSRTESRMPLSSID.fields_by_name['s_bit'])
_BGPSRTESRMPLSSID.fields_by_name['s_bit'].containing_oneof = _BGPSRTESRMPLSSID.oneofs_by_name['_s_bit']
_BGPSRTESRMPLSSID.oneofs_by_name['_ttl'].fields.append(
  _BGPSRTESRMPLSSID.fields_by_name['ttl'])
_BGPSRTESRMPLSSID.fields_by_name['ttl'].containing_oneof = _BGPSRTESRMPLSSID.oneofs_by_name['_ttl']
_BGPSRTESRV6SIDENDPOINTBEHAVIORANDSTRUCTURE.oneofs_by_name['_lb_length'].fields.append(
  _BGPSRTESRV6SIDENDPOINTBEHAVIORANDSTRUCTURE.fields_by_name['lb_length'])
_BGPSRTESRV6SIDENDPOINTBEHAVIORANDSTRUCTURE.fields_by_name['lb_length'].containing_oneof = _BGPSRTESRV6SIDENDPOINTBEHAVIORANDSTRUCTURE.oneofs_by_name['_lb_length']
_BGPSRTESRV6SIDENDPOINTBEHAVIORANDSTRUCTURE.oneofs_by_name['_ln_length'].fields.append(
  _BGPSRTESRV6SIDENDPOINTBEHAVIORANDSTRUCTURE.fields_by_name['ln_length'])
_BGPSRTESRV6SIDENDPOINTBEHAVIORANDSTRUCTURE.fields_by_name['ln_length'].containing_oneof = _BGPSRTESRV6SIDENDPOINTBEHAVIORANDSTRUCTURE.oneofs_by_name['_ln_length']
_BGPSRTESRV6SIDENDPOINTBEHAVIORANDSTRUCTURE.oneofs_by_name['_func_length'].fields.append(
  _BGPSRTESRV6SIDENDPOINTBEHAVIORANDSTRUCTURE.fields_by_name['func_length'])
_BGPSRTESRV6SIDENDPOINTBEHAVIORANDSTRUCTURE.fields_by_name['func_length'].containing_oneof = _BGPSRTESRV6SIDENDPOINTBEHAVIORANDSTRUCTURE.oneofs_by_name['_func_length']
_BGPSRTESRV6SIDENDPOINTBEHAVIORANDSTRUCTURE.oneofs_by_name['_arg_length'].fields.append(
  _BGPSRTESRV6SIDENDPOINTBEHAVIORANDSTRUCTURE.fields_by_name['arg_length'])
_BGPSRTESRV6SIDENDPOINTBEHAVIORANDSTRUCTURE.fields_by_name['arg_length'].containing_oneof = _BGPSRTESRV6SIDENDPOINTBEHAVIORANDSTRUCTURE.oneofs_by_name['_arg_length']
_BGPSRTESEGMENTATYPESUBTLV.oneofs_by_name['_flags'].fields.append(
  _BGPSRTESEGMENTATYPESUBTLV.fields_by_name['flags'])
_BGPSRTESEGMENTATYPESUBTLV.fields_by_name['flags'].containing_oneof = _BGPSRTESEGMENTATYPESUBTLV.oneofs_by_name['_flags']
_BGPSRTESEGMENTATYPESUBTLV.oneofs_by_name['_label'].fields.append(
  _BGPSRTESEGMENTATYPESUBTLV.fields_by_name['label'])
_BGPSRTESEGMENTATYPESUBTLV.fields_by_name['label'].containing_oneof = _BGPSRTESEGMENTATYPESUBTLV.oneofs_by_name['_label']
_BGPSRTESEGMENTATYPESUBTLV.oneofs_by_name['_tc'].fields.append(
  _BGPSRTESEGMENTATYPESUBTLV.fields_by_name['tc'])
_BGPSRTESEGMENTATYPESUBTLV.fields_by_name['tc'].containing_oneof = _BGPSRTESEGMENTATYPESUBTLV.oneofs_by_name['_tc']
_BGPSRTESEGMENTATYPESUBTLV.oneofs_by_name['_s_bit'].fields.append(
  _BGPSRTESEGMENTATYPESUBTLV.fields_by_name['s_bit'])
_BGPSRTESEGMENTATYPESUBTLV.fields_by_name['s_bit'].containing_oneof = _BGPSRTESEGMENTATYPESUBTLV.oneofs_by_name['_s_bit']
_BGPSRTESEGMENTATYPESUBTLV.oneofs_by_name['_ttl'].fields.append(
  _BGPSRTESEGMENTATYPESUBTLV.fields_by_name['ttl'])
_BGPSRTESEGMENTATYPESUBTLV.fields_by_name['ttl'].containing_oneof = _BGPSRTESEGMENTATYPESUBTLV.oneofs_by_name['_ttl']
_BGPSRTESEGMENTBTYPESUBTLV.fields_by_name['srv6_sid_endpoint_behavior'].message_type = _BGPSRTESRV6SIDENDPOINTBEHAVIORANDSTRUCTURE
_BGPSRTESEGMENTBTYPESUBTLV.oneofs_by_name['_flags'].fields.append(
  _BGPSRTESEGMENTBTYPESUBTLV.fields_by_name['flags'])
_BGPSRTESEGMENTBTYPESUBTLV.fields_by_name['flags'].containing_oneof = _BGPSRTESEGMENTBTYPESUBTLV.oneofs_by_name['_flags']
_BGPSRTESEGMENTBTYPESUBTLV.oneofs_by_name['_srv6_sid_endpoint_behavior'].fields.append(
  _BGPSRTESEGMENTBTYPESUBTLV.fields_by_name['srv6_sid_endpoint_behavior'])
_BGPSRTESEGMENTBTYPESUBTLV.fields_by_name['srv6_sid_endpoint_behavior'].containing_oneof = _BGPSRTESEGMENTBTYPESUBTLV.oneofs_by_name['_srv6_sid_endpoint_behavior']
_BGPSRTESEGMENTCTYPESUBTLV.fields_by_name['sr_mpls_sid'].message_type = _BGPSRTESRMPLSSID
_BGPSRTESEGMENTCTYPESUBTLV.oneofs_by_name['_flags'].fields.append(
  _BGPSRTESEGMENTCTYPESUBTLV.fields_by_name['flags'])
_BGPSRTESEGMENTCTYPESUBTLV.fields_by_name['flags'].containing_oneof = _BGPSRTESEGMENTCTYPESUBTLV.oneofs_by_name['_flags']
_BGPSRTESEGMENTCTYPESUBTLV.oneofs_by_name['_sr_algorithm'].fields.append(
  _BGPSRTESEGMENTCTYPESUBTLV.fields_by_name['sr_algorithm'])
_BGPSRTESEGMENTCTYPESUBTLV.fields_by_name['sr_algorithm'].containing_oneof = _BGPSRTESEGMENTCTYPESUBTLV.oneofs_by_name['_sr_algorithm']
_BGPSRTESEGMENTCTYPESUBTLV.oneofs_by_name['_sr_mpls_sid'].fields.append(
  _BGPSRTESEGMENTCTYPESUBTLV.fields_by_name['sr_mpls_sid'])
_BGPSRTESEGMENTCTYPESUBTLV.fields_by_name['sr_mpls_sid'].containing_oneof = _BGPSRTESEGMENTCTYPESUBTLV.oneofs_by_name['_sr_mpls_sid']
_BGPSRTESEGMENTDTYPESUBTLV.fields_by_name['sr_mpls_sid'].message_type = _BGPSRTESRMPLSSID
_BGPSRTESEGMENTDTYPESUBTLV.oneofs_by_name['_flags'].fields.append(
  _BGPSRTESEGMENTDTYPESUBTLV.fields_by_name['flags'])
_BGPSRTESEGMENTDTYPESUBTLV.fields_by_name['flags'].containing_oneof = _BGPSRTESEGMENTDTYPESUBTLV.oneofs_by_name['_flags']
_BGPSRTESEGMENTDTYPESUBTLV.oneofs_by_name['_sr_algorithm'].fields.append(
  _BGPSRTESEGMENTDTYPESUBTLV.fields_by_name['sr_algorithm'])
_BGPSRTESEGMENTDTYPESUBTLV.fields_by_name['sr_algorithm'].containing_oneof = _BGPSRTESEGMENTDTYPESUBTLV.oneofs_by_name['_sr_algorithm']
_BGPSRTESEGMENTDTYPESUBTLV.oneofs_by_name['_sr_mpls_sid'].fields.append(
  _BGPSRTESEGMENTDTYPESUBTLV.fields_by_name['sr_mpls_sid'])
_BGPSRTESEGMENTDTYPESUBTLV.fields_by_name['sr_mpls_sid'].containing_oneof = _BGPSRTESEGMENTDTYPESUBTLV.oneofs_by_name['_sr_mpls_sid']
_BGPSRTESEGMENTETYPESUBTLV.fields_by_name['sr_mpls_sid'].message_type = _BGPSRTESRMPLSSID
_BGPSRTESEGMENTETYPESUBTLV.oneofs_by_name['_flags'].fields.append(
  _BGPSRTESEGMENTETYPESUBTLV.fields_by_name['flags'])
_BGPSRTESEGMENTETYPESUBTLV.fields_by_name['flags'].containing_oneof = _BGPSRTESEGMENTETYPESUBTLV.oneofs_by_name['_flags']
_BGPSRTESEGMENTETYPESUBTLV.oneofs_by_name['_local_interface_id'].fields.append(
  _BGPSRTESEGMENTETYPESUBTLV.fields_by_name['local_interface_id'])
_BGPSRTESEGMENTETYPESUBTLV.fields_by_name['local_interface_id'].containing_oneof = _BGPSRTESEGMENTETYPESUBTLV.oneofs_by_name['_local_interface_id']
_BGPSRTESEGMENTETYPESUBTLV.oneofs_by_name['_sr_mpls_sid'].fields.append(
  _BGPSRTESEGMENTETYPESUBTLV.fields_by_name['sr_mpls_sid'])
_BGPSRTESEGMENTETYPESUBTLV.fields_by_name['sr_mpls_sid'].containing_oneof = _BGPSRTESEGMENTETYPESUBTLV.oneofs_by_name['_sr_mpls_sid']
_BGPSRTESEGMENTFTYPESUBTLV.fields_by_name['sr_mpls_sid'].message_type = _BGPSRTESRMPLSSID
_BGPSRTESEGMENTFTYPESUBTLV.oneofs_by_name['_flags'].fields.append(
  _BGPSRTESEGMENTFTYPESUBTLV.fields_by_name['flags'])
_BGPSRTESEGMENTFTYPESUBTLV.fields_by_name['flags'].containing_oneof = _BGPSRTESEGMENTFTYPESUBTLV.oneofs_by_name['_flags']
_BGPSRTESEGMENTFTYPESUBTLV.oneofs_by_name['_sr_mpls_sid'].fields.append(
  _BGPSRTESEGMENTFTYPESUBTLV.fields_by_name['sr_mpls_sid'])
_BGPSRTESEGMENTFTYPESUBTLV.fields_by_name['sr_mpls_sid'].containing_oneof = _BGPSRTESEGMENTFTYPESUBTLV.oneofs_by_name['_sr_mpls_sid']
_BGPSRTESEGMENTGTYPESUBTLV.fields_by_name['sr_mpls_sid'].message_type = _BGPSRTESRMPLSSID
_BGPSRTESEGMENTGTYPESUBTLV.oneofs_by_name['_flags'].fields.append(
  _BGPSRTESEGMENTGTYPESUBTLV.fields_by_name['flags'])
_BGPSRTESEGMENTGTYPESUBTLV.fields_by_name['flags'].containing_oneof = _BGPSRTESEGMENTGTYPESUBTLV.oneofs_by_name['_flags']
_BGPSRTESEGMENTGTYPESUBTLV.oneofs_by_name['_local_interface_id'].fields.append(
  _BGPSRTESEGMENTGTYPESUBTLV.fields_by_name['local_interface_id'])
_BGPSRTESEGMENTGTYPESUBTLV.fields_by_name['local_interface_id'].containing_oneof = _BGPSRTESEGMENTGTYPESUBTLV.oneofs_by_name['_local_interface_id']
_BGPSRTESEGMENTGTYPESUBTLV.oneofs_by_name['_remote_interface_id'].fields.append(
  _BGPSRTESEGMENTGTYPESUBTLV.fields_by_name['remote_interface_id'])
_BGPSRTESEGMENTGTYPESUBTLV.fields_by_name['remote_interface_id'].containing_oneof = _BGPSRTESEGMENTGTYPESUBTLV.oneofs_by_name['_remote_interface_id']
_BGPSRTESEGMENTGTYPESUBTLV.oneofs_by_name['_sr_mpls_sid'].fields.append(
  _BGPSRTESEGMENTGTYPESUBTLV.fields_by_name['sr_mpls_sid'])
_BGPSRTESEGMENTGTYPESUBTLV.fields_by_name['sr_mpls_sid'].containing_oneof = _BGPSRTESEGMENTGTYPESUBTLV.oneofs_by_name['_sr_mpls_sid']
_BGPSRTESEGMENTHTYPESUBTLV.fields_by_name['sr_mpls_sid'].message_type = _BGPSRTESRMPLSSID
_BGPSRTESEGMENTHTYPESUBTLV.oneofs_by_name['_flags'].fields.append(
  _BGPSRTESEGMENTHTYPESUBTLV.fields_by_name['flags'])
_BGPSRTESEGMENTHTYPESUBTLV.fields_by_name['flags'].containing_oneof = _BGPSRTESEGMENTHTYPESUBTLV.oneofs_by_name['_flags']
_BGPSRTESEGMENTHTYPESUBTLV.oneofs_by_name['_sr_mpls_sid'].fields.append(
  _BGPSRTESEGMENTHTYPESUBTLV.fields_by_name['sr_mpls_sid'])
_BGPSRTESEGMENTHTYPESUBTLV.fields_by_name['sr_mpls_sid'].containing_oneof = _BGPSRTESEGMENTHTYPESUBTLV.oneofs_by_name['_sr_mpls_sid']
_BGPSRTESEGMENTITYPESUBTLV.fields_by_name['srv6_sid_endpoint_behavior'].message_type = _BGPSRTESRV6SIDENDPOINTBEHAVIORANDSTRUCTURE
_BGPSRTESEGMENTITYPESUBTLV.oneofs_by_name['_flags'].fields.append(
  _BGPSRTESEGMENTITYPESUBTLV.fields_by_name['flags'])
_BGPSRTESEGMENTITYPESUBTLV.fields_by_name['flags'].containing_oneof = _BGPSRTESEGMENTITYPESUBTLV.oneofs_by_name['_flags']
_BGPSRTESEGMENTITYPESUBTLV.oneofs_by_name['_srv6_sid'].fields.append(
  _BGPSRTESEGMENTITYPESUBTLV.fields_by_name['srv6_sid'])
_BGPSRTESEGMENTITYPESUBTLV.fields_by_name['srv6_sid'].containing_oneof = _BGPSRTESEGMENTITYPESUBTLV.oneofs_by_name['_srv6_sid']
_BGPSRTESEGMENTITYPESUBTLV.oneofs_by_name['_srv6_sid_endpoint_behavior'].fields.append(
  _BGPSRTESEGMENTITYPESUBTLV.fields_by_name['srv6_sid_endpoint_behavior'])
_BGPSRTESEGMENTITYPESUBTLV.fields_by_name['srv6_sid_endpoint_behavior'].containing_oneof = _BGPSRTESEGMENTITYPESUBTLV.oneofs_by_name['_srv6_sid_endpoint_behavior']
_BGPSRTESEGMENTJTYPESUBTLV.fields_by_name['srv6_sid_endpoint_behavior'].message_type = _BGPSRTESRV6SIDENDPOINTBEHAVIORANDSTRUCTURE
_BGPSRTESEGMENTJTYPESUBTLV.oneofs_by_name['_flags'].fields.append(
  _BGPSRTESEGMENTJTYPESUBTLV.fields_by_name['flags'])
_BGPSRTESEGMENTJTYPESUBTLV.fields_by_name['flags'].containing_oneof = _BGPSRTESEGMENTJTYPESUBTLV.oneofs_by_name['_flags']
_BGPSRTESEGMENTJTYPESUBTLV.oneofs_by_name['_sr_algorithm'].fields.append(
  _BGPSRTESEGMENTJTYPESUBTLV.fields_by_name['sr_algorithm'])
_BGPSRTESEGMENTJTYPESUBTLV.fields_by_name['sr_algorithm'].containing_oneof = _BGPSRTESEGMENTJTYPESUBTLV.oneofs_by_name['_sr_algorithm']
_BGPSRTESEGMENTJTYPESUBTLV.oneofs_by_name['_local_interface_id'].fields.append(
  _BGPSRTESEGMENTJTYPESUBTLV.fields_by_name['local_interface_id'])
_BGPSRTESEGMENTJTYPESUBTLV.fields_by_name['local_interface_id'].containing_oneof = _BGPSRTESEGMENTJTYPESUBTLV.oneofs_by_name['_local_interface_id']
_BGPSRTESEGMENTJTYPESUBTLV.oneofs_by_name['_remote_interface_id'].fields.append(
  _BGPSRTESEGMENTJTYPESUBTLV.fields_by_name['remote_interface_id'])
_BGPSRTESEGMENTJTYPESUBTLV.fields_by_name['remote_interface_id'].containing_oneof = _BGPSRTESEGMENTJTYPESUBTLV.oneofs_by_name['_remote_interface_id']
_BGPSRTESEGMENTJTYPESUBTLV.oneofs_by_name['_srv6_sid'].fields.append(
  _BGPSRTESEGMENTJTYPESUBTLV.fields_by_name['srv6_sid'])
_BGPSRTESEGMENTJTYPESUBTLV.fields_by_name['srv6_sid'].containing_oneof = _BGPSRTESEGMENTJTYPESUBTLV.oneofs_by_name['_srv6_sid']
_BGPSRTESEGMENTJTYPESUBTLV.oneofs_by_name['_srv6_sid_endpoint_behavior'].fields.append(
  _BGPSRTESEGMENTJTYPESUBTLV.fields_by_name['srv6_sid_endpoint_behavior'])
_BGPSRTESEGMENTJTYPESUBTLV.fields_by_name['srv6_sid_endpoint_behavior'].containing_oneof = _BGPSRTESEGMENTJTYPESUBTLV.oneofs_by_name['_srv6_sid_endpoint_behavior']
_BGPSRTESEGMENTKTYPESUBTLV.fields_by_name['srv6_sid_endpoint_behavior'].message_type = _BGPSRTESRV6SIDENDPOINTBEHAVIORANDSTRUCTURE
_BGPSRTESEGMENTKTYPESUBTLV.oneofs_by_name['_flags'].fields.append(
  _BGPSRTESEGMENTKTYPESUBTLV.fields_by_name['flags'])
_BGPSRTESEGMENTKTYPESUBTLV.fields_by_name['flags'].containing_oneof = _BGPSRTESEGMENTKTYPESUBTLV.oneofs_by_name['_flags']
_BGPSRTESEGMENTKTYPESUBTLV.oneofs_by_name['_sr_algorithm'].fields.append(
  _BGPSRTESEGMENTKTYPESUBTLV.fields_by_name['sr_algorithm'])
_BGPSRTESEGMENTKTYPESUBTLV.fields_by_name['sr_algorithm'].containing_oneof = _BGPSRTESEGMENTKTYPESUBTLV.oneofs_by_name['_sr_algorithm']
_BGPSRTESEGMENTKTYPESUBTLV.oneofs_by_name['_srv6_sid'].fields.append(
  _BGPSRTESEGMENTKTYPESUBTLV.fields_by_name['srv6_sid'])
_BGPSRTESEGMENTKTYPESUBTLV.fields_by_name['srv6_sid'].containing_oneof = _BGPSRTESEGMENTKTYPESUBTLV.oneofs_by_name['_srv6_sid']
_BGPSRTESEGMENTKTYPESUBTLV.oneofs_by_name['_srv6_sid_endpoint_behavior'].fields.append(
  _BGPSRTESEGMENTKTYPESUBTLV.fields_by_name['srv6_sid_endpoint_behavior'])
_BGPSRTESEGMENTKTYPESUBTLV.fields_by_name['srv6_sid_endpoint_behavior'].containing_oneof = _BGPSRTESEGMENTKTYPESUBTLV.oneofs_by_name['_srv6_sid_endpoint_behavior']
_BGPSRTEV6POLICY_NEXTHOPMODE.containing_type = _BGPSRTEV6POLICY
_BGPSRTEV6POLICY_NEXTHOPMODE_ENUM.containing_type = _BGPSRTEV6POLICY_NEXTHOPMODE
_BGPSRTEV6POLICY_NEXTHOPADDRESSTYPE.containing_type = _BGPSRTEV6POLICY
_BGPSRTEV6POLICY_NEXTHOPADDRESSTYPE_ENUM.containing_type = _BGPSRTEV6POLICY_NEXTHOPADDRESSTYPE
_BGPSRTEV6POLICY.fields_by_name['next_hop_mode'].enum_type = _BGPSRTEV6POLICY_NEXTHOPMODE_ENUM
_BGPSRTEV6POLICY.fields_by_name['next_hop_address_type'].enum_type = _BGPSRTEV6POLICY_NEXTHOPADDRESSTYPE_ENUM
_BGPSRTEV6POLICY.fields_by_name['advanced'].message_type = _BGPROUTEADVANCED
_BGPSRTEV6POLICY.fields_by_name['add_path'].message_type = _BGPADDPATH
_BGPSRTEV6POLICY.fields_by_name['as_path'].message_type = _BGPASPATH
_BGPSRTEV6POLICY.fields_by_name['communities'].message_type = _BGPCOMMUNITY
_BGPSRTEV6POLICY.fields_by_name['extcommunities'].message_type = _BGPEXTCOMMUNITY
_BGPSRTEV6POLICY.fields_by_name['tunnel_tlvs'].message_type = _BGPSRTEV6TUNNELTLV
_BGPSRTEV6POLICY.oneofs_by_name['_distinguisher'].fields.append(
  _BGPSRTEV6POLICY.fields_by_name['distinguisher'])
_BGPSRTEV6POLICY.fields_by_name['distinguisher'].containing_oneof = _BGPSRTEV6POLICY.oneofs_by_name['_distinguisher']
_BGPSRTEV6POLICY.oneofs_by_name['_color'].fields.append(
  _BGPSRTEV6POLICY.fields_by_name['color'])
_BGPSRTEV6POLICY.fields_by_name['color'].containing_oneof = _BGPSRTEV6POLICY.oneofs_by_name['_color']
_BGPSRTEV6POLICY.oneofs_by_name['_next_hop_mode'].fields.append(
  _BGPSRTEV6POLICY.fields_by_name['next_hop_mode'])
_BGPSRTEV6POLICY.fields_by_name['next_hop_mode'].containing_oneof = _BGPSRTEV6POLICY.oneofs_by_name['_next_hop_mode']
_BGPSRTEV6POLICY.oneofs_by_name['_next_hop_address_type'].fields.append(
  _BGPSRTEV6POLICY.fields_by_name['next_hop_address_type'])
_BGPSRTEV6POLICY.fields_by_name['next_hop_address_type'].containing_oneof = _BGPSRTEV6POLICY.oneofs_by_name['_next_hop_address_type']
_BGPSRTEV6POLICY.oneofs_by_name['_next_hop_ipv4_address'].fields.append(
  _BGPSRTEV6POLICY.fields_by_name['next_hop_ipv4_address'])
_BGPSRTEV6POLICY.fields_by_name['next_hop_ipv4_address'].containing_oneof = _BGPSRTEV6POLICY.oneofs_by_name['_next_hop_ipv4_address']
_BGPSRTEV6POLICY.oneofs_by_name['_next_hop_ipv6_address'].fields.append(
  _BGPSRTEV6POLICY.fields_by_name['next_hop_ipv6_address'])
_BGPSRTEV6POLICY.fields_by_name['next_hop_ipv6_address'].containing_oneof = _BGPSRTEV6POLICY.oneofs_by_name['_next_hop_ipv6_address']
_BGPSRTEV6POLICY.oneofs_by_name['_advanced'].fields.append(
  _BGPSRTEV6POLICY.fields_by_name['advanced'])
_BGPSRTEV6POLICY.fields_by_name['advanced'].containing_oneof = _BGPSRTEV6POLICY.oneofs_by_name['_advanced']
_BGPSRTEV6POLICY.oneofs_by_name['_add_path'].fields.append(
  _BGPSRTEV6POLICY.fields_by_name['add_path'])
_BGPSRTEV6POLICY.fields_by_name['add_path'].containing_oneof = _BGPSRTEV6POLICY.oneofs_by_name['_add_path']
_BGPSRTEV6POLICY.oneofs_by_name['_as_path'].fields.append(
  _BGPSRTEV6POLICY.fields_by_name['as_path'])
_BGPSRTEV6POLICY.fields_by_name['as_path'].containing_oneof = _BGPSRTEV6POLICY.oneofs_by_name['_as_path']
_BGPSRTEV6POLICY.oneofs_by_name['_active'].fields.append(
  _BGPSRTEV6POLICY.fields_by_name['active'])
_BGPSRTEV6POLICY.fields_by_name['active'].containing_oneof = _BGPSRTEV6POLICY.oneofs_by_name['_active']
_BGPSRTEV6TUNNELTLV.fields_by_name['remote_endpoint_sub_tlv'].message_type = _BGPSRTEREMOTEENDPOINTSUBTLV
_BGPSRTEV6TUNNELTLV.fields_by_name['color_sub_tlv'].message_type = _BGPSRTECOLORSUBTLV
_BGPSRTEV6TUNNELTLV.fields_by_name['binding_sub_tlv'].message_type = _BGPSRTEBINDINGSUBTLV
_BGPSRTEV6TUNNELTLV.fields_by_name['preference_sub_tlv'].message_type = _BGPSRTEPREFERENCESUBTLV
_BGPSRTEV6TUNNELTLV.fields_by_name['policy_priority_sub_tlv'].message_type = _BGPSRTEPOLICYPRIORITYSUBTLV
_BGPSRTEV6TUNNELTLV.fields_by_name['policy_name_sub_tlv'].message_type = _BGPSRTEPOLICYNAMESUBTLV
_BGPSRTEV6TUNNELTLV.fields_by_name['explicit_null_label_policy_sub_tlv'].message_type = _BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV
_BGPSRTEV6TUNNELTLV.fields_by_name['segment_lists'].message_type = _BGPSRTESEGMENTLIST
_BGPSRTEV6TUNNELTLV.oneofs_by_name['_remote_endpoint_sub_tlv'].fields.append(
  _BGPSRTEV6TUNNELTLV.fields_by_name['remote_endpoint_sub_tlv'])
_BGPSRTEV6TUNNELTLV.fields_by_name['remote_endpoint_sub_tlv'].containing_oneof = _BGPSRTEV6TUNNELTLV.oneofs_by_name['_remote_endpoint_sub_tlv']
_BGPSRTEV6TUNNELTLV.oneofs_by_name['_color_sub_tlv'].fields.append(
  _BGPSRTEV6TUNNELTLV.fields_by_name['color_sub_tlv'])
_BGPSRTEV6TUNNELTLV.fields_by_name['color_sub_tlv'].containing_oneof = _BGPSRTEV6TUNNELTLV.oneofs_by_name['_color_sub_tlv']
_BGPSRTEV6TUNNELTLV.oneofs_by_name['_binding_sub_tlv'].fields.append(
  _BGPSRTEV6TUNNELTLV.fields_by_name['binding_sub_tlv'])
_BGPSRTEV6TUNNELTLV.fields_by_name['binding_sub_tlv'].containing_oneof = _BGPSRTEV6TUNNELTLV.oneofs_by_name['_binding_sub_tlv']
_BGPSRTEV6TUNNELTLV.oneofs_by_name['_preference_sub_tlv'].fields.append(
  _BGPSRTEV6TUNNELTLV.fields_by_name['preference_sub_tlv'])
_BGPSRTEV6TUNNELTLV.fields_by_name['preference_sub_tlv'].containing_oneof = _BGPSRTEV6TUNNELTLV.oneofs_by_name['_preference_sub_tlv']
_BGPSRTEV6TUNNELTLV.oneofs_by_name['_policy_priority_sub_tlv'].fields.append(
  _BGPSRTEV6TUNNELTLV.fields_by_name['policy_priority_sub_tlv'])
_BGPSRTEV6TUNNELTLV.fields_by_name['policy_priority_sub_tlv'].containing_oneof = _BGPSRTEV6TUNNELTLV.oneofs_by_name['_policy_priority_sub_tlv']
_BGPSRTEV6TUNNELTLV.oneofs_by_name['_policy_name_sub_tlv'].fields.append(
  _BGPSRTEV6TUNNELTLV.fields_by_name['policy_name_sub_tlv'])
_BGPSRTEV6TUNNELTLV.fields_by_name['policy_name_sub_tlv'].containing_oneof = _BGPSRTEV6TUNNELTLV.oneofs_by_name['_policy_name_sub_tlv']
_BGPSRTEV6TUNNELTLV.oneofs_by_name['_explicit_null_label_policy_sub_tlv'].fields.append(
  _BGPSRTEV6TUNNELTLV.fields_by_name['explicit_null_label_policy_sub_tlv'])
_BGPSRTEV6TUNNELTLV.fields_by_name['explicit_null_label_policy_sub_tlv'].containing_oneof = _BGPSRTEV6TUNNELTLV.oneofs_by_name['_explicit_null_label_policy_sub_tlv']
_BGPSRTEV6TUNNELTLV.oneofs_by_name['_active'].fields.append(
  _BGPSRTEV6TUNNELTLV.fields_by_name['active'])
_BGPSRTEV6TUNNELTLV.fields_by_name['active'].containing_oneof = _BGPSRTEV6TUNNELTLV.oneofs_by_name['_active']
_BGPV6PEER_ASTYPE.containing_type = _BGPV6PEER
_BGPV6PEER_ASTYPE_ENUM.containing_type = _BGPV6PEER_ASTYPE
_BGPV6PEER_ASNUMBERWIDTH.containing_type = _BGPV6PEER
_BGPV6PEER_ASNUMBERWIDTH_ENUM.containing_type = _BGPV6PEER_ASNUMBERWIDTH
_BGPV6PEER.fields_by_name['segment_routing'].message_type = _BGPV6SEGMENTROUTING
_BGPV6PEER.fields_by_name['as_type'].enum_type = _BGPV6PEER_ASTYPE_ENUM
_BGPV6PEER.fields_by_name['as_number_width'].enum_type = _BGPV6PEER_ASNUMBERWIDTH_ENUM
_BGPV6PEER.fields_by_name['advanced'].message_type = _BGPADVANCED
_BGPV6PEER.fields_by_name['capability'].message_type = _BGPCAPABILITY
_BGPV6PEER.fields_by_name['v4_routes'].message_type = _BGPV4ROUTERANGE
_BGPV6PEER.fields_by_name['v6_routes'].message_type = _BGPV6ROUTERANGE
_BGPV6PEER.fields_by_name['v4_srte_policies'].message_type = _BGPSRTEV4POLICY
_BGPV6PEER.fields_by_name['v6_srte_policies'].message_type = _BGPSRTEV6POLICY
_BGPV6PEER.oneofs_by_name['_segment_routing'].fields.append(
  _BGPV6PEER.fields_by_name['segment_routing'])
_BGPV6PEER.fields_by_name['segment_routing'].containing_oneof = _BGPV6PEER.oneofs_by_name['_segment_routing']
_BGPV6PEER.oneofs_by_name['_as_number_width'].fields.append(
  _BGPV6PEER.fields_by_name['as_number_width'])
_BGPV6PEER.fields_by_name['as_number_width'].containing_oneof = _BGPV6PEER.oneofs_by_name['_as_number_width']
_BGPV6PEER.oneofs_by_name['_advanced'].fields.append(
  _BGPV6PEER.fields_by_name['advanced'])
_BGPV6PEER.fields_by_name['advanced'].containing_oneof = _BGPV6PEER.oneofs_by_name['_advanced']
_BGPV6PEER.oneofs_by_name['_capability'].fields.append(
  _BGPV6PEER.fields_by_name['capability'])
_BGPV6PEER.fields_by_name['capability'].containing_oneof = _BGPV6PEER.oneofs_by_name['_capability']
_BGPV6INTERFACE.fields_by_name['peers'].message_type = _BGPV6PEER
_BGPV6SEGMENTROUTING.oneofs_by_name['_ingress_supports_vpn'].fields.append(
  _BGPV6SEGMENTROUTING.fields_by_name['ingress_supports_vpn'])
_BGPV6SEGMENTROUTING.fields_by_name['ingress_supports_vpn'].containing_oneof = _BGPV6SEGMENTROUTING.oneofs_by_name['_ingress_supports_vpn']
_BGPV6SEGMENTROUTING.oneofs_by_name['_reduced_encapsulation'].fields.append(
  _BGPV6SEGMENTROUTING.fields_by_name['reduced_encapsulation'])
_BGPV6SEGMENTROUTING.fields_by_name['reduced_encapsulation'].containing_oneof = _BGPV6SEGMENTROUTING.oneofs_by_name['_reduced_encapsulation']
_BGPV6SEGMENTROUTING.oneofs_by_name['_copy_time_to_live'].fields.append(
  _BGPV6SEGMENTROUTING.fields_by_name['copy_time_to_live'])
_BGPV6SEGMENTROUTING.fields_by_name['copy_time_to_live'].containing_oneof = _BGPV6SEGMENTROUTING.oneofs_by_name['_copy_time_to_live']
_BGPV6SEGMENTROUTING.oneofs_by_name['_time_to_live'].fields.append(
  _BGPV6SEGMENTROUTING.fields_by_name['time_to_live'])
_BGPV6SEGMENTROUTING.fields_by_name['time_to_live'].containing_oneof = _BGPV6SEGMENTROUTING.oneofs_by_name['_time_to_live']
_BGPV6SEGMENTROUTING.oneofs_by_name['_max_sids_per_srh'].fields.append(
  _BGPV6SEGMENTROUTING.fields_by_name['max_sids_per_srh'])
_BGPV6SEGMENTROUTING.fields_by_name['max_sids_per_srh'].containing_oneof = _BGPV6SEGMENTROUTING.oneofs_by_name['_max_sids_per_srh']
_BGPV6SEGMENTROUTING.oneofs_by_name['_auto_generate_segment_left_value'].fields.append(
  _BGPV6SEGMENTROUTING.fields_by_name['auto_generate_segment_left_value'])
_BGPV6SEGMENTROUTING.fields_by_name['auto_generate_segment_left_value'].containing_oneof = _BGPV6SEGMENTROUTING.oneofs_by_name['_auto_generate_segment_left_value']
_BGPV6SEGMENTROUTING.oneofs_by_name['_segment_left_value'].fields.append(
  _BGPV6SEGMENTROUTING.fields_by_name['segment_left_value'])
_BGPV6SEGMENTROUTING.fields_by_name['segment_left_value'].containing_oneof = _BGPV6SEGMENTROUTING.oneofs_by_name['_segment_left_value']
_BGPV6SEGMENTROUTING.oneofs_by_name['_advertise_sr_te_policy'].fields.append(
  _BGPV6SEGMENTROUTING.fields_by_name['advertise_sr_te_policy'])
_BGPV6SEGMENTROUTING.fields_by_name['advertise_sr_te_policy'].containing_oneof = _BGPV6SEGMENTROUTING.oneofs_by_name['_advertise_sr_te_policy']
_FLOW.fields_by_name['tx_rx'].message_type = _FLOWTXRX
_FLOW.fields_by_name['packet'].message_type = _FLOWHEADER
_FLOW.fields_by_name['size'].message_type = _FLOWSIZE
_FLOW.fields_by_name['rate'].message_type = _FLOWRATE
_FLOW.fields_by_name['duration'].message_type = _FLOWDURATION
_FLOW.fields_by_name['metrics'].message_type = _FLOWMETRICS
_FLOW.oneofs_by_name['_size'].fields.append(
  _FLOW.fields_by_name['size'])
_FLOW.fields_by_name['size'].containing_oneof = _FLOW.oneofs_by_name['_size']
_FLOW.oneofs_by_name['_rate'].fields.append(
  _FLOW.fields_by_name['rate'])
_FLOW.fields_by_name['rate'].containing_oneof = _FLOW.oneofs_by_name['_rate']
_FLOW.oneofs_by_name['_duration'].fields.append(
  _FLOW.fields_by_name['duration'])
_FLOW.fields_by_name['duration'].containing_oneof = _FLOW.oneofs_by_name['_duration']
_FLOW.oneofs_by_name['_metrics'].fields.append(
  _FLOW.fields_by_name['metrics'])
_FLOW.fields_by_name['metrics'].containing_oneof = _FLOW.oneofs_by_name['_metrics']
_FLOWTXRX_CHOICE.containing_type = _FLOWTXRX
_FLOWTXRX_CHOICE_ENUM.containing_type = _FLOWTXRX_CHOICE
_FLOWTXRX.fields_by_name['choice'].enum_type = _FLOWTXRX_CHOICE_ENUM
_FLOWTXRX.fields_by_name['port'].message_type = _FLOWPORT
_FLOWTXRX.fields_by_name['device'].message_type = _FLOWROUTER
_FLOWTXRX.oneofs_by_name['_choice'].fields.append(
  _FLOWTXRX.fields_by_name['choice'])
_FLOWTXRX.fields_by_name['choice'].containing_oneof = _FLOWTXRX.oneofs_by_name['_choice']
_FLOWTXRX.oneofs_by_name['_port'].fields.append(
  _FLOWTXRX.fields_by_name['port'])
_FLOWTXRX.fields_by_name['port'].containing_oneof = _FLOWTXRX.oneofs_by_name['_port']
_FLOWTXRX.oneofs_by_name['_device'].fields.append(
  _FLOWTXRX.fields_by_name['device'])
_FLOWTXRX.fields_by_name['device'].containing_oneof = _FLOWTXRX.oneofs_by_name['_device']
_FLOWPORT.oneofs_by_name['_rx_name'].fields.append(
  _FLOWPORT.fields_by_name['rx_name'])
_FLOWPORT.fields_by_name['rx_name'].containing_oneof = _FLOWPORT.oneofs_by_name['_rx_name']
_FLOWROUTER_MODE.containing_type = _FLOWROUTER
_FLOWROUTER_MODE_ENUM.containing_type = _FLOWROUTER_MODE
_FLOWROUTER.fields_by_name['mode'].enum_type = _FLOWROUTER_MODE_ENUM
_FLOWROUTER.oneofs_by_name['_mode'].fields.append(
  _FLOWROUTER.fields_by_name['mode'])
_FLOWROUTER.fields_by_name['mode'].containing_oneof = _FLOWROUTER.oneofs_by_name['_mode']
_FLOWHEADER_CHOICE.containing_type = _FLOWHEADER
_FLOWHEADER_CHOICE_ENUM.containing_type = _FLOWHEADER_CHOICE
_FLOWHEADER.fields_by_name['choice'].enum_type = _FLOWHEADER_CHOICE_ENUM
_FLOWHEADER.fields_by_name['custom'].message_type = _FLOWCUSTOM
_FLOWHEADER.fields_by_name['ethernet'].message_type = _FLOWETHERNET
_FLOWHEADER.fields_by_name['vlan'].message_type = _FLOWVLAN
_FLOWHEADER.fields_by_name['vxlan'].message_type = _FLOWVXLAN
_FLOWHEADER.fields_by_name['ipv4'].message_type = _FLOWIPV4
_FLOWHEADER.fields_by_name['ipv6'].message_type = _FLOWIPV6
_FLOWHEADER.fields_by_name['pfcpause'].message_type = _FLOWPFCPAUSE
_FLOWHEADER.fields_by_name['ethernetpause'].message_type = _FLOWETHERNETPAUSE
_FLOWHEADER.fields_by_name['tcp'].message_type = _FLOWTCP
_FLOWHEADER.fields_by_name['udp'].message_type = _FLOWUDP
_FLOWHEADER.fields_by_name['gre'].message_type = _FLOWGRE
_FLOWHEADER.fields_by_name['gtpv1'].message_type = _FLOWGTPV1
_FLOWHEADER.fields_by_name['gtpv2'].message_type = _FLOWGTPV2
_FLOWHEADER.fields_by_name['arp'].message_type = _FLOWARP
_FLOWHEADER.fields_by_name['icmp'].message_type = _FLOWICMP
_FLOWHEADER.fields_by_name['icmpv6'].message_type = _FLOWICMPV6
_FLOWHEADER.fields_by_name['ppp'].message_type = _FLOWPPP
_FLOWHEADER.fields_by_name['igmpv1'].message_type = _FLOWIGMPV1
_FLOWHEADER.oneofs_by_name['_choice'].fields.append(
  _FLOWHEADER.fields_by_name['choice'])
_FLOWHEADER.fields_by_name['choice'].containing_oneof = _FLOWHEADER.oneofs_by_name['_choice']
_FLOWHEADER.oneofs_by_name['_custom'].fields.append(
  _FLOWHEADER.fields_by_name['custom'])
_FLOWHEADER.fields_by_name['custom'].containing_oneof = _FLOWHEADER.oneofs_by_name['_custom']
_FLOWHEADER.oneofs_by_name['_ethernet'].fields.append(
  _FLOWHEADER.fields_by_name['ethernet'])
_FLOWHEADER.fields_by_name['ethernet'].containing_oneof = _FLOWHEADER.oneofs_by_name['_ethernet']
_FLOWHEADER.oneofs_by_name['_vlan'].fields.append(
  _FLOWHEADER.fields_by_name['vlan'])
_FLOWHEADER.fields_by_name['vlan'].containing_oneof = _FLOWHEADER.oneofs_by_name['_vlan']
_FLOWHEADER.oneofs_by_name['_vxlan'].fields.append(
  _FLOWHEADER.fields_by_name['vxlan'])
_FLOWHEADER.fields_by_name['vxlan'].containing_oneof = _FLOWHEADER.oneofs_by_name['_vxlan']
_FLOWHEADER.oneofs_by_name['_ipv4'].fields.append(
  _FLOWHEADER.fields_by_name['ipv4'])
_FLOWHEADER.fields_by_name['ipv4'].containing_oneof = _FLOWHEADER.oneofs_by_name['_ipv4']
_FLOWHEADER.oneofs_by_name['_ipv6'].fields.append(
  _FLOWHEADER.fields_by_name['ipv6'])
_FLOWHEADER.fields_by_name['ipv6'].containing_oneof = _FLOWHEADER.oneofs_by_name['_ipv6']
_FLOWHEADER.oneofs_by_name['_pfcpause'].fields.append(
  _FLOWHEADER.fields_by_name['pfcpause'])
_FLOWHEADER.fields_by_name['pfcpause'].containing_oneof = _FLOWHEADER.oneofs_by_name['_pfcpause']
_FLOWHEADER.oneofs_by_name['_ethernetpause'].fields.append(
  _FLOWHEADER.fields_by_name['ethernetpause'])
_FLOWHEADER.fields_by_name['ethernetpause'].containing_oneof = _FLOWHEADER.oneofs_by_name['_ethernetpause']
_FLOWHEADER.oneofs_by_name['_tcp'].fields.append(
  _FLOWHEADER.fields_by_name['tcp'])
_FLOWHEADER.fields_by_name['tcp'].containing_oneof = _FLOWHEADER.oneofs_by_name['_tcp']
_FLOWHEADER.oneofs_by_name['_udp'].fields.append(
  _FLOWHEADER.fields_by_name['udp'])
_FLOWHEADER.fields_by_name['udp'].containing_oneof = _FLOWHEADER.oneofs_by_name['_udp']
_FLOWHEADER.oneofs_by_name['_gre'].fields.append(
  _FLOWHEADER.fields_by_name['gre'])
_FLOWHEADER.fields_by_name['gre'].containing_oneof = _FLOWHEADER.oneofs_by_name['_gre']
_FLOWHEADER.oneofs_by_name['_gtpv1'].fields.append(
  _FLOWHEADER.fields_by_name['gtpv1'])
_FLOWHEADER.fields_by_name['gtpv1'].containing_oneof = _FLOWHEADER.oneofs_by_name['_gtpv1']
_FLOWHEADER.oneofs_by_name['_gtpv2'].fields.append(
  _FLOWHEADER.fields_by_name['gtpv2'])
_FLOWHEADER.fields_by_name['gtpv2'].containing_oneof = _FLOWHEADER.oneofs_by_name['_gtpv2']
_FLOWHEADER.oneofs_by_name['_arp'].fields.append(
  _FLOWHEADER.fields_by_name['arp'])
_FLOWHEADER.fields_by_name['arp'].containing_oneof = _FLOWHEADER.oneofs_by_name['_arp']
_FLOWHEADER.oneofs_by_name['_icmp'].fields.append(
  _FLOWHEADER.fields_by_name['icmp'])
_FLOWHEADER.fields_by_name['icmp'].containing_oneof = _FLOWHEADER.oneofs_by_name['_icmp']
_FLOWHEADER.oneofs_by_name['_icmpv6'].fields.append(
  _FLOWHEADER.fields_by_name['icmpv6'])
_FLOWHEADER.fields_by_name['icmpv6'].containing_oneof = _FLOWHEADER.oneofs_by_name['_icmpv6']
_FLOWHEADER.oneofs_by_name['_ppp'].fields.append(
  _FLOWHEADER.fields_by_name['ppp'])
_FLOWHEADER.fields_by_name['ppp'].containing_oneof = _FLOWHEADER.oneofs_by_name['_ppp']
_FLOWHEADER.oneofs_by_name['_igmpv1'].fields.append(
  _FLOWHEADER.fields_by_name['igmpv1'])
_FLOWHEADER.fields_by_name['igmpv1'].containing_oneof = _FLOWHEADER.oneofs_by_name['_igmpv1']
_FLOWETHERNET.fields_by_name['dst'].message_type = _PATTERNFLOWETHERNETDST
_FLOWETHERNET.fields_by_name['src'].message_type = _PATTERNFLOWETHERNETSRC
_FLOWETHERNET.fields_by_name['ether_type'].message_type = _PATTERNFLOWETHERNETETHERTYPE
_FLOWETHERNET.fields_by_name['pfc_queue'].message_type = _PATTERNFLOWETHERNETPFCQUEUE
_FLOWETHERNET.oneofs_by_name['_dst'].fields.append(
  _FLOWETHERNET.fields_by_name['dst'])
_FLOWETHERNET.fields_by_name['dst'].containing_oneof = _FLOWETHERNET.oneofs_by_name['_dst']
_FLOWETHERNET.oneofs_by_name['_src'].fields.append(
  _FLOWETHERNET.fields_by_name['src'])
_FLOWETHERNET.fields_by_name['src'].containing_oneof = _FLOWETHERNET.oneofs_by_name['_src']
_FLOWETHERNET.oneofs_by_name['_ether_type'].fields.append(
  _FLOWETHERNET.fields_by_name['ether_type'])
_FLOWETHERNET.fields_by_name['ether_type'].containing_oneof = _FLOWETHERNET.oneofs_by_name['_ether_type']
_FLOWETHERNET.oneofs_by_name['_pfc_queue'].fields.append(
  _FLOWETHERNET.fields_by_name['pfc_queue'])
_FLOWETHERNET.fields_by_name['pfc_queue'].containing_oneof = _FLOWETHERNET.oneofs_by_name['_pfc_queue']
_FLOWVLAN.fields_by_name['priority'].message_type = _PATTERNFLOWVLANPRIORITY
_FLOWVLAN.fields_by_name['cfi'].message_type = _PATTERNFLOWVLANCFI
_FLOWVLAN.fields_by_name['id'].message_type = _PATTERNFLOWVLANID
_FLOWVLAN.fields_by_name['tpid'].message_type = _PATTERNFLOWVLANTPID
_FLOWVLAN.oneofs_by_name['_priority'].fields.append(
  _FLOWVLAN.fields_by_name['priority'])
_FLOWVLAN.fields_by_name['priority'].containing_oneof = _FLOWVLAN.oneofs_by_name['_priority']
_FLOWVLAN.oneofs_by_name['_cfi'].fields.append(
  _FLOWVLAN.fields_by_name['cfi'])
_FLOWVLAN.fields_by_name['cfi'].containing_oneof = _FLOWVLAN.oneofs_by_name['_cfi']
_FLOWVLAN.oneofs_by_name['_id'].fields.append(
  _FLOWVLAN.fields_by_name['id'])
_FLOWVLAN.fields_by_name['id'].containing_oneof = _FLOWVLAN.oneofs_by_name['_id']
_FLOWVLAN.oneofs_by_name['_tpid'].fields.append(
  _FLOWVLAN.fields_by_name['tpid'])
_FLOWVLAN.fields_by_name['tpid'].containing_oneof = _FLOWVLAN.oneofs_by_name['_tpid']
_FLOWVXLAN.fields_by_name['flags'].message_type = _PATTERNFLOWVXLANFLAGS
_FLOWVXLAN.fields_by_name['reserved0'].message_type = _PATTERNFLOWVXLANRESERVED0
_FLOWVXLAN.fields_by_name['vni'].message_type = _PATTERNFLOWVXLANVNI
_FLOWVXLAN.fields_by_name['reserved1'].message_type = _PATTERNFLOWVXLANRESERVED1
_FLOWVXLAN.oneofs_by_name['_flags'].fields.append(
  _FLOWVXLAN.fields_by_name['flags'])
_FLOWVXLAN.fields_by_name['flags'].containing_oneof = _FLOWVXLAN.oneofs_by_name['_flags']
_FLOWVXLAN.oneofs_by_name['_reserved0'].fields.append(
  _FLOWVXLAN.fields_by_name['reserved0'])
_FLOWVXLAN.fields_by_name['reserved0'].containing_oneof = _FLOWVXLAN.oneofs_by_name['_reserved0']
_FLOWVXLAN.oneofs_by_name['_vni'].fields.append(
  _FLOWVXLAN.fields_by_name['vni'])
_FLOWVXLAN.fields_by_name['vni'].containing_oneof = _FLOWVXLAN.oneofs_by_name['_vni']
_FLOWVXLAN.oneofs_by_name['_reserved1'].fields.append(
  _FLOWVXLAN.fields_by_name['reserved1'])
_FLOWVXLAN.fields_by_name['reserved1'].containing_oneof = _FLOWVXLAN.oneofs_by_name['_reserved1']
_FLOWIPV4.fields_by_name['version'].message_type = _PATTERNFLOWIPV4VERSION
_FLOWIPV4.fields_by_name['header_length'].message_type = _PATTERNFLOWIPV4HEADERLENGTH
_FLOWIPV4.fields_by_name['priority'].message_type = _FLOWIPV4PRIORITY
_FLOWIPV4.fields_by_name['total_length'].message_type = _PATTERNFLOWIPV4TOTALLENGTH
_FLOWIPV4.fields_by_name['identification'].message_type = _PATTERNFLOWIPV4IDENTIFICATION
_FLOWIPV4.fields_by_name['reserved'].message_type = _PATTERNFLOWIPV4RESERVED
_FLOWIPV4.fields_by_name['dont_fragment'].message_type = _PATTERNFLOWIPV4DONTFRAGMENT
_FLOWIPV4.fields_by_name['more_fragments'].message_type = _PATTERNFLOWIPV4MOREFRAGMENTS
_FLOWIPV4.fields_by_name['fragment_offset'].message_type = _PATTERNFLOWIPV4FRAGMENTOFFSET
_FLOWIPV4.fields_by_name['time_to_live'].message_type = _PATTERNFLOWIPV4TIMETOLIVE
_FLOWIPV4.fields_by_name['protocol'].message_type = _PATTERNFLOWIPV4PROTOCOL
_FLOWIPV4.fields_by_name['header_checksum'].message_type = _PATTERNFLOWIPV4HEADERCHECKSUM
_FLOWIPV4.fields_by_name['src'].message_type = _PATTERNFLOWIPV4SRC
_FLOWIPV4.fields_by_name['dst'].message_type = _PATTERNFLOWIPV4DST
_FLOWIPV4.oneofs_by_name['_version'].fields.append(
  _FLOWIPV4.fields_by_name['version'])
_FLOWIPV4.fields_by_name['version'].containing_oneof = _FLOWIPV4.oneofs_by_name['_version']
_FLOWIPV4.oneofs_by_name['_header_length'].fields.append(
  _FLOWIPV4.fields_by_name['header_length'])
_FLOWIPV4.fields_by_name['header_length'].containing_oneof = _FLOWIPV4.oneofs_by_name['_header_length']
_FLOWIPV4.oneofs_by_name['_priority'].fields.append(
  _FLOWIPV4.fields_by_name['priority'])
_FLOWIPV4.fields_by_name['priority'].containing_oneof = _FLOWIPV4.oneofs_by_name['_priority']
_FLOWIPV4.oneofs_by_name['_total_length'].fields.append(
  _FLOWIPV4.fields_by_name['total_length'])
_FLOWIPV4.fields_by_name['total_length'].containing_oneof = _FLOWIPV4.oneofs_by_name['_total_length']
_FLOWIPV4.oneofs_by_name['_identification'].fields.append(
  _FLOWIPV4.fields_by_name['identification'])
_FLOWIPV4.fields_by_name['identification'].containing_oneof = _FLOWIPV4.oneofs_by_name['_identification']
_FLOWIPV4.oneofs_by_name['_reserved'].fields.append(
  _FLOWIPV4.fields_by_name['reserved'])
_FLOWIPV4.fields_by_name['reserved'].containing_oneof = _FLOWIPV4.oneofs_by_name['_reserved']
_FLOWIPV4.oneofs_by_name['_dont_fragment'].fields.append(
  _FLOWIPV4.fields_by_name['dont_fragment'])
_FLOWIPV4.fields_by_name['dont_fragment'].containing_oneof = _FLOWIPV4.oneofs_by_name['_dont_fragment']
_FLOWIPV4.oneofs_by_name['_more_fragments'].fields.append(
  _FLOWIPV4.fields_by_name['more_fragments'])
_FLOWIPV4.fields_by_name['more_fragments'].containing_oneof = _FLOWIPV4.oneofs_by_name['_more_fragments']
_FLOWIPV4.oneofs_by_name['_fragment_offset'].fields.append(
  _FLOWIPV4.fields_by_name['fragment_offset'])
_FLOWIPV4.fields_by_name['fragment_offset'].containing_oneof = _FLOWIPV4.oneofs_by_name['_fragment_offset']
_FLOWIPV4.oneofs_by_name['_time_to_live'].fields.append(
  _FLOWIPV4.fields_by_name['time_to_live'])
_FLOWIPV4.fields_by_name['time_to_live'].containing_oneof = _FLOWIPV4.oneofs_by_name['_time_to_live']
_FLOWIPV4.oneofs_by_name['_protocol'].fields.append(
  _FLOWIPV4.fields_by_name['protocol'])
_FLOWIPV4.fields_by_name['protocol'].containing_oneof = _FLOWIPV4.oneofs_by_name['_protocol']
_FLOWIPV4.oneofs_by_name['_header_checksum'].fields.append(
  _FLOWIPV4.fields_by_name['header_checksum'])
_FLOWIPV4.fields_by_name['header_checksum'].containing_oneof = _FLOWIPV4.oneofs_by_name['_header_checksum']
_FLOWIPV4.oneofs_by_name['_src'].fields.append(
  _FLOWIPV4.fields_by_name['src'])
_FLOWIPV4.fields_by_name['src'].containing_oneof = _FLOWIPV4.oneofs_by_name['_src']
_FLOWIPV4.oneofs_by_name['_dst'].fields.append(
  _FLOWIPV4.fields_by_name['dst'])
_FLOWIPV4.fields_by_name['dst'].containing_oneof = _FLOWIPV4.oneofs_by_name['_dst']
_FLOWIPV4PRIORITY_CHOICE.containing_type = _FLOWIPV4PRIORITY
_FLOWIPV4PRIORITY_CHOICE_ENUM.containing_type = _FLOWIPV4PRIORITY_CHOICE
_FLOWIPV4PRIORITY.fields_by_name['choice'].enum_type = _FLOWIPV4PRIORITY_CHOICE_ENUM
_FLOWIPV4PRIORITY.fields_by_name['raw'].message_type = _PATTERNFLOWIPV4PRIORITYRAW
_FLOWIPV4PRIORITY.fields_by_name['tos'].message_type = _FLOWIPV4TOS
_FLOWIPV4PRIORITY.fields_by_name['dscp'].message_type = _FLOWIPV4DSCP
_FLOWIPV4PRIORITY.oneofs_by_name['_choice'].fields.append(
  _FLOWIPV4PRIORITY.fields_by_name['choice'])
_FLOWIPV4PRIORITY.fields_by_name['choice'].containing_oneof = _FLOWIPV4PRIORITY.oneofs_by_name['_choice']
_FLOWIPV4PRIORITY.oneofs_by_name['_raw'].fields.append(
  _FLOWIPV4PRIORITY.fields_by_name['raw'])
_FLOWIPV4PRIORITY.fields_by_name['raw'].containing_oneof = _FLOWIPV4PRIORITY.oneofs_by_name['_raw']
_FLOWIPV4PRIORITY.oneofs_by_name['_tos'].fields.append(
  _FLOWIPV4PRIORITY.fields_by_name['tos'])
_FLOWIPV4PRIORITY.fields_by_name['tos'].containing_oneof = _FLOWIPV4PRIORITY.oneofs_by_name['_tos']
_FLOWIPV4PRIORITY.oneofs_by_name['_dscp'].fields.append(
  _FLOWIPV4PRIORITY.fields_by_name['dscp'])
_FLOWIPV4PRIORITY.fields_by_name['dscp'].containing_oneof = _FLOWIPV4PRIORITY.oneofs_by_name['_dscp']
_FLOWIPV4DSCP.fields_by_name['phb'].message_type = _PATTERNFLOWIPV4DSCPPHB
_FLOWIPV4DSCP.fields_by_name['ecn'].message_type = _PATTERNFLOWIPV4DSCPECN
_FLOWIPV4DSCP.oneofs_by_name['_phb'].fields.append(
  _FLOWIPV4DSCP.fields_by_name['phb'])
_FLOWIPV4DSCP.fields_by_name['phb'].containing_oneof = _FLOWIPV4DSCP.oneofs_by_name['_phb']
_FLOWIPV4DSCP.oneofs_by_name['_ecn'].fields.append(
  _FLOWIPV4DSCP.fields_by_name['ecn'])
_FLOWIPV4DSCP.fields_by_name['ecn'].containing_oneof = _FLOWIPV4DSCP.oneofs_by_name['_ecn']
_FLOWIPV4TOS.fields_by_name['precedence'].message_type = _PATTERNFLOWIPV4TOSPRECEDENCE
_FLOWIPV4TOS.fields_by_name['delay'].message_type = _PATTERNFLOWIPV4TOSDELAY
_FLOWIPV4TOS.fields_by_name['throughput'].message_type = _PATTERNFLOWIPV4TOSTHROUGHPUT
_FLOWIPV4TOS.fields_by_name['reliability'].message_type = _PATTERNFLOWIPV4TOSRELIABILITY
_FLOWIPV4TOS.fields_by_name['monetary'].message_type = _PATTERNFLOWIPV4TOSMONETARY
_FLOWIPV4TOS.fields_by_name['unused'].message_type = _PATTERNFLOWIPV4TOSUNUSED
_FLOWIPV4TOS.oneofs_by_name['_precedence'].fields.append(
  _FLOWIPV4TOS.fields_by_name['precedence'])
_FLOWIPV4TOS.fields_by_name['precedence'].containing_oneof = _FLOWIPV4TOS.oneofs_by_name['_precedence']
_FLOWIPV4TOS.oneofs_by_name['_delay'].fields.append(
  _FLOWIPV4TOS.fields_by_name['delay'])
_FLOWIPV4TOS.fields_by_name['delay'].containing_oneof = _FLOWIPV4TOS.oneofs_by_name['_delay']
_FLOWIPV4TOS.oneofs_by_name['_throughput'].fields.append(
  _FLOWIPV4TOS.fields_by_name['throughput'])
_FLOWIPV4TOS.fields_by_name['throughput'].containing_oneof = _FLOWIPV4TOS.oneofs_by_name['_throughput']
_FLOWIPV4TOS.oneofs_by_name['_reliability'].fields.append(
  _FLOWIPV4TOS.fields_by_name['reliability'])
_FLOWIPV4TOS.fields_by_name['reliability'].containing_oneof = _FLOWIPV4TOS.oneofs_by_name['_reliability']
_FLOWIPV4TOS.oneofs_by_name['_monetary'].fields.append(
  _FLOWIPV4TOS.fields_by_name['monetary'])
_FLOWIPV4TOS.fields_by_name['monetary'].containing_oneof = _FLOWIPV4TOS.oneofs_by_name['_monetary']
_FLOWIPV4TOS.oneofs_by_name['_unused'].fields.append(
  _FLOWIPV4TOS.fields_by_name['unused'])
_FLOWIPV4TOS.fields_by_name['unused'].containing_oneof = _FLOWIPV4TOS.oneofs_by_name['_unused']
_FLOWIPV6.fields_by_name['version'].message_type = _PATTERNFLOWIPV6VERSION
_FLOWIPV6.fields_by_name['traffic_class'].message_type = _PATTERNFLOWIPV6TRAFFICCLASS
_FLOWIPV6.fields_by_name['flow_label'].message_type = _PATTERNFLOWIPV6FLOWLABEL
_FLOWIPV6.fields_by_name['payload_length'].message_type = _PATTERNFLOWIPV6PAYLOADLENGTH
_FLOWIPV6.fields_by_name['next_header'].message_type = _PATTERNFLOWIPV6NEXTHEADER
_FLOWIPV6.fields_by_name['hop_limit'].message_type = _PATTERNFLOWIPV6HOPLIMIT
_FLOWIPV6.fields_by_name['src'].message_type = _PATTERNFLOWIPV6SRC
_FLOWIPV6.fields_by_name['dst'].message_type = _PATTERNFLOWIPV6DST
_FLOWIPV6.oneofs_by_name['_version'].fields.append(
  _FLOWIPV6.fields_by_name['version'])
_FLOWIPV6.fields_by_name['version'].containing_oneof = _FLOWIPV6.oneofs_by_name['_version']
_FLOWIPV6.oneofs_by_name['_traffic_class'].fields.append(
  _FLOWIPV6.fields_by_name['traffic_class'])
_FLOWIPV6.fields_by_name['traffic_class'].containing_oneof = _FLOWIPV6.oneofs_by_name['_traffic_class']
_FLOWIPV6.oneofs_by_name['_flow_label'].fields.append(
  _FLOWIPV6.fields_by_name['flow_label'])
_FLOWIPV6.fields_by_name['flow_label'].containing_oneof = _FLOWIPV6.oneofs_by_name['_flow_label']
_FLOWIPV6.oneofs_by_name['_payload_length'].fields.append(
  _FLOWIPV6.fields_by_name['payload_length'])
_FLOWIPV6.fields_by_name['payload_length'].containing_oneof = _FLOWIPV6.oneofs_by_name['_payload_length']
_FLOWIPV6.oneofs_by_name['_next_header'].fields.append(
  _FLOWIPV6.fields_by_name['next_header'])
_FLOWIPV6.fields_by_name['next_header'].containing_oneof = _FLOWIPV6.oneofs_by_name['_next_header']
_FLOWIPV6.oneofs_by_name['_hop_limit'].fields.append(
  _FLOWIPV6.fields_by_name['hop_limit'])
_FLOWIPV6.fields_by_name['hop_limit'].containing_oneof = _FLOWIPV6.oneofs_by_name['_hop_limit']
_FLOWIPV6.oneofs_by_name['_src'].fields.append(
  _FLOWIPV6.fields_by_name['src'])
_FLOWIPV6.fields_by_name['src'].containing_oneof = _FLOWIPV6.oneofs_by_name['_src']
_FLOWIPV6.oneofs_by_name['_dst'].fields.append(
  _FLOWIPV6.fields_by_name['dst'])
_FLOWIPV6.fields_by_name['dst'].containing_oneof = _FLOWIPV6.oneofs_by_name['_dst']
_FLOWPFCPAUSE.fields_by_name['dst'].message_type = _PATTERNFLOWPFCPAUSEDST
_FLOWPFCPAUSE.fields_by_name['src'].message_type = _PATTERNFLOWPFCPAUSESRC
_FLOWPFCPAUSE.fields_by_name['ether_type'].message_type = _PATTERNFLOWPFCPAUSEETHERTYPE
_FLOWPFCPAUSE.fields_by_name['control_op_code'].message_type = _PATTERNFLOWPFCPAUSECONTROLOPCODE
_FLOWPFCPAUSE.fields_by_name['class_enable_vector'].message_type = _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR
_FLOWPFCPAUSE.fields_by_name['pause_class_0'].message_type = _PATTERNFLOWPFCPAUSEPAUSECLASS0
_FLOWPFCPAUSE.fields_by_name['pause_class_1'].message_type = _PATTERNFLOWPFCPAUSEPAUSECLASS1
_FLOWPFCPAUSE.fields_by_name['pause_class_2'].message_type = _PATTERNFLOWPFCPAUSEPAUSECLASS2
_FLOWPFCPAUSE.fields_by_name['pause_class_3'].message_type = _PATTERNFLOWPFCPAUSEPAUSECLASS3
_FLOWPFCPAUSE.fields_by_name['pause_class_4'].message_type = _PATTERNFLOWPFCPAUSEPAUSECLASS4
_FLOWPFCPAUSE.fields_by_name['pause_class_5'].message_type = _PATTERNFLOWPFCPAUSEPAUSECLASS5
_FLOWPFCPAUSE.fields_by_name['pause_class_6'].message_type = _PATTERNFLOWPFCPAUSEPAUSECLASS6
_FLOWPFCPAUSE.fields_by_name['pause_class_7'].message_type = _PATTERNFLOWPFCPAUSEPAUSECLASS7
_FLOWPFCPAUSE.oneofs_by_name['_dst'].fields.append(
  _FLOWPFCPAUSE.fields_by_name['dst'])
_FLOWPFCPAUSE.fields_by_name['dst'].containing_oneof = _FLOWPFCPAUSE.oneofs_by_name['_dst']
_FLOWPFCPAUSE.oneofs_by_name['_src'].fields.append(
  _FLOWPFCPAUSE.fields_by_name['src'])
_FLOWPFCPAUSE.fields_by_name['src'].containing_oneof = _FLOWPFCPAUSE.oneofs_by_name['_src']
_FLOWPFCPAUSE.oneofs_by_name['_ether_type'].fields.append(
  _FLOWPFCPAUSE.fields_by_name['ether_type'])
_FLOWPFCPAUSE.fields_by_name['ether_type'].containing_oneof = _FLOWPFCPAUSE.oneofs_by_name['_ether_type']
_FLOWPFCPAUSE.oneofs_by_name['_control_op_code'].fields.append(
  _FLOWPFCPAUSE.fields_by_name['control_op_code'])
_FLOWPFCPAUSE.fields_by_name['control_op_code'].containing_oneof = _FLOWPFCPAUSE.oneofs_by_name['_control_op_code']
_FLOWPFCPAUSE.oneofs_by_name['_class_enable_vector'].fields.append(
  _FLOWPFCPAUSE.fields_by_name['class_enable_vector'])
_FLOWPFCPAUSE.fields_by_name['class_enable_vector'].containing_oneof = _FLOWPFCPAUSE.oneofs_by_name['_class_enable_vector']
_FLOWPFCPAUSE.oneofs_by_name['_pause_class_0'].fields.append(
  _FLOWPFCPAUSE.fields_by_name['pause_class_0'])
_FLOWPFCPAUSE.fields_by_name['pause_class_0'].containing_oneof = _FLOWPFCPAUSE.oneofs_by_name['_pause_class_0']
_FLOWPFCPAUSE.oneofs_by_name['_pause_class_1'].fields.append(
  _FLOWPFCPAUSE.fields_by_name['pause_class_1'])
_FLOWPFCPAUSE.fields_by_name['pause_class_1'].containing_oneof = _FLOWPFCPAUSE.oneofs_by_name['_pause_class_1']
_FLOWPFCPAUSE.oneofs_by_name['_pause_class_2'].fields.append(
  _FLOWPFCPAUSE.fields_by_name['pause_class_2'])
_FLOWPFCPAUSE.fields_by_name['pause_class_2'].containing_oneof = _FLOWPFCPAUSE.oneofs_by_name['_pause_class_2']
_FLOWPFCPAUSE.oneofs_by_name['_pause_class_3'].fields.append(
  _FLOWPFCPAUSE.fields_by_name['pause_class_3'])
_FLOWPFCPAUSE.fields_by_name['pause_class_3'].containing_oneof = _FLOWPFCPAUSE.oneofs_by_name['_pause_class_3']
_FLOWPFCPAUSE.oneofs_by_name['_pause_class_4'].fields.append(
  _FLOWPFCPAUSE.fields_by_name['pause_class_4'])
_FLOWPFCPAUSE.fields_by_name['pause_class_4'].containing_oneof = _FLOWPFCPAUSE.oneofs_by_name['_pause_class_4']
_FLOWPFCPAUSE.oneofs_by_name['_pause_class_5'].fields.append(
  _FLOWPFCPAUSE.fields_by_name['pause_class_5'])
_FLOWPFCPAUSE.fields_by_name['pause_class_5'].containing_oneof = _FLOWPFCPAUSE.oneofs_by_name['_pause_class_5']
_FLOWPFCPAUSE.oneofs_by_name['_pause_class_6'].fields.append(
  _FLOWPFCPAUSE.fields_by_name['pause_class_6'])
_FLOWPFCPAUSE.fields_by_name['pause_class_6'].containing_oneof = _FLOWPFCPAUSE.oneofs_by_name['_pause_class_6']
_FLOWPFCPAUSE.oneofs_by_name['_pause_class_7'].fields.append(
  _FLOWPFCPAUSE.fields_by_name['pause_class_7'])
_FLOWPFCPAUSE.fields_by_name['pause_class_7'].containing_oneof = _FLOWPFCPAUSE.oneofs_by_name['_pause_class_7']
_FLOWETHERNETPAUSE.fields_by_name['dst'].message_type = _PATTERNFLOWETHERNETPAUSEDST
_FLOWETHERNETPAUSE.fields_by_name['src'].message_type = _PATTERNFLOWETHERNETPAUSESRC
_FLOWETHERNETPAUSE.fields_by_name['ether_type'].message_type = _PATTERNFLOWETHERNETPAUSEETHERTYPE
_FLOWETHERNETPAUSE.fields_by_name['control_op_code'].message_type = _PATTERNFLOWETHERNETPAUSECONTROLOPCODE
_FLOWETHERNETPAUSE.fields_by_name['time'].message_type = _PATTERNFLOWETHERNETPAUSETIME
_FLOWETHERNETPAUSE.oneofs_by_name['_dst'].fields.append(
  _FLOWETHERNETPAUSE.fields_by_name['dst'])
_FLOWETHERNETPAUSE.fields_by_name['dst'].containing_oneof = _FLOWETHERNETPAUSE.oneofs_by_name['_dst']
_FLOWETHERNETPAUSE.oneofs_by_name['_src'].fields.append(
  _FLOWETHERNETPAUSE.fields_by_name['src'])
_FLOWETHERNETPAUSE.fields_by_name['src'].containing_oneof = _FLOWETHERNETPAUSE.oneofs_by_name['_src']
_FLOWETHERNETPAUSE.oneofs_by_name['_ether_type'].fields.append(
  _FLOWETHERNETPAUSE.fields_by_name['ether_type'])
_FLOWETHERNETPAUSE.fields_by_name['ether_type'].containing_oneof = _FLOWETHERNETPAUSE.oneofs_by_name['_ether_type']
_FLOWETHERNETPAUSE.oneofs_by_name['_control_op_code'].fields.append(
  _FLOWETHERNETPAUSE.fields_by_name['control_op_code'])
_FLOWETHERNETPAUSE.fields_by_name['control_op_code'].containing_oneof = _FLOWETHERNETPAUSE.oneofs_by_name['_control_op_code']
_FLOWETHERNETPAUSE.oneofs_by_name['_time'].fields.append(
  _FLOWETHERNETPAUSE.fields_by_name['time'])
_FLOWETHERNETPAUSE.fields_by_name['time'].containing_oneof = _FLOWETHERNETPAUSE.oneofs_by_name['_time']
_FLOWTCP.fields_by_name['src_port'].message_type = _PATTERNFLOWTCPSRCPORT
_FLOWTCP.fields_by_name['dst_port'].message_type = _PATTERNFLOWTCPDSTPORT
_FLOWTCP.fields_by_name['seq_num'].message_type = _PATTERNFLOWTCPSEQNUM
_FLOWTCP.fields_by_name['ack_num'].message_type = _PATTERNFLOWTCPACKNUM
_FLOWTCP.fields_by_name['data_offset'].message_type = _PATTERNFLOWTCPDATAOFFSET
_FLOWTCP.fields_by_name['ecn_ns'].message_type = _PATTERNFLOWTCPECNNS
_FLOWTCP.fields_by_name['ecn_cwr'].message_type = _PATTERNFLOWTCPECNCWR
_FLOWTCP.fields_by_name['ecn_echo'].message_type = _PATTERNFLOWTCPECNECHO
_FLOWTCP.fields_by_name['ctl_urg'].message_type = _PATTERNFLOWTCPCTLURG
_FLOWTCP.fields_by_name['ctl_ack'].message_type = _PATTERNFLOWTCPCTLACK
_FLOWTCP.fields_by_name['ctl_psh'].message_type = _PATTERNFLOWTCPCTLPSH
_FLOWTCP.fields_by_name['ctl_rst'].message_type = _PATTERNFLOWTCPCTLRST
_FLOWTCP.fields_by_name['ctl_syn'].message_type = _PATTERNFLOWTCPCTLSYN
_FLOWTCP.fields_by_name['ctl_fin'].message_type = _PATTERNFLOWTCPCTLFIN
_FLOWTCP.fields_by_name['window'].message_type = _PATTERNFLOWTCPWINDOW
_FLOWTCP.oneofs_by_name['_src_port'].fields.append(
  _FLOWTCP.fields_by_name['src_port'])
_FLOWTCP.fields_by_name['src_port'].containing_oneof = _FLOWTCP.oneofs_by_name['_src_port']
_FLOWTCP.oneofs_by_name['_dst_port'].fields.append(
  _FLOWTCP.fields_by_name['dst_port'])
_FLOWTCP.fields_by_name['dst_port'].containing_oneof = _FLOWTCP.oneofs_by_name['_dst_port']
_FLOWTCP.oneofs_by_name['_seq_num'].fields.append(
  _FLOWTCP.fields_by_name['seq_num'])
_FLOWTCP.fields_by_name['seq_num'].containing_oneof = _FLOWTCP.oneofs_by_name['_seq_num']
_FLOWTCP.oneofs_by_name['_ack_num'].fields.append(
  _FLOWTCP.fields_by_name['ack_num'])
_FLOWTCP.fields_by_name['ack_num'].containing_oneof = _FLOWTCP.oneofs_by_name['_ack_num']
_FLOWTCP.oneofs_by_name['_data_offset'].fields.append(
  _FLOWTCP.fields_by_name['data_offset'])
_FLOWTCP.fields_by_name['data_offset'].containing_oneof = _FLOWTCP.oneofs_by_name['_data_offset']
_FLOWTCP.oneofs_by_name['_ecn_ns'].fields.append(
  _FLOWTCP.fields_by_name['ecn_ns'])
_FLOWTCP.fields_by_name['ecn_ns'].containing_oneof = _FLOWTCP.oneofs_by_name['_ecn_ns']
_FLOWTCP.oneofs_by_name['_ecn_cwr'].fields.append(
  _FLOWTCP.fields_by_name['ecn_cwr'])
_FLOWTCP.fields_by_name['ecn_cwr'].containing_oneof = _FLOWTCP.oneofs_by_name['_ecn_cwr']
_FLOWTCP.oneofs_by_name['_ecn_echo'].fields.append(
  _FLOWTCP.fields_by_name['ecn_echo'])
_FLOWTCP.fields_by_name['ecn_echo'].containing_oneof = _FLOWTCP.oneofs_by_name['_ecn_echo']
_FLOWTCP.oneofs_by_name['_ctl_urg'].fields.append(
  _FLOWTCP.fields_by_name['ctl_urg'])
_FLOWTCP.fields_by_name['ctl_urg'].containing_oneof = _FLOWTCP.oneofs_by_name['_ctl_urg']
_FLOWTCP.oneofs_by_name['_ctl_ack'].fields.append(
  _FLOWTCP.fields_by_name['ctl_ack'])
_FLOWTCP.fields_by_name['ctl_ack'].containing_oneof = _FLOWTCP.oneofs_by_name['_ctl_ack']
_FLOWTCP.oneofs_by_name['_ctl_psh'].fields.append(
  _FLOWTCP.fields_by_name['ctl_psh'])
_FLOWTCP.fields_by_name['ctl_psh'].containing_oneof = _FLOWTCP.oneofs_by_name['_ctl_psh']
_FLOWTCP.oneofs_by_name['_ctl_rst'].fields.append(
  _FLOWTCP.fields_by_name['ctl_rst'])
_FLOWTCP.fields_by_name['ctl_rst'].containing_oneof = _FLOWTCP.oneofs_by_name['_ctl_rst']
_FLOWTCP.oneofs_by_name['_ctl_syn'].fields.append(
  _FLOWTCP.fields_by_name['ctl_syn'])
_FLOWTCP.fields_by_name['ctl_syn'].containing_oneof = _FLOWTCP.oneofs_by_name['_ctl_syn']
_FLOWTCP.oneofs_by_name['_ctl_fin'].fields.append(
  _FLOWTCP.fields_by_name['ctl_fin'])
_FLOWTCP.fields_by_name['ctl_fin'].containing_oneof = _FLOWTCP.oneofs_by_name['_ctl_fin']
_FLOWTCP.oneofs_by_name['_window'].fields.append(
  _FLOWTCP.fields_by_name['window'])
_FLOWTCP.fields_by_name['window'].containing_oneof = _FLOWTCP.oneofs_by_name['_window']
_FLOWUDP.fields_by_name['src_port'].message_type = _PATTERNFLOWUDPSRCPORT
_FLOWUDP.fields_by_name['dst_port'].message_type = _PATTERNFLOWUDPDSTPORT
_FLOWUDP.fields_by_name['length'].message_type = _PATTERNFLOWUDPLENGTH
_FLOWUDP.fields_by_name['checksum'].message_type = _PATTERNFLOWUDPCHECKSUM
_FLOWUDP.oneofs_by_name['_src_port'].fields.append(
  _FLOWUDP.fields_by_name['src_port'])
_FLOWUDP.fields_by_name['src_port'].containing_oneof = _FLOWUDP.oneofs_by_name['_src_port']
_FLOWUDP.oneofs_by_name['_dst_port'].fields.append(
  _FLOWUDP.fields_by_name['dst_port'])
_FLOWUDP.fields_by_name['dst_port'].containing_oneof = _FLOWUDP.oneofs_by_name['_dst_port']
_FLOWUDP.oneofs_by_name['_length'].fields.append(
  _FLOWUDP.fields_by_name['length'])
_FLOWUDP.fields_by_name['length'].containing_oneof = _FLOWUDP.oneofs_by_name['_length']
_FLOWUDP.oneofs_by_name['_checksum'].fields.append(
  _FLOWUDP.fields_by_name['checksum'])
_FLOWUDP.fields_by_name['checksum'].containing_oneof = _FLOWUDP.oneofs_by_name['_checksum']
_FLOWGRE.fields_by_name['checksum_present'].message_type = _PATTERNFLOWGRECHECKSUMPRESENT
_FLOWGRE.fields_by_name['reserved0'].message_type = _PATTERNFLOWGRERESERVED0
_FLOWGRE.fields_by_name['version'].message_type = _PATTERNFLOWGREVERSION
_FLOWGRE.fields_by_name['protocol'].message_type = _PATTERNFLOWGREPROTOCOL
_FLOWGRE.fields_by_name['checksum'].message_type = _PATTERNFLOWGRECHECKSUM
_FLOWGRE.fields_by_name['reserved1'].message_type = _PATTERNFLOWGRERESERVED1
_FLOWGRE.oneofs_by_name['_checksum_present'].fields.append(
  _FLOWGRE.fields_by_name['checksum_present'])
_FLOWGRE.fields_by_name['checksum_present'].containing_oneof = _FLOWGRE.oneofs_by_name['_checksum_present']
_FLOWGRE.oneofs_by_name['_reserved0'].fields.append(
  _FLOWGRE.fields_by_name['reserved0'])
_FLOWGRE.fields_by_name['reserved0'].containing_oneof = _FLOWGRE.oneofs_by_name['_reserved0']
_FLOWGRE.oneofs_by_name['_version'].fields.append(
  _FLOWGRE.fields_by_name['version'])
_FLOWGRE.fields_by_name['version'].containing_oneof = _FLOWGRE.oneofs_by_name['_version']
_FLOWGRE.oneofs_by_name['_protocol'].fields.append(
  _FLOWGRE.fields_by_name['protocol'])
_FLOWGRE.fields_by_name['protocol'].containing_oneof = _FLOWGRE.oneofs_by_name['_protocol']
_FLOWGRE.oneofs_by_name['_checksum'].fields.append(
  _FLOWGRE.fields_by_name['checksum'])
_FLOWGRE.fields_by_name['checksum'].containing_oneof = _FLOWGRE.oneofs_by_name['_checksum']
_FLOWGRE.oneofs_by_name['_reserved1'].fields.append(
  _FLOWGRE.fields_by_name['reserved1'])
_FLOWGRE.fields_by_name['reserved1'].containing_oneof = _FLOWGRE.oneofs_by_name['_reserved1']
_FLOWGTPV1.fields_by_name['version'].message_type = _PATTERNFLOWGTPV1VERSION
_FLOWGTPV1.fields_by_name['protocol_type'].message_type = _PATTERNFLOWGTPV1PROTOCOLTYPE
_FLOWGTPV1.fields_by_name['reserved'].message_type = _PATTERNFLOWGTPV1RESERVED
_FLOWGTPV1.fields_by_name['e_flag'].message_type = _PATTERNFLOWGTPV1EFLAG
_FLOWGTPV1.fields_by_name['s_flag'].message_type = _PATTERNFLOWGTPV1SFLAG
_FLOWGTPV1.fields_by_name['pn_flag'].message_type = _PATTERNFLOWGTPV1PNFLAG
_FLOWGTPV1.fields_by_name['message_type'].message_type = _PATTERNFLOWGTPV1MESSAGETYPE
_FLOWGTPV1.fields_by_name['message_length'].message_type = _PATTERNFLOWGTPV1MESSAGELENGTH
_FLOWGTPV1.fields_by_name['teid'].message_type = _PATTERNFLOWGTPV1TEID
_FLOWGTPV1.fields_by_name['squence_number'].message_type = _PATTERNFLOWGTPV1SQUENCENUMBER
_FLOWGTPV1.fields_by_name['n_pdu_number'].message_type = _PATTERNFLOWGTPV1NPDUNUMBER
_FLOWGTPV1.fields_by_name['next_extension_header_type'].message_type = _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE
_FLOWGTPV1.fields_by_name['extension_headers'].message_type = _FLOWGTPEXTENSION
_FLOWGTPV1.oneofs_by_name['_version'].fields.append(
  _FLOWGTPV1.fields_by_name['version'])
_FLOWGTPV1.fields_by_name['version'].containing_oneof = _FLOWGTPV1.oneofs_by_name['_version']
_FLOWGTPV1.oneofs_by_name['_protocol_type'].fields.append(
  _FLOWGTPV1.fields_by_name['protocol_type'])
_FLOWGTPV1.fields_by_name['protocol_type'].containing_oneof = _FLOWGTPV1.oneofs_by_name['_protocol_type']
_FLOWGTPV1.oneofs_by_name['_reserved'].fields.append(
  _FLOWGTPV1.fields_by_name['reserved'])
_FLOWGTPV1.fields_by_name['reserved'].containing_oneof = _FLOWGTPV1.oneofs_by_name['_reserved']
_FLOWGTPV1.oneofs_by_name['_e_flag'].fields.append(
  _FLOWGTPV1.fields_by_name['e_flag'])
_FLOWGTPV1.fields_by_name['e_flag'].containing_oneof = _FLOWGTPV1.oneofs_by_name['_e_flag']
_FLOWGTPV1.oneofs_by_name['_s_flag'].fields.append(
  _FLOWGTPV1.fields_by_name['s_flag'])
_FLOWGTPV1.fields_by_name['s_flag'].containing_oneof = _FLOWGTPV1.oneofs_by_name['_s_flag']
_FLOWGTPV1.oneofs_by_name['_pn_flag'].fields.append(
  _FLOWGTPV1.fields_by_name['pn_flag'])
_FLOWGTPV1.fields_by_name['pn_flag'].containing_oneof = _FLOWGTPV1.oneofs_by_name['_pn_flag']
_FLOWGTPV1.oneofs_by_name['_message_type'].fields.append(
  _FLOWGTPV1.fields_by_name['message_type'])
_FLOWGTPV1.fields_by_name['message_type'].containing_oneof = _FLOWGTPV1.oneofs_by_name['_message_type']
_FLOWGTPV1.oneofs_by_name['_message_length'].fields.append(
  _FLOWGTPV1.fields_by_name['message_length'])
_FLOWGTPV1.fields_by_name['message_length'].containing_oneof = _FLOWGTPV1.oneofs_by_name['_message_length']
_FLOWGTPV1.oneofs_by_name['_teid'].fields.append(
  _FLOWGTPV1.fields_by_name['teid'])
_FLOWGTPV1.fields_by_name['teid'].containing_oneof = _FLOWGTPV1.oneofs_by_name['_teid']
_FLOWGTPV1.oneofs_by_name['_squence_number'].fields.append(
  _FLOWGTPV1.fields_by_name['squence_number'])
_FLOWGTPV1.fields_by_name['squence_number'].containing_oneof = _FLOWGTPV1.oneofs_by_name['_squence_number']
_FLOWGTPV1.oneofs_by_name['_n_pdu_number'].fields.append(
  _FLOWGTPV1.fields_by_name['n_pdu_number'])
_FLOWGTPV1.fields_by_name['n_pdu_number'].containing_oneof = _FLOWGTPV1.oneofs_by_name['_n_pdu_number']
_FLOWGTPV1.oneofs_by_name['_next_extension_header_type'].fields.append(
  _FLOWGTPV1.fields_by_name['next_extension_header_type'])
_FLOWGTPV1.fields_by_name['next_extension_header_type'].containing_oneof = _FLOWGTPV1.oneofs_by_name['_next_extension_header_type']
_FLOWGTPEXTENSION.fields_by_name['extension_length'].message_type = _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH
_FLOWGTPEXTENSION.fields_by_name['contents'].message_type = _PATTERNFLOWGTPEXTENSIONCONTENTS
_FLOWGTPEXTENSION.fields_by_name['next_extension_header'].message_type = _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER
_FLOWGTPEXTENSION.oneofs_by_name['_extension_length'].fields.append(
  _FLOWGTPEXTENSION.fields_by_name['extension_length'])
_FLOWGTPEXTENSION.fields_by_name['extension_length'].containing_oneof = _FLOWGTPEXTENSION.oneofs_by_name['_extension_length']
_FLOWGTPEXTENSION.oneofs_by_name['_contents'].fields.append(
  _FLOWGTPEXTENSION.fields_by_name['contents'])
_FLOWGTPEXTENSION.fields_by_name['contents'].containing_oneof = _FLOWGTPEXTENSION.oneofs_by_name['_contents']
_FLOWGTPEXTENSION.oneofs_by_name['_next_extension_header'].fields.append(
  _FLOWGTPEXTENSION.fields_by_name['next_extension_header'])
_FLOWGTPEXTENSION.fields_by_name['next_extension_header'].containing_oneof = _FLOWGTPEXTENSION.oneofs_by_name['_next_extension_header']
_FLOWGTPV2.fields_by_name['version'].message_type = _PATTERNFLOWGTPV2VERSION
_FLOWGTPV2.fields_by_name['piggybacking_flag'].message_type = _PATTERNFLOWGTPV2PIGGYBACKINGFLAG
_FLOWGTPV2.fields_by_name['teid_flag'].message_type = _PATTERNFLOWGTPV2TEIDFLAG
_FLOWGTPV2.fields_by_name['spare1'].message_type = _PATTERNFLOWGTPV2SPARE1
_FLOWGTPV2.fields_by_name['message_type'].message_type = _PATTERNFLOWGTPV2MESSAGETYPE
_FLOWGTPV2.fields_by_name['message_length'].message_type = _PATTERNFLOWGTPV2MESSAGELENGTH
_FLOWGTPV2.fields_by_name['teid'].message_type = _PATTERNFLOWGTPV2TEID
_FLOWGTPV2.fields_by_name['sequence_number'].message_type = _PATTERNFLOWGTPV2SEQUENCENUMBER
_FLOWGTPV2.fields_by_name['spare2'].message_type = _PATTERNFLOWGTPV2SPARE2
_FLOWGTPV2.oneofs_by_name['_version'].fields.append(
  _FLOWGTPV2.fields_by_name['version'])
_FLOWGTPV2.fields_by_name['version'].containing_oneof = _FLOWGTPV2.oneofs_by_name['_version']
_FLOWGTPV2.oneofs_by_name['_piggybacking_flag'].fields.append(
  _FLOWGTPV2.fields_by_name['piggybacking_flag'])
_FLOWGTPV2.fields_by_name['piggybacking_flag'].containing_oneof = _FLOWGTPV2.oneofs_by_name['_piggybacking_flag']
_FLOWGTPV2.oneofs_by_name['_teid_flag'].fields.append(
  _FLOWGTPV2.fields_by_name['teid_flag'])
_FLOWGTPV2.fields_by_name['teid_flag'].containing_oneof = _FLOWGTPV2.oneofs_by_name['_teid_flag']
_FLOWGTPV2.oneofs_by_name['_spare1'].fields.append(
  _FLOWGTPV2.fields_by_name['spare1'])
_FLOWGTPV2.fields_by_name['spare1'].containing_oneof = _FLOWGTPV2.oneofs_by_name['_spare1']
_FLOWGTPV2.oneofs_by_name['_message_type'].fields.append(
  _FLOWGTPV2.fields_by_name['message_type'])
_FLOWGTPV2.fields_by_name['message_type'].containing_oneof = _FLOWGTPV2.oneofs_by_name['_message_type']
_FLOWGTPV2.oneofs_by_name['_message_length'].fields.append(
  _FLOWGTPV2.fields_by_name['message_length'])
_FLOWGTPV2.fields_by_name['message_length'].containing_oneof = _FLOWGTPV2.oneofs_by_name['_message_length']
_FLOWGTPV2.oneofs_by_name['_teid'].fields.append(
  _FLOWGTPV2.fields_by_name['teid'])
_FLOWGTPV2.fields_by_name['teid'].containing_oneof = _FLOWGTPV2.oneofs_by_name['_teid']
_FLOWGTPV2.oneofs_by_name['_sequence_number'].fields.append(
  _FLOWGTPV2.fields_by_name['sequence_number'])
_FLOWGTPV2.fields_by_name['sequence_number'].containing_oneof = _FLOWGTPV2.oneofs_by_name['_sequence_number']
_FLOWGTPV2.oneofs_by_name['_spare2'].fields.append(
  _FLOWGTPV2.fields_by_name['spare2'])
_FLOWGTPV2.fields_by_name['spare2'].containing_oneof = _FLOWGTPV2.oneofs_by_name['_spare2']
_FLOWARP.fields_by_name['hardware_type'].message_type = _PATTERNFLOWARPHARDWARETYPE
_FLOWARP.fields_by_name['protocol_type'].message_type = _PATTERNFLOWARPPROTOCOLTYPE
_FLOWARP.fields_by_name['hardware_length'].message_type = _PATTERNFLOWARPHARDWARELENGTH
_FLOWARP.fields_by_name['protocol_length'].message_type = _PATTERNFLOWARPPROTOCOLLENGTH
_FLOWARP.fields_by_name['operation'].message_type = _PATTERNFLOWARPOPERATION
_FLOWARP.fields_by_name['sender_hardware_addr'].message_type = _PATTERNFLOWARPSENDERHARDWAREADDR
_FLOWARP.fields_by_name['sender_protocol_addr'].message_type = _PATTERNFLOWARPSENDERPROTOCOLADDR
_FLOWARP.fields_by_name['target_hardware_addr'].message_type = _PATTERNFLOWARPTARGETHARDWAREADDR
_FLOWARP.fields_by_name['target_protocol_addr'].message_type = _PATTERNFLOWARPTARGETPROTOCOLADDR
_FLOWARP.oneofs_by_name['_hardware_type'].fields.append(
  _FLOWARP.fields_by_name['hardware_type'])
_FLOWARP.fields_by_name['hardware_type'].containing_oneof = _FLOWARP.oneofs_by_name['_hardware_type']
_FLOWARP.oneofs_by_name['_protocol_type'].fields.append(
  _FLOWARP.fields_by_name['protocol_type'])
_FLOWARP.fields_by_name['protocol_type'].containing_oneof = _FLOWARP.oneofs_by_name['_protocol_type']
_FLOWARP.oneofs_by_name['_hardware_length'].fields.append(
  _FLOWARP.fields_by_name['hardware_length'])
_FLOWARP.fields_by_name['hardware_length'].containing_oneof = _FLOWARP.oneofs_by_name['_hardware_length']
_FLOWARP.oneofs_by_name['_protocol_length'].fields.append(
  _FLOWARP.fields_by_name['protocol_length'])
_FLOWARP.fields_by_name['protocol_length'].containing_oneof = _FLOWARP.oneofs_by_name['_protocol_length']
_FLOWARP.oneofs_by_name['_operation'].fields.append(
  _FLOWARP.fields_by_name['operation'])
_FLOWARP.fields_by_name['operation'].containing_oneof = _FLOWARP.oneofs_by_name['_operation']
_FLOWARP.oneofs_by_name['_sender_hardware_addr'].fields.append(
  _FLOWARP.fields_by_name['sender_hardware_addr'])
_FLOWARP.fields_by_name['sender_hardware_addr'].containing_oneof = _FLOWARP.oneofs_by_name['_sender_hardware_addr']
_FLOWARP.oneofs_by_name['_sender_protocol_addr'].fields.append(
  _FLOWARP.fields_by_name['sender_protocol_addr'])
_FLOWARP.fields_by_name['sender_protocol_addr'].containing_oneof = _FLOWARP.oneofs_by_name['_sender_protocol_addr']
_FLOWARP.oneofs_by_name['_target_hardware_addr'].fields.append(
  _FLOWARP.fields_by_name['target_hardware_addr'])
_FLOWARP.fields_by_name['target_hardware_addr'].containing_oneof = _FLOWARP.oneofs_by_name['_target_hardware_addr']
_FLOWARP.oneofs_by_name['_target_protocol_addr'].fields.append(
  _FLOWARP.fields_by_name['target_protocol_addr'])
_FLOWARP.fields_by_name['target_protocol_addr'].containing_oneof = _FLOWARP.oneofs_by_name['_target_protocol_addr']
_FLOWICMP_CHOICE.containing_type = _FLOWICMP
_FLOWICMP_CHOICE_ENUM.containing_type = _FLOWICMP_CHOICE
_FLOWICMP.fields_by_name['choice'].enum_type = _FLOWICMP_CHOICE_ENUM
_FLOWICMP.fields_by_name['echo'].message_type = _FLOWICMPECHO
_FLOWICMP.oneofs_by_name['_choice'].fields.append(
  _FLOWICMP.fields_by_name['choice'])
_FLOWICMP.fields_by_name['choice'].containing_oneof = _FLOWICMP.oneofs_by_name['_choice']
_FLOWICMP.oneofs_by_name['_echo'].fields.append(
  _FLOWICMP.fields_by_name['echo'])
_FLOWICMP.fields_by_name['echo'].containing_oneof = _FLOWICMP.oneofs_by_name['_echo']
_FLOWICMPECHO.fields_by_name['type'].message_type = _PATTERNFLOWICMPECHOTYPE
_FLOWICMPECHO.fields_by_name['code'].message_type = _PATTERNFLOWICMPECHOCODE
_FLOWICMPECHO.fields_by_name['checksum'].message_type = _PATTERNFLOWICMPECHOCHECKSUM
_FLOWICMPECHO.fields_by_name['identifier'].message_type = _PATTERNFLOWICMPECHOIDENTIFIER
_FLOWICMPECHO.fields_by_name['sequence_number'].message_type = _PATTERNFLOWICMPECHOSEQUENCENUMBER
_FLOWICMPECHO.oneofs_by_name['_type'].fields.append(
  _FLOWICMPECHO.fields_by_name['type'])
_FLOWICMPECHO.fields_by_name['type'].containing_oneof = _FLOWICMPECHO.oneofs_by_name['_type']
_FLOWICMPECHO.oneofs_by_name['_code'].fields.append(
  _FLOWICMPECHO.fields_by_name['code'])
_FLOWICMPECHO.fields_by_name['code'].containing_oneof = _FLOWICMPECHO.oneofs_by_name['_code']
_FLOWICMPECHO.oneofs_by_name['_checksum'].fields.append(
  _FLOWICMPECHO.fields_by_name['checksum'])
_FLOWICMPECHO.fields_by_name['checksum'].containing_oneof = _FLOWICMPECHO.oneofs_by_name['_checksum']
_FLOWICMPECHO.oneofs_by_name['_identifier'].fields.append(
  _FLOWICMPECHO.fields_by_name['identifier'])
_FLOWICMPECHO.fields_by_name['identifier'].containing_oneof = _FLOWICMPECHO.oneofs_by_name['_identifier']
_FLOWICMPECHO.oneofs_by_name['_sequence_number'].fields.append(
  _FLOWICMPECHO.fields_by_name['sequence_number'])
_FLOWICMPECHO.fields_by_name['sequence_number'].containing_oneof = _FLOWICMPECHO.oneofs_by_name['_sequence_number']
_FLOWICMPV6_CHOICE.containing_type = _FLOWICMPV6
_FLOWICMPV6_CHOICE_ENUM.containing_type = _FLOWICMPV6_CHOICE
_FLOWICMPV6.fields_by_name['choice'].enum_type = _FLOWICMPV6_CHOICE_ENUM
_FLOWICMPV6.fields_by_name['echo'].message_type = _FLOWICMPV6ECHO
_FLOWICMPV6.oneofs_by_name['_choice'].fields.append(
  _FLOWICMPV6.fields_by_name['choice'])
_FLOWICMPV6.fields_by_name['choice'].containing_oneof = _FLOWICMPV6.oneofs_by_name['_choice']
_FLOWICMPV6.oneofs_by_name['_echo'].fields.append(
  _FLOWICMPV6.fields_by_name['echo'])
_FLOWICMPV6.fields_by_name['echo'].containing_oneof = _FLOWICMPV6.oneofs_by_name['_echo']
_FLOWICMPV6ECHO.fields_by_name['type'].message_type = _PATTERNFLOWICMPV6ECHOTYPE
_FLOWICMPV6ECHO.fields_by_name['code'].message_type = _PATTERNFLOWICMPV6ECHOCODE
_FLOWICMPV6ECHO.fields_by_name['identifier'].message_type = _PATTERNFLOWICMPV6ECHOIDENTIFIER
_FLOWICMPV6ECHO.fields_by_name['sequence_number'].message_type = _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER
_FLOWICMPV6ECHO.fields_by_name['checksum'].message_type = _PATTERNFLOWICMPV6ECHOCHECKSUM
_FLOWICMPV6ECHO.oneofs_by_name['_type'].fields.append(
  _FLOWICMPV6ECHO.fields_by_name['type'])
_FLOWICMPV6ECHO.fields_by_name['type'].containing_oneof = _FLOWICMPV6ECHO.oneofs_by_name['_type']
_FLOWICMPV6ECHO.oneofs_by_name['_code'].fields.append(
  _FLOWICMPV6ECHO.fields_by_name['code'])
_FLOWICMPV6ECHO.fields_by_name['code'].containing_oneof = _FLOWICMPV6ECHO.oneofs_by_name['_code']
_FLOWICMPV6ECHO.oneofs_by_name['_identifier'].fields.append(
  _FLOWICMPV6ECHO.fields_by_name['identifier'])
_FLOWICMPV6ECHO.fields_by_name['identifier'].containing_oneof = _FLOWICMPV6ECHO.oneofs_by_name['_identifier']
_FLOWICMPV6ECHO.oneofs_by_name['_sequence_number'].fields.append(
  _FLOWICMPV6ECHO.fields_by_name['sequence_number'])
_FLOWICMPV6ECHO.fields_by_name['sequence_number'].containing_oneof = _FLOWICMPV6ECHO.oneofs_by_name['_sequence_number']
_FLOWICMPV6ECHO.oneofs_by_name['_checksum'].fields.append(
  _FLOWICMPV6ECHO.fields_by_name['checksum'])
_FLOWICMPV6ECHO.fields_by_name['checksum'].containing_oneof = _FLOWICMPV6ECHO.oneofs_by_name['_checksum']
_FLOWPPP.fields_by_name['address'].message_type = _PATTERNFLOWPPPADDRESS
_FLOWPPP.fields_by_name['control'].message_type = _PATTERNFLOWPPPCONTROL
_FLOWPPP.fields_by_name['protocol_type'].message_type = _PATTERNFLOWPPPPROTOCOLTYPE
_FLOWPPP.oneofs_by_name['_address'].fields.append(
  _FLOWPPP.fields_by_name['address'])
_FLOWPPP.fields_by_name['address'].containing_oneof = _FLOWPPP.oneofs_by_name['_address']
_FLOWPPP.oneofs_by_name['_control'].fields.append(
  _FLOWPPP.fields_by_name['control'])
_FLOWPPP.fields_by_name['control'].containing_oneof = _FLOWPPP.oneofs_by_name['_control']
_FLOWPPP.oneofs_by_name['_protocol_type'].fields.append(
  _FLOWPPP.fields_by_name['protocol_type'])
_FLOWPPP.fields_by_name['protocol_type'].containing_oneof = _FLOWPPP.oneofs_by_name['_protocol_type']
_FLOWIGMPV1.fields_by_name['version'].message_type = _PATTERNFLOWIGMPV1VERSION
_FLOWIGMPV1.fields_by_name['type'].message_type = _PATTERNFLOWIGMPV1TYPE
_FLOWIGMPV1.fields_by_name['unused'].message_type = _PATTERNFLOWIGMPV1UNUSED
_FLOWIGMPV1.fields_by_name['checksum'].message_type = _PATTERNFLOWIGMPV1CHECKSUM
_FLOWIGMPV1.fields_by_name['group_address'].message_type = _PATTERNFLOWIGMPV1GROUPADDRESS
_FLOWIGMPV1.oneofs_by_name['_version'].fields.append(
  _FLOWIGMPV1.fields_by_name['version'])
_FLOWIGMPV1.fields_by_name['version'].containing_oneof = _FLOWIGMPV1.oneofs_by_name['_version']
_FLOWIGMPV1.oneofs_by_name['_type'].fields.append(
  _FLOWIGMPV1.fields_by_name['type'])
_FLOWIGMPV1.fields_by_name['type'].containing_oneof = _FLOWIGMPV1.oneofs_by_name['_type']
_FLOWIGMPV1.oneofs_by_name['_unused'].fields.append(
  _FLOWIGMPV1.fields_by_name['unused'])
_FLOWIGMPV1.fields_by_name['unused'].containing_oneof = _FLOWIGMPV1.oneofs_by_name['_unused']
_FLOWIGMPV1.oneofs_by_name['_checksum'].fields.append(
  _FLOWIGMPV1.fields_by_name['checksum'])
_FLOWIGMPV1.fields_by_name['checksum'].containing_oneof = _FLOWIGMPV1.oneofs_by_name['_checksum']
_FLOWIGMPV1.oneofs_by_name['_group_address'].fields.append(
  _FLOWIGMPV1.fields_by_name['group_address'])
_FLOWIGMPV1.fields_by_name['group_address'].containing_oneof = _FLOWIGMPV1.oneofs_by_name['_group_address']
_FLOWSIZE_CHOICE.containing_type = _FLOWSIZE
_FLOWSIZE_CHOICE_ENUM.containing_type = _FLOWSIZE_CHOICE
_FLOWSIZE.fields_by_name['choice'].enum_type = _FLOWSIZE_CHOICE_ENUM
_FLOWSIZE.fields_by_name['increment'].message_type = _FLOWSIZEINCREMENT
_FLOWSIZE.fields_by_name['random'].message_type = _FLOWSIZERANDOM
_FLOWSIZE.oneofs_by_name['_choice'].fields.append(
  _FLOWSIZE.fields_by_name['choice'])
_FLOWSIZE.fields_by_name['choice'].containing_oneof = _FLOWSIZE.oneofs_by_name['_choice']
_FLOWSIZE.oneofs_by_name['_fixed'].fields.append(
  _FLOWSIZE.fields_by_name['fixed'])
_FLOWSIZE.fields_by_name['fixed'].containing_oneof = _FLOWSIZE.oneofs_by_name['_fixed']
_FLOWSIZE.oneofs_by_name['_increment'].fields.append(
  _FLOWSIZE.fields_by_name['increment'])
_FLOWSIZE.fields_by_name['increment'].containing_oneof = _FLOWSIZE.oneofs_by_name['_increment']
_FLOWSIZE.oneofs_by_name['_random'].fields.append(
  _FLOWSIZE.fields_by_name['random'])
_FLOWSIZE.fields_by_name['random'].containing_oneof = _FLOWSIZE.oneofs_by_name['_random']
_FLOWSIZEINCREMENT.oneofs_by_name['_start'].fields.append(
  _FLOWSIZEINCREMENT.fields_by_name['start'])
_FLOWSIZEINCREMENT.fields_by_name['start'].containing_oneof = _FLOWSIZEINCREMENT.oneofs_by_name['_start']
_FLOWSIZEINCREMENT.oneofs_by_name['_end'].fields.append(
  _FLOWSIZEINCREMENT.fields_by_name['end'])
_FLOWSIZEINCREMENT.fields_by_name['end'].containing_oneof = _FLOWSIZEINCREMENT.oneofs_by_name['_end']
_FLOWSIZEINCREMENT.oneofs_by_name['_step'].fields.append(
  _FLOWSIZEINCREMENT.fields_by_name['step'])
_FLOWSIZEINCREMENT.fields_by_name['step'].containing_oneof = _FLOWSIZEINCREMENT.oneofs_by_name['_step']
_FLOWSIZERANDOM.oneofs_by_name['_min'].fields.append(
  _FLOWSIZERANDOM.fields_by_name['min'])
_FLOWSIZERANDOM.fields_by_name['min'].containing_oneof = _FLOWSIZERANDOM.oneofs_by_name['_min']
_FLOWSIZERANDOM.oneofs_by_name['_max'].fields.append(
  _FLOWSIZERANDOM.fields_by_name['max'])
_FLOWSIZERANDOM.fields_by_name['max'].containing_oneof = _FLOWSIZERANDOM.oneofs_by_name['_max']
_FLOWRATE_CHOICE.containing_type = _FLOWRATE
_FLOWRATE_CHOICE_ENUM.containing_type = _FLOWRATE_CHOICE
_FLOWRATE.fields_by_name['choice'].enum_type = _FLOWRATE_CHOICE_ENUM
_FLOWRATE.oneofs_by_name['_choice'].fields.append(
  _FLOWRATE.fields_by_name['choice'])
_FLOWRATE.fields_by_name['choice'].containing_oneof = _FLOWRATE.oneofs_by_name['_choice']
_FLOWRATE.oneofs_by_name['_pps'].fields.append(
  _FLOWRATE.fields_by_name['pps'])
_FLOWRATE.fields_by_name['pps'].containing_oneof = _FLOWRATE.oneofs_by_name['_pps']
_FLOWRATE.oneofs_by_name['_bps'].fields.append(
  _FLOWRATE.fields_by_name['bps'])
_FLOWRATE.fields_by_name['bps'].containing_oneof = _FLOWRATE.oneofs_by_name['_bps']
_FLOWRATE.oneofs_by_name['_kbps'].fields.append(
  _FLOWRATE.fields_by_name['kbps'])
_FLOWRATE.fields_by_name['kbps'].containing_oneof = _FLOWRATE.oneofs_by_name['_kbps']
_FLOWRATE.oneofs_by_name['_mbps'].fields.append(
  _FLOWRATE.fields_by_name['mbps'])
_FLOWRATE.fields_by_name['mbps'].containing_oneof = _FLOWRATE.oneofs_by_name['_mbps']
_FLOWRATE.oneofs_by_name['_gbps'].fields.append(
  _FLOWRATE.fields_by_name['gbps'])
_FLOWRATE.fields_by_name['gbps'].containing_oneof = _FLOWRATE.oneofs_by_name['_gbps']
_FLOWRATE.oneofs_by_name['_percentage'].fields.append(
  _FLOWRATE.fields_by_name['percentage'])
_FLOWRATE.fields_by_name['percentage'].containing_oneof = _FLOWRATE.oneofs_by_name['_percentage']
_FLOWDURATION_CHOICE.containing_type = _FLOWDURATION
_FLOWDURATION_CHOICE_ENUM.containing_type = _FLOWDURATION_CHOICE
_FLOWDURATION.fields_by_name['choice'].enum_type = _FLOWDURATION_CHOICE_ENUM
_FLOWDURATION.fields_by_name['fixed_packets'].message_type = _FLOWFIXEDPACKETS
_FLOWDURATION.fields_by_name['fixed_seconds'].message_type = _FLOWFIXEDSECONDS
_FLOWDURATION.fields_by_name['burst'].message_type = _FLOWBURST
_FLOWDURATION.fields_by_name['continuous'].message_type = _FLOWCONTINUOUS
_FLOWDURATION.oneofs_by_name['_choice'].fields.append(
  _FLOWDURATION.fields_by_name['choice'])
_FLOWDURATION.fields_by_name['choice'].containing_oneof = _FLOWDURATION.oneofs_by_name['_choice']
_FLOWDURATION.oneofs_by_name['_fixed_packets'].fields.append(
  _FLOWDURATION.fields_by_name['fixed_packets'])
_FLOWDURATION.fields_by_name['fixed_packets'].containing_oneof = _FLOWDURATION.oneofs_by_name['_fixed_packets']
_FLOWDURATION.oneofs_by_name['_fixed_seconds'].fields.append(
  _FLOWDURATION.fields_by_name['fixed_seconds'])
_FLOWDURATION.fields_by_name['fixed_seconds'].containing_oneof = _FLOWDURATION.oneofs_by_name['_fixed_seconds']
_FLOWDURATION.oneofs_by_name['_burst'].fields.append(
  _FLOWDURATION.fields_by_name['burst'])
_FLOWDURATION.fields_by_name['burst'].containing_oneof = _FLOWDURATION.oneofs_by_name['_burst']
_FLOWDURATION.oneofs_by_name['_continuous'].fields.append(
  _FLOWDURATION.fields_by_name['continuous'])
_FLOWDURATION.fields_by_name['continuous'].containing_oneof = _FLOWDURATION.oneofs_by_name['_continuous']
_FLOWCONTINUOUS.fields_by_name['delay'].message_type = _FLOWDELAY
_FLOWCONTINUOUS.oneofs_by_name['_gap'].fields.append(
  _FLOWCONTINUOUS.fields_by_name['gap'])
_FLOWCONTINUOUS.fields_by_name['gap'].containing_oneof = _FLOWCONTINUOUS.oneofs_by_name['_gap']
_FLOWCONTINUOUS.oneofs_by_name['_delay'].fields.append(
  _FLOWCONTINUOUS.fields_by_name['delay'])
_FLOWCONTINUOUS.fields_by_name['delay'].containing_oneof = _FLOWCONTINUOUS.oneofs_by_name['_delay']
_FLOWDELAY_CHOICE.containing_type = _FLOWDELAY
_FLOWDELAY_CHOICE_ENUM.containing_type = _FLOWDELAY_CHOICE
_FLOWDELAY.fields_by_name['choice'].enum_type = _FLOWDELAY_CHOICE_ENUM
_FLOWDELAY.oneofs_by_name['_choice'].fields.append(
  _FLOWDELAY.fields_by_name['choice'])
_FLOWDELAY.fields_by_name['choice'].containing_oneof = _FLOWDELAY.oneofs_by_name['_choice']
_FLOWDELAY.oneofs_by_name['_bytes'].fields.append(
  _FLOWDELAY.fields_by_name['bytes'])
_FLOWDELAY.fields_by_name['bytes'].containing_oneof = _FLOWDELAY.oneofs_by_name['_bytes']
_FLOWDELAY.oneofs_by_name['_nanoseconds'].fields.append(
  _FLOWDELAY.fields_by_name['nanoseconds'])
_FLOWDELAY.fields_by_name['nanoseconds'].containing_oneof = _FLOWDELAY.oneofs_by_name['_nanoseconds']
_FLOWDELAY.oneofs_by_name['_microseconds'].fields.append(
  _FLOWDELAY.fields_by_name['microseconds'])
_FLOWDELAY.fields_by_name['microseconds'].containing_oneof = _FLOWDELAY.oneofs_by_name['_microseconds']
_FLOWFIXEDPACKETS.fields_by_name['delay'].message_type = _FLOWDELAY
_FLOWFIXEDPACKETS.oneofs_by_name['_packets'].fields.append(
  _FLOWFIXEDPACKETS.fields_by_name['packets'])
_FLOWFIXEDPACKETS.fields_by_name['packets'].containing_oneof = _FLOWFIXEDPACKETS.oneofs_by_name['_packets']
_FLOWFIXEDPACKETS.oneofs_by_name['_gap'].fields.append(
  _FLOWFIXEDPACKETS.fields_by_name['gap'])
_FLOWFIXEDPACKETS.fields_by_name['gap'].containing_oneof = _FLOWFIXEDPACKETS.oneofs_by_name['_gap']
_FLOWFIXEDPACKETS.oneofs_by_name['_delay'].fields.append(
  _FLOWFIXEDPACKETS.fields_by_name['delay'])
_FLOWFIXEDPACKETS.fields_by_name['delay'].containing_oneof = _FLOWFIXEDPACKETS.oneofs_by_name['_delay']
_FLOWFIXEDSECONDS.fields_by_name['delay'].message_type = _FLOWDELAY
_FLOWFIXEDSECONDS.oneofs_by_name['_seconds'].fields.append(
  _FLOWFIXEDSECONDS.fields_by_name['seconds'])
_FLOWFIXEDSECONDS.fields_by_name['seconds'].containing_oneof = _FLOWFIXEDSECONDS.oneofs_by_name['_seconds']
_FLOWFIXEDSECONDS.oneofs_by_name['_gap'].fields.append(
  _FLOWFIXEDSECONDS.fields_by_name['gap'])
_FLOWFIXEDSECONDS.fields_by_name['gap'].containing_oneof = _FLOWFIXEDSECONDS.oneofs_by_name['_gap']
_FLOWFIXEDSECONDS.oneofs_by_name['_delay'].fields.append(
  _FLOWFIXEDSECONDS.fields_by_name['delay'])
_FLOWFIXEDSECONDS.fields_by_name['delay'].containing_oneof = _FLOWFIXEDSECONDS.oneofs_by_name['_delay']
_FLOWBURST.fields_by_name['inter_burst_gap'].message_type = _FLOWDURATIONINTERBURSTGAP
_FLOWBURST.oneofs_by_name['_bursts'].fields.append(
  _FLOWBURST.fields_by_name['bursts'])
_FLOWBURST.fields_by_name['bursts'].containing_oneof = _FLOWBURST.oneofs_by_name['_bursts']
_FLOWBURST.oneofs_by_name['_packets'].fields.append(
  _FLOWBURST.fields_by_name['packets'])
_FLOWBURST.fields_by_name['packets'].containing_oneof = _FLOWBURST.oneofs_by_name['_packets']
_FLOWBURST.oneofs_by_name['_gap'].fields.append(
  _FLOWBURST.fields_by_name['gap'])
_FLOWBURST.fields_by_name['gap'].containing_oneof = _FLOWBURST.oneofs_by_name['_gap']
_FLOWBURST.oneofs_by_name['_inter_burst_gap'].fields.append(
  _FLOWBURST.fields_by_name['inter_burst_gap'])
_FLOWBURST.fields_by_name['inter_burst_gap'].containing_oneof = _FLOWBURST.oneofs_by_name['_inter_burst_gap']
_FLOWDURATIONINTERBURSTGAP_CHOICE.containing_type = _FLOWDURATIONINTERBURSTGAP
_FLOWDURATIONINTERBURSTGAP_CHOICE_ENUM.containing_type = _FLOWDURATIONINTERBURSTGAP_CHOICE
_FLOWDURATIONINTERBURSTGAP.fields_by_name['choice'].enum_type = _FLOWDURATIONINTERBURSTGAP_CHOICE_ENUM
_FLOWDURATIONINTERBURSTGAP.oneofs_by_name['_choice'].fields.append(
  _FLOWDURATIONINTERBURSTGAP.fields_by_name['choice'])
_FLOWDURATIONINTERBURSTGAP.fields_by_name['choice'].containing_oneof = _FLOWDURATIONINTERBURSTGAP.oneofs_by_name['_choice']
_FLOWDURATIONINTERBURSTGAP.oneofs_by_name['_bytes'].fields.append(
  _FLOWDURATIONINTERBURSTGAP.fields_by_name['bytes'])
_FLOWDURATIONINTERBURSTGAP.fields_by_name['bytes'].containing_oneof = _FLOWDURATIONINTERBURSTGAP.oneofs_by_name['_bytes']
_FLOWDURATIONINTERBURSTGAP.oneofs_by_name['_nanoseconds'].fields.append(
  _FLOWDURATIONINTERBURSTGAP.fields_by_name['nanoseconds'])
_FLOWDURATIONINTERBURSTGAP.fields_by_name['nanoseconds'].containing_oneof = _FLOWDURATIONINTERBURSTGAP.oneofs_by_name['_nanoseconds']
_FLOWDURATIONINTERBURSTGAP.oneofs_by_name['_microseconds'].fields.append(
  _FLOWDURATIONINTERBURSTGAP.fields_by_name['microseconds'])
_FLOWDURATIONINTERBURSTGAP.fields_by_name['microseconds'].containing_oneof = _FLOWDURATIONINTERBURSTGAP.oneofs_by_name['_microseconds']
_FLOWMETRICS.fields_by_name['latency'].message_type = _FLOWLATENCYMETRICS
_FLOWMETRICS.oneofs_by_name['_enable'].fields.append(
  _FLOWMETRICS.fields_by_name['enable'])
_FLOWMETRICS.fields_by_name['enable'].containing_oneof = _FLOWMETRICS.oneofs_by_name['_enable']
_FLOWMETRICS.oneofs_by_name['_loss'].fields.append(
  _FLOWMETRICS.fields_by_name['loss'])
_FLOWMETRICS.fields_by_name['loss'].containing_oneof = _FLOWMETRICS.oneofs_by_name['_loss']
_FLOWMETRICS.oneofs_by_name['_timestamps'].fields.append(
  _FLOWMETRICS.fields_by_name['timestamps'])
_FLOWMETRICS.fields_by_name['timestamps'].containing_oneof = _FLOWMETRICS.oneofs_by_name['_timestamps']
_FLOWMETRICS.oneofs_by_name['_latency'].fields.append(
  _FLOWMETRICS.fields_by_name['latency'])
_FLOWMETRICS.fields_by_name['latency'].containing_oneof = _FLOWMETRICS.oneofs_by_name['_latency']
_FLOWLATENCYMETRICS_MODE.containing_type = _FLOWLATENCYMETRICS
_FLOWLATENCYMETRICS_MODE_ENUM.containing_type = _FLOWLATENCYMETRICS_MODE
_FLOWLATENCYMETRICS.fields_by_name['mode'].enum_type = _FLOWLATENCYMETRICS_MODE_ENUM
_FLOWLATENCYMETRICS.oneofs_by_name['_enable'].fields.append(
  _FLOWLATENCYMETRICS.fields_by_name['enable'])
_FLOWLATENCYMETRICS.fields_by_name['enable'].containing_oneof = _FLOWLATENCYMETRICS.oneofs_by_name['_enable']
_FLOWLATENCYMETRICS.oneofs_by_name['_mode'].fields.append(
  _FLOWLATENCYMETRICS.fields_by_name['mode'])
_FLOWLATENCYMETRICS.fields_by_name['mode'].containing_oneof = _FLOWLATENCYMETRICS.oneofs_by_name['_mode']
_EVENT.fields_by_name['link'].message_type = _EVENTLINK
_EVENT.fields_by_name['rx_rate_threshold'].message_type = _EVENTRXRATETHRESHOLD
_EVENT.fields_by_name['route_advertise_withdraw'].message_type = _EVENTROUTEADVERTISEWITHDRAW
_EVENT.oneofs_by_name['_enable'].fields.append(
  _EVENT.fields_by_name['enable'])
_EVENT.fields_by_name['enable'].containing_oneof = _EVENT.oneofs_by_name['_enable']
_EVENT.oneofs_by_name['_link'].fields.append(
  _EVENT.fields_by_name['link'])
_EVENT.fields_by_name['link'].containing_oneof = _EVENT.oneofs_by_name['_link']
_EVENT.oneofs_by_name['_rx_rate_threshold'].fields.append(
  _EVENT.fields_by_name['rx_rate_threshold'])
_EVENT.fields_by_name['rx_rate_threshold'].containing_oneof = _EVENT.oneofs_by_name['_rx_rate_threshold']
_EVENT.oneofs_by_name['_route_advertise_withdraw'].fields.append(
  _EVENT.fields_by_name['route_advertise_withdraw'])
_EVENT.fields_by_name['route_advertise_withdraw'].containing_oneof = _EVENT.oneofs_by_name['_route_advertise_withdraw']
_EVENTRXRATETHRESHOLD.oneofs_by_name['_enable'].fields.append(
  _EVENTRXRATETHRESHOLD.fields_by_name['enable'])
_EVENTRXRATETHRESHOLD.fields_by_name['enable'].containing_oneof = _EVENTRXRATETHRESHOLD.oneofs_by_name['_enable']
_EVENTRXRATETHRESHOLD.oneofs_by_name['_threshold'].fields.append(
  _EVENTRXRATETHRESHOLD.fields_by_name['threshold'])
_EVENTRXRATETHRESHOLD.fields_by_name['threshold'].containing_oneof = _EVENTRXRATETHRESHOLD.oneofs_by_name['_threshold']
_EVENTLINK.oneofs_by_name['_enable'].fields.append(
  _EVENTLINK.fields_by_name['enable'])
_EVENTLINK.fields_by_name['enable'].containing_oneof = _EVENTLINK.oneofs_by_name['_enable']
_EVENTROUTEADVERTISEWITHDRAW.oneofs_by_name['_enable'].fields.append(
  _EVENTROUTEADVERTISEWITHDRAW.fields_by_name['enable'])
_EVENTROUTEADVERTISEWITHDRAW.fields_by_name['enable'].containing_oneof = _EVENTROUTEADVERTISEWITHDRAW.oneofs_by_name['_enable']
_EVENTREQUEST_TYPE.containing_type = _EVENTREQUEST
_EVENTREQUEST_TYPE_ENUM.containing_type = _EVENTREQUEST_TYPE
_EVENTREQUEST.fields_by_name['type'].enum_type = _EVENTREQUEST_TYPE_ENUM
_EVENTSUBSCRIPTION.fields_by_name['events'].message_type = _EVENTREQUEST
_EVENTSUBSCRIPTION.oneofs_by_name['_events'].fields.append(
  _EVENTSUBSCRIPTION.fields_by_name['events'])
_EVENTSUBSCRIPTION.fields_by_name['events'].containing_oneof = _EVENTSUBSCRIPTION.oneofs_by_name['_events']
_EVENTSUBSCRIPTION.oneofs_by_name['_callbackurl'].fields.append(
  _EVENTSUBSCRIPTION.fields_by_name['callbackurl'])
_EVENTSUBSCRIPTION.fields_by_name['callbackurl'].containing_oneof = _EVENTSUBSCRIPTION.oneofs_by_name['_callbackurl']
_LINKSTATE_STATE.containing_type = _LINKSTATE
_LINKSTATE_STATE_ENUM.containing_type = _LINKSTATE_STATE
_LINKSTATE.fields_by_name['state'].enum_type = _LINKSTATE_STATE_ENUM
_TRANSMITSTATE_STATE.containing_type = _TRANSMITSTATE
_TRANSMITSTATE_STATE_ENUM.containing_type = _TRANSMITSTATE_STATE
_TRANSMITSTATE.fields_by_name['state'].enum_type = _TRANSMITSTATE_STATE_ENUM
_CAPTURESTATE_STATE.containing_type = _CAPTURESTATE
_CAPTURESTATE_STATE_ENUM.containing_type = _CAPTURESTATE_STATE
_CAPTURESTATE.fields_by_name['state'].enum_type = _CAPTURESTATE_STATE_ENUM
_FLOWSUPDATE_PROPERTYNAMES.containing_type = _FLOWSUPDATE
_FLOWSUPDATE_PROPERTYNAMES_ENUM.containing_type = _FLOWSUPDATE_PROPERTYNAMES
_FLOWSUPDATE.fields_by_name['property_names'].enum_type = _FLOWSUPDATE_PROPERTYNAMES_ENUM
_FLOWSUPDATE.fields_by_name['flows'].message_type = _FLOW
_ROUTESTATE_STATE.containing_type = _ROUTESTATE
_ROUTESTATE_STATE_ENUM.containing_type = _ROUTESTATE_STATE
_ROUTESTATE.fields_by_name['state'].enum_type = _ROUTESTATE_STATE_ENUM
_PINGREQUEST.fields_by_name['endpoints'].message_type = _PING
_PROTOCOLSTATE_STATE.containing_type = _PROTOCOLSTATE
_PROTOCOLSTATE_STATE_ENUM.containing_type = _PROTOCOLSTATE_STATE
_PROTOCOLSTATE.fields_by_name['state'].enum_type = _PROTOCOLSTATE_STATE_ENUM
_PING_CHOICE.containing_type = _PING
_PING_CHOICE_ENUM.containing_type = _PING_CHOICE
_PING.fields_by_name['choice'].enum_type = _PING_CHOICE_ENUM
_PING.fields_by_name['ipv4'].message_type = _PINGIPV4
_PING.fields_by_name['ipv6'].message_type = _PINGIPV6
_PING.oneofs_by_name['_choice'].fields.append(
  _PING.fields_by_name['choice'])
_PING.fields_by_name['choice'].containing_oneof = _PING.oneofs_by_name['_choice']
_PING.oneofs_by_name['_ipv4'].fields.append(
  _PING.fields_by_name['ipv4'])
_PING.fields_by_name['ipv4'].containing_oneof = _PING.oneofs_by_name['_ipv4']
_PING.oneofs_by_name['_ipv6'].fields.append(
  _PING.fields_by_name['ipv6'])
_PING.fields_by_name['ipv6'].containing_oneof = _PING.oneofs_by_name['_ipv6']
_PINGIPV4.oneofs_by_name['_src_name'].fields.append(
  _PINGIPV4.fields_by_name['src_name'])
_PINGIPV4.fields_by_name['src_name'].containing_oneof = _PINGIPV4.oneofs_by_name['_src_name']
_PINGIPV4.oneofs_by_name['_dst_ip'].fields.append(
  _PINGIPV4.fields_by_name['dst_ip'])
_PINGIPV4.fields_by_name['dst_ip'].containing_oneof = _PINGIPV4.oneofs_by_name['_dst_ip']
_PINGIPV6.oneofs_by_name['_src_name'].fields.append(
  _PINGIPV6.fields_by_name['src_name'])
_PINGIPV6.fields_by_name['src_name'].containing_oneof = _PINGIPV6.oneofs_by_name['_src_name']
_PINGIPV6.oneofs_by_name['_dst_ip'].fields.append(
  _PINGIPV6.fields_by_name['dst_ip'])
_PINGIPV6.fields_by_name['dst_ip'].containing_oneof = _PINGIPV6.oneofs_by_name['_dst_ip']
_PINGRESPONSE.fields_by_name['responses'].message_type = _RESPONSE
_RESPONSE_RESULT.containing_type = _RESPONSE
_RESPONSE_RESULT_ENUM.containing_type = _RESPONSE_RESULT
_RESPONSE.fields_by_name['result'].enum_type = _RESPONSE_RESULT_ENUM
_RESPONSE.oneofs_by_name['_src_name'].fields.append(
  _RESPONSE.fields_by_name['src_name'])
_RESPONSE.fields_by_name['src_name'].containing_oneof = _RESPONSE.oneofs_by_name['_src_name']
_RESPONSE.oneofs_by_name['_dst_ip'].fields.append(
  _RESPONSE.fields_by_name['dst_ip'])
_RESPONSE.fields_by_name['dst_ip'].containing_oneof = _RESPONSE.oneofs_by_name['_dst_ip']
_RESPONSE.oneofs_by_name['_result'].fields.append(
  _RESPONSE.fields_by_name['result'])
_RESPONSE.fields_by_name['result'].containing_oneof = _RESPONSE.oneofs_by_name['_result']
_METRICSREQUEST_CHOICE.containing_type = _METRICSREQUEST
_METRICSREQUEST_CHOICE_ENUM.containing_type = _METRICSREQUEST_CHOICE
_METRICSREQUEST.fields_by_name['choice'].enum_type = _METRICSREQUEST_CHOICE_ENUM
_METRICSREQUEST.fields_by_name['port'].message_type = _PORTMETRICSREQUEST
_METRICSREQUEST.fields_by_name['flow'].message_type = _FLOWMETRICSREQUEST
_METRICSREQUEST.fields_by_name['bgpv4'].message_type = _BGPV4METRICSREQUEST
_METRICSREQUEST.fields_by_name['bgpv6'].message_type = _BGPV6METRICSREQUEST
_METRICSREQUEST.fields_by_name['isis'].message_type = _ISISMETRICSREQUEST
_METRICSREQUEST.oneofs_by_name['_choice'].fields.append(
  _METRICSREQUEST.fields_by_name['choice'])
_METRICSREQUEST.fields_by_name['choice'].containing_oneof = _METRICSREQUEST.oneofs_by_name['_choice']
_METRICSREQUEST.oneofs_by_name['_port'].fields.append(
  _METRICSREQUEST.fields_by_name['port'])
_METRICSREQUEST.fields_by_name['port'].containing_oneof = _METRICSREQUEST.oneofs_by_name['_port']
_METRICSREQUEST.oneofs_by_name['_flow'].fields.append(
  _METRICSREQUEST.fields_by_name['flow'])
_METRICSREQUEST.fields_by_name['flow'].containing_oneof = _METRICSREQUEST.oneofs_by_name['_flow']
_METRICSREQUEST.oneofs_by_name['_bgpv4'].fields.append(
  _METRICSREQUEST.fields_by_name['bgpv4'])
_METRICSREQUEST.fields_by_name['bgpv4'].containing_oneof = _METRICSREQUEST.oneofs_by_name['_bgpv4']
_METRICSREQUEST.oneofs_by_name['_bgpv6'].fields.append(
  _METRICSREQUEST.fields_by_name['bgpv6'])
_METRICSREQUEST.fields_by_name['bgpv6'].containing_oneof = _METRICSREQUEST.oneofs_by_name['_bgpv6']
_METRICSREQUEST.oneofs_by_name['_isis'].fields.append(
  _METRICSREQUEST.fields_by_name['isis'])
_METRICSREQUEST.fields_by_name['isis'].containing_oneof = _METRICSREQUEST.oneofs_by_name['_isis']
_METRICSRESPONSE_CHOICE.containing_type = _METRICSRESPONSE
_METRICSRESPONSE_CHOICE_ENUM.containing_type = _METRICSRESPONSE_CHOICE
_METRICSRESPONSE.fields_by_name['choice'].enum_type = _METRICSRESPONSE_CHOICE_ENUM
_METRICSRESPONSE.fields_by_name['port_metrics'].message_type = _PORTMETRIC
_METRICSRESPONSE.fields_by_name['flow_metrics'].message_type = _FLOWMETRIC
_METRICSRESPONSE.fields_by_name['bgpv4_metrics'].message_type = _BGPV4METRIC
_METRICSRESPONSE.fields_by_name['bgpv6_metrics'].message_type = _BGPV6METRIC
_METRICSRESPONSE.fields_by_name['isis_metrics'].message_type = _ISISMETRIC
_METRICSRESPONSE.oneofs_by_name['_choice'].fields.append(
  _METRICSRESPONSE.fields_by_name['choice'])
_METRICSRESPONSE.fields_by_name['choice'].containing_oneof = _METRICSRESPONSE.oneofs_by_name['_choice']
_PORTMETRICSREQUEST_COLUMNNAMES.containing_type = _PORTMETRICSREQUEST
_PORTMETRICSREQUEST_COLUMNNAMES_ENUM.containing_type = _PORTMETRICSREQUEST_COLUMNNAMES
_PORTMETRICSREQUEST.fields_by_name['column_names'].enum_type = _PORTMETRICSREQUEST_COLUMNNAMES_ENUM
_PORTMETRIC_LINK.containing_type = _PORTMETRIC
_PORTMETRIC_LINK_ENUM.containing_type = _PORTMETRIC_LINK
_PORTMETRIC_CAPTURE.containing_type = _PORTMETRIC
_PORTMETRIC_CAPTURE_ENUM.containing_type = _PORTMETRIC_CAPTURE
_PORTMETRIC.fields_by_name['link'].enum_type = _PORTMETRIC_LINK_ENUM
_PORTMETRIC.fields_by_name['capture'].enum_type = _PORTMETRIC_CAPTURE_ENUM
_PORTMETRIC.oneofs_by_name['_name'].fields.append(
  _PORTMETRIC.fields_by_name['name'])
_PORTMETRIC.fields_by_name['name'].containing_oneof = _PORTMETRIC.oneofs_by_name['_name']
_PORTMETRIC.oneofs_by_name['_location'].fields.append(
  _PORTMETRIC.fields_by_name['location'])
_PORTMETRIC.fields_by_name['location'].containing_oneof = _PORTMETRIC.oneofs_by_name['_location']
_PORTMETRIC.oneofs_by_name['_link'].fields.append(
  _PORTMETRIC.fields_by_name['link'])
_PORTMETRIC.fields_by_name['link'].containing_oneof = _PORTMETRIC.oneofs_by_name['_link']
_PORTMETRIC.oneofs_by_name['_capture'].fields.append(
  _PORTMETRIC.fields_by_name['capture'])
_PORTMETRIC.fields_by_name['capture'].containing_oneof = _PORTMETRIC.oneofs_by_name['_capture']
_PORTMETRIC.oneofs_by_name['_frames_tx'].fields.append(
  _PORTMETRIC.fields_by_name['frames_tx'])
_PORTMETRIC.fields_by_name['frames_tx'].containing_oneof = _PORTMETRIC.oneofs_by_name['_frames_tx']
_PORTMETRIC.oneofs_by_name['_frames_rx'].fields.append(
  _PORTMETRIC.fields_by_name['frames_rx'])
_PORTMETRIC.fields_by_name['frames_rx'].containing_oneof = _PORTMETRIC.oneofs_by_name['_frames_rx']
_PORTMETRIC.oneofs_by_name['_bytes_tx'].fields.append(
  _PORTMETRIC.fields_by_name['bytes_tx'])
_PORTMETRIC.fields_by_name['bytes_tx'].containing_oneof = _PORTMETRIC.oneofs_by_name['_bytes_tx']
_PORTMETRIC.oneofs_by_name['_bytes_rx'].fields.append(
  _PORTMETRIC.fields_by_name['bytes_rx'])
_PORTMETRIC.fields_by_name['bytes_rx'].containing_oneof = _PORTMETRIC.oneofs_by_name['_bytes_rx']
_PORTMETRIC.oneofs_by_name['_frames_tx_rate'].fields.append(
  _PORTMETRIC.fields_by_name['frames_tx_rate'])
_PORTMETRIC.fields_by_name['frames_tx_rate'].containing_oneof = _PORTMETRIC.oneofs_by_name['_frames_tx_rate']
_PORTMETRIC.oneofs_by_name['_frames_rx_rate'].fields.append(
  _PORTMETRIC.fields_by_name['frames_rx_rate'])
_PORTMETRIC.fields_by_name['frames_rx_rate'].containing_oneof = _PORTMETRIC.oneofs_by_name['_frames_rx_rate']
_PORTMETRIC.oneofs_by_name['_bytes_tx_rate'].fields.append(
  _PORTMETRIC.fields_by_name['bytes_tx_rate'])
_PORTMETRIC.fields_by_name['bytes_tx_rate'].containing_oneof = _PORTMETRIC.oneofs_by_name['_bytes_tx_rate']
_PORTMETRIC.oneofs_by_name['_bytes_rx_rate'].fields.append(
  _PORTMETRIC.fields_by_name['bytes_rx_rate'])
_PORTMETRIC.fields_by_name['bytes_rx_rate'].containing_oneof = _PORTMETRIC.oneofs_by_name['_bytes_rx_rate']
_FLOWMETRICSREQUEST_METRICNAMES.containing_type = _FLOWMETRICSREQUEST
_FLOWMETRICSREQUEST_METRICNAMES_ENUM.containing_type = _FLOWMETRICSREQUEST_METRICNAMES
_FLOWMETRICSREQUEST.fields_by_name['metric_groups'].message_type = _FLOWMETRICGROUPREQUEST
_FLOWMETRICSREQUEST.fields_by_name['metric_names'].enum_type = _FLOWMETRICSREQUEST_METRICNAMES_ENUM
_FLOWMETRICSREQUEST.oneofs_by_name['_metric_groups'].fields.append(
  _FLOWMETRICSREQUEST.fields_by_name['metric_groups'])
_FLOWMETRICSREQUEST.fields_by_name['metric_groups'].containing_oneof = _FLOWMETRICSREQUEST.oneofs_by_name['_metric_groups']
_FLOWMETRICGROUPREQUEST_CHOICE.containing_type = _FLOWMETRICGROUPREQUEST
_FLOWMETRICGROUPREQUEST_CHOICE_ENUM.containing_type = _FLOWMETRICGROUPREQUEST_CHOICE
_FLOWMETRICGROUPREQUEST.fields_by_name['choice'].enum_type = _FLOWMETRICGROUPREQUEST_CHOICE_ENUM
_FLOWMETRICGROUPREQUEST.oneofs_by_name['_choice'].fields.append(
  _FLOWMETRICGROUPREQUEST.fields_by_name['choice'])
_FLOWMETRICGROUPREQUEST.fields_by_name['choice'].containing_oneof = _FLOWMETRICGROUPREQUEST.oneofs_by_name['_choice']
_FLOWMETRIC_TRANSMIT.containing_type = _FLOWMETRIC
_FLOWMETRIC_TRANSMIT_ENUM.containing_type = _FLOWMETRIC_TRANSMIT
_FLOWMETRIC.fields_by_name['metric_groups'].message_type = _FLOWMETRICGROUP
_FLOWMETRIC.fields_by_name['transmit'].enum_type = _FLOWMETRIC_TRANSMIT_ENUM
_FLOWMETRIC.fields_by_name['timestamps'].message_type = _METRICTIMESTAMP
_FLOWMETRIC.fields_by_name['latency'].message_type = _METRICLATENCY
_FLOWMETRIC.oneofs_by_name['_name'].fields.append(
  _FLOWMETRIC.fields_by_name['name'])
_FLOWMETRIC.fields_by_name['name'].containing_oneof = _FLOWMETRIC.oneofs_by_name['_name']
_FLOWMETRIC.oneofs_by_name['_port_tx'].fields.append(
  _FLOWMETRIC.fields_by_name['port_tx'])
_FLOWMETRIC.fields_by_name['port_tx'].containing_oneof = _FLOWMETRIC.oneofs_by_name['_port_tx']
_FLOWMETRIC.oneofs_by_name['_port_rx'].fields.append(
  _FLOWMETRIC.fields_by_name['port_rx'])
_FLOWMETRIC.fields_by_name['port_rx'].containing_oneof = _FLOWMETRIC.oneofs_by_name['_port_rx']
_FLOWMETRIC.oneofs_by_name['_transmit'].fields.append(
  _FLOWMETRIC.fields_by_name['transmit'])
_FLOWMETRIC.fields_by_name['transmit'].containing_oneof = _FLOWMETRIC.oneofs_by_name['_transmit']
_FLOWMETRIC.oneofs_by_name['_frames_tx'].fields.append(
  _FLOWMETRIC.fields_by_name['frames_tx'])
_FLOWMETRIC.fields_by_name['frames_tx'].containing_oneof = _FLOWMETRIC.oneofs_by_name['_frames_tx']
_FLOWMETRIC.oneofs_by_name['_frames_rx'].fields.append(
  _FLOWMETRIC.fields_by_name['frames_rx'])
_FLOWMETRIC.fields_by_name['frames_rx'].containing_oneof = _FLOWMETRIC.oneofs_by_name['_frames_rx']
_FLOWMETRIC.oneofs_by_name['_bytes_tx'].fields.append(
  _FLOWMETRIC.fields_by_name['bytes_tx'])
_FLOWMETRIC.fields_by_name['bytes_tx'].containing_oneof = _FLOWMETRIC.oneofs_by_name['_bytes_tx']
_FLOWMETRIC.oneofs_by_name['_bytes_rx'].fields.append(
  _FLOWMETRIC.fields_by_name['bytes_rx'])
_FLOWMETRIC.fields_by_name['bytes_rx'].containing_oneof = _FLOWMETRIC.oneofs_by_name['_bytes_rx']
_FLOWMETRIC.oneofs_by_name['_frames_tx_rate'].fields.append(
  _FLOWMETRIC.fields_by_name['frames_tx_rate'])
_FLOWMETRIC.fields_by_name['frames_tx_rate'].containing_oneof = _FLOWMETRIC.oneofs_by_name['_frames_tx_rate']
_FLOWMETRIC.oneofs_by_name['_frames_rx_rate'].fields.append(
  _FLOWMETRIC.fields_by_name['frames_rx_rate'])
_FLOWMETRIC.fields_by_name['frames_rx_rate'].containing_oneof = _FLOWMETRIC.oneofs_by_name['_frames_rx_rate']
_FLOWMETRIC.oneofs_by_name['_loss'].fields.append(
  _FLOWMETRIC.fields_by_name['loss'])
_FLOWMETRIC.fields_by_name['loss'].containing_oneof = _FLOWMETRIC.oneofs_by_name['_loss']
_FLOWMETRIC.oneofs_by_name['_timestamps'].fields.append(
  _FLOWMETRIC.fields_by_name['timestamps'])
_FLOWMETRIC.fields_by_name['timestamps'].containing_oneof = _FLOWMETRIC.oneofs_by_name['_timestamps']
_FLOWMETRIC.oneofs_by_name['_latency'].fields.append(
  _FLOWMETRIC.fields_by_name['latency'])
_FLOWMETRIC.fields_by_name['latency'].containing_oneof = _FLOWMETRIC.oneofs_by_name['_latency']
_FLOWMETRICGROUP.oneofs_by_name['_name'].fields.append(
  _FLOWMETRICGROUP.fields_by_name['name'])
_FLOWMETRICGROUP.fields_by_name['name'].containing_oneof = _FLOWMETRICGROUP.oneofs_by_name['_name']
_FLOWMETRICGROUP.oneofs_by_name['_value'].fields.append(
  _FLOWMETRICGROUP.fields_by_name['value'])
_FLOWMETRICGROUP.fields_by_name['value'].containing_oneof = _FLOWMETRICGROUP.oneofs_by_name['_value']
_METRICTIMESTAMP.oneofs_by_name['_first_timestamp_ns'].fields.append(
  _METRICTIMESTAMP.fields_by_name['first_timestamp_ns'])
_METRICTIMESTAMP.fields_by_name['first_timestamp_ns'].containing_oneof = _METRICTIMESTAMP.oneofs_by_name['_first_timestamp_ns']
_METRICTIMESTAMP.oneofs_by_name['_last_timestamp_ns'].fields.append(
  _METRICTIMESTAMP.fields_by_name['last_timestamp_ns'])
_METRICTIMESTAMP.fields_by_name['last_timestamp_ns'].containing_oneof = _METRICTIMESTAMP.oneofs_by_name['_last_timestamp_ns']
_METRICLATENCY.oneofs_by_name['_minimum_ns'].fields.append(
  _METRICLATENCY.fields_by_name['minimum_ns'])
_METRICLATENCY.fields_by_name['minimum_ns'].containing_oneof = _METRICLATENCY.oneofs_by_name['_minimum_ns']
_METRICLATENCY.oneofs_by_name['_maximum_ns'].fields.append(
  _METRICLATENCY.fields_by_name['maximum_ns'])
_METRICLATENCY.fields_by_name['maximum_ns'].containing_oneof = _METRICLATENCY.oneofs_by_name['_maximum_ns']
_METRICLATENCY.oneofs_by_name['_average_ns'].fields.append(
  _METRICLATENCY.fields_by_name['average_ns'])
_METRICLATENCY.fields_by_name['average_ns'].containing_oneof = _METRICLATENCY.oneofs_by_name['_average_ns']
_BGPV4METRICSREQUEST_COLUMNNAMES.containing_type = _BGPV4METRICSREQUEST
_BGPV4METRICSREQUEST_COLUMNNAMES_ENUM.containing_type = _BGPV4METRICSREQUEST_COLUMNNAMES
_BGPV4METRICSREQUEST.fields_by_name['column_names'].enum_type = _BGPV4METRICSREQUEST_COLUMNNAMES_ENUM
_BGPV4METRIC_SESSIONSTATE.containing_type = _BGPV4METRIC
_BGPV4METRIC_SESSIONSTATE_ENUM.containing_type = _BGPV4METRIC_SESSIONSTATE
_BGPV4METRIC.fields_by_name['session_state'].enum_type = _BGPV4METRIC_SESSIONSTATE_ENUM
_BGPV4METRIC.oneofs_by_name['_name'].fields.append(
  _BGPV4METRIC.fields_by_name['name'])
_BGPV4METRIC.fields_by_name['name'].containing_oneof = _BGPV4METRIC.oneofs_by_name['_name']
_BGPV4METRIC.oneofs_by_name['_session_state'].fields.append(
  _BGPV4METRIC.fields_by_name['session_state'])
_BGPV4METRIC.fields_by_name['session_state'].containing_oneof = _BGPV4METRIC.oneofs_by_name['_session_state']
_BGPV4METRIC.oneofs_by_name['_session_flap_count'].fields.append(
  _BGPV4METRIC.fields_by_name['session_flap_count'])
_BGPV4METRIC.fields_by_name['session_flap_count'].containing_oneof = _BGPV4METRIC.oneofs_by_name['_session_flap_count']
_BGPV4METRIC.oneofs_by_name['_routes_advertised'].fields.append(
  _BGPV4METRIC.fields_by_name['routes_advertised'])
_BGPV4METRIC.fields_by_name['routes_advertised'].containing_oneof = _BGPV4METRIC.oneofs_by_name['_routes_advertised']
_BGPV4METRIC.oneofs_by_name['_routes_received'].fields.append(
  _BGPV4METRIC.fields_by_name['routes_received'])
_BGPV4METRIC.fields_by_name['routes_received'].containing_oneof = _BGPV4METRIC.oneofs_by_name['_routes_received']
_BGPV4METRIC.oneofs_by_name['_route_withdraws_sent'].fields.append(
  _BGPV4METRIC.fields_by_name['route_withdraws_sent'])
_BGPV4METRIC.fields_by_name['route_withdraws_sent'].containing_oneof = _BGPV4METRIC.oneofs_by_name['_route_withdraws_sent']
_BGPV4METRIC.oneofs_by_name['_route_withdraws_received'].fields.append(
  _BGPV4METRIC.fields_by_name['route_withdraws_received'])
_BGPV4METRIC.fields_by_name['route_withdraws_received'].containing_oneof = _BGPV4METRIC.oneofs_by_name['_route_withdraws_received']
_BGPV4METRIC.oneofs_by_name['_updates_sent'].fields.append(
  _BGPV4METRIC.fields_by_name['updates_sent'])
_BGPV4METRIC.fields_by_name['updates_sent'].containing_oneof = _BGPV4METRIC.oneofs_by_name['_updates_sent']
_BGPV4METRIC.oneofs_by_name['_updates_received'].fields.append(
  _BGPV4METRIC.fields_by_name['updates_received'])
_BGPV4METRIC.fields_by_name['updates_received'].containing_oneof = _BGPV4METRIC.oneofs_by_name['_updates_received']
_BGPV4METRIC.oneofs_by_name['_opens_sent'].fields.append(
  _BGPV4METRIC.fields_by_name['opens_sent'])
_BGPV4METRIC.fields_by_name['opens_sent'].containing_oneof = _BGPV4METRIC.oneofs_by_name['_opens_sent']
_BGPV4METRIC.oneofs_by_name['_opens_received'].fields.append(
  _BGPV4METRIC.fields_by_name['opens_received'])
_BGPV4METRIC.fields_by_name['opens_received'].containing_oneof = _BGPV4METRIC.oneofs_by_name['_opens_received']
_BGPV4METRIC.oneofs_by_name['_keepalives_sent'].fields.append(
  _BGPV4METRIC.fields_by_name['keepalives_sent'])
_BGPV4METRIC.fields_by_name['keepalives_sent'].containing_oneof = _BGPV4METRIC.oneofs_by_name['_keepalives_sent']
_BGPV4METRIC.oneofs_by_name['_keepalives_received'].fields.append(
  _BGPV4METRIC.fields_by_name['keepalives_received'])
_BGPV4METRIC.fields_by_name['keepalives_received'].containing_oneof = _BGPV4METRIC.oneofs_by_name['_keepalives_received']
_BGPV4METRIC.oneofs_by_name['_notifications_sent'].fields.append(
  _BGPV4METRIC.fields_by_name['notifications_sent'])
_BGPV4METRIC.fields_by_name['notifications_sent'].containing_oneof = _BGPV4METRIC.oneofs_by_name['_notifications_sent']
_BGPV4METRIC.oneofs_by_name['_notifications_received'].fields.append(
  _BGPV4METRIC.fields_by_name['notifications_received'])
_BGPV4METRIC.fields_by_name['notifications_received'].containing_oneof = _BGPV4METRIC.oneofs_by_name['_notifications_received']
_BGPV6METRICSREQUEST_COLUMNNAMES.containing_type = _BGPV6METRICSREQUEST
_BGPV6METRICSREQUEST_COLUMNNAMES_ENUM.containing_type = _BGPV6METRICSREQUEST_COLUMNNAMES
_BGPV6METRICSREQUEST.fields_by_name['column_names'].enum_type = _BGPV6METRICSREQUEST_COLUMNNAMES_ENUM
_BGPV6METRIC_SESSIONSTATE.containing_type = _BGPV6METRIC
_BGPV6METRIC_SESSIONSTATE_ENUM.containing_type = _BGPV6METRIC_SESSIONSTATE
_BGPV6METRIC.fields_by_name['session_state'].enum_type = _BGPV6METRIC_SESSIONSTATE_ENUM
_BGPV6METRIC.oneofs_by_name['_name'].fields.append(
  _BGPV6METRIC.fields_by_name['name'])
_BGPV6METRIC.fields_by_name['name'].containing_oneof = _BGPV6METRIC.oneofs_by_name['_name']
_BGPV6METRIC.oneofs_by_name['_session_state'].fields.append(
  _BGPV6METRIC.fields_by_name['session_state'])
_BGPV6METRIC.fields_by_name['session_state'].containing_oneof = _BGPV6METRIC.oneofs_by_name['_session_state']
_BGPV6METRIC.oneofs_by_name['_session_flap_count'].fields.append(
  _BGPV6METRIC.fields_by_name['session_flap_count'])
_BGPV6METRIC.fields_by_name['session_flap_count'].containing_oneof = _BGPV6METRIC.oneofs_by_name['_session_flap_count']
_BGPV6METRIC.oneofs_by_name['_routes_advertised'].fields.append(
  _BGPV6METRIC.fields_by_name['routes_advertised'])
_BGPV6METRIC.fields_by_name['routes_advertised'].containing_oneof = _BGPV6METRIC.oneofs_by_name['_routes_advertised']
_BGPV6METRIC.oneofs_by_name['_routes_received'].fields.append(
  _BGPV6METRIC.fields_by_name['routes_received'])
_BGPV6METRIC.fields_by_name['routes_received'].containing_oneof = _BGPV6METRIC.oneofs_by_name['_routes_received']
_BGPV6METRIC.oneofs_by_name['_route_withdraws_sent'].fields.append(
  _BGPV6METRIC.fields_by_name['route_withdraws_sent'])
_BGPV6METRIC.fields_by_name['route_withdraws_sent'].containing_oneof = _BGPV6METRIC.oneofs_by_name['_route_withdraws_sent']
_BGPV6METRIC.oneofs_by_name['_route_withdraws_received'].fields.append(
  _BGPV6METRIC.fields_by_name['route_withdraws_received'])
_BGPV6METRIC.fields_by_name['route_withdraws_received'].containing_oneof = _BGPV6METRIC.oneofs_by_name['_route_withdraws_received']
_BGPV6METRIC.oneofs_by_name['_updates_sent'].fields.append(
  _BGPV6METRIC.fields_by_name['updates_sent'])
_BGPV6METRIC.fields_by_name['updates_sent'].containing_oneof = _BGPV6METRIC.oneofs_by_name['_updates_sent']
_BGPV6METRIC.oneofs_by_name['_updates_received'].fields.append(
  _BGPV6METRIC.fields_by_name['updates_received'])
_BGPV6METRIC.fields_by_name['updates_received'].containing_oneof = _BGPV6METRIC.oneofs_by_name['_updates_received']
_BGPV6METRIC.oneofs_by_name['_opens_sent'].fields.append(
  _BGPV6METRIC.fields_by_name['opens_sent'])
_BGPV6METRIC.fields_by_name['opens_sent'].containing_oneof = _BGPV6METRIC.oneofs_by_name['_opens_sent']
_BGPV6METRIC.oneofs_by_name['_opens_received'].fields.append(
  _BGPV6METRIC.fields_by_name['opens_received'])
_BGPV6METRIC.fields_by_name['opens_received'].containing_oneof = _BGPV6METRIC.oneofs_by_name['_opens_received']
_BGPV6METRIC.oneofs_by_name['_keepalives_sent'].fields.append(
  _BGPV6METRIC.fields_by_name['keepalives_sent'])
_BGPV6METRIC.fields_by_name['keepalives_sent'].containing_oneof = _BGPV6METRIC.oneofs_by_name['_keepalives_sent']
_BGPV6METRIC.oneofs_by_name['_keepalives_received'].fields.append(
  _BGPV6METRIC.fields_by_name['keepalives_received'])
_BGPV6METRIC.fields_by_name['keepalives_received'].containing_oneof = _BGPV6METRIC.oneofs_by_name['_keepalives_received']
_BGPV6METRIC.oneofs_by_name['_notifications_sent'].fields.append(
  _BGPV6METRIC.fields_by_name['notifications_sent'])
_BGPV6METRIC.fields_by_name['notifications_sent'].containing_oneof = _BGPV6METRIC.oneofs_by_name['_notifications_sent']
_BGPV6METRIC.oneofs_by_name['_notifications_received'].fields.append(
  _BGPV6METRIC.fields_by_name['notifications_received'])
_BGPV6METRIC.fields_by_name['notifications_received'].containing_oneof = _BGPV6METRIC.oneofs_by_name['_notifications_received']
_ISISMETRICSREQUEST_COLUMNNAMES.containing_type = _ISISMETRICSREQUEST
_ISISMETRICSREQUEST_COLUMNNAMES_ENUM.containing_type = _ISISMETRICSREQUEST_COLUMNNAMES
_ISISMETRICSREQUEST.fields_by_name['column_names'].enum_type = _ISISMETRICSREQUEST_COLUMNNAMES_ENUM
_ISISMETRIC.oneofs_by_name['_name'].fields.append(
  _ISISMETRIC.fields_by_name['name'])
_ISISMETRIC.fields_by_name['name'].containing_oneof = _ISISMETRIC.oneofs_by_name['_name']
_ISISMETRIC.oneofs_by_name['_l1_sessions_up'].fields.append(
  _ISISMETRIC.fields_by_name['l1_sessions_up'])
_ISISMETRIC.fields_by_name['l1_sessions_up'].containing_oneof = _ISISMETRIC.oneofs_by_name['_l1_sessions_up']
_ISISMETRIC.oneofs_by_name['_l1_session_flap'].fields.append(
  _ISISMETRIC.fields_by_name['l1_session_flap'])
_ISISMETRIC.fields_by_name['l1_session_flap'].containing_oneof = _ISISMETRIC.oneofs_by_name['_l1_session_flap']
_ISISMETRIC.oneofs_by_name['_l1_broadcast_hellos_sent'].fields.append(
  _ISISMETRIC.fields_by_name['l1_broadcast_hellos_sent'])
_ISISMETRIC.fields_by_name['l1_broadcast_hellos_sent'].containing_oneof = _ISISMETRIC.oneofs_by_name['_l1_broadcast_hellos_sent']
_ISISMETRIC.oneofs_by_name['_l1_broadcast_hellos_received'].fields.append(
  _ISISMETRIC.fields_by_name['l1_broadcast_hellos_received'])
_ISISMETRIC.fields_by_name['l1_broadcast_hellos_received'].containing_oneof = _ISISMETRIC.oneofs_by_name['_l1_broadcast_hellos_received']
_ISISMETRIC.oneofs_by_name['_l1_point_to_point_hellos_sent'].fields.append(
  _ISISMETRIC.fields_by_name['l1_point_to_point_hellos_sent'])
_ISISMETRIC.fields_by_name['l1_point_to_point_hellos_sent'].containing_oneof = _ISISMETRIC.oneofs_by_name['_l1_point_to_point_hellos_sent']
_ISISMETRIC.oneofs_by_name['_l1_point_to_point_hellos_received'].fields.append(
  _ISISMETRIC.fields_by_name['l1_point_to_point_hellos_received'])
_ISISMETRIC.fields_by_name['l1_point_to_point_hellos_received'].containing_oneof = _ISISMETRIC.oneofs_by_name['_l1_point_to_point_hellos_received']
_ISISMETRIC.oneofs_by_name['_l1_database_size'].fields.append(
  _ISISMETRIC.fields_by_name['l1_database_size'])
_ISISMETRIC.fields_by_name['l1_database_size'].containing_oneof = _ISISMETRIC.oneofs_by_name['_l1_database_size']
_ISISMETRIC.oneofs_by_name['_l1_psnp_sent'].fields.append(
  _ISISMETRIC.fields_by_name['l1_psnp_sent'])
_ISISMETRIC.fields_by_name['l1_psnp_sent'].containing_oneof = _ISISMETRIC.oneofs_by_name['_l1_psnp_sent']
_ISISMETRIC.oneofs_by_name['_l1_psnp_received'].fields.append(
  _ISISMETRIC.fields_by_name['l1_psnp_received'])
_ISISMETRIC.fields_by_name['l1_psnp_received'].containing_oneof = _ISISMETRIC.oneofs_by_name['_l1_psnp_received']
_ISISMETRIC.oneofs_by_name['_l1_csnp_sent'].fields.append(
  _ISISMETRIC.fields_by_name['l1_csnp_sent'])
_ISISMETRIC.fields_by_name['l1_csnp_sent'].containing_oneof = _ISISMETRIC.oneofs_by_name['_l1_csnp_sent']
_ISISMETRIC.oneofs_by_name['_l1_csnp_received'].fields.append(
  _ISISMETRIC.fields_by_name['l1_csnp_received'])
_ISISMETRIC.fields_by_name['l1_csnp_received'].containing_oneof = _ISISMETRIC.oneofs_by_name['_l1_csnp_received']
_ISISMETRIC.oneofs_by_name['_l1_lsp_sent'].fields.append(
  _ISISMETRIC.fields_by_name['l1_lsp_sent'])
_ISISMETRIC.fields_by_name['l1_lsp_sent'].containing_oneof = _ISISMETRIC.oneofs_by_name['_l1_lsp_sent']
_ISISMETRIC.oneofs_by_name['_l1_lsp_received'].fields.append(
  _ISISMETRIC.fields_by_name['l1_lsp_received'])
_ISISMETRIC.fields_by_name['l1_lsp_received'].containing_oneof = _ISISMETRIC.oneofs_by_name['_l1_lsp_received']
_ISISMETRIC.oneofs_by_name['_l2_sessions_up'].fields.append(
  _ISISMETRIC.fields_by_name['l2_sessions_up'])
_ISISMETRIC.fields_by_name['l2_sessions_up'].containing_oneof = _ISISMETRIC.oneofs_by_name['_l2_sessions_up']
_ISISMETRIC.oneofs_by_name['_l2_session_flap'].fields.append(
  _ISISMETRIC.fields_by_name['l2_session_flap'])
_ISISMETRIC.fields_by_name['l2_session_flap'].containing_oneof = _ISISMETRIC.oneofs_by_name['_l2_session_flap']
_ISISMETRIC.oneofs_by_name['_l2_broadcast_hellos_sent'].fields.append(
  _ISISMETRIC.fields_by_name['l2_broadcast_hellos_sent'])
_ISISMETRIC.fields_by_name['l2_broadcast_hellos_sent'].containing_oneof = _ISISMETRIC.oneofs_by_name['_l2_broadcast_hellos_sent']
_ISISMETRIC.oneofs_by_name['_l2_broadcast_hellos_received'].fields.append(
  _ISISMETRIC.fields_by_name['l2_broadcast_hellos_received'])
_ISISMETRIC.fields_by_name['l2_broadcast_hellos_received'].containing_oneof = _ISISMETRIC.oneofs_by_name['_l2_broadcast_hellos_received']
_ISISMETRIC.oneofs_by_name['_l2_point_to_point_hellos_sent'].fields.append(
  _ISISMETRIC.fields_by_name['l2_point_to_point_hellos_sent'])
_ISISMETRIC.fields_by_name['l2_point_to_point_hellos_sent'].containing_oneof = _ISISMETRIC.oneofs_by_name['_l2_point_to_point_hellos_sent']
_ISISMETRIC.oneofs_by_name['_l2_point_to_point_hellos_received'].fields.append(
  _ISISMETRIC.fields_by_name['l2_point_to_point_hellos_received'])
_ISISMETRIC.fields_by_name['l2_point_to_point_hellos_received'].containing_oneof = _ISISMETRIC.oneofs_by_name['_l2_point_to_point_hellos_received']
_ISISMETRIC.oneofs_by_name['_l2_database_size'].fields.append(
  _ISISMETRIC.fields_by_name['l2_database_size'])
_ISISMETRIC.fields_by_name['l2_database_size'].containing_oneof = _ISISMETRIC.oneofs_by_name['_l2_database_size']
_ISISMETRIC.oneofs_by_name['_l2_psnp_sent'].fields.append(
  _ISISMETRIC.fields_by_name['l2_psnp_sent'])
_ISISMETRIC.fields_by_name['l2_psnp_sent'].containing_oneof = _ISISMETRIC.oneofs_by_name['_l2_psnp_sent']
_ISISMETRIC.oneofs_by_name['_l2_psnp_received'].fields.append(
  _ISISMETRIC.fields_by_name['l2_psnp_received'])
_ISISMETRIC.fields_by_name['l2_psnp_received'].containing_oneof = _ISISMETRIC.oneofs_by_name['_l2_psnp_received']
_ISISMETRIC.oneofs_by_name['_l2_csnp_sent'].fields.append(
  _ISISMETRIC.fields_by_name['l2_csnp_sent'])
_ISISMETRIC.fields_by_name['l2_csnp_sent'].containing_oneof = _ISISMETRIC.oneofs_by_name['_l2_csnp_sent']
_ISISMETRIC.oneofs_by_name['_l2_csnp_received'].fields.append(
  _ISISMETRIC.fields_by_name['l2_csnp_received'])
_ISISMETRIC.fields_by_name['l2_csnp_received'].containing_oneof = _ISISMETRIC.oneofs_by_name['_l2_csnp_received']
_ISISMETRIC.oneofs_by_name['_l2_lsp_sent'].fields.append(
  _ISISMETRIC.fields_by_name['l2_lsp_sent'])
_ISISMETRIC.fields_by_name['l2_lsp_sent'].containing_oneof = _ISISMETRIC.oneofs_by_name['_l2_lsp_sent']
_ISISMETRIC.oneofs_by_name['_l2_lsp_received'].fields.append(
  _ISISMETRIC.fields_by_name['l2_lsp_received'])
_ISISMETRIC.fields_by_name['l2_lsp_received'].containing_oneof = _ISISMETRIC.oneofs_by_name['_l2_lsp_received']
_STATESREQUEST_CHOICE.containing_type = _STATESREQUEST
_STATESREQUEST_CHOICE_ENUM.containing_type = _STATESREQUEST_CHOICE
_STATESREQUEST.fields_by_name['choice'].enum_type = _STATESREQUEST_CHOICE_ENUM
_STATESREQUEST.fields_by_name['ipv4_neighbors'].message_type = _NEIGHBORSV4STATESREQUEST
_STATESREQUEST.fields_by_name['ipv6_neighbors'].message_type = _NEIGHBORSV6STATESREQUEST
_STATESREQUEST.oneofs_by_name['_choice'].fields.append(
  _STATESREQUEST.fields_by_name['choice'])
_STATESREQUEST.fields_by_name['choice'].containing_oneof = _STATESREQUEST.oneofs_by_name['_choice']
_STATESREQUEST.oneofs_by_name['_ipv4_neighbors'].fields.append(
  _STATESREQUEST.fields_by_name['ipv4_neighbors'])
_STATESREQUEST.fields_by_name['ipv4_neighbors'].containing_oneof = _STATESREQUEST.oneofs_by_name['_ipv4_neighbors']
_STATESREQUEST.oneofs_by_name['_ipv6_neighbors'].fields.append(
  _STATESREQUEST.fields_by_name['ipv6_neighbors'])
_STATESREQUEST.fields_by_name['ipv6_neighbors'].containing_oneof = _STATESREQUEST.oneofs_by_name['_ipv6_neighbors']
_STATESRESPONSE_CHOICE.containing_type = _STATESRESPONSE
_STATESRESPONSE_CHOICE_ENUM.containing_type = _STATESRESPONSE_CHOICE
_STATESRESPONSE.fields_by_name['choice'].enum_type = _STATESRESPONSE_CHOICE_ENUM
_STATESRESPONSE.fields_by_name['ipv4_neighbors'].message_type = _NEIGHBORSV4STATE
_STATESRESPONSE.fields_by_name['ipv6_neighbors'].message_type = _NEIGHBORSV6STATE
_STATESRESPONSE.oneofs_by_name['_choice'].fields.append(
  _STATESRESPONSE.fields_by_name['choice'])
_STATESRESPONSE.fields_by_name['choice'].containing_oneof = _STATESRESPONSE.oneofs_by_name['_choice']
_NEIGHBORSV4STATE.oneofs_by_name['_link_layer_address'].fields.append(
  _NEIGHBORSV4STATE.fields_by_name['link_layer_address'])
_NEIGHBORSV4STATE.fields_by_name['link_layer_address'].containing_oneof = _NEIGHBORSV4STATE.oneofs_by_name['_link_layer_address']
_NEIGHBORSV6STATE.oneofs_by_name['_link_layer_address'].fields.append(
  _NEIGHBORSV6STATE.fields_by_name['link_layer_address'])
_NEIGHBORSV6STATE.fields_by_name['link_layer_address'].containing_oneof = _NEIGHBORSV6STATE.oneofs_by_name['_link_layer_address']
_PATTERNFLOWETHERNETDSTCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWETHERNETDSTCOUNTER.fields_by_name['start'])
_PATTERNFLOWETHERNETDSTCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWETHERNETDSTCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWETHERNETDSTCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWETHERNETDSTCOUNTER.fields_by_name['step'])
_PATTERNFLOWETHERNETDSTCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWETHERNETDSTCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWETHERNETDSTCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWETHERNETDSTCOUNTER.fields_by_name['count'])
_PATTERNFLOWETHERNETDSTCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWETHERNETDSTCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWETHERNETDST_CHOICE.containing_type = _PATTERNFLOWETHERNETDST
_PATTERNFLOWETHERNETDST_CHOICE_ENUM.containing_type = _PATTERNFLOWETHERNETDST_CHOICE
_PATTERNFLOWETHERNETDST.fields_by_name['choice'].enum_type = _PATTERNFLOWETHERNETDST_CHOICE_ENUM
_PATTERNFLOWETHERNETDST.fields_by_name['increment'].message_type = _PATTERNFLOWETHERNETDSTCOUNTER
_PATTERNFLOWETHERNETDST.fields_by_name['decrement'].message_type = _PATTERNFLOWETHERNETDSTCOUNTER
_PATTERNFLOWETHERNETDST.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWETHERNETDST.fields_by_name['choice'])
_PATTERNFLOWETHERNETDST.fields_by_name['choice'].containing_oneof = _PATTERNFLOWETHERNETDST.oneofs_by_name['_choice']
_PATTERNFLOWETHERNETDST.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWETHERNETDST.fields_by_name['value'])
_PATTERNFLOWETHERNETDST.fields_by_name['value'].containing_oneof = _PATTERNFLOWETHERNETDST.oneofs_by_name['_value']
_PATTERNFLOWETHERNETDST.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWETHERNETDST.fields_by_name['metric_group'])
_PATTERNFLOWETHERNETDST.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWETHERNETDST.oneofs_by_name['_metric_group']
_PATTERNFLOWETHERNETDST.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWETHERNETDST.fields_by_name['increment'])
_PATTERNFLOWETHERNETDST.fields_by_name['increment'].containing_oneof = _PATTERNFLOWETHERNETDST.oneofs_by_name['_increment']
_PATTERNFLOWETHERNETDST.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWETHERNETDST.fields_by_name['decrement'])
_PATTERNFLOWETHERNETDST.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWETHERNETDST.oneofs_by_name['_decrement']
_PATTERNFLOWETHERNETSRCCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWETHERNETSRCCOUNTER.fields_by_name['start'])
_PATTERNFLOWETHERNETSRCCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWETHERNETSRCCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWETHERNETSRCCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWETHERNETSRCCOUNTER.fields_by_name['step'])
_PATTERNFLOWETHERNETSRCCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWETHERNETSRCCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWETHERNETSRCCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWETHERNETSRCCOUNTER.fields_by_name['count'])
_PATTERNFLOWETHERNETSRCCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWETHERNETSRCCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWETHERNETSRC_CHOICE.containing_type = _PATTERNFLOWETHERNETSRC
_PATTERNFLOWETHERNETSRC_CHOICE_ENUM.containing_type = _PATTERNFLOWETHERNETSRC_CHOICE
_PATTERNFLOWETHERNETSRC.fields_by_name['choice'].enum_type = _PATTERNFLOWETHERNETSRC_CHOICE_ENUM
_PATTERNFLOWETHERNETSRC.fields_by_name['increment'].message_type = _PATTERNFLOWETHERNETSRCCOUNTER
_PATTERNFLOWETHERNETSRC.fields_by_name['decrement'].message_type = _PATTERNFLOWETHERNETSRCCOUNTER
_PATTERNFLOWETHERNETSRC.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWETHERNETSRC.fields_by_name['choice'])
_PATTERNFLOWETHERNETSRC.fields_by_name['choice'].containing_oneof = _PATTERNFLOWETHERNETSRC.oneofs_by_name['_choice']
_PATTERNFLOWETHERNETSRC.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWETHERNETSRC.fields_by_name['value'])
_PATTERNFLOWETHERNETSRC.fields_by_name['value'].containing_oneof = _PATTERNFLOWETHERNETSRC.oneofs_by_name['_value']
_PATTERNFLOWETHERNETSRC.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWETHERNETSRC.fields_by_name['metric_group'])
_PATTERNFLOWETHERNETSRC.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWETHERNETSRC.oneofs_by_name['_metric_group']
_PATTERNFLOWETHERNETSRC.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWETHERNETSRC.fields_by_name['increment'])
_PATTERNFLOWETHERNETSRC.fields_by_name['increment'].containing_oneof = _PATTERNFLOWETHERNETSRC.oneofs_by_name['_increment']
_PATTERNFLOWETHERNETSRC.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWETHERNETSRC.fields_by_name['decrement'])
_PATTERNFLOWETHERNETSRC.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWETHERNETSRC.oneofs_by_name['_decrement']
_PATTERNFLOWETHERNETETHERTYPECOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWETHERNETETHERTYPECOUNTER.fields_by_name['start'])
_PATTERNFLOWETHERNETETHERTYPECOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWETHERNETETHERTYPECOUNTER.oneofs_by_name['_start']
_PATTERNFLOWETHERNETETHERTYPECOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWETHERNETETHERTYPECOUNTER.fields_by_name['step'])
_PATTERNFLOWETHERNETETHERTYPECOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWETHERNETETHERTYPECOUNTER.oneofs_by_name['_step']
_PATTERNFLOWETHERNETETHERTYPECOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWETHERNETETHERTYPECOUNTER.fields_by_name['count'])
_PATTERNFLOWETHERNETETHERTYPECOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWETHERNETETHERTYPECOUNTER.oneofs_by_name['_count']
_PATTERNFLOWETHERNETETHERTYPE_CHOICE.containing_type = _PATTERNFLOWETHERNETETHERTYPE
_PATTERNFLOWETHERNETETHERTYPE_CHOICE_ENUM.containing_type = _PATTERNFLOWETHERNETETHERTYPE_CHOICE
_PATTERNFLOWETHERNETETHERTYPE_AUTO.containing_type = _PATTERNFLOWETHERNETETHERTYPE
_PATTERNFLOWETHERNETETHERTYPE_AUTO_ENUM.containing_type = _PATTERNFLOWETHERNETETHERTYPE_AUTO
_PATTERNFLOWETHERNETETHERTYPE.fields_by_name['choice'].enum_type = _PATTERNFLOWETHERNETETHERTYPE_CHOICE_ENUM
_PATTERNFLOWETHERNETETHERTYPE.fields_by_name['auto'].enum_type = _PATTERNFLOWETHERNETETHERTYPE_AUTO_ENUM
_PATTERNFLOWETHERNETETHERTYPE.fields_by_name['increment'].message_type = _PATTERNFLOWETHERNETETHERTYPECOUNTER
_PATTERNFLOWETHERNETETHERTYPE.fields_by_name['decrement'].message_type = _PATTERNFLOWETHERNETETHERTYPECOUNTER
_PATTERNFLOWETHERNETETHERTYPE.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWETHERNETETHERTYPE.fields_by_name['choice'])
_PATTERNFLOWETHERNETETHERTYPE.fields_by_name['choice'].containing_oneof = _PATTERNFLOWETHERNETETHERTYPE.oneofs_by_name['_choice']
_PATTERNFLOWETHERNETETHERTYPE.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWETHERNETETHERTYPE.fields_by_name['value'])
_PATTERNFLOWETHERNETETHERTYPE.fields_by_name['value'].containing_oneof = _PATTERNFLOWETHERNETETHERTYPE.oneofs_by_name['_value']
_PATTERNFLOWETHERNETETHERTYPE.oneofs_by_name['_auto'].fields.append(
  _PATTERNFLOWETHERNETETHERTYPE.fields_by_name['auto'])
_PATTERNFLOWETHERNETETHERTYPE.fields_by_name['auto'].containing_oneof = _PATTERNFLOWETHERNETETHERTYPE.oneofs_by_name['_auto']
_PATTERNFLOWETHERNETETHERTYPE.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWETHERNETETHERTYPE.fields_by_name['metric_group'])
_PATTERNFLOWETHERNETETHERTYPE.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWETHERNETETHERTYPE.oneofs_by_name['_metric_group']
_PATTERNFLOWETHERNETETHERTYPE.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWETHERNETETHERTYPE.fields_by_name['increment'])
_PATTERNFLOWETHERNETETHERTYPE.fields_by_name['increment'].containing_oneof = _PATTERNFLOWETHERNETETHERTYPE.oneofs_by_name['_increment']
_PATTERNFLOWETHERNETETHERTYPE.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWETHERNETETHERTYPE.fields_by_name['decrement'])
_PATTERNFLOWETHERNETETHERTYPE.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWETHERNETETHERTYPE.oneofs_by_name['_decrement']
_PATTERNFLOWETHERNETPFCQUEUECOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWETHERNETPFCQUEUECOUNTER.fields_by_name['start'])
_PATTERNFLOWETHERNETPFCQUEUECOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWETHERNETPFCQUEUECOUNTER.oneofs_by_name['_start']
_PATTERNFLOWETHERNETPFCQUEUECOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWETHERNETPFCQUEUECOUNTER.fields_by_name['step'])
_PATTERNFLOWETHERNETPFCQUEUECOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWETHERNETPFCQUEUECOUNTER.oneofs_by_name['_step']
_PATTERNFLOWETHERNETPFCQUEUECOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWETHERNETPFCQUEUECOUNTER.fields_by_name['count'])
_PATTERNFLOWETHERNETPFCQUEUECOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWETHERNETPFCQUEUECOUNTER.oneofs_by_name['_count']
_PATTERNFLOWETHERNETPFCQUEUE_CHOICE.containing_type = _PATTERNFLOWETHERNETPFCQUEUE
_PATTERNFLOWETHERNETPFCQUEUE_CHOICE_ENUM.containing_type = _PATTERNFLOWETHERNETPFCQUEUE_CHOICE
_PATTERNFLOWETHERNETPFCQUEUE.fields_by_name['choice'].enum_type = _PATTERNFLOWETHERNETPFCQUEUE_CHOICE_ENUM
_PATTERNFLOWETHERNETPFCQUEUE.fields_by_name['increment'].message_type = _PATTERNFLOWETHERNETPFCQUEUECOUNTER
_PATTERNFLOWETHERNETPFCQUEUE.fields_by_name['decrement'].message_type = _PATTERNFLOWETHERNETPFCQUEUECOUNTER
_PATTERNFLOWETHERNETPFCQUEUE.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWETHERNETPFCQUEUE.fields_by_name['choice'])
_PATTERNFLOWETHERNETPFCQUEUE.fields_by_name['choice'].containing_oneof = _PATTERNFLOWETHERNETPFCQUEUE.oneofs_by_name['_choice']
_PATTERNFLOWETHERNETPFCQUEUE.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWETHERNETPFCQUEUE.fields_by_name['value'])
_PATTERNFLOWETHERNETPFCQUEUE.fields_by_name['value'].containing_oneof = _PATTERNFLOWETHERNETPFCQUEUE.oneofs_by_name['_value']
_PATTERNFLOWETHERNETPFCQUEUE.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWETHERNETPFCQUEUE.fields_by_name['metric_group'])
_PATTERNFLOWETHERNETPFCQUEUE.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWETHERNETPFCQUEUE.oneofs_by_name['_metric_group']
_PATTERNFLOWETHERNETPFCQUEUE.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWETHERNETPFCQUEUE.fields_by_name['increment'])
_PATTERNFLOWETHERNETPFCQUEUE.fields_by_name['increment'].containing_oneof = _PATTERNFLOWETHERNETPFCQUEUE.oneofs_by_name['_increment']
_PATTERNFLOWETHERNETPFCQUEUE.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWETHERNETPFCQUEUE.fields_by_name['decrement'])
_PATTERNFLOWETHERNETPFCQUEUE.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWETHERNETPFCQUEUE.oneofs_by_name['_decrement']
_PATTERNFLOWVLANPRIORITYCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWVLANPRIORITYCOUNTER.fields_by_name['start'])
_PATTERNFLOWVLANPRIORITYCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWVLANPRIORITYCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWVLANPRIORITYCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWVLANPRIORITYCOUNTER.fields_by_name['step'])
_PATTERNFLOWVLANPRIORITYCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWVLANPRIORITYCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWVLANPRIORITYCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWVLANPRIORITYCOUNTER.fields_by_name['count'])
_PATTERNFLOWVLANPRIORITYCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWVLANPRIORITYCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWVLANPRIORITY_CHOICE.containing_type = _PATTERNFLOWVLANPRIORITY
_PATTERNFLOWVLANPRIORITY_CHOICE_ENUM.containing_type = _PATTERNFLOWVLANPRIORITY_CHOICE
_PATTERNFLOWVLANPRIORITY.fields_by_name['choice'].enum_type = _PATTERNFLOWVLANPRIORITY_CHOICE_ENUM
_PATTERNFLOWVLANPRIORITY.fields_by_name['increment'].message_type = _PATTERNFLOWVLANPRIORITYCOUNTER
_PATTERNFLOWVLANPRIORITY.fields_by_name['decrement'].message_type = _PATTERNFLOWVLANPRIORITYCOUNTER
_PATTERNFLOWVLANPRIORITY.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWVLANPRIORITY.fields_by_name['choice'])
_PATTERNFLOWVLANPRIORITY.fields_by_name['choice'].containing_oneof = _PATTERNFLOWVLANPRIORITY.oneofs_by_name['_choice']
_PATTERNFLOWVLANPRIORITY.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWVLANPRIORITY.fields_by_name['value'])
_PATTERNFLOWVLANPRIORITY.fields_by_name['value'].containing_oneof = _PATTERNFLOWVLANPRIORITY.oneofs_by_name['_value']
_PATTERNFLOWVLANPRIORITY.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWVLANPRIORITY.fields_by_name['metric_group'])
_PATTERNFLOWVLANPRIORITY.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWVLANPRIORITY.oneofs_by_name['_metric_group']
_PATTERNFLOWVLANPRIORITY.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWVLANPRIORITY.fields_by_name['increment'])
_PATTERNFLOWVLANPRIORITY.fields_by_name['increment'].containing_oneof = _PATTERNFLOWVLANPRIORITY.oneofs_by_name['_increment']
_PATTERNFLOWVLANPRIORITY.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWVLANPRIORITY.fields_by_name['decrement'])
_PATTERNFLOWVLANPRIORITY.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWVLANPRIORITY.oneofs_by_name['_decrement']
_PATTERNFLOWVLANCFICOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWVLANCFICOUNTER.fields_by_name['start'])
_PATTERNFLOWVLANCFICOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWVLANCFICOUNTER.oneofs_by_name['_start']
_PATTERNFLOWVLANCFICOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWVLANCFICOUNTER.fields_by_name['step'])
_PATTERNFLOWVLANCFICOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWVLANCFICOUNTER.oneofs_by_name['_step']
_PATTERNFLOWVLANCFICOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWVLANCFICOUNTER.fields_by_name['count'])
_PATTERNFLOWVLANCFICOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWVLANCFICOUNTER.oneofs_by_name['_count']
_PATTERNFLOWVLANCFI_CHOICE.containing_type = _PATTERNFLOWVLANCFI
_PATTERNFLOWVLANCFI_CHOICE_ENUM.containing_type = _PATTERNFLOWVLANCFI_CHOICE
_PATTERNFLOWVLANCFI.fields_by_name['choice'].enum_type = _PATTERNFLOWVLANCFI_CHOICE_ENUM
_PATTERNFLOWVLANCFI.fields_by_name['increment'].message_type = _PATTERNFLOWVLANCFICOUNTER
_PATTERNFLOWVLANCFI.fields_by_name['decrement'].message_type = _PATTERNFLOWVLANCFICOUNTER
_PATTERNFLOWVLANCFI.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWVLANCFI.fields_by_name['choice'])
_PATTERNFLOWVLANCFI.fields_by_name['choice'].containing_oneof = _PATTERNFLOWVLANCFI.oneofs_by_name['_choice']
_PATTERNFLOWVLANCFI.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWVLANCFI.fields_by_name['value'])
_PATTERNFLOWVLANCFI.fields_by_name['value'].containing_oneof = _PATTERNFLOWVLANCFI.oneofs_by_name['_value']
_PATTERNFLOWVLANCFI.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWVLANCFI.fields_by_name['metric_group'])
_PATTERNFLOWVLANCFI.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWVLANCFI.oneofs_by_name['_metric_group']
_PATTERNFLOWVLANCFI.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWVLANCFI.fields_by_name['increment'])
_PATTERNFLOWVLANCFI.fields_by_name['increment'].containing_oneof = _PATTERNFLOWVLANCFI.oneofs_by_name['_increment']
_PATTERNFLOWVLANCFI.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWVLANCFI.fields_by_name['decrement'])
_PATTERNFLOWVLANCFI.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWVLANCFI.oneofs_by_name['_decrement']
_PATTERNFLOWVLANIDCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWVLANIDCOUNTER.fields_by_name['start'])
_PATTERNFLOWVLANIDCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWVLANIDCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWVLANIDCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWVLANIDCOUNTER.fields_by_name['step'])
_PATTERNFLOWVLANIDCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWVLANIDCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWVLANIDCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWVLANIDCOUNTER.fields_by_name['count'])
_PATTERNFLOWVLANIDCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWVLANIDCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWVLANID_CHOICE.containing_type = _PATTERNFLOWVLANID
_PATTERNFLOWVLANID_CHOICE_ENUM.containing_type = _PATTERNFLOWVLANID_CHOICE
_PATTERNFLOWVLANID.fields_by_name['choice'].enum_type = _PATTERNFLOWVLANID_CHOICE_ENUM
_PATTERNFLOWVLANID.fields_by_name['increment'].message_type = _PATTERNFLOWVLANIDCOUNTER
_PATTERNFLOWVLANID.fields_by_name['decrement'].message_type = _PATTERNFLOWVLANIDCOUNTER
_PATTERNFLOWVLANID.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWVLANID.fields_by_name['choice'])
_PATTERNFLOWVLANID.fields_by_name['choice'].containing_oneof = _PATTERNFLOWVLANID.oneofs_by_name['_choice']
_PATTERNFLOWVLANID.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWVLANID.fields_by_name['value'])
_PATTERNFLOWVLANID.fields_by_name['value'].containing_oneof = _PATTERNFLOWVLANID.oneofs_by_name['_value']
_PATTERNFLOWVLANID.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWVLANID.fields_by_name['metric_group'])
_PATTERNFLOWVLANID.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWVLANID.oneofs_by_name['_metric_group']
_PATTERNFLOWVLANID.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWVLANID.fields_by_name['increment'])
_PATTERNFLOWVLANID.fields_by_name['increment'].containing_oneof = _PATTERNFLOWVLANID.oneofs_by_name['_increment']
_PATTERNFLOWVLANID.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWVLANID.fields_by_name['decrement'])
_PATTERNFLOWVLANID.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWVLANID.oneofs_by_name['_decrement']
_PATTERNFLOWVLANTPIDCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWVLANTPIDCOUNTER.fields_by_name['start'])
_PATTERNFLOWVLANTPIDCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWVLANTPIDCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWVLANTPIDCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWVLANTPIDCOUNTER.fields_by_name['step'])
_PATTERNFLOWVLANTPIDCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWVLANTPIDCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWVLANTPIDCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWVLANTPIDCOUNTER.fields_by_name['count'])
_PATTERNFLOWVLANTPIDCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWVLANTPIDCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWVLANTPID_CHOICE.containing_type = _PATTERNFLOWVLANTPID
_PATTERNFLOWVLANTPID_CHOICE_ENUM.containing_type = _PATTERNFLOWVLANTPID_CHOICE
_PATTERNFLOWVLANTPID.fields_by_name['choice'].enum_type = _PATTERNFLOWVLANTPID_CHOICE_ENUM
_PATTERNFLOWVLANTPID.fields_by_name['increment'].message_type = _PATTERNFLOWVLANTPIDCOUNTER
_PATTERNFLOWVLANTPID.fields_by_name['decrement'].message_type = _PATTERNFLOWVLANTPIDCOUNTER
_PATTERNFLOWVLANTPID.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWVLANTPID.fields_by_name['choice'])
_PATTERNFLOWVLANTPID.fields_by_name['choice'].containing_oneof = _PATTERNFLOWVLANTPID.oneofs_by_name['_choice']
_PATTERNFLOWVLANTPID.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWVLANTPID.fields_by_name['value'])
_PATTERNFLOWVLANTPID.fields_by_name['value'].containing_oneof = _PATTERNFLOWVLANTPID.oneofs_by_name['_value']
_PATTERNFLOWVLANTPID.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWVLANTPID.fields_by_name['metric_group'])
_PATTERNFLOWVLANTPID.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWVLANTPID.oneofs_by_name['_metric_group']
_PATTERNFLOWVLANTPID.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWVLANTPID.fields_by_name['increment'])
_PATTERNFLOWVLANTPID.fields_by_name['increment'].containing_oneof = _PATTERNFLOWVLANTPID.oneofs_by_name['_increment']
_PATTERNFLOWVLANTPID.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWVLANTPID.fields_by_name['decrement'])
_PATTERNFLOWVLANTPID.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWVLANTPID.oneofs_by_name['_decrement']
_PATTERNFLOWVXLANFLAGSCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWVXLANFLAGSCOUNTER.fields_by_name['start'])
_PATTERNFLOWVXLANFLAGSCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWVXLANFLAGSCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWVXLANFLAGSCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWVXLANFLAGSCOUNTER.fields_by_name['step'])
_PATTERNFLOWVXLANFLAGSCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWVXLANFLAGSCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWVXLANFLAGSCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWVXLANFLAGSCOUNTER.fields_by_name['count'])
_PATTERNFLOWVXLANFLAGSCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWVXLANFLAGSCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWVXLANFLAGS_CHOICE.containing_type = _PATTERNFLOWVXLANFLAGS
_PATTERNFLOWVXLANFLAGS_CHOICE_ENUM.containing_type = _PATTERNFLOWVXLANFLAGS_CHOICE
_PATTERNFLOWVXLANFLAGS.fields_by_name['choice'].enum_type = _PATTERNFLOWVXLANFLAGS_CHOICE_ENUM
_PATTERNFLOWVXLANFLAGS.fields_by_name['increment'].message_type = _PATTERNFLOWVXLANFLAGSCOUNTER
_PATTERNFLOWVXLANFLAGS.fields_by_name['decrement'].message_type = _PATTERNFLOWVXLANFLAGSCOUNTER
_PATTERNFLOWVXLANFLAGS.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWVXLANFLAGS.fields_by_name['choice'])
_PATTERNFLOWVXLANFLAGS.fields_by_name['choice'].containing_oneof = _PATTERNFLOWVXLANFLAGS.oneofs_by_name['_choice']
_PATTERNFLOWVXLANFLAGS.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWVXLANFLAGS.fields_by_name['value'])
_PATTERNFLOWVXLANFLAGS.fields_by_name['value'].containing_oneof = _PATTERNFLOWVXLANFLAGS.oneofs_by_name['_value']
_PATTERNFLOWVXLANFLAGS.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWVXLANFLAGS.fields_by_name['metric_group'])
_PATTERNFLOWVXLANFLAGS.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWVXLANFLAGS.oneofs_by_name['_metric_group']
_PATTERNFLOWVXLANFLAGS.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWVXLANFLAGS.fields_by_name['increment'])
_PATTERNFLOWVXLANFLAGS.fields_by_name['increment'].containing_oneof = _PATTERNFLOWVXLANFLAGS.oneofs_by_name['_increment']
_PATTERNFLOWVXLANFLAGS.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWVXLANFLAGS.fields_by_name['decrement'])
_PATTERNFLOWVXLANFLAGS.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWVXLANFLAGS.oneofs_by_name['_decrement']
_PATTERNFLOWVXLANRESERVED0COUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWVXLANRESERVED0COUNTER.fields_by_name['start'])
_PATTERNFLOWVXLANRESERVED0COUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWVXLANRESERVED0COUNTER.oneofs_by_name['_start']
_PATTERNFLOWVXLANRESERVED0COUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWVXLANRESERVED0COUNTER.fields_by_name['step'])
_PATTERNFLOWVXLANRESERVED0COUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWVXLANRESERVED0COUNTER.oneofs_by_name['_step']
_PATTERNFLOWVXLANRESERVED0COUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWVXLANRESERVED0COUNTER.fields_by_name['count'])
_PATTERNFLOWVXLANRESERVED0COUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWVXLANRESERVED0COUNTER.oneofs_by_name['_count']
_PATTERNFLOWVXLANRESERVED0_CHOICE.containing_type = _PATTERNFLOWVXLANRESERVED0
_PATTERNFLOWVXLANRESERVED0_CHOICE_ENUM.containing_type = _PATTERNFLOWVXLANRESERVED0_CHOICE
_PATTERNFLOWVXLANRESERVED0.fields_by_name['choice'].enum_type = _PATTERNFLOWVXLANRESERVED0_CHOICE_ENUM
_PATTERNFLOWVXLANRESERVED0.fields_by_name['increment'].message_type = _PATTERNFLOWVXLANRESERVED0COUNTER
_PATTERNFLOWVXLANRESERVED0.fields_by_name['decrement'].message_type = _PATTERNFLOWVXLANRESERVED0COUNTER
_PATTERNFLOWVXLANRESERVED0.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWVXLANRESERVED0.fields_by_name['choice'])
_PATTERNFLOWVXLANRESERVED0.fields_by_name['choice'].containing_oneof = _PATTERNFLOWVXLANRESERVED0.oneofs_by_name['_choice']
_PATTERNFLOWVXLANRESERVED0.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWVXLANRESERVED0.fields_by_name['value'])
_PATTERNFLOWVXLANRESERVED0.fields_by_name['value'].containing_oneof = _PATTERNFLOWVXLANRESERVED0.oneofs_by_name['_value']
_PATTERNFLOWVXLANRESERVED0.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWVXLANRESERVED0.fields_by_name['metric_group'])
_PATTERNFLOWVXLANRESERVED0.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWVXLANRESERVED0.oneofs_by_name['_metric_group']
_PATTERNFLOWVXLANRESERVED0.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWVXLANRESERVED0.fields_by_name['increment'])
_PATTERNFLOWVXLANRESERVED0.fields_by_name['increment'].containing_oneof = _PATTERNFLOWVXLANRESERVED0.oneofs_by_name['_increment']
_PATTERNFLOWVXLANRESERVED0.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWVXLANRESERVED0.fields_by_name['decrement'])
_PATTERNFLOWVXLANRESERVED0.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWVXLANRESERVED0.oneofs_by_name['_decrement']
_PATTERNFLOWVXLANVNICOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWVXLANVNICOUNTER.fields_by_name['start'])
_PATTERNFLOWVXLANVNICOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWVXLANVNICOUNTER.oneofs_by_name['_start']
_PATTERNFLOWVXLANVNICOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWVXLANVNICOUNTER.fields_by_name['step'])
_PATTERNFLOWVXLANVNICOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWVXLANVNICOUNTER.oneofs_by_name['_step']
_PATTERNFLOWVXLANVNICOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWVXLANVNICOUNTER.fields_by_name['count'])
_PATTERNFLOWVXLANVNICOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWVXLANVNICOUNTER.oneofs_by_name['_count']
_PATTERNFLOWVXLANVNI_CHOICE.containing_type = _PATTERNFLOWVXLANVNI
_PATTERNFLOWVXLANVNI_CHOICE_ENUM.containing_type = _PATTERNFLOWVXLANVNI_CHOICE
_PATTERNFLOWVXLANVNI.fields_by_name['choice'].enum_type = _PATTERNFLOWVXLANVNI_CHOICE_ENUM
_PATTERNFLOWVXLANVNI.fields_by_name['increment'].message_type = _PATTERNFLOWVXLANVNICOUNTER
_PATTERNFLOWVXLANVNI.fields_by_name['decrement'].message_type = _PATTERNFLOWVXLANVNICOUNTER
_PATTERNFLOWVXLANVNI.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWVXLANVNI.fields_by_name['choice'])
_PATTERNFLOWVXLANVNI.fields_by_name['choice'].containing_oneof = _PATTERNFLOWVXLANVNI.oneofs_by_name['_choice']
_PATTERNFLOWVXLANVNI.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWVXLANVNI.fields_by_name['value'])
_PATTERNFLOWVXLANVNI.fields_by_name['value'].containing_oneof = _PATTERNFLOWVXLANVNI.oneofs_by_name['_value']
_PATTERNFLOWVXLANVNI.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWVXLANVNI.fields_by_name['metric_group'])
_PATTERNFLOWVXLANVNI.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWVXLANVNI.oneofs_by_name['_metric_group']
_PATTERNFLOWVXLANVNI.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWVXLANVNI.fields_by_name['increment'])
_PATTERNFLOWVXLANVNI.fields_by_name['increment'].containing_oneof = _PATTERNFLOWVXLANVNI.oneofs_by_name['_increment']
_PATTERNFLOWVXLANVNI.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWVXLANVNI.fields_by_name['decrement'])
_PATTERNFLOWVXLANVNI.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWVXLANVNI.oneofs_by_name['_decrement']
_PATTERNFLOWVXLANRESERVED1COUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWVXLANRESERVED1COUNTER.fields_by_name['start'])
_PATTERNFLOWVXLANRESERVED1COUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWVXLANRESERVED1COUNTER.oneofs_by_name['_start']
_PATTERNFLOWVXLANRESERVED1COUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWVXLANRESERVED1COUNTER.fields_by_name['step'])
_PATTERNFLOWVXLANRESERVED1COUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWVXLANRESERVED1COUNTER.oneofs_by_name['_step']
_PATTERNFLOWVXLANRESERVED1COUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWVXLANRESERVED1COUNTER.fields_by_name['count'])
_PATTERNFLOWVXLANRESERVED1COUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWVXLANRESERVED1COUNTER.oneofs_by_name['_count']
_PATTERNFLOWVXLANRESERVED1_CHOICE.containing_type = _PATTERNFLOWVXLANRESERVED1
_PATTERNFLOWVXLANRESERVED1_CHOICE_ENUM.containing_type = _PATTERNFLOWVXLANRESERVED1_CHOICE
_PATTERNFLOWVXLANRESERVED1.fields_by_name['choice'].enum_type = _PATTERNFLOWVXLANRESERVED1_CHOICE_ENUM
_PATTERNFLOWVXLANRESERVED1.fields_by_name['increment'].message_type = _PATTERNFLOWVXLANRESERVED1COUNTER
_PATTERNFLOWVXLANRESERVED1.fields_by_name['decrement'].message_type = _PATTERNFLOWVXLANRESERVED1COUNTER
_PATTERNFLOWVXLANRESERVED1.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWVXLANRESERVED1.fields_by_name['choice'])
_PATTERNFLOWVXLANRESERVED1.fields_by_name['choice'].containing_oneof = _PATTERNFLOWVXLANRESERVED1.oneofs_by_name['_choice']
_PATTERNFLOWVXLANRESERVED1.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWVXLANRESERVED1.fields_by_name['value'])
_PATTERNFLOWVXLANRESERVED1.fields_by_name['value'].containing_oneof = _PATTERNFLOWVXLANRESERVED1.oneofs_by_name['_value']
_PATTERNFLOWVXLANRESERVED1.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWVXLANRESERVED1.fields_by_name['metric_group'])
_PATTERNFLOWVXLANRESERVED1.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWVXLANRESERVED1.oneofs_by_name['_metric_group']
_PATTERNFLOWVXLANRESERVED1.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWVXLANRESERVED1.fields_by_name['increment'])
_PATTERNFLOWVXLANRESERVED1.fields_by_name['increment'].containing_oneof = _PATTERNFLOWVXLANRESERVED1.oneofs_by_name['_increment']
_PATTERNFLOWVXLANRESERVED1.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWVXLANRESERVED1.fields_by_name['decrement'])
_PATTERNFLOWVXLANRESERVED1.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWVXLANRESERVED1.oneofs_by_name['_decrement']
_PATTERNFLOWIPV4VERSIONCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWIPV4VERSIONCOUNTER.fields_by_name['start'])
_PATTERNFLOWIPV4VERSIONCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWIPV4VERSIONCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWIPV4VERSIONCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWIPV4VERSIONCOUNTER.fields_by_name['step'])
_PATTERNFLOWIPV4VERSIONCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWIPV4VERSIONCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWIPV4VERSIONCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWIPV4VERSIONCOUNTER.fields_by_name['count'])
_PATTERNFLOWIPV4VERSIONCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWIPV4VERSIONCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWIPV4VERSION_CHOICE.containing_type = _PATTERNFLOWIPV4VERSION
_PATTERNFLOWIPV4VERSION_CHOICE_ENUM.containing_type = _PATTERNFLOWIPV4VERSION_CHOICE
_PATTERNFLOWIPV4VERSION.fields_by_name['choice'].enum_type = _PATTERNFLOWIPV4VERSION_CHOICE_ENUM
_PATTERNFLOWIPV4VERSION.fields_by_name['increment'].message_type = _PATTERNFLOWIPV4VERSIONCOUNTER
_PATTERNFLOWIPV4VERSION.fields_by_name['decrement'].message_type = _PATTERNFLOWIPV4VERSIONCOUNTER
_PATTERNFLOWIPV4VERSION.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWIPV4VERSION.fields_by_name['choice'])
_PATTERNFLOWIPV4VERSION.fields_by_name['choice'].containing_oneof = _PATTERNFLOWIPV4VERSION.oneofs_by_name['_choice']
_PATTERNFLOWIPV4VERSION.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWIPV4VERSION.fields_by_name['value'])
_PATTERNFLOWIPV4VERSION.fields_by_name['value'].containing_oneof = _PATTERNFLOWIPV4VERSION.oneofs_by_name['_value']
_PATTERNFLOWIPV4VERSION.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWIPV4VERSION.fields_by_name['metric_group'])
_PATTERNFLOWIPV4VERSION.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWIPV4VERSION.oneofs_by_name['_metric_group']
_PATTERNFLOWIPV4VERSION.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWIPV4VERSION.fields_by_name['increment'])
_PATTERNFLOWIPV4VERSION.fields_by_name['increment'].containing_oneof = _PATTERNFLOWIPV4VERSION.oneofs_by_name['_increment']
_PATTERNFLOWIPV4VERSION.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWIPV4VERSION.fields_by_name['decrement'])
_PATTERNFLOWIPV4VERSION.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWIPV4VERSION.oneofs_by_name['_decrement']
_PATTERNFLOWIPV4HEADERLENGTHCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWIPV4HEADERLENGTHCOUNTER.fields_by_name['start'])
_PATTERNFLOWIPV4HEADERLENGTHCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWIPV4HEADERLENGTHCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWIPV4HEADERLENGTHCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWIPV4HEADERLENGTHCOUNTER.fields_by_name['step'])
_PATTERNFLOWIPV4HEADERLENGTHCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWIPV4HEADERLENGTHCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWIPV4HEADERLENGTHCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWIPV4HEADERLENGTHCOUNTER.fields_by_name['count'])
_PATTERNFLOWIPV4HEADERLENGTHCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWIPV4HEADERLENGTHCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWIPV4HEADERLENGTH_CHOICE.containing_type = _PATTERNFLOWIPV4HEADERLENGTH
_PATTERNFLOWIPV4HEADERLENGTH_CHOICE_ENUM.containing_type = _PATTERNFLOWIPV4HEADERLENGTH_CHOICE
_PATTERNFLOWIPV4HEADERLENGTH_AUTO.containing_type = _PATTERNFLOWIPV4HEADERLENGTH
_PATTERNFLOWIPV4HEADERLENGTH_AUTO_ENUM.containing_type = _PATTERNFLOWIPV4HEADERLENGTH_AUTO
_PATTERNFLOWIPV4HEADERLENGTH.fields_by_name['choice'].enum_type = _PATTERNFLOWIPV4HEADERLENGTH_CHOICE_ENUM
_PATTERNFLOWIPV4HEADERLENGTH.fields_by_name['auto'].enum_type = _PATTERNFLOWIPV4HEADERLENGTH_AUTO_ENUM
_PATTERNFLOWIPV4HEADERLENGTH.fields_by_name['increment'].message_type = _PATTERNFLOWIPV4HEADERLENGTHCOUNTER
_PATTERNFLOWIPV4HEADERLENGTH.fields_by_name['decrement'].message_type = _PATTERNFLOWIPV4HEADERLENGTHCOUNTER
_PATTERNFLOWIPV4HEADERLENGTH.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWIPV4HEADERLENGTH.fields_by_name['choice'])
_PATTERNFLOWIPV4HEADERLENGTH.fields_by_name['choice'].containing_oneof = _PATTERNFLOWIPV4HEADERLENGTH.oneofs_by_name['_choice']
_PATTERNFLOWIPV4HEADERLENGTH.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWIPV4HEADERLENGTH.fields_by_name['value'])
_PATTERNFLOWIPV4HEADERLENGTH.fields_by_name['value'].containing_oneof = _PATTERNFLOWIPV4HEADERLENGTH.oneofs_by_name['_value']
_PATTERNFLOWIPV4HEADERLENGTH.oneofs_by_name['_auto'].fields.append(
  _PATTERNFLOWIPV4HEADERLENGTH.fields_by_name['auto'])
_PATTERNFLOWIPV4HEADERLENGTH.fields_by_name['auto'].containing_oneof = _PATTERNFLOWIPV4HEADERLENGTH.oneofs_by_name['_auto']
_PATTERNFLOWIPV4HEADERLENGTH.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWIPV4HEADERLENGTH.fields_by_name['metric_group'])
_PATTERNFLOWIPV4HEADERLENGTH.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWIPV4HEADERLENGTH.oneofs_by_name['_metric_group']
_PATTERNFLOWIPV4HEADERLENGTH.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWIPV4HEADERLENGTH.fields_by_name['increment'])
_PATTERNFLOWIPV4HEADERLENGTH.fields_by_name['increment'].containing_oneof = _PATTERNFLOWIPV4HEADERLENGTH.oneofs_by_name['_increment']
_PATTERNFLOWIPV4HEADERLENGTH.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWIPV4HEADERLENGTH.fields_by_name['decrement'])
_PATTERNFLOWIPV4HEADERLENGTH.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWIPV4HEADERLENGTH.oneofs_by_name['_decrement']
_PATTERNFLOWIPV4TOTALLENGTHCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWIPV4TOTALLENGTHCOUNTER.fields_by_name['start'])
_PATTERNFLOWIPV4TOTALLENGTHCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWIPV4TOTALLENGTHCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWIPV4TOTALLENGTHCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWIPV4TOTALLENGTHCOUNTER.fields_by_name['step'])
_PATTERNFLOWIPV4TOTALLENGTHCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWIPV4TOTALLENGTHCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWIPV4TOTALLENGTHCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWIPV4TOTALLENGTHCOUNTER.fields_by_name['count'])
_PATTERNFLOWIPV4TOTALLENGTHCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWIPV4TOTALLENGTHCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWIPV4TOTALLENGTH_CHOICE.containing_type = _PATTERNFLOWIPV4TOTALLENGTH
_PATTERNFLOWIPV4TOTALLENGTH_CHOICE_ENUM.containing_type = _PATTERNFLOWIPV4TOTALLENGTH_CHOICE
_PATTERNFLOWIPV4TOTALLENGTH_AUTO.containing_type = _PATTERNFLOWIPV4TOTALLENGTH
_PATTERNFLOWIPV4TOTALLENGTH_AUTO_ENUM.containing_type = _PATTERNFLOWIPV4TOTALLENGTH_AUTO
_PATTERNFLOWIPV4TOTALLENGTH.fields_by_name['choice'].enum_type = _PATTERNFLOWIPV4TOTALLENGTH_CHOICE_ENUM
_PATTERNFLOWIPV4TOTALLENGTH.fields_by_name['auto'].enum_type = _PATTERNFLOWIPV4TOTALLENGTH_AUTO_ENUM
_PATTERNFLOWIPV4TOTALLENGTH.fields_by_name['increment'].message_type = _PATTERNFLOWIPV4TOTALLENGTHCOUNTER
_PATTERNFLOWIPV4TOTALLENGTH.fields_by_name['decrement'].message_type = _PATTERNFLOWIPV4TOTALLENGTHCOUNTER
_PATTERNFLOWIPV4TOTALLENGTH.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWIPV4TOTALLENGTH.fields_by_name['choice'])
_PATTERNFLOWIPV4TOTALLENGTH.fields_by_name['choice'].containing_oneof = _PATTERNFLOWIPV4TOTALLENGTH.oneofs_by_name['_choice']
_PATTERNFLOWIPV4TOTALLENGTH.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWIPV4TOTALLENGTH.fields_by_name['value'])
_PATTERNFLOWIPV4TOTALLENGTH.fields_by_name['value'].containing_oneof = _PATTERNFLOWIPV4TOTALLENGTH.oneofs_by_name['_value']
_PATTERNFLOWIPV4TOTALLENGTH.oneofs_by_name['_auto'].fields.append(
  _PATTERNFLOWIPV4TOTALLENGTH.fields_by_name['auto'])
_PATTERNFLOWIPV4TOTALLENGTH.fields_by_name['auto'].containing_oneof = _PATTERNFLOWIPV4TOTALLENGTH.oneofs_by_name['_auto']
_PATTERNFLOWIPV4TOTALLENGTH.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWIPV4TOTALLENGTH.fields_by_name['metric_group'])
_PATTERNFLOWIPV4TOTALLENGTH.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWIPV4TOTALLENGTH.oneofs_by_name['_metric_group']
_PATTERNFLOWIPV4TOTALLENGTH.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWIPV4TOTALLENGTH.fields_by_name['increment'])
_PATTERNFLOWIPV4TOTALLENGTH.fields_by_name['increment'].containing_oneof = _PATTERNFLOWIPV4TOTALLENGTH.oneofs_by_name['_increment']
_PATTERNFLOWIPV4TOTALLENGTH.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWIPV4TOTALLENGTH.fields_by_name['decrement'])
_PATTERNFLOWIPV4TOTALLENGTH.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWIPV4TOTALLENGTH.oneofs_by_name['_decrement']
_PATTERNFLOWIPV4IDENTIFICATIONCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWIPV4IDENTIFICATIONCOUNTER.fields_by_name['start'])
_PATTERNFLOWIPV4IDENTIFICATIONCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWIPV4IDENTIFICATIONCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWIPV4IDENTIFICATIONCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWIPV4IDENTIFICATIONCOUNTER.fields_by_name['step'])
_PATTERNFLOWIPV4IDENTIFICATIONCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWIPV4IDENTIFICATIONCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWIPV4IDENTIFICATIONCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWIPV4IDENTIFICATIONCOUNTER.fields_by_name['count'])
_PATTERNFLOWIPV4IDENTIFICATIONCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWIPV4IDENTIFICATIONCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWIPV4IDENTIFICATION_CHOICE.containing_type = _PATTERNFLOWIPV4IDENTIFICATION
_PATTERNFLOWIPV4IDENTIFICATION_CHOICE_ENUM.containing_type = _PATTERNFLOWIPV4IDENTIFICATION_CHOICE
_PATTERNFLOWIPV4IDENTIFICATION.fields_by_name['choice'].enum_type = _PATTERNFLOWIPV4IDENTIFICATION_CHOICE_ENUM
_PATTERNFLOWIPV4IDENTIFICATION.fields_by_name['increment'].message_type = _PATTERNFLOWIPV4IDENTIFICATIONCOUNTER
_PATTERNFLOWIPV4IDENTIFICATION.fields_by_name['decrement'].message_type = _PATTERNFLOWIPV4IDENTIFICATIONCOUNTER
_PATTERNFLOWIPV4IDENTIFICATION.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWIPV4IDENTIFICATION.fields_by_name['choice'])
_PATTERNFLOWIPV4IDENTIFICATION.fields_by_name['choice'].containing_oneof = _PATTERNFLOWIPV4IDENTIFICATION.oneofs_by_name['_choice']
_PATTERNFLOWIPV4IDENTIFICATION.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWIPV4IDENTIFICATION.fields_by_name['value'])
_PATTERNFLOWIPV4IDENTIFICATION.fields_by_name['value'].containing_oneof = _PATTERNFLOWIPV4IDENTIFICATION.oneofs_by_name['_value']
_PATTERNFLOWIPV4IDENTIFICATION.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWIPV4IDENTIFICATION.fields_by_name['metric_group'])
_PATTERNFLOWIPV4IDENTIFICATION.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWIPV4IDENTIFICATION.oneofs_by_name['_metric_group']
_PATTERNFLOWIPV4IDENTIFICATION.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWIPV4IDENTIFICATION.fields_by_name['increment'])
_PATTERNFLOWIPV4IDENTIFICATION.fields_by_name['increment'].containing_oneof = _PATTERNFLOWIPV4IDENTIFICATION.oneofs_by_name['_increment']
_PATTERNFLOWIPV4IDENTIFICATION.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWIPV4IDENTIFICATION.fields_by_name['decrement'])
_PATTERNFLOWIPV4IDENTIFICATION.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWIPV4IDENTIFICATION.oneofs_by_name['_decrement']
_PATTERNFLOWIPV4RESERVEDCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWIPV4RESERVEDCOUNTER.fields_by_name['start'])
_PATTERNFLOWIPV4RESERVEDCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWIPV4RESERVEDCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWIPV4RESERVEDCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWIPV4RESERVEDCOUNTER.fields_by_name['step'])
_PATTERNFLOWIPV4RESERVEDCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWIPV4RESERVEDCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWIPV4RESERVEDCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWIPV4RESERVEDCOUNTER.fields_by_name['count'])
_PATTERNFLOWIPV4RESERVEDCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWIPV4RESERVEDCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWIPV4RESERVED_CHOICE.containing_type = _PATTERNFLOWIPV4RESERVED
_PATTERNFLOWIPV4RESERVED_CHOICE_ENUM.containing_type = _PATTERNFLOWIPV4RESERVED_CHOICE
_PATTERNFLOWIPV4RESERVED.fields_by_name['choice'].enum_type = _PATTERNFLOWIPV4RESERVED_CHOICE_ENUM
_PATTERNFLOWIPV4RESERVED.fields_by_name['increment'].message_type = _PATTERNFLOWIPV4RESERVEDCOUNTER
_PATTERNFLOWIPV4RESERVED.fields_by_name['decrement'].message_type = _PATTERNFLOWIPV4RESERVEDCOUNTER
_PATTERNFLOWIPV4RESERVED.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWIPV4RESERVED.fields_by_name['choice'])
_PATTERNFLOWIPV4RESERVED.fields_by_name['choice'].containing_oneof = _PATTERNFLOWIPV4RESERVED.oneofs_by_name['_choice']
_PATTERNFLOWIPV4RESERVED.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWIPV4RESERVED.fields_by_name['value'])
_PATTERNFLOWIPV4RESERVED.fields_by_name['value'].containing_oneof = _PATTERNFLOWIPV4RESERVED.oneofs_by_name['_value']
_PATTERNFLOWIPV4RESERVED.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWIPV4RESERVED.fields_by_name['metric_group'])
_PATTERNFLOWIPV4RESERVED.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWIPV4RESERVED.oneofs_by_name['_metric_group']
_PATTERNFLOWIPV4RESERVED.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWIPV4RESERVED.fields_by_name['increment'])
_PATTERNFLOWIPV4RESERVED.fields_by_name['increment'].containing_oneof = _PATTERNFLOWIPV4RESERVED.oneofs_by_name['_increment']
_PATTERNFLOWIPV4RESERVED.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWIPV4RESERVED.fields_by_name['decrement'])
_PATTERNFLOWIPV4RESERVED.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWIPV4RESERVED.oneofs_by_name['_decrement']
_PATTERNFLOWIPV4DONTFRAGMENTCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWIPV4DONTFRAGMENTCOUNTER.fields_by_name['start'])
_PATTERNFLOWIPV4DONTFRAGMENTCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWIPV4DONTFRAGMENTCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWIPV4DONTFRAGMENTCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWIPV4DONTFRAGMENTCOUNTER.fields_by_name['step'])
_PATTERNFLOWIPV4DONTFRAGMENTCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWIPV4DONTFRAGMENTCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWIPV4DONTFRAGMENTCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWIPV4DONTFRAGMENTCOUNTER.fields_by_name['count'])
_PATTERNFLOWIPV4DONTFRAGMENTCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWIPV4DONTFRAGMENTCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWIPV4DONTFRAGMENT_CHOICE.containing_type = _PATTERNFLOWIPV4DONTFRAGMENT
_PATTERNFLOWIPV4DONTFRAGMENT_CHOICE_ENUM.containing_type = _PATTERNFLOWIPV4DONTFRAGMENT_CHOICE
_PATTERNFLOWIPV4DONTFRAGMENT.fields_by_name['choice'].enum_type = _PATTERNFLOWIPV4DONTFRAGMENT_CHOICE_ENUM
_PATTERNFLOWIPV4DONTFRAGMENT.fields_by_name['increment'].message_type = _PATTERNFLOWIPV4DONTFRAGMENTCOUNTER
_PATTERNFLOWIPV4DONTFRAGMENT.fields_by_name['decrement'].message_type = _PATTERNFLOWIPV4DONTFRAGMENTCOUNTER
_PATTERNFLOWIPV4DONTFRAGMENT.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWIPV4DONTFRAGMENT.fields_by_name['choice'])
_PATTERNFLOWIPV4DONTFRAGMENT.fields_by_name['choice'].containing_oneof = _PATTERNFLOWIPV4DONTFRAGMENT.oneofs_by_name['_choice']
_PATTERNFLOWIPV4DONTFRAGMENT.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWIPV4DONTFRAGMENT.fields_by_name['value'])
_PATTERNFLOWIPV4DONTFRAGMENT.fields_by_name['value'].containing_oneof = _PATTERNFLOWIPV4DONTFRAGMENT.oneofs_by_name['_value']
_PATTERNFLOWIPV4DONTFRAGMENT.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWIPV4DONTFRAGMENT.fields_by_name['metric_group'])
_PATTERNFLOWIPV4DONTFRAGMENT.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWIPV4DONTFRAGMENT.oneofs_by_name['_metric_group']
_PATTERNFLOWIPV4DONTFRAGMENT.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWIPV4DONTFRAGMENT.fields_by_name['increment'])
_PATTERNFLOWIPV4DONTFRAGMENT.fields_by_name['increment'].containing_oneof = _PATTERNFLOWIPV4DONTFRAGMENT.oneofs_by_name['_increment']
_PATTERNFLOWIPV4DONTFRAGMENT.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWIPV4DONTFRAGMENT.fields_by_name['decrement'])
_PATTERNFLOWIPV4DONTFRAGMENT.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWIPV4DONTFRAGMENT.oneofs_by_name['_decrement']
_PATTERNFLOWIPV4MOREFRAGMENTSCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWIPV4MOREFRAGMENTSCOUNTER.fields_by_name['start'])
_PATTERNFLOWIPV4MOREFRAGMENTSCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWIPV4MOREFRAGMENTSCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWIPV4MOREFRAGMENTSCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWIPV4MOREFRAGMENTSCOUNTER.fields_by_name['step'])
_PATTERNFLOWIPV4MOREFRAGMENTSCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWIPV4MOREFRAGMENTSCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWIPV4MOREFRAGMENTSCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWIPV4MOREFRAGMENTSCOUNTER.fields_by_name['count'])
_PATTERNFLOWIPV4MOREFRAGMENTSCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWIPV4MOREFRAGMENTSCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWIPV4MOREFRAGMENTS_CHOICE.containing_type = _PATTERNFLOWIPV4MOREFRAGMENTS
_PATTERNFLOWIPV4MOREFRAGMENTS_CHOICE_ENUM.containing_type = _PATTERNFLOWIPV4MOREFRAGMENTS_CHOICE
_PATTERNFLOWIPV4MOREFRAGMENTS.fields_by_name['choice'].enum_type = _PATTERNFLOWIPV4MOREFRAGMENTS_CHOICE_ENUM
_PATTERNFLOWIPV4MOREFRAGMENTS.fields_by_name['increment'].message_type = _PATTERNFLOWIPV4MOREFRAGMENTSCOUNTER
_PATTERNFLOWIPV4MOREFRAGMENTS.fields_by_name['decrement'].message_type = _PATTERNFLOWIPV4MOREFRAGMENTSCOUNTER
_PATTERNFLOWIPV4MOREFRAGMENTS.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWIPV4MOREFRAGMENTS.fields_by_name['choice'])
_PATTERNFLOWIPV4MOREFRAGMENTS.fields_by_name['choice'].containing_oneof = _PATTERNFLOWIPV4MOREFRAGMENTS.oneofs_by_name['_choice']
_PATTERNFLOWIPV4MOREFRAGMENTS.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWIPV4MOREFRAGMENTS.fields_by_name['value'])
_PATTERNFLOWIPV4MOREFRAGMENTS.fields_by_name['value'].containing_oneof = _PATTERNFLOWIPV4MOREFRAGMENTS.oneofs_by_name['_value']
_PATTERNFLOWIPV4MOREFRAGMENTS.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWIPV4MOREFRAGMENTS.fields_by_name['metric_group'])
_PATTERNFLOWIPV4MOREFRAGMENTS.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWIPV4MOREFRAGMENTS.oneofs_by_name['_metric_group']
_PATTERNFLOWIPV4MOREFRAGMENTS.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWIPV4MOREFRAGMENTS.fields_by_name['increment'])
_PATTERNFLOWIPV4MOREFRAGMENTS.fields_by_name['increment'].containing_oneof = _PATTERNFLOWIPV4MOREFRAGMENTS.oneofs_by_name['_increment']
_PATTERNFLOWIPV4MOREFRAGMENTS.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWIPV4MOREFRAGMENTS.fields_by_name['decrement'])
_PATTERNFLOWIPV4MOREFRAGMENTS.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWIPV4MOREFRAGMENTS.oneofs_by_name['_decrement']
_PATTERNFLOWIPV4FRAGMENTOFFSETCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWIPV4FRAGMENTOFFSETCOUNTER.fields_by_name['start'])
_PATTERNFLOWIPV4FRAGMENTOFFSETCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWIPV4FRAGMENTOFFSETCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWIPV4FRAGMENTOFFSETCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWIPV4FRAGMENTOFFSETCOUNTER.fields_by_name['step'])
_PATTERNFLOWIPV4FRAGMENTOFFSETCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWIPV4FRAGMENTOFFSETCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWIPV4FRAGMENTOFFSETCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWIPV4FRAGMENTOFFSETCOUNTER.fields_by_name['count'])
_PATTERNFLOWIPV4FRAGMENTOFFSETCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWIPV4FRAGMENTOFFSETCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWIPV4FRAGMENTOFFSET_CHOICE.containing_type = _PATTERNFLOWIPV4FRAGMENTOFFSET
_PATTERNFLOWIPV4FRAGMENTOFFSET_CHOICE_ENUM.containing_type = _PATTERNFLOWIPV4FRAGMENTOFFSET_CHOICE
_PATTERNFLOWIPV4FRAGMENTOFFSET.fields_by_name['choice'].enum_type = _PATTERNFLOWIPV4FRAGMENTOFFSET_CHOICE_ENUM
_PATTERNFLOWIPV4FRAGMENTOFFSET.fields_by_name['increment'].message_type = _PATTERNFLOWIPV4FRAGMENTOFFSETCOUNTER
_PATTERNFLOWIPV4FRAGMENTOFFSET.fields_by_name['decrement'].message_type = _PATTERNFLOWIPV4FRAGMENTOFFSETCOUNTER
_PATTERNFLOWIPV4FRAGMENTOFFSET.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWIPV4FRAGMENTOFFSET.fields_by_name['choice'])
_PATTERNFLOWIPV4FRAGMENTOFFSET.fields_by_name['choice'].containing_oneof = _PATTERNFLOWIPV4FRAGMENTOFFSET.oneofs_by_name['_choice']
_PATTERNFLOWIPV4FRAGMENTOFFSET.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWIPV4FRAGMENTOFFSET.fields_by_name['value'])
_PATTERNFLOWIPV4FRAGMENTOFFSET.fields_by_name['value'].containing_oneof = _PATTERNFLOWIPV4FRAGMENTOFFSET.oneofs_by_name['_value']
_PATTERNFLOWIPV4FRAGMENTOFFSET.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWIPV4FRAGMENTOFFSET.fields_by_name['metric_group'])
_PATTERNFLOWIPV4FRAGMENTOFFSET.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWIPV4FRAGMENTOFFSET.oneofs_by_name['_metric_group']
_PATTERNFLOWIPV4FRAGMENTOFFSET.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWIPV4FRAGMENTOFFSET.fields_by_name['increment'])
_PATTERNFLOWIPV4FRAGMENTOFFSET.fields_by_name['increment'].containing_oneof = _PATTERNFLOWIPV4FRAGMENTOFFSET.oneofs_by_name['_increment']
_PATTERNFLOWIPV4FRAGMENTOFFSET.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWIPV4FRAGMENTOFFSET.fields_by_name['decrement'])
_PATTERNFLOWIPV4FRAGMENTOFFSET.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWIPV4FRAGMENTOFFSET.oneofs_by_name['_decrement']
_PATTERNFLOWIPV4TIMETOLIVECOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWIPV4TIMETOLIVECOUNTER.fields_by_name['start'])
_PATTERNFLOWIPV4TIMETOLIVECOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWIPV4TIMETOLIVECOUNTER.oneofs_by_name['_start']
_PATTERNFLOWIPV4TIMETOLIVECOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWIPV4TIMETOLIVECOUNTER.fields_by_name['step'])
_PATTERNFLOWIPV4TIMETOLIVECOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWIPV4TIMETOLIVECOUNTER.oneofs_by_name['_step']
_PATTERNFLOWIPV4TIMETOLIVECOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWIPV4TIMETOLIVECOUNTER.fields_by_name['count'])
_PATTERNFLOWIPV4TIMETOLIVECOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWIPV4TIMETOLIVECOUNTER.oneofs_by_name['_count']
_PATTERNFLOWIPV4TIMETOLIVE_CHOICE.containing_type = _PATTERNFLOWIPV4TIMETOLIVE
_PATTERNFLOWIPV4TIMETOLIVE_CHOICE_ENUM.containing_type = _PATTERNFLOWIPV4TIMETOLIVE_CHOICE
_PATTERNFLOWIPV4TIMETOLIVE.fields_by_name['choice'].enum_type = _PATTERNFLOWIPV4TIMETOLIVE_CHOICE_ENUM
_PATTERNFLOWIPV4TIMETOLIVE.fields_by_name['increment'].message_type = _PATTERNFLOWIPV4TIMETOLIVECOUNTER
_PATTERNFLOWIPV4TIMETOLIVE.fields_by_name['decrement'].message_type = _PATTERNFLOWIPV4TIMETOLIVECOUNTER
_PATTERNFLOWIPV4TIMETOLIVE.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWIPV4TIMETOLIVE.fields_by_name['choice'])
_PATTERNFLOWIPV4TIMETOLIVE.fields_by_name['choice'].containing_oneof = _PATTERNFLOWIPV4TIMETOLIVE.oneofs_by_name['_choice']
_PATTERNFLOWIPV4TIMETOLIVE.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWIPV4TIMETOLIVE.fields_by_name['value'])
_PATTERNFLOWIPV4TIMETOLIVE.fields_by_name['value'].containing_oneof = _PATTERNFLOWIPV4TIMETOLIVE.oneofs_by_name['_value']
_PATTERNFLOWIPV4TIMETOLIVE.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWIPV4TIMETOLIVE.fields_by_name['metric_group'])
_PATTERNFLOWIPV4TIMETOLIVE.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWIPV4TIMETOLIVE.oneofs_by_name['_metric_group']
_PATTERNFLOWIPV4TIMETOLIVE.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWIPV4TIMETOLIVE.fields_by_name['increment'])
_PATTERNFLOWIPV4TIMETOLIVE.fields_by_name['increment'].containing_oneof = _PATTERNFLOWIPV4TIMETOLIVE.oneofs_by_name['_increment']
_PATTERNFLOWIPV4TIMETOLIVE.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWIPV4TIMETOLIVE.fields_by_name['decrement'])
_PATTERNFLOWIPV4TIMETOLIVE.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWIPV4TIMETOLIVE.oneofs_by_name['_decrement']
_PATTERNFLOWIPV4PROTOCOLCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWIPV4PROTOCOLCOUNTER.fields_by_name['start'])
_PATTERNFLOWIPV4PROTOCOLCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWIPV4PROTOCOLCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWIPV4PROTOCOLCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWIPV4PROTOCOLCOUNTER.fields_by_name['step'])
_PATTERNFLOWIPV4PROTOCOLCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWIPV4PROTOCOLCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWIPV4PROTOCOLCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWIPV4PROTOCOLCOUNTER.fields_by_name['count'])
_PATTERNFLOWIPV4PROTOCOLCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWIPV4PROTOCOLCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWIPV4PROTOCOL_CHOICE.containing_type = _PATTERNFLOWIPV4PROTOCOL
_PATTERNFLOWIPV4PROTOCOL_CHOICE_ENUM.containing_type = _PATTERNFLOWIPV4PROTOCOL_CHOICE
_PATTERNFLOWIPV4PROTOCOL_AUTO.containing_type = _PATTERNFLOWIPV4PROTOCOL
_PATTERNFLOWIPV4PROTOCOL_AUTO_ENUM.containing_type = _PATTERNFLOWIPV4PROTOCOL_AUTO
_PATTERNFLOWIPV4PROTOCOL.fields_by_name['choice'].enum_type = _PATTERNFLOWIPV4PROTOCOL_CHOICE_ENUM
_PATTERNFLOWIPV4PROTOCOL.fields_by_name['auto'].enum_type = _PATTERNFLOWIPV4PROTOCOL_AUTO_ENUM
_PATTERNFLOWIPV4PROTOCOL.fields_by_name['increment'].message_type = _PATTERNFLOWIPV4PROTOCOLCOUNTER
_PATTERNFLOWIPV4PROTOCOL.fields_by_name['decrement'].message_type = _PATTERNFLOWIPV4PROTOCOLCOUNTER
_PATTERNFLOWIPV4PROTOCOL.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWIPV4PROTOCOL.fields_by_name['choice'])
_PATTERNFLOWIPV4PROTOCOL.fields_by_name['choice'].containing_oneof = _PATTERNFLOWIPV4PROTOCOL.oneofs_by_name['_choice']
_PATTERNFLOWIPV4PROTOCOL.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWIPV4PROTOCOL.fields_by_name['value'])
_PATTERNFLOWIPV4PROTOCOL.fields_by_name['value'].containing_oneof = _PATTERNFLOWIPV4PROTOCOL.oneofs_by_name['_value']
_PATTERNFLOWIPV4PROTOCOL.oneofs_by_name['_auto'].fields.append(
  _PATTERNFLOWIPV4PROTOCOL.fields_by_name['auto'])
_PATTERNFLOWIPV4PROTOCOL.fields_by_name['auto'].containing_oneof = _PATTERNFLOWIPV4PROTOCOL.oneofs_by_name['_auto']
_PATTERNFLOWIPV4PROTOCOL.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWIPV4PROTOCOL.fields_by_name['metric_group'])
_PATTERNFLOWIPV4PROTOCOL.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWIPV4PROTOCOL.oneofs_by_name['_metric_group']
_PATTERNFLOWIPV4PROTOCOL.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWIPV4PROTOCOL.fields_by_name['increment'])
_PATTERNFLOWIPV4PROTOCOL.fields_by_name['increment'].containing_oneof = _PATTERNFLOWIPV4PROTOCOL.oneofs_by_name['_increment']
_PATTERNFLOWIPV4PROTOCOL.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWIPV4PROTOCOL.fields_by_name['decrement'])
_PATTERNFLOWIPV4PROTOCOL.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWIPV4PROTOCOL.oneofs_by_name['_decrement']
_PATTERNFLOWIPV4HEADERCHECKSUM_CHOICE.containing_type = _PATTERNFLOWIPV4HEADERCHECKSUM
_PATTERNFLOWIPV4HEADERCHECKSUM_CHOICE_ENUM.containing_type = _PATTERNFLOWIPV4HEADERCHECKSUM_CHOICE
_PATTERNFLOWIPV4HEADERCHECKSUM_GENERATED.containing_type = _PATTERNFLOWIPV4HEADERCHECKSUM
_PATTERNFLOWIPV4HEADERCHECKSUM_GENERATED_ENUM.containing_type = _PATTERNFLOWIPV4HEADERCHECKSUM_GENERATED
_PATTERNFLOWIPV4HEADERCHECKSUM.fields_by_name['choice'].enum_type = _PATTERNFLOWIPV4HEADERCHECKSUM_CHOICE_ENUM
_PATTERNFLOWIPV4HEADERCHECKSUM.fields_by_name['generated'].enum_type = _PATTERNFLOWIPV4HEADERCHECKSUM_GENERATED_ENUM
_PATTERNFLOWIPV4HEADERCHECKSUM.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWIPV4HEADERCHECKSUM.fields_by_name['choice'])
_PATTERNFLOWIPV4HEADERCHECKSUM.fields_by_name['choice'].containing_oneof = _PATTERNFLOWIPV4HEADERCHECKSUM.oneofs_by_name['_choice']
_PATTERNFLOWIPV4HEADERCHECKSUM.oneofs_by_name['_generated'].fields.append(
  _PATTERNFLOWIPV4HEADERCHECKSUM.fields_by_name['generated'])
_PATTERNFLOWIPV4HEADERCHECKSUM.fields_by_name['generated'].containing_oneof = _PATTERNFLOWIPV4HEADERCHECKSUM.oneofs_by_name['_generated']
_PATTERNFLOWIPV4HEADERCHECKSUM.oneofs_by_name['_custom'].fields.append(
  _PATTERNFLOWIPV4HEADERCHECKSUM.fields_by_name['custom'])
_PATTERNFLOWIPV4HEADERCHECKSUM.fields_by_name['custom'].containing_oneof = _PATTERNFLOWIPV4HEADERCHECKSUM.oneofs_by_name['_custom']
_PATTERNFLOWIPV4SRCCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWIPV4SRCCOUNTER.fields_by_name['start'])
_PATTERNFLOWIPV4SRCCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWIPV4SRCCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWIPV4SRCCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWIPV4SRCCOUNTER.fields_by_name['step'])
_PATTERNFLOWIPV4SRCCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWIPV4SRCCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWIPV4SRCCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWIPV4SRCCOUNTER.fields_by_name['count'])
_PATTERNFLOWIPV4SRCCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWIPV4SRCCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWIPV4SRC_CHOICE.containing_type = _PATTERNFLOWIPV4SRC
_PATTERNFLOWIPV4SRC_CHOICE_ENUM.containing_type = _PATTERNFLOWIPV4SRC_CHOICE
_PATTERNFLOWIPV4SRC.fields_by_name['choice'].enum_type = _PATTERNFLOWIPV4SRC_CHOICE_ENUM
_PATTERNFLOWIPV4SRC.fields_by_name['increment'].message_type = _PATTERNFLOWIPV4SRCCOUNTER
_PATTERNFLOWIPV4SRC.fields_by_name['decrement'].message_type = _PATTERNFLOWIPV4SRCCOUNTER
_PATTERNFLOWIPV4SRC.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWIPV4SRC.fields_by_name['choice'])
_PATTERNFLOWIPV4SRC.fields_by_name['choice'].containing_oneof = _PATTERNFLOWIPV4SRC.oneofs_by_name['_choice']
_PATTERNFLOWIPV4SRC.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWIPV4SRC.fields_by_name['value'])
_PATTERNFLOWIPV4SRC.fields_by_name['value'].containing_oneof = _PATTERNFLOWIPV4SRC.oneofs_by_name['_value']
_PATTERNFLOWIPV4SRC.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWIPV4SRC.fields_by_name['metric_group'])
_PATTERNFLOWIPV4SRC.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWIPV4SRC.oneofs_by_name['_metric_group']
_PATTERNFLOWIPV4SRC.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWIPV4SRC.fields_by_name['increment'])
_PATTERNFLOWIPV4SRC.fields_by_name['increment'].containing_oneof = _PATTERNFLOWIPV4SRC.oneofs_by_name['_increment']
_PATTERNFLOWIPV4SRC.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWIPV4SRC.fields_by_name['decrement'])
_PATTERNFLOWIPV4SRC.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWIPV4SRC.oneofs_by_name['_decrement']
_PATTERNFLOWIPV4DSTCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWIPV4DSTCOUNTER.fields_by_name['start'])
_PATTERNFLOWIPV4DSTCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWIPV4DSTCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWIPV4DSTCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWIPV4DSTCOUNTER.fields_by_name['step'])
_PATTERNFLOWIPV4DSTCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWIPV4DSTCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWIPV4DSTCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWIPV4DSTCOUNTER.fields_by_name['count'])
_PATTERNFLOWIPV4DSTCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWIPV4DSTCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWIPV4DST_CHOICE.containing_type = _PATTERNFLOWIPV4DST
_PATTERNFLOWIPV4DST_CHOICE_ENUM.containing_type = _PATTERNFLOWIPV4DST_CHOICE
_PATTERNFLOWIPV4DST.fields_by_name['choice'].enum_type = _PATTERNFLOWIPV4DST_CHOICE_ENUM
_PATTERNFLOWIPV4DST.fields_by_name['increment'].message_type = _PATTERNFLOWIPV4DSTCOUNTER
_PATTERNFLOWIPV4DST.fields_by_name['decrement'].message_type = _PATTERNFLOWIPV4DSTCOUNTER
_PATTERNFLOWIPV4DST.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWIPV4DST.fields_by_name['choice'])
_PATTERNFLOWIPV4DST.fields_by_name['choice'].containing_oneof = _PATTERNFLOWIPV4DST.oneofs_by_name['_choice']
_PATTERNFLOWIPV4DST.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWIPV4DST.fields_by_name['value'])
_PATTERNFLOWIPV4DST.fields_by_name['value'].containing_oneof = _PATTERNFLOWIPV4DST.oneofs_by_name['_value']
_PATTERNFLOWIPV4DST.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWIPV4DST.fields_by_name['metric_group'])
_PATTERNFLOWIPV4DST.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWIPV4DST.oneofs_by_name['_metric_group']
_PATTERNFLOWIPV4DST.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWIPV4DST.fields_by_name['increment'])
_PATTERNFLOWIPV4DST.fields_by_name['increment'].containing_oneof = _PATTERNFLOWIPV4DST.oneofs_by_name['_increment']
_PATTERNFLOWIPV4DST.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWIPV4DST.fields_by_name['decrement'])
_PATTERNFLOWIPV4DST.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWIPV4DST.oneofs_by_name['_decrement']
_PATTERNFLOWIPV4PRIORITYRAWCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWIPV4PRIORITYRAWCOUNTER.fields_by_name['start'])
_PATTERNFLOWIPV4PRIORITYRAWCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWIPV4PRIORITYRAWCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWIPV4PRIORITYRAWCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWIPV4PRIORITYRAWCOUNTER.fields_by_name['step'])
_PATTERNFLOWIPV4PRIORITYRAWCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWIPV4PRIORITYRAWCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWIPV4PRIORITYRAWCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWIPV4PRIORITYRAWCOUNTER.fields_by_name['count'])
_PATTERNFLOWIPV4PRIORITYRAWCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWIPV4PRIORITYRAWCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWIPV4PRIORITYRAW_CHOICE.containing_type = _PATTERNFLOWIPV4PRIORITYRAW
_PATTERNFLOWIPV4PRIORITYRAW_CHOICE_ENUM.containing_type = _PATTERNFLOWIPV4PRIORITYRAW_CHOICE
_PATTERNFLOWIPV4PRIORITYRAW.fields_by_name['choice'].enum_type = _PATTERNFLOWIPV4PRIORITYRAW_CHOICE_ENUM
_PATTERNFLOWIPV4PRIORITYRAW.fields_by_name['increment'].message_type = _PATTERNFLOWIPV4PRIORITYRAWCOUNTER
_PATTERNFLOWIPV4PRIORITYRAW.fields_by_name['decrement'].message_type = _PATTERNFLOWIPV4PRIORITYRAWCOUNTER
_PATTERNFLOWIPV4PRIORITYRAW.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWIPV4PRIORITYRAW.fields_by_name['choice'])
_PATTERNFLOWIPV4PRIORITYRAW.fields_by_name['choice'].containing_oneof = _PATTERNFLOWIPV4PRIORITYRAW.oneofs_by_name['_choice']
_PATTERNFLOWIPV4PRIORITYRAW.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWIPV4PRIORITYRAW.fields_by_name['value'])
_PATTERNFLOWIPV4PRIORITYRAW.fields_by_name['value'].containing_oneof = _PATTERNFLOWIPV4PRIORITYRAW.oneofs_by_name['_value']
_PATTERNFLOWIPV4PRIORITYRAW.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWIPV4PRIORITYRAW.fields_by_name['metric_group'])
_PATTERNFLOWIPV4PRIORITYRAW.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWIPV4PRIORITYRAW.oneofs_by_name['_metric_group']
_PATTERNFLOWIPV4PRIORITYRAW.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWIPV4PRIORITYRAW.fields_by_name['increment'])
_PATTERNFLOWIPV4PRIORITYRAW.fields_by_name['increment'].containing_oneof = _PATTERNFLOWIPV4PRIORITYRAW.oneofs_by_name['_increment']
_PATTERNFLOWIPV4PRIORITYRAW.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWIPV4PRIORITYRAW.fields_by_name['decrement'])
_PATTERNFLOWIPV4PRIORITYRAW.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWIPV4PRIORITYRAW.oneofs_by_name['_decrement']
_PATTERNFLOWIPV4DSCPPHBCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWIPV4DSCPPHBCOUNTER.fields_by_name['start'])
_PATTERNFLOWIPV4DSCPPHBCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWIPV4DSCPPHBCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWIPV4DSCPPHBCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWIPV4DSCPPHBCOUNTER.fields_by_name['step'])
_PATTERNFLOWIPV4DSCPPHBCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWIPV4DSCPPHBCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWIPV4DSCPPHBCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWIPV4DSCPPHBCOUNTER.fields_by_name['count'])
_PATTERNFLOWIPV4DSCPPHBCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWIPV4DSCPPHBCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWIPV4DSCPPHB_CHOICE.containing_type = _PATTERNFLOWIPV4DSCPPHB
_PATTERNFLOWIPV4DSCPPHB_CHOICE_ENUM.containing_type = _PATTERNFLOWIPV4DSCPPHB_CHOICE
_PATTERNFLOWIPV4DSCPPHB.fields_by_name['choice'].enum_type = _PATTERNFLOWIPV4DSCPPHB_CHOICE_ENUM
_PATTERNFLOWIPV4DSCPPHB.fields_by_name['increment'].message_type = _PATTERNFLOWIPV4DSCPPHBCOUNTER
_PATTERNFLOWIPV4DSCPPHB.fields_by_name['decrement'].message_type = _PATTERNFLOWIPV4DSCPPHBCOUNTER
_PATTERNFLOWIPV4DSCPPHB.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWIPV4DSCPPHB.fields_by_name['choice'])
_PATTERNFLOWIPV4DSCPPHB.fields_by_name['choice'].containing_oneof = _PATTERNFLOWIPV4DSCPPHB.oneofs_by_name['_choice']
_PATTERNFLOWIPV4DSCPPHB.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWIPV4DSCPPHB.fields_by_name['value'])
_PATTERNFLOWIPV4DSCPPHB.fields_by_name['value'].containing_oneof = _PATTERNFLOWIPV4DSCPPHB.oneofs_by_name['_value']
_PATTERNFLOWIPV4DSCPPHB.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWIPV4DSCPPHB.fields_by_name['metric_group'])
_PATTERNFLOWIPV4DSCPPHB.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWIPV4DSCPPHB.oneofs_by_name['_metric_group']
_PATTERNFLOWIPV4DSCPPHB.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWIPV4DSCPPHB.fields_by_name['increment'])
_PATTERNFLOWIPV4DSCPPHB.fields_by_name['increment'].containing_oneof = _PATTERNFLOWIPV4DSCPPHB.oneofs_by_name['_increment']
_PATTERNFLOWIPV4DSCPPHB.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWIPV4DSCPPHB.fields_by_name['decrement'])
_PATTERNFLOWIPV4DSCPPHB.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWIPV4DSCPPHB.oneofs_by_name['_decrement']
_PATTERNFLOWIPV4DSCPECNCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWIPV4DSCPECNCOUNTER.fields_by_name['start'])
_PATTERNFLOWIPV4DSCPECNCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWIPV4DSCPECNCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWIPV4DSCPECNCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWIPV4DSCPECNCOUNTER.fields_by_name['step'])
_PATTERNFLOWIPV4DSCPECNCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWIPV4DSCPECNCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWIPV4DSCPECNCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWIPV4DSCPECNCOUNTER.fields_by_name['count'])
_PATTERNFLOWIPV4DSCPECNCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWIPV4DSCPECNCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWIPV4DSCPECN_CHOICE.containing_type = _PATTERNFLOWIPV4DSCPECN
_PATTERNFLOWIPV4DSCPECN_CHOICE_ENUM.containing_type = _PATTERNFLOWIPV4DSCPECN_CHOICE
_PATTERNFLOWIPV4DSCPECN.fields_by_name['choice'].enum_type = _PATTERNFLOWIPV4DSCPECN_CHOICE_ENUM
_PATTERNFLOWIPV4DSCPECN.fields_by_name['increment'].message_type = _PATTERNFLOWIPV4DSCPECNCOUNTER
_PATTERNFLOWIPV4DSCPECN.fields_by_name['decrement'].message_type = _PATTERNFLOWIPV4DSCPECNCOUNTER
_PATTERNFLOWIPV4DSCPECN.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWIPV4DSCPECN.fields_by_name['choice'])
_PATTERNFLOWIPV4DSCPECN.fields_by_name['choice'].containing_oneof = _PATTERNFLOWIPV4DSCPECN.oneofs_by_name['_choice']
_PATTERNFLOWIPV4DSCPECN.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWIPV4DSCPECN.fields_by_name['value'])
_PATTERNFLOWIPV4DSCPECN.fields_by_name['value'].containing_oneof = _PATTERNFLOWIPV4DSCPECN.oneofs_by_name['_value']
_PATTERNFLOWIPV4DSCPECN.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWIPV4DSCPECN.fields_by_name['metric_group'])
_PATTERNFLOWIPV4DSCPECN.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWIPV4DSCPECN.oneofs_by_name['_metric_group']
_PATTERNFLOWIPV4DSCPECN.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWIPV4DSCPECN.fields_by_name['increment'])
_PATTERNFLOWIPV4DSCPECN.fields_by_name['increment'].containing_oneof = _PATTERNFLOWIPV4DSCPECN.oneofs_by_name['_increment']
_PATTERNFLOWIPV4DSCPECN.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWIPV4DSCPECN.fields_by_name['decrement'])
_PATTERNFLOWIPV4DSCPECN.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWIPV4DSCPECN.oneofs_by_name['_decrement']
_PATTERNFLOWIPV4TOSPRECEDENCECOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWIPV4TOSPRECEDENCECOUNTER.fields_by_name['start'])
_PATTERNFLOWIPV4TOSPRECEDENCECOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWIPV4TOSPRECEDENCECOUNTER.oneofs_by_name['_start']
_PATTERNFLOWIPV4TOSPRECEDENCECOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWIPV4TOSPRECEDENCECOUNTER.fields_by_name['step'])
_PATTERNFLOWIPV4TOSPRECEDENCECOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWIPV4TOSPRECEDENCECOUNTER.oneofs_by_name['_step']
_PATTERNFLOWIPV4TOSPRECEDENCECOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWIPV4TOSPRECEDENCECOUNTER.fields_by_name['count'])
_PATTERNFLOWIPV4TOSPRECEDENCECOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWIPV4TOSPRECEDENCECOUNTER.oneofs_by_name['_count']
_PATTERNFLOWIPV4TOSPRECEDENCE_CHOICE.containing_type = _PATTERNFLOWIPV4TOSPRECEDENCE
_PATTERNFLOWIPV4TOSPRECEDENCE_CHOICE_ENUM.containing_type = _PATTERNFLOWIPV4TOSPRECEDENCE_CHOICE
_PATTERNFLOWIPV4TOSPRECEDENCE.fields_by_name['choice'].enum_type = _PATTERNFLOWIPV4TOSPRECEDENCE_CHOICE_ENUM
_PATTERNFLOWIPV4TOSPRECEDENCE.fields_by_name['increment'].message_type = _PATTERNFLOWIPV4TOSPRECEDENCECOUNTER
_PATTERNFLOWIPV4TOSPRECEDENCE.fields_by_name['decrement'].message_type = _PATTERNFLOWIPV4TOSPRECEDENCECOUNTER
_PATTERNFLOWIPV4TOSPRECEDENCE.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWIPV4TOSPRECEDENCE.fields_by_name['choice'])
_PATTERNFLOWIPV4TOSPRECEDENCE.fields_by_name['choice'].containing_oneof = _PATTERNFLOWIPV4TOSPRECEDENCE.oneofs_by_name['_choice']
_PATTERNFLOWIPV4TOSPRECEDENCE.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWIPV4TOSPRECEDENCE.fields_by_name['value'])
_PATTERNFLOWIPV4TOSPRECEDENCE.fields_by_name['value'].containing_oneof = _PATTERNFLOWIPV4TOSPRECEDENCE.oneofs_by_name['_value']
_PATTERNFLOWIPV4TOSPRECEDENCE.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWIPV4TOSPRECEDENCE.fields_by_name['metric_group'])
_PATTERNFLOWIPV4TOSPRECEDENCE.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWIPV4TOSPRECEDENCE.oneofs_by_name['_metric_group']
_PATTERNFLOWIPV4TOSPRECEDENCE.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWIPV4TOSPRECEDENCE.fields_by_name['increment'])
_PATTERNFLOWIPV4TOSPRECEDENCE.fields_by_name['increment'].containing_oneof = _PATTERNFLOWIPV4TOSPRECEDENCE.oneofs_by_name['_increment']
_PATTERNFLOWIPV4TOSPRECEDENCE.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWIPV4TOSPRECEDENCE.fields_by_name['decrement'])
_PATTERNFLOWIPV4TOSPRECEDENCE.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWIPV4TOSPRECEDENCE.oneofs_by_name['_decrement']
_PATTERNFLOWIPV4TOSDELAYCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWIPV4TOSDELAYCOUNTER.fields_by_name['start'])
_PATTERNFLOWIPV4TOSDELAYCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWIPV4TOSDELAYCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWIPV4TOSDELAYCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWIPV4TOSDELAYCOUNTER.fields_by_name['step'])
_PATTERNFLOWIPV4TOSDELAYCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWIPV4TOSDELAYCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWIPV4TOSDELAYCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWIPV4TOSDELAYCOUNTER.fields_by_name['count'])
_PATTERNFLOWIPV4TOSDELAYCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWIPV4TOSDELAYCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWIPV4TOSDELAY_CHOICE.containing_type = _PATTERNFLOWIPV4TOSDELAY
_PATTERNFLOWIPV4TOSDELAY_CHOICE_ENUM.containing_type = _PATTERNFLOWIPV4TOSDELAY_CHOICE
_PATTERNFLOWIPV4TOSDELAY.fields_by_name['choice'].enum_type = _PATTERNFLOWIPV4TOSDELAY_CHOICE_ENUM
_PATTERNFLOWIPV4TOSDELAY.fields_by_name['increment'].message_type = _PATTERNFLOWIPV4TOSDELAYCOUNTER
_PATTERNFLOWIPV4TOSDELAY.fields_by_name['decrement'].message_type = _PATTERNFLOWIPV4TOSDELAYCOUNTER
_PATTERNFLOWIPV4TOSDELAY.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWIPV4TOSDELAY.fields_by_name['choice'])
_PATTERNFLOWIPV4TOSDELAY.fields_by_name['choice'].containing_oneof = _PATTERNFLOWIPV4TOSDELAY.oneofs_by_name['_choice']
_PATTERNFLOWIPV4TOSDELAY.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWIPV4TOSDELAY.fields_by_name['value'])
_PATTERNFLOWIPV4TOSDELAY.fields_by_name['value'].containing_oneof = _PATTERNFLOWIPV4TOSDELAY.oneofs_by_name['_value']
_PATTERNFLOWIPV4TOSDELAY.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWIPV4TOSDELAY.fields_by_name['metric_group'])
_PATTERNFLOWIPV4TOSDELAY.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWIPV4TOSDELAY.oneofs_by_name['_metric_group']
_PATTERNFLOWIPV4TOSDELAY.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWIPV4TOSDELAY.fields_by_name['increment'])
_PATTERNFLOWIPV4TOSDELAY.fields_by_name['increment'].containing_oneof = _PATTERNFLOWIPV4TOSDELAY.oneofs_by_name['_increment']
_PATTERNFLOWIPV4TOSDELAY.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWIPV4TOSDELAY.fields_by_name['decrement'])
_PATTERNFLOWIPV4TOSDELAY.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWIPV4TOSDELAY.oneofs_by_name['_decrement']
_PATTERNFLOWIPV4TOSTHROUGHPUTCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWIPV4TOSTHROUGHPUTCOUNTER.fields_by_name['start'])
_PATTERNFLOWIPV4TOSTHROUGHPUTCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWIPV4TOSTHROUGHPUTCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWIPV4TOSTHROUGHPUTCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWIPV4TOSTHROUGHPUTCOUNTER.fields_by_name['step'])
_PATTERNFLOWIPV4TOSTHROUGHPUTCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWIPV4TOSTHROUGHPUTCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWIPV4TOSTHROUGHPUTCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWIPV4TOSTHROUGHPUTCOUNTER.fields_by_name['count'])
_PATTERNFLOWIPV4TOSTHROUGHPUTCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWIPV4TOSTHROUGHPUTCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWIPV4TOSTHROUGHPUT_CHOICE.containing_type = _PATTERNFLOWIPV4TOSTHROUGHPUT
_PATTERNFLOWIPV4TOSTHROUGHPUT_CHOICE_ENUM.containing_type = _PATTERNFLOWIPV4TOSTHROUGHPUT_CHOICE
_PATTERNFLOWIPV4TOSTHROUGHPUT.fields_by_name['choice'].enum_type = _PATTERNFLOWIPV4TOSTHROUGHPUT_CHOICE_ENUM
_PATTERNFLOWIPV4TOSTHROUGHPUT.fields_by_name['increment'].message_type = _PATTERNFLOWIPV4TOSTHROUGHPUTCOUNTER
_PATTERNFLOWIPV4TOSTHROUGHPUT.fields_by_name['decrement'].message_type = _PATTERNFLOWIPV4TOSTHROUGHPUTCOUNTER
_PATTERNFLOWIPV4TOSTHROUGHPUT.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWIPV4TOSTHROUGHPUT.fields_by_name['choice'])
_PATTERNFLOWIPV4TOSTHROUGHPUT.fields_by_name['choice'].containing_oneof = _PATTERNFLOWIPV4TOSTHROUGHPUT.oneofs_by_name['_choice']
_PATTERNFLOWIPV4TOSTHROUGHPUT.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWIPV4TOSTHROUGHPUT.fields_by_name['value'])
_PATTERNFLOWIPV4TOSTHROUGHPUT.fields_by_name['value'].containing_oneof = _PATTERNFLOWIPV4TOSTHROUGHPUT.oneofs_by_name['_value']
_PATTERNFLOWIPV4TOSTHROUGHPUT.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWIPV4TOSTHROUGHPUT.fields_by_name['metric_group'])
_PATTERNFLOWIPV4TOSTHROUGHPUT.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWIPV4TOSTHROUGHPUT.oneofs_by_name['_metric_group']
_PATTERNFLOWIPV4TOSTHROUGHPUT.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWIPV4TOSTHROUGHPUT.fields_by_name['increment'])
_PATTERNFLOWIPV4TOSTHROUGHPUT.fields_by_name['increment'].containing_oneof = _PATTERNFLOWIPV4TOSTHROUGHPUT.oneofs_by_name['_increment']
_PATTERNFLOWIPV4TOSTHROUGHPUT.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWIPV4TOSTHROUGHPUT.fields_by_name['decrement'])
_PATTERNFLOWIPV4TOSTHROUGHPUT.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWIPV4TOSTHROUGHPUT.oneofs_by_name['_decrement']
_PATTERNFLOWIPV4TOSRELIABILITYCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWIPV4TOSRELIABILITYCOUNTER.fields_by_name['start'])
_PATTERNFLOWIPV4TOSRELIABILITYCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWIPV4TOSRELIABILITYCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWIPV4TOSRELIABILITYCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWIPV4TOSRELIABILITYCOUNTER.fields_by_name['step'])
_PATTERNFLOWIPV4TOSRELIABILITYCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWIPV4TOSRELIABILITYCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWIPV4TOSRELIABILITYCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWIPV4TOSRELIABILITYCOUNTER.fields_by_name['count'])
_PATTERNFLOWIPV4TOSRELIABILITYCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWIPV4TOSRELIABILITYCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWIPV4TOSRELIABILITY_CHOICE.containing_type = _PATTERNFLOWIPV4TOSRELIABILITY
_PATTERNFLOWIPV4TOSRELIABILITY_CHOICE_ENUM.containing_type = _PATTERNFLOWIPV4TOSRELIABILITY_CHOICE
_PATTERNFLOWIPV4TOSRELIABILITY.fields_by_name['choice'].enum_type = _PATTERNFLOWIPV4TOSRELIABILITY_CHOICE_ENUM
_PATTERNFLOWIPV4TOSRELIABILITY.fields_by_name['increment'].message_type = _PATTERNFLOWIPV4TOSRELIABILITYCOUNTER
_PATTERNFLOWIPV4TOSRELIABILITY.fields_by_name['decrement'].message_type = _PATTERNFLOWIPV4TOSRELIABILITYCOUNTER
_PATTERNFLOWIPV4TOSRELIABILITY.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWIPV4TOSRELIABILITY.fields_by_name['choice'])
_PATTERNFLOWIPV4TOSRELIABILITY.fields_by_name['choice'].containing_oneof = _PATTERNFLOWIPV4TOSRELIABILITY.oneofs_by_name['_choice']
_PATTERNFLOWIPV4TOSRELIABILITY.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWIPV4TOSRELIABILITY.fields_by_name['value'])
_PATTERNFLOWIPV4TOSRELIABILITY.fields_by_name['value'].containing_oneof = _PATTERNFLOWIPV4TOSRELIABILITY.oneofs_by_name['_value']
_PATTERNFLOWIPV4TOSRELIABILITY.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWIPV4TOSRELIABILITY.fields_by_name['metric_group'])
_PATTERNFLOWIPV4TOSRELIABILITY.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWIPV4TOSRELIABILITY.oneofs_by_name['_metric_group']
_PATTERNFLOWIPV4TOSRELIABILITY.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWIPV4TOSRELIABILITY.fields_by_name['increment'])
_PATTERNFLOWIPV4TOSRELIABILITY.fields_by_name['increment'].containing_oneof = _PATTERNFLOWIPV4TOSRELIABILITY.oneofs_by_name['_increment']
_PATTERNFLOWIPV4TOSRELIABILITY.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWIPV4TOSRELIABILITY.fields_by_name['decrement'])
_PATTERNFLOWIPV4TOSRELIABILITY.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWIPV4TOSRELIABILITY.oneofs_by_name['_decrement']
_PATTERNFLOWIPV4TOSMONETARYCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWIPV4TOSMONETARYCOUNTER.fields_by_name['start'])
_PATTERNFLOWIPV4TOSMONETARYCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWIPV4TOSMONETARYCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWIPV4TOSMONETARYCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWIPV4TOSMONETARYCOUNTER.fields_by_name['step'])
_PATTERNFLOWIPV4TOSMONETARYCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWIPV4TOSMONETARYCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWIPV4TOSMONETARYCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWIPV4TOSMONETARYCOUNTER.fields_by_name['count'])
_PATTERNFLOWIPV4TOSMONETARYCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWIPV4TOSMONETARYCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWIPV4TOSMONETARY_CHOICE.containing_type = _PATTERNFLOWIPV4TOSMONETARY
_PATTERNFLOWIPV4TOSMONETARY_CHOICE_ENUM.containing_type = _PATTERNFLOWIPV4TOSMONETARY_CHOICE
_PATTERNFLOWIPV4TOSMONETARY.fields_by_name['choice'].enum_type = _PATTERNFLOWIPV4TOSMONETARY_CHOICE_ENUM
_PATTERNFLOWIPV4TOSMONETARY.fields_by_name['increment'].message_type = _PATTERNFLOWIPV4TOSMONETARYCOUNTER
_PATTERNFLOWIPV4TOSMONETARY.fields_by_name['decrement'].message_type = _PATTERNFLOWIPV4TOSMONETARYCOUNTER
_PATTERNFLOWIPV4TOSMONETARY.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWIPV4TOSMONETARY.fields_by_name['choice'])
_PATTERNFLOWIPV4TOSMONETARY.fields_by_name['choice'].containing_oneof = _PATTERNFLOWIPV4TOSMONETARY.oneofs_by_name['_choice']
_PATTERNFLOWIPV4TOSMONETARY.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWIPV4TOSMONETARY.fields_by_name['value'])
_PATTERNFLOWIPV4TOSMONETARY.fields_by_name['value'].containing_oneof = _PATTERNFLOWIPV4TOSMONETARY.oneofs_by_name['_value']
_PATTERNFLOWIPV4TOSMONETARY.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWIPV4TOSMONETARY.fields_by_name['metric_group'])
_PATTERNFLOWIPV4TOSMONETARY.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWIPV4TOSMONETARY.oneofs_by_name['_metric_group']
_PATTERNFLOWIPV4TOSMONETARY.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWIPV4TOSMONETARY.fields_by_name['increment'])
_PATTERNFLOWIPV4TOSMONETARY.fields_by_name['increment'].containing_oneof = _PATTERNFLOWIPV4TOSMONETARY.oneofs_by_name['_increment']
_PATTERNFLOWIPV4TOSMONETARY.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWIPV4TOSMONETARY.fields_by_name['decrement'])
_PATTERNFLOWIPV4TOSMONETARY.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWIPV4TOSMONETARY.oneofs_by_name['_decrement']
_PATTERNFLOWIPV4TOSUNUSEDCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWIPV4TOSUNUSEDCOUNTER.fields_by_name['start'])
_PATTERNFLOWIPV4TOSUNUSEDCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWIPV4TOSUNUSEDCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWIPV4TOSUNUSEDCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWIPV4TOSUNUSEDCOUNTER.fields_by_name['step'])
_PATTERNFLOWIPV4TOSUNUSEDCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWIPV4TOSUNUSEDCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWIPV4TOSUNUSEDCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWIPV4TOSUNUSEDCOUNTER.fields_by_name['count'])
_PATTERNFLOWIPV4TOSUNUSEDCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWIPV4TOSUNUSEDCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWIPV4TOSUNUSED_CHOICE.containing_type = _PATTERNFLOWIPV4TOSUNUSED
_PATTERNFLOWIPV4TOSUNUSED_CHOICE_ENUM.containing_type = _PATTERNFLOWIPV4TOSUNUSED_CHOICE
_PATTERNFLOWIPV4TOSUNUSED.fields_by_name['choice'].enum_type = _PATTERNFLOWIPV4TOSUNUSED_CHOICE_ENUM
_PATTERNFLOWIPV4TOSUNUSED.fields_by_name['increment'].message_type = _PATTERNFLOWIPV4TOSUNUSEDCOUNTER
_PATTERNFLOWIPV4TOSUNUSED.fields_by_name['decrement'].message_type = _PATTERNFLOWIPV4TOSUNUSEDCOUNTER
_PATTERNFLOWIPV4TOSUNUSED.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWIPV4TOSUNUSED.fields_by_name['choice'])
_PATTERNFLOWIPV4TOSUNUSED.fields_by_name['choice'].containing_oneof = _PATTERNFLOWIPV4TOSUNUSED.oneofs_by_name['_choice']
_PATTERNFLOWIPV4TOSUNUSED.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWIPV4TOSUNUSED.fields_by_name['value'])
_PATTERNFLOWIPV4TOSUNUSED.fields_by_name['value'].containing_oneof = _PATTERNFLOWIPV4TOSUNUSED.oneofs_by_name['_value']
_PATTERNFLOWIPV4TOSUNUSED.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWIPV4TOSUNUSED.fields_by_name['metric_group'])
_PATTERNFLOWIPV4TOSUNUSED.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWIPV4TOSUNUSED.oneofs_by_name['_metric_group']
_PATTERNFLOWIPV4TOSUNUSED.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWIPV4TOSUNUSED.fields_by_name['increment'])
_PATTERNFLOWIPV4TOSUNUSED.fields_by_name['increment'].containing_oneof = _PATTERNFLOWIPV4TOSUNUSED.oneofs_by_name['_increment']
_PATTERNFLOWIPV4TOSUNUSED.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWIPV4TOSUNUSED.fields_by_name['decrement'])
_PATTERNFLOWIPV4TOSUNUSED.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWIPV4TOSUNUSED.oneofs_by_name['_decrement']
_PATTERNFLOWIPV6VERSIONCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWIPV6VERSIONCOUNTER.fields_by_name['start'])
_PATTERNFLOWIPV6VERSIONCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWIPV6VERSIONCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWIPV6VERSIONCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWIPV6VERSIONCOUNTER.fields_by_name['step'])
_PATTERNFLOWIPV6VERSIONCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWIPV6VERSIONCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWIPV6VERSIONCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWIPV6VERSIONCOUNTER.fields_by_name['count'])
_PATTERNFLOWIPV6VERSIONCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWIPV6VERSIONCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWIPV6VERSION_CHOICE.containing_type = _PATTERNFLOWIPV6VERSION
_PATTERNFLOWIPV6VERSION_CHOICE_ENUM.containing_type = _PATTERNFLOWIPV6VERSION_CHOICE
_PATTERNFLOWIPV6VERSION.fields_by_name['choice'].enum_type = _PATTERNFLOWIPV6VERSION_CHOICE_ENUM
_PATTERNFLOWIPV6VERSION.fields_by_name['increment'].message_type = _PATTERNFLOWIPV6VERSIONCOUNTER
_PATTERNFLOWIPV6VERSION.fields_by_name['decrement'].message_type = _PATTERNFLOWIPV6VERSIONCOUNTER
_PATTERNFLOWIPV6VERSION.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWIPV6VERSION.fields_by_name['choice'])
_PATTERNFLOWIPV6VERSION.fields_by_name['choice'].containing_oneof = _PATTERNFLOWIPV6VERSION.oneofs_by_name['_choice']
_PATTERNFLOWIPV6VERSION.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWIPV6VERSION.fields_by_name['value'])
_PATTERNFLOWIPV6VERSION.fields_by_name['value'].containing_oneof = _PATTERNFLOWIPV6VERSION.oneofs_by_name['_value']
_PATTERNFLOWIPV6VERSION.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWIPV6VERSION.fields_by_name['metric_group'])
_PATTERNFLOWIPV6VERSION.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWIPV6VERSION.oneofs_by_name['_metric_group']
_PATTERNFLOWIPV6VERSION.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWIPV6VERSION.fields_by_name['increment'])
_PATTERNFLOWIPV6VERSION.fields_by_name['increment'].containing_oneof = _PATTERNFLOWIPV6VERSION.oneofs_by_name['_increment']
_PATTERNFLOWIPV6VERSION.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWIPV6VERSION.fields_by_name['decrement'])
_PATTERNFLOWIPV6VERSION.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWIPV6VERSION.oneofs_by_name['_decrement']
_PATTERNFLOWIPV6TRAFFICCLASSCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWIPV6TRAFFICCLASSCOUNTER.fields_by_name['start'])
_PATTERNFLOWIPV6TRAFFICCLASSCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWIPV6TRAFFICCLASSCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWIPV6TRAFFICCLASSCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWIPV6TRAFFICCLASSCOUNTER.fields_by_name['step'])
_PATTERNFLOWIPV6TRAFFICCLASSCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWIPV6TRAFFICCLASSCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWIPV6TRAFFICCLASSCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWIPV6TRAFFICCLASSCOUNTER.fields_by_name['count'])
_PATTERNFLOWIPV6TRAFFICCLASSCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWIPV6TRAFFICCLASSCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWIPV6TRAFFICCLASS_CHOICE.containing_type = _PATTERNFLOWIPV6TRAFFICCLASS
_PATTERNFLOWIPV6TRAFFICCLASS_CHOICE_ENUM.containing_type = _PATTERNFLOWIPV6TRAFFICCLASS_CHOICE
_PATTERNFLOWIPV6TRAFFICCLASS.fields_by_name['choice'].enum_type = _PATTERNFLOWIPV6TRAFFICCLASS_CHOICE_ENUM
_PATTERNFLOWIPV6TRAFFICCLASS.fields_by_name['increment'].message_type = _PATTERNFLOWIPV6TRAFFICCLASSCOUNTER
_PATTERNFLOWIPV6TRAFFICCLASS.fields_by_name['decrement'].message_type = _PATTERNFLOWIPV6TRAFFICCLASSCOUNTER
_PATTERNFLOWIPV6TRAFFICCLASS.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWIPV6TRAFFICCLASS.fields_by_name['choice'])
_PATTERNFLOWIPV6TRAFFICCLASS.fields_by_name['choice'].containing_oneof = _PATTERNFLOWIPV6TRAFFICCLASS.oneofs_by_name['_choice']
_PATTERNFLOWIPV6TRAFFICCLASS.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWIPV6TRAFFICCLASS.fields_by_name['value'])
_PATTERNFLOWIPV6TRAFFICCLASS.fields_by_name['value'].containing_oneof = _PATTERNFLOWIPV6TRAFFICCLASS.oneofs_by_name['_value']
_PATTERNFLOWIPV6TRAFFICCLASS.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWIPV6TRAFFICCLASS.fields_by_name['metric_group'])
_PATTERNFLOWIPV6TRAFFICCLASS.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWIPV6TRAFFICCLASS.oneofs_by_name['_metric_group']
_PATTERNFLOWIPV6TRAFFICCLASS.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWIPV6TRAFFICCLASS.fields_by_name['increment'])
_PATTERNFLOWIPV6TRAFFICCLASS.fields_by_name['increment'].containing_oneof = _PATTERNFLOWIPV6TRAFFICCLASS.oneofs_by_name['_increment']
_PATTERNFLOWIPV6TRAFFICCLASS.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWIPV6TRAFFICCLASS.fields_by_name['decrement'])
_PATTERNFLOWIPV6TRAFFICCLASS.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWIPV6TRAFFICCLASS.oneofs_by_name['_decrement']
_PATTERNFLOWIPV6FLOWLABELCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWIPV6FLOWLABELCOUNTER.fields_by_name['start'])
_PATTERNFLOWIPV6FLOWLABELCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWIPV6FLOWLABELCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWIPV6FLOWLABELCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWIPV6FLOWLABELCOUNTER.fields_by_name['step'])
_PATTERNFLOWIPV6FLOWLABELCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWIPV6FLOWLABELCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWIPV6FLOWLABELCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWIPV6FLOWLABELCOUNTER.fields_by_name['count'])
_PATTERNFLOWIPV6FLOWLABELCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWIPV6FLOWLABELCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWIPV6FLOWLABEL_CHOICE.containing_type = _PATTERNFLOWIPV6FLOWLABEL
_PATTERNFLOWIPV6FLOWLABEL_CHOICE_ENUM.containing_type = _PATTERNFLOWIPV6FLOWLABEL_CHOICE
_PATTERNFLOWIPV6FLOWLABEL.fields_by_name['choice'].enum_type = _PATTERNFLOWIPV6FLOWLABEL_CHOICE_ENUM
_PATTERNFLOWIPV6FLOWLABEL.fields_by_name['increment'].message_type = _PATTERNFLOWIPV6FLOWLABELCOUNTER
_PATTERNFLOWIPV6FLOWLABEL.fields_by_name['decrement'].message_type = _PATTERNFLOWIPV6FLOWLABELCOUNTER
_PATTERNFLOWIPV6FLOWLABEL.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWIPV6FLOWLABEL.fields_by_name['choice'])
_PATTERNFLOWIPV6FLOWLABEL.fields_by_name['choice'].containing_oneof = _PATTERNFLOWIPV6FLOWLABEL.oneofs_by_name['_choice']
_PATTERNFLOWIPV6FLOWLABEL.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWIPV6FLOWLABEL.fields_by_name['value'])
_PATTERNFLOWIPV6FLOWLABEL.fields_by_name['value'].containing_oneof = _PATTERNFLOWIPV6FLOWLABEL.oneofs_by_name['_value']
_PATTERNFLOWIPV6FLOWLABEL.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWIPV6FLOWLABEL.fields_by_name['metric_group'])
_PATTERNFLOWIPV6FLOWLABEL.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWIPV6FLOWLABEL.oneofs_by_name['_metric_group']
_PATTERNFLOWIPV6FLOWLABEL.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWIPV6FLOWLABEL.fields_by_name['increment'])
_PATTERNFLOWIPV6FLOWLABEL.fields_by_name['increment'].containing_oneof = _PATTERNFLOWIPV6FLOWLABEL.oneofs_by_name['_increment']
_PATTERNFLOWIPV6FLOWLABEL.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWIPV6FLOWLABEL.fields_by_name['decrement'])
_PATTERNFLOWIPV6FLOWLABEL.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWIPV6FLOWLABEL.oneofs_by_name['_decrement']
_PATTERNFLOWIPV6PAYLOADLENGTHCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWIPV6PAYLOADLENGTHCOUNTER.fields_by_name['start'])
_PATTERNFLOWIPV6PAYLOADLENGTHCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWIPV6PAYLOADLENGTHCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWIPV6PAYLOADLENGTHCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWIPV6PAYLOADLENGTHCOUNTER.fields_by_name['step'])
_PATTERNFLOWIPV6PAYLOADLENGTHCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWIPV6PAYLOADLENGTHCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWIPV6PAYLOADLENGTHCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWIPV6PAYLOADLENGTHCOUNTER.fields_by_name['count'])
_PATTERNFLOWIPV6PAYLOADLENGTHCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWIPV6PAYLOADLENGTHCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWIPV6PAYLOADLENGTH_CHOICE.containing_type = _PATTERNFLOWIPV6PAYLOADLENGTH
_PATTERNFLOWIPV6PAYLOADLENGTH_CHOICE_ENUM.containing_type = _PATTERNFLOWIPV6PAYLOADLENGTH_CHOICE
_PATTERNFLOWIPV6PAYLOADLENGTH_AUTO.containing_type = _PATTERNFLOWIPV6PAYLOADLENGTH
_PATTERNFLOWIPV6PAYLOADLENGTH_AUTO_ENUM.containing_type = _PATTERNFLOWIPV6PAYLOADLENGTH_AUTO
_PATTERNFLOWIPV6PAYLOADLENGTH.fields_by_name['choice'].enum_type = _PATTERNFLOWIPV6PAYLOADLENGTH_CHOICE_ENUM
_PATTERNFLOWIPV6PAYLOADLENGTH.fields_by_name['auto'].enum_type = _PATTERNFLOWIPV6PAYLOADLENGTH_AUTO_ENUM
_PATTERNFLOWIPV6PAYLOADLENGTH.fields_by_name['increment'].message_type = _PATTERNFLOWIPV6PAYLOADLENGTHCOUNTER
_PATTERNFLOWIPV6PAYLOADLENGTH.fields_by_name['decrement'].message_type = _PATTERNFLOWIPV6PAYLOADLENGTHCOUNTER
_PATTERNFLOWIPV6PAYLOADLENGTH.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWIPV6PAYLOADLENGTH.fields_by_name['choice'])
_PATTERNFLOWIPV6PAYLOADLENGTH.fields_by_name['choice'].containing_oneof = _PATTERNFLOWIPV6PAYLOADLENGTH.oneofs_by_name['_choice']
_PATTERNFLOWIPV6PAYLOADLENGTH.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWIPV6PAYLOADLENGTH.fields_by_name['value'])
_PATTERNFLOWIPV6PAYLOADLENGTH.fields_by_name['value'].containing_oneof = _PATTERNFLOWIPV6PAYLOADLENGTH.oneofs_by_name['_value']
_PATTERNFLOWIPV6PAYLOADLENGTH.oneofs_by_name['_auto'].fields.append(
  _PATTERNFLOWIPV6PAYLOADLENGTH.fields_by_name['auto'])
_PATTERNFLOWIPV6PAYLOADLENGTH.fields_by_name['auto'].containing_oneof = _PATTERNFLOWIPV6PAYLOADLENGTH.oneofs_by_name['_auto']
_PATTERNFLOWIPV6PAYLOADLENGTH.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWIPV6PAYLOADLENGTH.fields_by_name['metric_group'])
_PATTERNFLOWIPV6PAYLOADLENGTH.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWIPV6PAYLOADLENGTH.oneofs_by_name['_metric_group']
_PATTERNFLOWIPV6PAYLOADLENGTH.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWIPV6PAYLOADLENGTH.fields_by_name['increment'])
_PATTERNFLOWIPV6PAYLOADLENGTH.fields_by_name['increment'].containing_oneof = _PATTERNFLOWIPV6PAYLOADLENGTH.oneofs_by_name['_increment']
_PATTERNFLOWIPV6PAYLOADLENGTH.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWIPV6PAYLOADLENGTH.fields_by_name['decrement'])
_PATTERNFLOWIPV6PAYLOADLENGTH.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWIPV6PAYLOADLENGTH.oneofs_by_name['_decrement']
_PATTERNFLOWIPV6NEXTHEADERCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWIPV6NEXTHEADERCOUNTER.fields_by_name['start'])
_PATTERNFLOWIPV6NEXTHEADERCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWIPV6NEXTHEADERCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWIPV6NEXTHEADERCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWIPV6NEXTHEADERCOUNTER.fields_by_name['step'])
_PATTERNFLOWIPV6NEXTHEADERCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWIPV6NEXTHEADERCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWIPV6NEXTHEADERCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWIPV6NEXTHEADERCOUNTER.fields_by_name['count'])
_PATTERNFLOWIPV6NEXTHEADERCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWIPV6NEXTHEADERCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWIPV6NEXTHEADER_CHOICE.containing_type = _PATTERNFLOWIPV6NEXTHEADER
_PATTERNFLOWIPV6NEXTHEADER_CHOICE_ENUM.containing_type = _PATTERNFLOWIPV6NEXTHEADER_CHOICE
_PATTERNFLOWIPV6NEXTHEADER.fields_by_name['choice'].enum_type = _PATTERNFLOWIPV6NEXTHEADER_CHOICE_ENUM
_PATTERNFLOWIPV6NEXTHEADER.fields_by_name['increment'].message_type = _PATTERNFLOWIPV6NEXTHEADERCOUNTER
_PATTERNFLOWIPV6NEXTHEADER.fields_by_name['decrement'].message_type = _PATTERNFLOWIPV6NEXTHEADERCOUNTER
_PATTERNFLOWIPV6NEXTHEADER.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWIPV6NEXTHEADER.fields_by_name['choice'])
_PATTERNFLOWIPV6NEXTHEADER.fields_by_name['choice'].containing_oneof = _PATTERNFLOWIPV6NEXTHEADER.oneofs_by_name['_choice']
_PATTERNFLOWIPV6NEXTHEADER.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWIPV6NEXTHEADER.fields_by_name['value'])
_PATTERNFLOWIPV6NEXTHEADER.fields_by_name['value'].containing_oneof = _PATTERNFLOWIPV6NEXTHEADER.oneofs_by_name['_value']
_PATTERNFLOWIPV6NEXTHEADER.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWIPV6NEXTHEADER.fields_by_name['metric_group'])
_PATTERNFLOWIPV6NEXTHEADER.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWIPV6NEXTHEADER.oneofs_by_name['_metric_group']
_PATTERNFLOWIPV6NEXTHEADER.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWIPV6NEXTHEADER.fields_by_name['increment'])
_PATTERNFLOWIPV6NEXTHEADER.fields_by_name['increment'].containing_oneof = _PATTERNFLOWIPV6NEXTHEADER.oneofs_by_name['_increment']
_PATTERNFLOWIPV6NEXTHEADER.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWIPV6NEXTHEADER.fields_by_name['decrement'])
_PATTERNFLOWIPV6NEXTHEADER.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWIPV6NEXTHEADER.oneofs_by_name['_decrement']
_PATTERNFLOWIPV6HOPLIMITCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWIPV6HOPLIMITCOUNTER.fields_by_name['start'])
_PATTERNFLOWIPV6HOPLIMITCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWIPV6HOPLIMITCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWIPV6HOPLIMITCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWIPV6HOPLIMITCOUNTER.fields_by_name['step'])
_PATTERNFLOWIPV6HOPLIMITCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWIPV6HOPLIMITCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWIPV6HOPLIMITCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWIPV6HOPLIMITCOUNTER.fields_by_name['count'])
_PATTERNFLOWIPV6HOPLIMITCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWIPV6HOPLIMITCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWIPV6HOPLIMIT_CHOICE.containing_type = _PATTERNFLOWIPV6HOPLIMIT
_PATTERNFLOWIPV6HOPLIMIT_CHOICE_ENUM.containing_type = _PATTERNFLOWIPV6HOPLIMIT_CHOICE
_PATTERNFLOWIPV6HOPLIMIT.fields_by_name['choice'].enum_type = _PATTERNFLOWIPV6HOPLIMIT_CHOICE_ENUM
_PATTERNFLOWIPV6HOPLIMIT.fields_by_name['increment'].message_type = _PATTERNFLOWIPV6HOPLIMITCOUNTER
_PATTERNFLOWIPV6HOPLIMIT.fields_by_name['decrement'].message_type = _PATTERNFLOWIPV6HOPLIMITCOUNTER
_PATTERNFLOWIPV6HOPLIMIT.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWIPV6HOPLIMIT.fields_by_name['choice'])
_PATTERNFLOWIPV6HOPLIMIT.fields_by_name['choice'].containing_oneof = _PATTERNFLOWIPV6HOPLIMIT.oneofs_by_name['_choice']
_PATTERNFLOWIPV6HOPLIMIT.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWIPV6HOPLIMIT.fields_by_name['value'])
_PATTERNFLOWIPV6HOPLIMIT.fields_by_name['value'].containing_oneof = _PATTERNFLOWIPV6HOPLIMIT.oneofs_by_name['_value']
_PATTERNFLOWIPV6HOPLIMIT.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWIPV6HOPLIMIT.fields_by_name['metric_group'])
_PATTERNFLOWIPV6HOPLIMIT.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWIPV6HOPLIMIT.oneofs_by_name['_metric_group']
_PATTERNFLOWIPV6HOPLIMIT.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWIPV6HOPLIMIT.fields_by_name['increment'])
_PATTERNFLOWIPV6HOPLIMIT.fields_by_name['increment'].containing_oneof = _PATTERNFLOWIPV6HOPLIMIT.oneofs_by_name['_increment']
_PATTERNFLOWIPV6HOPLIMIT.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWIPV6HOPLIMIT.fields_by_name['decrement'])
_PATTERNFLOWIPV6HOPLIMIT.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWIPV6HOPLIMIT.oneofs_by_name['_decrement']
_PATTERNFLOWIPV6SRCCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWIPV6SRCCOUNTER.fields_by_name['start'])
_PATTERNFLOWIPV6SRCCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWIPV6SRCCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWIPV6SRCCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWIPV6SRCCOUNTER.fields_by_name['step'])
_PATTERNFLOWIPV6SRCCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWIPV6SRCCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWIPV6SRCCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWIPV6SRCCOUNTER.fields_by_name['count'])
_PATTERNFLOWIPV6SRCCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWIPV6SRCCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWIPV6SRC_CHOICE.containing_type = _PATTERNFLOWIPV6SRC
_PATTERNFLOWIPV6SRC_CHOICE_ENUM.containing_type = _PATTERNFLOWIPV6SRC_CHOICE
_PATTERNFLOWIPV6SRC.fields_by_name['choice'].enum_type = _PATTERNFLOWIPV6SRC_CHOICE_ENUM
_PATTERNFLOWIPV6SRC.fields_by_name['increment'].message_type = _PATTERNFLOWIPV6SRCCOUNTER
_PATTERNFLOWIPV6SRC.fields_by_name['decrement'].message_type = _PATTERNFLOWIPV6SRCCOUNTER
_PATTERNFLOWIPV6SRC.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWIPV6SRC.fields_by_name['choice'])
_PATTERNFLOWIPV6SRC.fields_by_name['choice'].containing_oneof = _PATTERNFLOWIPV6SRC.oneofs_by_name['_choice']
_PATTERNFLOWIPV6SRC.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWIPV6SRC.fields_by_name['value'])
_PATTERNFLOWIPV6SRC.fields_by_name['value'].containing_oneof = _PATTERNFLOWIPV6SRC.oneofs_by_name['_value']
_PATTERNFLOWIPV6SRC.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWIPV6SRC.fields_by_name['metric_group'])
_PATTERNFLOWIPV6SRC.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWIPV6SRC.oneofs_by_name['_metric_group']
_PATTERNFLOWIPV6SRC.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWIPV6SRC.fields_by_name['increment'])
_PATTERNFLOWIPV6SRC.fields_by_name['increment'].containing_oneof = _PATTERNFLOWIPV6SRC.oneofs_by_name['_increment']
_PATTERNFLOWIPV6SRC.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWIPV6SRC.fields_by_name['decrement'])
_PATTERNFLOWIPV6SRC.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWIPV6SRC.oneofs_by_name['_decrement']
_PATTERNFLOWIPV6DSTCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWIPV6DSTCOUNTER.fields_by_name['start'])
_PATTERNFLOWIPV6DSTCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWIPV6DSTCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWIPV6DSTCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWIPV6DSTCOUNTER.fields_by_name['step'])
_PATTERNFLOWIPV6DSTCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWIPV6DSTCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWIPV6DSTCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWIPV6DSTCOUNTER.fields_by_name['count'])
_PATTERNFLOWIPV6DSTCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWIPV6DSTCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWIPV6DST_CHOICE.containing_type = _PATTERNFLOWIPV6DST
_PATTERNFLOWIPV6DST_CHOICE_ENUM.containing_type = _PATTERNFLOWIPV6DST_CHOICE
_PATTERNFLOWIPV6DST.fields_by_name['choice'].enum_type = _PATTERNFLOWIPV6DST_CHOICE_ENUM
_PATTERNFLOWIPV6DST.fields_by_name['increment'].message_type = _PATTERNFLOWIPV6DSTCOUNTER
_PATTERNFLOWIPV6DST.fields_by_name['decrement'].message_type = _PATTERNFLOWIPV6DSTCOUNTER
_PATTERNFLOWIPV6DST.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWIPV6DST.fields_by_name['choice'])
_PATTERNFLOWIPV6DST.fields_by_name['choice'].containing_oneof = _PATTERNFLOWIPV6DST.oneofs_by_name['_choice']
_PATTERNFLOWIPV6DST.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWIPV6DST.fields_by_name['value'])
_PATTERNFLOWIPV6DST.fields_by_name['value'].containing_oneof = _PATTERNFLOWIPV6DST.oneofs_by_name['_value']
_PATTERNFLOWIPV6DST.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWIPV6DST.fields_by_name['metric_group'])
_PATTERNFLOWIPV6DST.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWIPV6DST.oneofs_by_name['_metric_group']
_PATTERNFLOWIPV6DST.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWIPV6DST.fields_by_name['increment'])
_PATTERNFLOWIPV6DST.fields_by_name['increment'].containing_oneof = _PATTERNFLOWIPV6DST.oneofs_by_name['_increment']
_PATTERNFLOWIPV6DST.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWIPV6DST.fields_by_name['decrement'])
_PATTERNFLOWIPV6DST.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWIPV6DST.oneofs_by_name['_decrement']
_PATTERNFLOWPFCPAUSEDSTCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWPFCPAUSEDSTCOUNTER.fields_by_name['start'])
_PATTERNFLOWPFCPAUSEDSTCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWPFCPAUSEDSTCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWPFCPAUSEDSTCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWPFCPAUSEDSTCOUNTER.fields_by_name['step'])
_PATTERNFLOWPFCPAUSEDSTCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWPFCPAUSEDSTCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWPFCPAUSEDSTCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWPFCPAUSEDSTCOUNTER.fields_by_name['count'])
_PATTERNFLOWPFCPAUSEDSTCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWPFCPAUSEDSTCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWPFCPAUSEDST_CHOICE.containing_type = _PATTERNFLOWPFCPAUSEDST
_PATTERNFLOWPFCPAUSEDST_CHOICE_ENUM.containing_type = _PATTERNFLOWPFCPAUSEDST_CHOICE
_PATTERNFLOWPFCPAUSEDST.fields_by_name['choice'].enum_type = _PATTERNFLOWPFCPAUSEDST_CHOICE_ENUM
_PATTERNFLOWPFCPAUSEDST.fields_by_name['increment'].message_type = _PATTERNFLOWPFCPAUSEDSTCOUNTER
_PATTERNFLOWPFCPAUSEDST.fields_by_name['decrement'].message_type = _PATTERNFLOWPFCPAUSEDSTCOUNTER
_PATTERNFLOWPFCPAUSEDST.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWPFCPAUSEDST.fields_by_name['choice'])
_PATTERNFLOWPFCPAUSEDST.fields_by_name['choice'].containing_oneof = _PATTERNFLOWPFCPAUSEDST.oneofs_by_name['_choice']
_PATTERNFLOWPFCPAUSEDST.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWPFCPAUSEDST.fields_by_name['value'])
_PATTERNFLOWPFCPAUSEDST.fields_by_name['value'].containing_oneof = _PATTERNFLOWPFCPAUSEDST.oneofs_by_name['_value']
_PATTERNFLOWPFCPAUSEDST.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWPFCPAUSEDST.fields_by_name['metric_group'])
_PATTERNFLOWPFCPAUSEDST.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWPFCPAUSEDST.oneofs_by_name['_metric_group']
_PATTERNFLOWPFCPAUSEDST.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWPFCPAUSEDST.fields_by_name['increment'])
_PATTERNFLOWPFCPAUSEDST.fields_by_name['increment'].containing_oneof = _PATTERNFLOWPFCPAUSEDST.oneofs_by_name['_increment']
_PATTERNFLOWPFCPAUSEDST.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWPFCPAUSEDST.fields_by_name['decrement'])
_PATTERNFLOWPFCPAUSEDST.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWPFCPAUSEDST.oneofs_by_name['_decrement']
_PATTERNFLOWPFCPAUSESRCCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWPFCPAUSESRCCOUNTER.fields_by_name['start'])
_PATTERNFLOWPFCPAUSESRCCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWPFCPAUSESRCCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWPFCPAUSESRCCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWPFCPAUSESRCCOUNTER.fields_by_name['step'])
_PATTERNFLOWPFCPAUSESRCCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWPFCPAUSESRCCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWPFCPAUSESRCCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWPFCPAUSESRCCOUNTER.fields_by_name['count'])
_PATTERNFLOWPFCPAUSESRCCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWPFCPAUSESRCCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWPFCPAUSESRC_CHOICE.containing_type = _PATTERNFLOWPFCPAUSESRC
_PATTERNFLOWPFCPAUSESRC_CHOICE_ENUM.containing_type = _PATTERNFLOWPFCPAUSESRC_CHOICE
_PATTERNFLOWPFCPAUSESRC.fields_by_name['choice'].enum_type = _PATTERNFLOWPFCPAUSESRC_CHOICE_ENUM
_PATTERNFLOWPFCPAUSESRC.fields_by_name['increment'].message_type = _PATTERNFLOWPFCPAUSESRCCOUNTER
_PATTERNFLOWPFCPAUSESRC.fields_by_name['decrement'].message_type = _PATTERNFLOWPFCPAUSESRCCOUNTER
_PATTERNFLOWPFCPAUSESRC.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWPFCPAUSESRC.fields_by_name['choice'])
_PATTERNFLOWPFCPAUSESRC.fields_by_name['choice'].containing_oneof = _PATTERNFLOWPFCPAUSESRC.oneofs_by_name['_choice']
_PATTERNFLOWPFCPAUSESRC.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWPFCPAUSESRC.fields_by_name['value'])
_PATTERNFLOWPFCPAUSESRC.fields_by_name['value'].containing_oneof = _PATTERNFLOWPFCPAUSESRC.oneofs_by_name['_value']
_PATTERNFLOWPFCPAUSESRC.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWPFCPAUSESRC.fields_by_name['metric_group'])
_PATTERNFLOWPFCPAUSESRC.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWPFCPAUSESRC.oneofs_by_name['_metric_group']
_PATTERNFLOWPFCPAUSESRC.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWPFCPAUSESRC.fields_by_name['increment'])
_PATTERNFLOWPFCPAUSESRC.fields_by_name['increment'].containing_oneof = _PATTERNFLOWPFCPAUSESRC.oneofs_by_name['_increment']
_PATTERNFLOWPFCPAUSESRC.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWPFCPAUSESRC.fields_by_name['decrement'])
_PATTERNFLOWPFCPAUSESRC.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWPFCPAUSESRC.oneofs_by_name['_decrement']
_PATTERNFLOWPFCPAUSEETHERTYPECOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWPFCPAUSEETHERTYPECOUNTER.fields_by_name['start'])
_PATTERNFLOWPFCPAUSEETHERTYPECOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWPFCPAUSEETHERTYPECOUNTER.oneofs_by_name['_start']
_PATTERNFLOWPFCPAUSEETHERTYPECOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWPFCPAUSEETHERTYPECOUNTER.fields_by_name['step'])
_PATTERNFLOWPFCPAUSEETHERTYPECOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWPFCPAUSEETHERTYPECOUNTER.oneofs_by_name['_step']
_PATTERNFLOWPFCPAUSEETHERTYPECOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWPFCPAUSEETHERTYPECOUNTER.fields_by_name['count'])
_PATTERNFLOWPFCPAUSEETHERTYPECOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWPFCPAUSEETHERTYPECOUNTER.oneofs_by_name['_count']
_PATTERNFLOWPFCPAUSEETHERTYPE_CHOICE.containing_type = _PATTERNFLOWPFCPAUSEETHERTYPE
_PATTERNFLOWPFCPAUSEETHERTYPE_CHOICE_ENUM.containing_type = _PATTERNFLOWPFCPAUSEETHERTYPE_CHOICE
_PATTERNFLOWPFCPAUSEETHERTYPE.fields_by_name['choice'].enum_type = _PATTERNFLOWPFCPAUSEETHERTYPE_CHOICE_ENUM
_PATTERNFLOWPFCPAUSEETHERTYPE.fields_by_name['increment'].message_type = _PATTERNFLOWPFCPAUSEETHERTYPECOUNTER
_PATTERNFLOWPFCPAUSEETHERTYPE.fields_by_name['decrement'].message_type = _PATTERNFLOWPFCPAUSEETHERTYPECOUNTER
_PATTERNFLOWPFCPAUSEETHERTYPE.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWPFCPAUSEETHERTYPE.fields_by_name['choice'])
_PATTERNFLOWPFCPAUSEETHERTYPE.fields_by_name['choice'].containing_oneof = _PATTERNFLOWPFCPAUSEETHERTYPE.oneofs_by_name['_choice']
_PATTERNFLOWPFCPAUSEETHERTYPE.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWPFCPAUSEETHERTYPE.fields_by_name['value'])
_PATTERNFLOWPFCPAUSEETHERTYPE.fields_by_name['value'].containing_oneof = _PATTERNFLOWPFCPAUSEETHERTYPE.oneofs_by_name['_value']
_PATTERNFLOWPFCPAUSEETHERTYPE.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWPFCPAUSEETHERTYPE.fields_by_name['metric_group'])
_PATTERNFLOWPFCPAUSEETHERTYPE.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWPFCPAUSEETHERTYPE.oneofs_by_name['_metric_group']
_PATTERNFLOWPFCPAUSEETHERTYPE.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWPFCPAUSEETHERTYPE.fields_by_name['increment'])
_PATTERNFLOWPFCPAUSEETHERTYPE.fields_by_name['increment'].containing_oneof = _PATTERNFLOWPFCPAUSEETHERTYPE.oneofs_by_name['_increment']
_PATTERNFLOWPFCPAUSEETHERTYPE.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWPFCPAUSEETHERTYPE.fields_by_name['decrement'])
_PATTERNFLOWPFCPAUSEETHERTYPE.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWPFCPAUSEETHERTYPE.oneofs_by_name['_decrement']
_PATTERNFLOWPFCPAUSECONTROLOPCODECOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWPFCPAUSECONTROLOPCODECOUNTER.fields_by_name['start'])
_PATTERNFLOWPFCPAUSECONTROLOPCODECOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWPFCPAUSECONTROLOPCODECOUNTER.oneofs_by_name['_start']
_PATTERNFLOWPFCPAUSECONTROLOPCODECOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWPFCPAUSECONTROLOPCODECOUNTER.fields_by_name['step'])
_PATTERNFLOWPFCPAUSECONTROLOPCODECOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWPFCPAUSECONTROLOPCODECOUNTER.oneofs_by_name['_step']
_PATTERNFLOWPFCPAUSECONTROLOPCODECOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWPFCPAUSECONTROLOPCODECOUNTER.fields_by_name['count'])
_PATTERNFLOWPFCPAUSECONTROLOPCODECOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWPFCPAUSECONTROLOPCODECOUNTER.oneofs_by_name['_count']
_PATTERNFLOWPFCPAUSECONTROLOPCODE_CHOICE.containing_type = _PATTERNFLOWPFCPAUSECONTROLOPCODE
_PATTERNFLOWPFCPAUSECONTROLOPCODE_CHOICE_ENUM.containing_type = _PATTERNFLOWPFCPAUSECONTROLOPCODE_CHOICE
_PATTERNFLOWPFCPAUSECONTROLOPCODE.fields_by_name['choice'].enum_type = _PATTERNFLOWPFCPAUSECONTROLOPCODE_CHOICE_ENUM
_PATTERNFLOWPFCPAUSECONTROLOPCODE.fields_by_name['increment'].message_type = _PATTERNFLOWPFCPAUSECONTROLOPCODECOUNTER
_PATTERNFLOWPFCPAUSECONTROLOPCODE.fields_by_name['decrement'].message_type = _PATTERNFLOWPFCPAUSECONTROLOPCODECOUNTER
_PATTERNFLOWPFCPAUSECONTROLOPCODE.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWPFCPAUSECONTROLOPCODE.fields_by_name['choice'])
_PATTERNFLOWPFCPAUSECONTROLOPCODE.fields_by_name['choice'].containing_oneof = _PATTERNFLOWPFCPAUSECONTROLOPCODE.oneofs_by_name['_choice']
_PATTERNFLOWPFCPAUSECONTROLOPCODE.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWPFCPAUSECONTROLOPCODE.fields_by_name['value'])
_PATTERNFLOWPFCPAUSECONTROLOPCODE.fields_by_name['value'].containing_oneof = _PATTERNFLOWPFCPAUSECONTROLOPCODE.oneofs_by_name['_value']
_PATTERNFLOWPFCPAUSECONTROLOPCODE.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWPFCPAUSECONTROLOPCODE.fields_by_name['metric_group'])
_PATTERNFLOWPFCPAUSECONTROLOPCODE.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWPFCPAUSECONTROLOPCODE.oneofs_by_name['_metric_group']
_PATTERNFLOWPFCPAUSECONTROLOPCODE.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWPFCPAUSECONTROLOPCODE.fields_by_name['increment'])
_PATTERNFLOWPFCPAUSECONTROLOPCODE.fields_by_name['increment'].containing_oneof = _PATTERNFLOWPFCPAUSECONTROLOPCODE.oneofs_by_name['_increment']
_PATTERNFLOWPFCPAUSECONTROLOPCODE.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWPFCPAUSECONTROLOPCODE.fields_by_name['decrement'])
_PATTERNFLOWPFCPAUSECONTROLOPCODE.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWPFCPAUSECONTROLOPCODE.oneofs_by_name['_decrement']
_PATTERNFLOWPFCPAUSECLASSENABLEVECTORCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWPFCPAUSECLASSENABLEVECTORCOUNTER.fields_by_name['start'])
_PATTERNFLOWPFCPAUSECLASSENABLEVECTORCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWPFCPAUSECLASSENABLEVECTORCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWPFCPAUSECLASSENABLEVECTORCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWPFCPAUSECLASSENABLEVECTORCOUNTER.fields_by_name['step'])
_PATTERNFLOWPFCPAUSECLASSENABLEVECTORCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWPFCPAUSECLASSENABLEVECTORCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWPFCPAUSECLASSENABLEVECTORCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWPFCPAUSECLASSENABLEVECTORCOUNTER.fields_by_name['count'])
_PATTERNFLOWPFCPAUSECLASSENABLEVECTORCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWPFCPAUSECLASSENABLEVECTORCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR_CHOICE.containing_type = _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR
_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR_CHOICE_ENUM.containing_type = _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR_CHOICE
_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR.fields_by_name['choice'].enum_type = _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR_CHOICE_ENUM
_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR.fields_by_name['increment'].message_type = _PATTERNFLOWPFCPAUSECLASSENABLEVECTORCOUNTER
_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR.fields_by_name['decrement'].message_type = _PATTERNFLOWPFCPAUSECLASSENABLEVECTORCOUNTER
_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR.fields_by_name['choice'])
_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR.fields_by_name['choice'].containing_oneof = _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR.oneofs_by_name['_choice']
_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR.fields_by_name['value'])
_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR.fields_by_name['value'].containing_oneof = _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR.oneofs_by_name['_value']
_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR.fields_by_name['metric_group'])
_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR.oneofs_by_name['_metric_group']
_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR.fields_by_name['increment'])
_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR.fields_by_name['increment'].containing_oneof = _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR.oneofs_by_name['_increment']
_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR.fields_by_name['decrement'])
_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR.oneofs_by_name['_decrement']
_PATTERNFLOWPFCPAUSEPAUSECLASS0COUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS0COUNTER.fields_by_name['start'])
_PATTERNFLOWPFCPAUSEPAUSECLASS0COUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS0COUNTER.oneofs_by_name['_start']
_PATTERNFLOWPFCPAUSEPAUSECLASS0COUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS0COUNTER.fields_by_name['step'])
_PATTERNFLOWPFCPAUSEPAUSECLASS0COUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS0COUNTER.oneofs_by_name['_step']
_PATTERNFLOWPFCPAUSEPAUSECLASS0COUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS0COUNTER.fields_by_name['count'])
_PATTERNFLOWPFCPAUSEPAUSECLASS0COUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS0COUNTER.oneofs_by_name['_count']
_PATTERNFLOWPFCPAUSEPAUSECLASS0_CHOICE.containing_type = _PATTERNFLOWPFCPAUSEPAUSECLASS0
_PATTERNFLOWPFCPAUSEPAUSECLASS0_CHOICE_ENUM.containing_type = _PATTERNFLOWPFCPAUSEPAUSECLASS0_CHOICE
_PATTERNFLOWPFCPAUSEPAUSECLASS0.fields_by_name['choice'].enum_type = _PATTERNFLOWPFCPAUSEPAUSECLASS0_CHOICE_ENUM
_PATTERNFLOWPFCPAUSEPAUSECLASS0.fields_by_name['increment'].message_type = _PATTERNFLOWPFCPAUSEPAUSECLASS0COUNTER
_PATTERNFLOWPFCPAUSEPAUSECLASS0.fields_by_name['decrement'].message_type = _PATTERNFLOWPFCPAUSEPAUSECLASS0COUNTER
_PATTERNFLOWPFCPAUSEPAUSECLASS0.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS0.fields_by_name['choice'])
_PATTERNFLOWPFCPAUSEPAUSECLASS0.fields_by_name['choice'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS0.oneofs_by_name['_choice']
_PATTERNFLOWPFCPAUSEPAUSECLASS0.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS0.fields_by_name['value'])
_PATTERNFLOWPFCPAUSEPAUSECLASS0.fields_by_name['value'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS0.oneofs_by_name['_value']
_PATTERNFLOWPFCPAUSEPAUSECLASS0.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS0.fields_by_name['metric_group'])
_PATTERNFLOWPFCPAUSEPAUSECLASS0.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS0.oneofs_by_name['_metric_group']
_PATTERNFLOWPFCPAUSEPAUSECLASS0.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS0.fields_by_name['increment'])
_PATTERNFLOWPFCPAUSEPAUSECLASS0.fields_by_name['increment'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS0.oneofs_by_name['_increment']
_PATTERNFLOWPFCPAUSEPAUSECLASS0.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS0.fields_by_name['decrement'])
_PATTERNFLOWPFCPAUSEPAUSECLASS0.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS0.oneofs_by_name['_decrement']
_PATTERNFLOWPFCPAUSEPAUSECLASS1COUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS1COUNTER.fields_by_name['start'])
_PATTERNFLOWPFCPAUSEPAUSECLASS1COUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS1COUNTER.oneofs_by_name['_start']
_PATTERNFLOWPFCPAUSEPAUSECLASS1COUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS1COUNTER.fields_by_name['step'])
_PATTERNFLOWPFCPAUSEPAUSECLASS1COUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS1COUNTER.oneofs_by_name['_step']
_PATTERNFLOWPFCPAUSEPAUSECLASS1COUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS1COUNTER.fields_by_name['count'])
_PATTERNFLOWPFCPAUSEPAUSECLASS1COUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS1COUNTER.oneofs_by_name['_count']
_PATTERNFLOWPFCPAUSEPAUSECLASS1_CHOICE.containing_type = _PATTERNFLOWPFCPAUSEPAUSECLASS1
_PATTERNFLOWPFCPAUSEPAUSECLASS1_CHOICE_ENUM.containing_type = _PATTERNFLOWPFCPAUSEPAUSECLASS1_CHOICE
_PATTERNFLOWPFCPAUSEPAUSECLASS1.fields_by_name['choice'].enum_type = _PATTERNFLOWPFCPAUSEPAUSECLASS1_CHOICE_ENUM
_PATTERNFLOWPFCPAUSEPAUSECLASS1.fields_by_name['increment'].message_type = _PATTERNFLOWPFCPAUSEPAUSECLASS1COUNTER
_PATTERNFLOWPFCPAUSEPAUSECLASS1.fields_by_name['decrement'].message_type = _PATTERNFLOWPFCPAUSEPAUSECLASS1COUNTER
_PATTERNFLOWPFCPAUSEPAUSECLASS1.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS1.fields_by_name['choice'])
_PATTERNFLOWPFCPAUSEPAUSECLASS1.fields_by_name['choice'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS1.oneofs_by_name['_choice']
_PATTERNFLOWPFCPAUSEPAUSECLASS1.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS1.fields_by_name['value'])
_PATTERNFLOWPFCPAUSEPAUSECLASS1.fields_by_name['value'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS1.oneofs_by_name['_value']
_PATTERNFLOWPFCPAUSEPAUSECLASS1.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS1.fields_by_name['metric_group'])
_PATTERNFLOWPFCPAUSEPAUSECLASS1.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS1.oneofs_by_name['_metric_group']
_PATTERNFLOWPFCPAUSEPAUSECLASS1.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS1.fields_by_name['increment'])
_PATTERNFLOWPFCPAUSEPAUSECLASS1.fields_by_name['increment'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS1.oneofs_by_name['_increment']
_PATTERNFLOWPFCPAUSEPAUSECLASS1.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS1.fields_by_name['decrement'])
_PATTERNFLOWPFCPAUSEPAUSECLASS1.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS1.oneofs_by_name['_decrement']
_PATTERNFLOWPFCPAUSEPAUSECLASS2COUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS2COUNTER.fields_by_name['start'])
_PATTERNFLOWPFCPAUSEPAUSECLASS2COUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS2COUNTER.oneofs_by_name['_start']
_PATTERNFLOWPFCPAUSEPAUSECLASS2COUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS2COUNTER.fields_by_name['step'])
_PATTERNFLOWPFCPAUSEPAUSECLASS2COUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS2COUNTER.oneofs_by_name['_step']
_PATTERNFLOWPFCPAUSEPAUSECLASS2COUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS2COUNTER.fields_by_name['count'])
_PATTERNFLOWPFCPAUSEPAUSECLASS2COUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS2COUNTER.oneofs_by_name['_count']
_PATTERNFLOWPFCPAUSEPAUSECLASS2_CHOICE.containing_type = _PATTERNFLOWPFCPAUSEPAUSECLASS2
_PATTERNFLOWPFCPAUSEPAUSECLASS2_CHOICE_ENUM.containing_type = _PATTERNFLOWPFCPAUSEPAUSECLASS2_CHOICE
_PATTERNFLOWPFCPAUSEPAUSECLASS2.fields_by_name['choice'].enum_type = _PATTERNFLOWPFCPAUSEPAUSECLASS2_CHOICE_ENUM
_PATTERNFLOWPFCPAUSEPAUSECLASS2.fields_by_name['increment'].message_type = _PATTERNFLOWPFCPAUSEPAUSECLASS2COUNTER
_PATTERNFLOWPFCPAUSEPAUSECLASS2.fields_by_name['decrement'].message_type = _PATTERNFLOWPFCPAUSEPAUSECLASS2COUNTER
_PATTERNFLOWPFCPAUSEPAUSECLASS2.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS2.fields_by_name['choice'])
_PATTERNFLOWPFCPAUSEPAUSECLASS2.fields_by_name['choice'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS2.oneofs_by_name['_choice']
_PATTERNFLOWPFCPAUSEPAUSECLASS2.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS2.fields_by_name['value'])
_PATTERNFLOWPFCPAUSEPAUSECLASS2.fields_by_name['value'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS2.oneofs_by_name['_value']
_PATTERNFLOWPFCPAUSEPAUSECLASS2.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS2.fields_by_name['metric_group'])
_PATTERNFLOWPFCPAUSEPAUSECLASS2.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS2.oneofs_by_name['_metric_group']
_PATTERNFLOWPFCPAUSEPAUSECLASS2.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS2.fields_by_name['increment'])
_PATTERNFLOWPFCPAUSEPAUSECLASS2.fields_by_name['increment'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS2.oneofs_by_name['_increment']
_PATTERNFLOWPFCPAUSEPAUSECLASS2.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS2.fields_by_name['decrement'])
_PATTERNFLOWPFCPAUSEPAUSECLASS2.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS2.oneofs_by_name['_decrement']
_PATTERNFLOWPFCPAUSEPAUSECLASS3COUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS3COUNTER.fields_by_name['start'])
_PATTERNFLOWPFCPAUSEPAUSECLASS3COUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS3COUNTER.oneofs_by_name['_start']
_PATTERNFLOWPFCPAUSEPAUSECLASS3COUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS3COUNTER.fields_by_name['step'])
_PATTERNFLOWPFCPAUSEPAUSECLASS3COUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS3COUNTER.oneofs_by_name['_step']
_PATTERNFLOWPFCPAUSEPAUSECLASS3COUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS3COUNTER.fields_by_name['count'])
_PATTERNFLOWPFCPAUSEPAUSECLASS3COUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS3COUNTER.oneofs_by_name['_count']
_PATTERNFLOWPFCPAUSEPAUSECLASS3_CHOICE.containing_type = _PATTERNFLOWPFCPAUSEPAUSECLASS3
_PATTERNFLOWPFCPAUSEPAUSECLASS3_CHOICE_ENUM.containing_type = _PATTERNFLOWPFCPAUSEPAUSECLASS3_CHOICE
_PATTERNFLOWPFCPAUSEPAUSECLASS3.fields_by_name['choice'].enum_type = _PATTERNFLOWPFCPAUSEPAUSECLASS3_CHOICE_ENUM
_PATTERNFLOWPFCPAUSEPAUSECLASS3.fields_by_name['increment'].message_type = _PATTERNFLOWPFCPAUSEPAUSECLASS3COUNTER
_PATTERNFLOWPFCPAUSEPAUSECLASS3.fields_by_name['decrement'].message_type = _PATTERNFLOWPFCPAUSEPAUSECLASS3COUNTER
_PATTERNFLOWPFCPAUSEPAUSECLASS3.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS3.fields_by_name['choice'])
_PATTERNFLOWPFCPAUSEPAUSECLASS3.fields_by_name['choice'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS3.oneofs_by_name['_choice']
_PATTERNFLOWPFCPAUSEPAUSECLASS3.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS3.fields_by_name['value'])
_PATTERNFLOWPFCPAUSEPAUSECLASS3.fields_by_name['value'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS3.oneofs_by_name['_value']
_PATTERNFLOWPFCPAUSEPAUSECLASS3.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS3.fields_by_name['metric_group'])
_PATTERNFLOWPFCPAUSEPAUSECLASS3.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS3.oneofs_by_name['_metric_group']
_PATTERNFLOWPFCPAUSEPAUSECLASS3.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS3.fields_by_name['increment'])
_PATTERNFLOWPFCPAUSEPAUSECLASS3.fields_by_name['increment'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS3.oneofs_by_name['_increment']
_PATTERNFLOWPFCPAUSEPAUSECLASS3.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS3.fields_by_name['decrement'])
_PATTERNFLOWPFCPAUSEPAUSECLASS3.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS3.oneofs_by_name['_decrement']
_PATTERNFLOWPFCPAUSEPAUSECLASS4COUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS4COUNTER.fields_by_name['start'])
_PATTERNFLOWPFCPAUSEPAUSECLASS4COUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS4COUNTER.oneofs_by_name['_start']
_PATTERNFLOWPFCPAUSEPAUSECLASS4COUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS4COUNTER.fields_by_name['step'])
_PATTERNFLOWPFCPAUSEPAUSECLASS4COUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS4COUNTER.oneofs_by_name['_step']
_PATTERNFLOWPFCPAUSEPAUSECLASS4COUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS4COUNTER.fields_by_name['count'])
_PATTERNFLOWPFCPAUSEPAUSECLASS4COUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS4COUNTER.oneofs_by_name['_count']
_PATTERNFLOWPFCPAUSEPAUSECLASS4_CHOICE.containing_type = _PATTERNFLOWPFCPAUSEPAUSECLASS4
_PATTERNFLOWPFCPAUSEPAUSECLASS4_CHOICE_ENUM.containing_type = _PATTERNFLOWPFCPAUSEPAUSECLASS4_CHOICE
_PATTERNFLOWPFCPAUSEPAUSECLASS4.fields_by_name['choice'].enum_type = _PATTERNFLOWPFCPAUSEPAUSECLASS4_CHOICE_ENUM
_PATTERNFLOWPFCPAUSEPAUSECLASS4.fields_by_name['increment'].message_type = _PATTERNFLOWPFCPAUSEPAUSECLASS4COUNTER
_PATTERNFLOWPFCPAUSEPAUSECLASS4.fields_by_name['decrement'].message_type = _PATTERNFLOWPFCPAUSEPAUSECLASS4COUNTER
_PATTERNFLOWPFCPAUSEPAUSECLASS4.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS4.fields_by_name['choice'])
_PATTERNFLOWPFCPAUSEPAUSECLASS4.fields_by_name['choice'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS4.oneofs_by_name['_choice']
_PATTERNFLOWPFCPAUSEPAUSECLASS4.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS4.fields_by_name['value'])
_PATTERNFLOWPFCPAUSEPAUSECLASS4.fields_by_name['value'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS4.oneofs_by_name['_value']
_PATTERNFLOWPFCPAUSEPAUSECLASS4.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS4.fields_by_name['metric_group'])
_PATTERNFLOWPFCPAUSEPAUSECLASS4.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS4.oneofs_by_name['_metric_group']
_PATTERNFLOWPFCPAUSEPAUSECLASS4.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS4.fields_by_name['increment'])
_PATTERNFLOWPFCPAUSEPAUSECLASS4.fields_by_name['increment'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS4.oneofs_by_name['_increment']
_PATTERNFLOWPFCPAUSEPAUSECLASS4.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS4.fields_by_name['decrement'])
_PATTERNFLOWPFCPAUSEPAUSECLASS4.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS4.oneofs_by_name['_decrement']
_PATTERNFLOWPFCPAUSEPAUSECLASS5COUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS5COUNTER.fields_by_name['start'])
_PATTERNFLOWPFCPAUSEPAUSECLASS5COUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS5COUNTER.oneofs_by_name['_start']
_PATTERNFLOWPFCPAUSEPAUSECLASS5COUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS5COUNTER.fields_by_name['step'])
_PATTERNFLOWPFCPAUSEPAUSECLASS5COUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS5COUNTER.oneofs_by_name['_step']
_PATTERNFLOWPFCPAUSEPAUSECLASS5COUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS5COUNTER.fields_by_name['count'])
_PATTERNFLOWPFCPAUSEPAUSECLASS5COUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS5COUNTER.oneofs_by_name['_count']
_PATTERNFLOWPFCPAUSEPAUSECLASS5_CHOICE.containing_type = _PATTERNFLOWPFCPAUSEPAUSECLASS5
_PATTERNFLOWPFCPAUSEPAUSECLASS5_CHOICE_ENUM.containing_type = _PATTERNFLOWPFCPAUSEPAUSECLASS5_CHOICE
_PATTERNFLOWPFCPAUSEPAUSECLASS5.fields_by_name['choice'].enum_type = _PATTERNFLOWPFCPAUSEPAUSECLASS5_CHOICE_ENUM
_PATTERNFLOWPFCPAUSEPAUSECLASS5.fields_by_name['increment'].message_type = _PATTERNFLOWPFCPAUSEPAUSECLASS5COUNTER
_PATTERNFLOWPFCPAUSEPAUSECLASS5.fields_by_name['decrement'].message_type = _PATTERNFLOWPFCPAUSEPAUSECLASS5COUNTER
_PATTERNFLOWPFCPAUSEPAUSECLASS5.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS5.fields_by_name['choice'])
_PATTERNFLOWPFCPAUSEPAUSECLASS5.fields_by_name['choice'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS5.oneofs_by_name['_choice']
_PATTERNFLOWPFCPAUSEPAUSECLASS5.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS5.fields_by_name['value'])
_PATTERNFLOWPFCPAUSEPAUSECLASS5.fields_by_name['value'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS5.oneofs_by_name['_value']
_PATTERNFLOWPFCPAUSEPAUSECLASS5.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS5.fields_by_name['metric_group'])
_PATTERNFLOWPFCPAUSEPAUSECLASS5.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS5.oneofs_by_name['_metric_group']
_PATTERNFLOWPFCPAUSEPAUSECLASS5.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS5.fields_by_name['increment'])
_PATTERNFLOWPFCPAUSEPAUSECLASS5.fields_by_name['increment'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS5.oneofs_by_name['_increment']
_PATTERNFLOWPFCPAUSEPAUSECLASS5.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS5.fields_by_name['decrement'])
_PATTERNFLOWPFCPAUSEPAUSECLASS5.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS5.oneofs_by_name['_decrement']
_PATTERNFLOWPFCPAUSEPAUSECLASS6COUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS6COUNTER.fields_by_name['start'])
_PATTERNFLOWPFCPAUSEPAUSECLASS6COUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS6COUNTER.oneofs_by_name['_start']
_PATTERNFLOWPFCPAUSEPAUSECLASS6COUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS6COUNTER.fields_by_name['step'])
_PATTERNFLOWPFCPAUSEPAUSECLASS6COUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS6COUNTER.oneofs_by_name['_step']
_PATTERNFLOWPFCPAUSEPAUSECLASS6COUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS6COUNTER.fields_by_name['count'])
_PATTERNFLOWPFCPAUSEPAUSECLASS6COUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS6COUNTER.oneofs_by_name['_count']
_PATTERNFLOWPFCPAUSEPAUSECLASS6_CHOICE.containing_type = _PATTERNFLOWPFCPAUSEPAUSECLASS6
_PATTERNFLOWPFCPAUSEPAUSECLASS6_CHOICE_ENUM.containing_type = _PATTERNFLOWPFCPAUSEPAUSECLASS6_CHOICE
_PATTERNFLOWPFCPAUSEPAUSECLASS6.fields_by_name['choice'].enum_type = _PATTERNFLOWPFCPAUSEPAUSECLASS6_CHOICE_ENUM
_PATTERNFLOWPFCPAUSEPAUSECLASS6.fields_by_name['increment'].message_type = _PATTERNFLOWPFCPAUSEPAUSECLASS6COUNTER
_PATTERNFLOWPFCPAUSEPAUSECLASS6.fields_by_name['decrement'].message_type = _PATTERNFLOWPFCPAUSEPAUSECLASS6COUNTER
_PATTERNFLOWPFCPAUSEPAUSECLASS6.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS6.fields_by_name['choice'])
_PATTERNFLOWPFCPAUSEPAUSECLASS6.fields_by_name['choice'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS6.oneofs_by_name['_choice']
_PATTERNFLOWPFCPAUSEPAUSECLASS6.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS6.fields_by_name['value'])
_PATTERNFLOWPFCPAUSEPAUSECLASS6.fields_by_name['value'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS6.oneofs_by_name['_value']
_PATTERNFLOWPFCPAUSEPAUSECLASS6.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS6.fields_by_name['metric_group'])
_PATTERNFLOWPFCPAUSEPAUSECLASS6.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS6.oneofs_by_name['_metric_group']
_PATTERNFLOWPFCPAUSEPAUSECLASS6.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS6.fields_by_name['increment'])
_PATTERNFLOWPFCPAUSEPAUSECLASS6.fields_by_name['increment'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS6.oneofs_by_name['_increment']
_PATTERNFLOWPFCPAUSEPAUSECLASS6.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS6.fields_by_name['decrement'])
_PATTERNFLOWPFCPAUSEPAUSECLASS6.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS6.oneofs_by_name['_decrement']
_PATTERNFLOWPFCPAUSEPAUSECLASS7COUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS7COUNTER.fields_by_name['start'])
_PATTERNFLOWPFCPAUSEPAUSECLASS7COUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS7COUNTER.oneofs_by_name['_start']
_PATTERNFLOWPFCPAUSEPAUSECLASS7COUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS7COUNTER.fields_by_name['step'])
_PATTERNFLOWPFCPAUSEPAUSECLASS7COUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS7COUNTER.oneofs_by_name['_step']
_PATTERNFLOWPFCPAUSEPAUSECLASS7COUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS7COUNTER.fields_by_name['count'])
_PATTERNFLOWPFCPAUSEPAUSECLASS7COUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS7COUNTER.oneofs_by_name['_count']
_PATTERNFLOWPFCPAUSEPAUSECLASS7_CHOICE.containing_type = _PATTERNFLOWPFCPAUSEPAUSECLASS7
_PATTERNFLOWPFCPAUSEPAUSECLASS7_CHOICE_ENUM.containing_type = _PATTERNFLOWPFCPAUSEPAUSECLASS7_CHOICE
_PATTERNFLOWPFCPAUSEPAUSECLASS7.fields_by_name['choice'].enum_type = _PATTERNFLOWPFCPAUSEPAUSECLASS7_CHOICE_ENUM
_PATTERNFLOWPFCPAUSEPAUSECLASS7.fields_by_name['increment'].message_type = _PATTERNFLOWPFCPAUSEPAUSECLASS7COUNTER
_PATTERNFLOWPFCPAUSEPAUSECLASS7.fields_by_name['decrement'].message_type = _PATTERNFLOWPFCPAUSEPAUSECLASS7COUNTER
_PATTERNFLOWPFCPAUSEPAUSECLASS7.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS7.fields_by_name['choice'])
_PATTERNFLOWPFCPAUSEPAUSECLASS7.fields_by_name['choice'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS7.oneofs_by_name['_choice']
_PATTERNFLOWPFCPAUSEPAUSECLASS7.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS7.fields_by_name['value'])
_PATTERNFLOWPFCPAUSEPAUSECLASS7.fields_by_name['value'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS7.oneofs_by_name['_value']
_PATTERNFLOWPFCPAUSEPAUSECLASS7.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS7.fields_by_name['metric_group'])
_PATTERNFLOWPFCPAUSEPAUSECLASS7.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS7.oneofs_by_name['_metric_group']
_PATTERNFLOWPFCPAUSEPAUSECLASS7.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS7.fields_by_name['increment'])
_PATTERNFLOWPFCPAUSEPAUSECLASS7.fields_by_name['increment'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS7.oneofs_by_name['_increment']
_PATTERNFLOWPFCPAUSEPAUSECLASS7.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWPFCPAUSEPAUSECLASS7.fields_by_name['decrement'])
_PATTERNFLOWPFCPAUSEPAUSECLASS7.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWPFCPAUSEPAUSECLASS7.oneofs_by_name['_decrement']
_PATTERNFLOWETHERNETPAUSEDSTCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWETHERNETPAUSEDSTCOUNTER.fields_by_name['start'])
_PATTERNFLOWETHERNETPAUSEDSTCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWETHERNETPAUSEDSTCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWETHERNETPAUSEDSTCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWETHERNETPAUSEDSTCOUNTER.fields_by_name['step'])
_PATTERNFLOWETHERNETPAUSEDSTCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWETHERNETPAUSEDSTCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWETHERNETPAUSEDSTCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWETHERNETPAUSEDSTCOUNTER.fields_by_name['count'])
_PATTERNFLOWETHERNETPAUSEDSTCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWETHERNETPAUSEDSTCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWETHERNETPAUSEDST_CHOICE.containing_type = _PATTERNFLOWETHERNETPAUSEDST
_PATTERNFLOWETHERNETPAUSEDST_CHOICE_ENUM.containing_type = _PATTERNFLOWETHERNETPAUSEDST_CHOICE
_PATTERNFLOWETHERNETPAUSEDST.fields_by_name['choice'].enum_type = _PATTERNFLOWETHERNETPAUSEDST_CHOICE_ENUM
_PATTERNFLOWETHERNETPAUSEDST.fields_by_name['increment'].message_type = _PATTERNFLOWETHERNETPAUSEDSTCOUNTER
_PATTERNFLOWETHERNETPAUSEDST.fields_by_name['decrement'].message_type = _PATTERNFLOWETHERNETPAUSEDSTCOUNTER
_PATTERNFLOWETHERNETPAUSEDST.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWETHERNETPAUSEDST.fields_by_name['choice'])
_PATTERNFLOWETHERNETPAUSEDST.fields_by_name['choice'].containing_oneof = _PATTERNFLOWETHERNETPAUSEDST.oneofs_by_name['_choice']
_PATTERNFLOWETHERNETPAUSEDST.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWETHERNETPAUSEDST.fields_by_name['value'])
_PATTERNFLOWETHERNETPAUSEDST.fields_by_name['value'].containing_oneof = _PATTERNFLOWETHERNETPAUSEDST.oneofs_by_name['_value']
_PATTERNFLOWETHERNETPAUSEDST.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWETHERNETPAUSEDST.fields_by_name['metric_group'])
_PATTERNFLOWETHERNETPAUSEDST.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWETHERNETPAUSEDST.oneofs_by_name['_metric_group']
_PATTERNFLOWETHERNETPAUSEDST.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWETHERNETPAUSEDST.fields_by_name['increment'])
_PATTERNFLOWETHERNETPAUSEDST.fields_by_name['increment'].containing_oneof = _PATTERNFLOWETHERNETPAUSEDST.oneofs_by_name['_increment']
_PATTERNFLOWETHERNETPAUSEDST.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWETHERNETPAUSEDST.fields_by_name['decrement'])
_PATTERNFLOWETHERNETPAUSEDST.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWETHERNETPAUSEDST.oneofs_by_name['_decrement']
_PATTERNFLOWETHERNETPAUSESRCCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWETHERNETPAUSESRCCOUNTER.fields_by_name['start'])
_PATTERNFLOWETHERNETPAUSESRCCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWETHERNETPAUSESRCCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWETHERNETPAUSESRCCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWETHERNETPAUSESRCCOUNTER.fields_by_name['step'])
_PATTERNFLOWETHERNETPAUSESRCCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWETHERNETPAUSESRCCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWETHERNETPAUSESRCCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWETHERNETPAUSESRCCOUNTER.fields_by_name['count'])
_PATTERNFLOWETHERNETPAUSESRCCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWETHERNETPAUSESRCCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWETHERNETPAUSESRC_CHOICE.containing_type = _PATTERNFLOWETHERNETPAUSESRC
_PATTERNFLOWETHERNETPAUSESRC_CHOICE_ENUM.containing_type = _PATTERNFLOWETHERNETPAUSESRC_CHOICE
_PATTERNFLOWETHERNETPAUSESRC.fields_by_name['choice'].enum_type = _PATTERNFLOWETHERNETPAUSESRC_CHOICE_ENUM
_PATTERNFLOWETHERNETPAUSESRC.fields_by_name['increment'].message_type = _PATTERNFLOWETHERNETPAUSESRCCOUNTER
_PATTERNFLOWETHERNETPAUSESRC.fields_by_name['decrement'].message_type = _PATTERNFLOWETHERNETPAUSESRCCOUNTER
_PATTERNFLOWETHERNETPAUSESRC.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWETHERNETPAUSESRC.fields_by_name['choice'])
_PATTERNFLOWETHERNETPAUSESRC.fields_by_name['choice'].containing_oneof = _PATTERNFLOWETHERNETPAUSESRC.oneofs_by_name['_choice']
_PATTERNFLOWETHERNETPAUSESRC.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWETHERNETPAUSESRC.fields_by_name['value'])
_PATTERNFLOWETHERNETPAUSESRC.fields_by_name['value'].containing_oneof = _PATTERNFLOWETHERNETPAUSESRC.oneofs_by_name['_value']
_PATTERNFLOWETHERNETPAUSESRC.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWETHERNETPAUSESRC.fields_by_name['metric_group'])
_PATTERNFLOWETHERNETPAUSESRC.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWETHERNETPAUSESRC.oneofs_by_name['_metric_group']
_PATTERNFLOWETHERNETPAUSESRC.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWETHERNETPAUSESRC.fields_by_name['increment'])
_PATTERNFLOWETHERNETPAUSESRC.fields_by_name['increment'].containing_oneof = _PATTERNFLOWETHERNETPAUSESRC.oneofs_by_name['_increment']
_PATTERNFLOWETHERNETPAUSESRC.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWETHERNETPAUSESRC.fields_by_name['decrement'])
_PATTERNFLOWETHERNETPAUSESRC.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWETHERNETPAUSESRC.oneofs_by_name['_decrement']
_PATTERNFLOWETHERNETPAUSEETHERTYPECOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWETHERNETPAUSEETHERTYPECOUNTER.fields_by_name['start'])
_PATTERNFLOWETHERNETPAUSEETHERTYPECOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWETHERNETPAUSEETHERTYPECOUNTER.oneofs_by_name['_start']
_PATTERNFLOWETHERNETPAUSEETHERTYPECOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWETHERNETPAUSEETHERTYPECOUNTER.fields_by_name['step'])
_PATTERNFLOWETHERNETPAUSEETHERTYPECOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWETHERNETPAUSEETHERTYPECOUNTER.oneofs_by_name['_step']
_PATTERNFLOWETHERNETPAUSEETHERTYPECOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWETHERNETPAUSEETHERTYPECOUNTER.fields_by_name['count'])
_PATTERNFLOWETHERNETPAUSEETHERTYPECOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWETHERNETPAUSEETHERTYPECOUNTER.oneofs_by_name['_count']
_PATTERNFLOWETHERNETPAUSEETHERTYPE_CHOICE.containing_type = _PATTERNFLOWETHERNETPAUSEETHERTYPE
_PATTERNFLOWETHERNETPAUSEETHERTYPE_CHOICE_ENUM.containing_type = _PATTERNFLOWETHERNETPAUSEETHERTYPE_CHOICE
_PATTERNFLOWETHERNETPAUSEETHERTYPE.fields_by_name['choice'].enum_type = _PATTERNFLOWETHERNETPAUSEETHERTYPE_CHOICE_ENUM
_PATTERNFLOWETHERNETPAUSEETHERTYPE.fields_by_name['increment'].message_type = _PATTERNFLOWETHERNETPAUSEETHERTYPECOUNTER
_PATTERNFLOWETHERNETPAUSEETHERTYPE.fields_by_name['decrement'].message_type = _PATTERNFLOWETHERNETPAUSEETHERTYPECOUNTER
_PATTERNFLOWETHERNETPAUSEETHERTYPE.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWETHERNETPAUSEETHERTYPE.fields_by_name['choice'])
_PATTERNFLOWETHERNETPAUSEETHERTYPE.fields_by_name['choice'].containing_oneof = _PATTERNFLOWETHERNETPAUSEETHERTYPE.oneofs_by_name['_choice']
_PATTERNFLOWETHERNETPAUSEETHERTYPE.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWETHERNETPAUSEETHERTYPE.fields_by_name['value'])
_PATTERNFLOWETHERNETPAUSEETHERTYPE.fields_by_name['value'].containing_oneof = _PATTERNFLOWETHERNETPAUSEETHERTYPE.oneofs_by_name['_value']
_PATTERNFLOWETHERNETPAUSEETHERTYPE.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWETHERNETPAUSEETHERTYPE.fields_by_name['metric_group'])
_PATTERNFLOWETHERNETPAUSEETHERTYPE.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWETHERNETPAUSEETHERTYPE.oneofs_by_name['_metric_group']
_PATTERNFLOWETHERNETPAUSEETHERTYPE.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWETHERNETPAUSEETHERTYPE.fields_by_name['increment'])
_PATTERNFLOWETHERNETPAUSEETHERTYPE.fields_by_name['increment'].containing_oneof = _PATTERNFLOWETHERNETPAUSEETHERTYPE.oneofs_by_name['_increment']
_PATTERNFLOWETHERNETPAUSEETHERTYPE.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWETHERNETPAUSEETHERTYPE.fields_by_name['decrement'])
_PATTERNFLOWETHERNETPAUSEETHERTYPE.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWETHERNETPAUSEETHERTYPE.oneofs_by_name['_decrement']
_PATTERNFLOWETHERNETPAUSECONTROLOPCODECOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWETHERNETPAUSECONTROLOPCODECOUNTER.fields_by_name['start'])
_PATTERNFLOWETHERNETPAUSECONTROLOPCODECOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWETHERNETPAUSECONTROLOPCODECOUNTER.oneofs_by_name['_start']
_PATTERNFLOWETHERNETPAUSECONTROLOPCODECOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWETHERNETPAUSECONTROLOPCODECOUNTER.fields_by_name['step'])
_PATTERNFLOWETHERNETPAUSECONTROLOPCODECOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWETHERNETPAUSECONTROLOPCODECOUNTER.oneofs_by_name['_step']
_PATTERNFLOWETHERNETPAUSECONTROLOPCODECOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWETHERNETPAUSECONTROLOPCODECOUNTER.fields_by_name['count'])
_PATTERNFLOWETHERNETPAUSECONTROLOPCODECOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWETHERNETPAUSECONTROLOPCODECOUNTER.oneofs_by_name['_count']
_PATTERNFLOWETHERNETPAUSECONTROLOPCODE_CHOICE.containing_type = _PATTERNFLOWETHERNETPAUSECONTROLOPCODE
_PATTERNFLOWETHERNETPAUSECONTROLOPCODE_CHOICE_ENUM.containing_type = _PATTERNFLOWETHERNETPAUSECONTROLOPCODE_CHOICE
_PATTERNFLOWETHERNETPAUSECONTROLOPCODE.fields_by_name['choice'].enum_type = _PATTERNFLOWETHERNETPAUSECONTROLOPCODE_CHOICE_ENUM
_PATTERNFLOWETHERNETPAUSECONTROLOPCODE.fields_by_name['increment'].message_type = _PATTERNFLOWETHERNETPAUSECONTROLOPCODECOUNTER
_PATTERNFLOWETHERNETPAUSECONTROLOPCODE.fields_by_name['decrement'].message_type = _PATTERNFLOWETHERNETPAUSECONTROLOPCODECOUNTER
_PATTERNFLOWETHERNETPAUSECONTROLOPCODE.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWETHERNETPAUSECONTROLOPCODE.fields_by_name['choice'])
_PATTERNFLOWETHERNETPAUSECONTROLOPCODE.fields_by_name['choice'].containing_oneof = _PATTERNFLOWETHERNETPAUSECONTROLOPCODE.oneofs_by_name['_choice']
_PATTERNFLOWETHERNETPAUSECONTROLOPCODE.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWETHERNETPAUSECONTROLOPCODE.fields_by_name['value'])
_PATTERNFLOWETHERNETPAUSECONTROLOPCODE.fields_by_name['value'].containing_oneof = _PATTERNFLOWETHERNETPAUSECONTROLOPCODE.oneofs_by_name['_value']
_PATTERNFLOWETHERNETPAUSECONTROLOPCODE.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWETHERNETPAUSECONTROLOPCODE.fields_by_name['metric_group'])
_PATTERNFLOWETHERNETPAUSECONTROLOPCODE.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWETHERNETPAUSECONTROLOPCODE.oneofs_by_name['_metric_group']
_PATTERNFLOWETHERNETPAUSECONTROLOPCODE.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWETHERNETPAUSECONTROLOPCODE.fields_by_name['increment'])
_PATTERNFLOWETHERNETPAUSECONTROLOPCODE.fields_by_name['increment'].containing_oneof = _PATTERNFLOWETHERNETPAUSECONTROLOPCODE.oneofs_by_name['_increment']
_PATTERNFLOWETHERNETPAUSECONTROLOPCODE.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWETHERNETPAUSECONTROLOPCODE.fields_by_name['decrement'])
_PATTERNFLOWETHERNETPAUSECONTROLOPCODE.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWETHERNETPAUSECONTROLOPCODE.oneofs_by_name['_decrement']
_PATTERNFLOWETHERNETPAUSETIMECOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWETHERNETPAUSETIMECOUNTER.fields_by_name['start'])
_PATTERNFLOWETHERNETPAUSETIMECOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWETHERNETPAUSETIMECOUNTER.oneofs_by_name['_start']
_PATTERNFLOWETHERNETPAUSETIMECOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWETHERNETPAUSETIMECOUNTER.fields_by_name['step'])
_PATTERNFLOWETHERNETPAUSETIMECOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWETHERNETPAUSETIMECOUNTER.oneofs_by_name['_step']
_PATTERNFLOWETHERNETPAUSETIMECOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWETHERNETPAUSETIMECOUNTER.fields_by_name['count'])
_PATTERNFLOWETHERNETPAUSETIMECOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWETHERNETPAUSETIMECOUNTER.oneofs_by_name['_count']
_PATTERNFLOWETHERNETPAUSETIME_CHOICE.containing_type = _PATTERNFLOWETHERNETPAUSETIME
_PATTERNFLOWETHERNETPAUSETIME_CHOICE_ENUM.containing_type = _PATTERNFLOWETHERNETPAUSETIME_CHOICE
_PATTERNFLOWETHERNETPAUSETIME.fields_by_name['choice'].enum_type = _PATTERNFLOWETHERNETPAUSETIME_CHOICE_ENUM
_PATTERNFLOWETHERNETPAUSETIME.fields_by_name['increment'].message_type = _PATTERNFLOWETHERNETPAUSETIMECOUNTER
_PATTERNFLOWETHERNETPAUSETIME.fields_by_name['decrement'].message_type = _PATTERNFLOWETHERNETPAUSETIMECOUNTER
_PATTERNFLOWETHERNETPAUSETIME.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWETHERNETPAUSETIME.fields_by_name['choice'])
_PATTERNFLOWETHERNETPAUSETIME.fields_by_name['choice'].containing_oneof = _PATTERNFLOWETHERNETPAUSETIME.oneofs_by_name['_choice']
_PATTERNFLOWETHERNETPAUSETIME.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWETHERNETPAUSETIME.fields_by_name['value'])
_PATTERNFLOWETHERNETPAUSETIME.fields_by_name['value'].containing_oneof = _PATTERNFLOWETHERNETPAUSETIME.oneofs_by_name['_value']
_PATTERNFLOWETHERNETPAUSETIME.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWETHERNETPAUSETIME.fields_by_name['metric_group'])
_PATTERNFLOWETHERNETPAUSETIME.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWETHERNETPAUSETIME.oneofs_by_name['_metric_group']
_PATTERNFLOWETHERNETPAUSETIME.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWETHERNETPAUSETIME.fields_by_name['increment'])
_PATTERNFLOWETHERNETPAUSETIME.fields_by_name['increment'].containing_oneof = _PATTERNFLOWETHERNETPAUSETIME.oneofs_by_name['_increment']
_PATTERNFLOWETHERNETPAUSETIME.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWETHERNETPAUSETIME.fields_by_name['decrement'])
_PATTERNFLOWETHERNETPAUSETIME.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWETHERNETPAUSETIME.oneofs_by_name['_decrement']
_PATTERNFLOWTCPSRCPORTCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWTCPSRCPORTCOUNTER.fields_by_name['start'])
_PATTERNFLOWTCPSRCPORTCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWTCPSRCPORTCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWTCPSRCPORTCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWTCPSRCPORTCOUNTER.fields_by_name['step'])
_PATTERNFLOWTCPSRCPORTCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWTCPSRCPORTCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWTCPSRCPORTCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWTCPSRCPORTCOUNTER.fields_by_name['count'])
_PATTERNFLOWTCPSRCPORTCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWTCPSRCPORTCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWTCPSRCPORT_CHOICE.containing_type = _PATTERNFLOWTCPSRCPORT
_PATTERNFLOWTCPSRCPORT_CHOICE_ENUM.containing_type = _PATTERNFLOWTCPSRCPORT_CHOICE
_PATTERNFLOWTCPSRCPORT.fields_by_name['choice'].enum_type = _PATTERNFLOWTCPSRCPORT_CHOICE_ENUM
_PATTERNFLOWTCPSRCPORT.fields_by_name['increment'].message_type = _PATTERNFLOWTCPSRCPORTCOUNTER
_PATTERNFLOWTCPSRCPORT.fields_by_name['decrement'].message_type = _PATTERNFLOWTCPSRCPORTCOUNTER
_PATTERNFLOWTCPSRCPORT.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWTCPSRCPORT.fields_by_name['choice'])
_PATTERNFLOWTCPSRCPORT.fields_by_name['choice'].containing_oneof = _PATTERNFLOWTCPSRCPORT.oneofs_by_name['_choice']
_PATTERNFLOWTCPSRCPORT.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWTCPSRCPORT.fields_by_name['value'])
_PATTERNFLOWTCPSRCPORT.fields_by_name['value'].containing_oneof = _PATTERNFLOWTCPSRCPORT.oneofs_by_name['_value']
_PATTERNFLOWTCPSRCPORT.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWTCPSRCPORT.fields_by_name['metric_group'])
_PATTERNFLOWTCPSRCPORT.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWTCPSRCPORT.oneofs_by_name['_metric_group']
_PATTERNFLOWTCPSRCPORT.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWTCPSRCPORT.fields_by_name['increment'])
_PATTERNFLOWTCPSRCPORT.fields_by_name['increment'].containing_oneof = _PATTERNFLOWTCPSRCPORT.oneofs_by_name['_increment']
_PATTERNFLOWTCPSRCPORT.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWTCPSRCPORT.fields_by_name['decrement'])
_PATTERNFLOWTCPSRCPORT.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWTCPSRCPORT.oneofs_by_name['_decrement']
_PATTERNFLOWTCPDSTPORTCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWTCPDSTPORTCOUNTER.fields_by_name['start'])
_PATTERNFLOWTCPDSTPORTCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWTCPDSTPORTCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWTCPDSTPORTCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWTCPDSTPORTCOUNTER.fields_by_name['step'])
_PATTERNFLOWTCPDSTPORTCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWTCPDSTPORTCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWTCPDSTPORTCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWTCPDSTPORTCOUNTER.fields_by_name['count'])
_PATTERNFLOWTCPDSTPORTCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWTCPDSTPORTCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWTCPDSTPORT_CHOICE.containing_type = _PATTERNFLOWTCPDSTPORT
_PATTERNFLOWTCPDSTPORT_CHOICE_ENUM.containing_type = _PATTERNFLOWTCPDSTPORT_CHOICE
_PATTERNFLOWTCPDSTPORT.fields_by_name['choice'].enum_type = _PATTERNFLOWTCPDSTPORT_CHOICE_ENUM
_PATTERNFLOWTCPDSTPORT.fields_by_name['increment'].message_type = _PATTERNFLOWTCPDSTPORTCOUNTER
_PATTERNFLOWTCPDSTPORT.fields_by_name['decrement'].message_type = _PATTERNFLOWTCPDSTPORTCOUNTER
_PATTERNFLOWTCPDSTPORT.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWTCPDSTPORT.fields_by_name['choice'])
_PATTERNFLOWTCPDSTPORT.fields_by_name['choice'].containing_oneof = _PATTERNFLOWTCPDSTPORT.oneofs_by_name['_choice']
_PATTERNFLOWTCPDSTPORT.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWTCPDSTPORT.fields_by_name['value'])
_PATTERNFLOWTCPDSTPORT.fields_by_name['value'].containing_oneof = _PATTERNFLOWTCPDSTPORT.oneofs_by_name['_value']
_PATTERNFLOWTCPDSTPORT.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWTCPDSTPORT.fields_by_name['metric_group'])
_PATTERNFLOWTCPDSTPORT.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWTCPDSTPORT.oneofs_by_name['_metric_group']
_PATTERNFLOWTCPDSTPORT.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWTCPDSTPORT.fields_by_name['increment'])
_PATTERNFLOWTCPDSTPORT.fields_by_name['increment'].containing_oneof = _PATTERNFLOWTCPDSTPORT.oneofs_by_name['_increment']
_PATTERNFLOWTCPDSTPORT.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWTCPDSTPORT.fields_by_name['decrement'])
_PATTERNFLOWTCPDSTPORT.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWTCPDSTPORT.oneofs_by_name['_decrement']
_PATTERNFLOWTCPSEQNUMCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWTCPSEQNUMCOUNTER.fields_by_name['start'])
_PATTERNFLOWTCPSEQNUMCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWTCPSEQNUMCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWTCPSEQNUMCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWTCPSEQNUMCOUNTER.fields_by_name['step'])
_PATTERNFLOWTCPSEQNUMCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWTCPSEQNUMCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWTCPSEQNUMCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWTCPSEQNUMCOUNTER.fields_by_name['count'])
_PATTERNFLOWTCPSEQNUMCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWTCPSEQNUMCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWTCPSEQNUM_CHOICE.containing_type = _PATTERNFLOWTCPSEQNUM
_PATTERNFLOWTCPSEQNUM_CHOICE_ENUM.containing_type = _PATTERNFLOWTCPSEQNUM_CHOICE
_PATTERNFLOWTCPSEQNUM.fields_by_name['choice'].enum_type = _PATTERNFLOWTCPSEQNUM_CHOICE_ENUM
_PATTERNFLOWTCPSEQNUM.fields_by_name['increment'].message_type = _PATTERNFLOWTCPSEQNUMCOUNTER
_PATTERNFLOWTCPSEQNUM.fields_by_name['decrement'].message_type = _PATTERNFLOWTCPSEQNUMCOUNTER
_PATTERNFLOWTCPSEQNUM.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWTCPSEQNUM.fields_by_name['choice'])
_PATTERNFLOWTCPSEQNUM.fields_by_name['choice'].containing_oneof = _PATTERNFLOWTCPSEQNUM.oneofs_by_name['_choice']
_PATTERNFLOWTCPSEQNUM.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWTCPSEQNUM.fields_by_name['value'])
_PATTERNFLOWTCPSEQNUM.fields_by_name['value'].containing_oneof = _PATTERNFLOWTCPSEQNUM.oneofs_by_name['_value']
_PATTERNFLOWTCPSEQNUM.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWTCPSEQNUM.fields_by_name['metric_group'])
_PATTERNFLOWTCPSEQNUM.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWTCPSEQNUM.oneofs_by_name['_metric_group']
_PATTERNFLOWTCPSEQNUM.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWTCPSEQNUM.fields_by_name['increment'])
_PATTERNFLOWTCPSEQNUM.fields_by_name['increment'].containing_oneof = _PATTERNFLOWTCPSEQNUM.oneofs_by_name['_increment']
_PATTERNFLOWTCPSEQNUM.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWTCPSEQNUM.fields_by_name['decrement'])
_PATTERNFLOWTCPSEQNUM.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWTCPSEQNUM.oneofs_by_name['_decrement']
_PATTERNFLOWTCPACKNUMCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWTCPACKNUMCOUNTER.fields_by_name['start'])
_PATTERNFLOWTCPACKNUMCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWTCPACKNUMCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWTCPACKNUMCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWTCPACKNUMCOUNTER.fields_by_name['step'])
_PATTERNFLOWTCPACKNUMCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWTCPACKNUMCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWTCPACKNUMCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWTCPACKNUMCOUNTER.fields_by_name['count'])
_PATTERNFLOWTCPACKNUMCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWTCPACKNUMCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWTCPACKNUM_CHOICE.containing_type = _PATTERNFLOWTCPACKNUM
_PATTERNFLOWTCPACKNUM_CHOICE_ENUM.containing_type = _PATTERNFLOWTCPACKNUM_CHOICE
_PATTERNFLOWTCPACKNUM.fields_by_name['choice'].enum_type = _PATTERNFLOWTCPACKNUM_CHOICE_ENUM
_PATTERNFLOWTCPACKNUM.fields_by_name['increment'].message_type = _PATTERNFLOWTCPACKNUMCOUNTER
_PATTERNFLOWTCPACKNUM.fields_by_name['decrement'].message_type = _PATTERNFLOWTCPACKNUMCOUNTER
_PATTERNFLOWTCPACKNUM.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWTCPACKNUM.fields_by_name['choice'])
_PATTERNFLOWTCPACKNUM.fields_by_name['choice'].containing_oneof = _PATTERNFLOWTCPACKNUM.oneofs_by_name['_choice']
_PATTERNFLOWTCPACKNUM.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWTCPACKNUM.fields_by_name['value'])
_PATTERNFLOWTCPACKNUM.fields_by_name['value'].containing_oneof = _PATTERNFLOWTCPACKNUM.oneofs_by_name['_value']
_PATTERNFLOWTCPACKNUM.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWTCPACKNUM.fields_by_name['metric_group'])
_PATTERNFLOWTCPACKNUM.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWTCPACKNUM.oneofs_by_name['_metric_group']
_PATTERNFLOWTCPACKNUM.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWTCPACKNUM.fields_by_name['increment'])
_PATTERNFLOWTCPACKNUM.fields_by_name['increment'].containing_oneof = _PATTERNFLOWTCPACKNUM.oneofs_by_name['_increment']
_PATTERNFLOWTCPACKNUM.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWTCPACKNUM.fields_by_name['decrement'])
_PATTERNFLOWTCPACKNUM.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWTCPACKNUM.oneofs_by_name['_decrement']
_PATTERNFLOWTCPDATAOFFSETCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWTCPDATAOFFSETCOUNTER.fields_by_name['start'])
_PATTERNFLOWTCPDATAOFFSETCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWTCPDATAOFFSETCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWTCPDATAOFFSETCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWTCPDATAOFFSETCOUNTER.fields_by_name['step'])
_PATTERNFLOWTCPDATAOFFSETCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWTCPDATAOFFSETCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWTCPDATAOFFSETCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWTCPDATAOFFSETCOUNTER.fields_by_name['count'])
_PATTERNFLOWTCPDATAOFFSETCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWTCPDATAOFFSETCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWTCPDATAOFFSET_CHOICE.containing_type = _PATTERNFLOWTCPDATAOFFSET
_PATTERNFLOWTCPDATAOFFSET_CHOICE_ENUM.containing_type = _PATTERNFLOWTCPDATAOFFSET_CHOICE
_PATTERNFLOWTCPDATAOFFSET.fields_by_name['choice'].enum_type = _PATTERNFLOWTCPDATAOFFSET_CHOICE_ENUM
_PATTERNFLOWTCPDATAOFFSET.fields_by_name['increment'].message_type = _PATTERNFLOWTCPDATAOFFSETCOUNTER
_PATTERNFLOWTCPDATAOFFSET.fields_by_name['decrement'].message_type = _PATTERNFLOWTCPDATAOFFSETCOUNTER
_PATTERNFLOWTCPDATAOFFSET.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWTCPDATAOFFSET.fields_by_name['choice'])
_PATTERNFLOWTCPDATAOFFSET.fields_by_name['choice'].containing_oneof = _PATTERNFLOWTCPDATAOFFSET.oneofs_by_name['_choice']
_PATTERNFLOWTCPDATAOFFSET.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWTCPDATAOFFSET.fields_by_name['value'])
_PATTERNFLOWTCPDATAOFFSET.fields_by_name['value'].containing_oneof = _PATTERNFLOWTCPDATAOFFSET.oneofs_by_name['_value']
_PATTERNFLOWTCPDATAOFFSET.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWTCPDATAOFFSET.fields_by_name['metric_group'])
_PATTERNFLOWTCPDATAOFFSET.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWTCPDATAOFFSET.oneofs_by_name['_metric_group']
_PATTERNFLOWTCPDATAOFFSET.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWTCPDATAOFFSET.fields_by_name['increment'])
_PATTERNFLOWTCPDATAOFFSET.fields_by_name['increment'].containing_oneof = _PATTERNFLOWTCPDATAOFFSET.oneofs_by_name['_increment']
_PATTERNFLOWTCPDATAOFFSET.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWTCPDATAOFFSET.fields_by_name['decrement'])
_PATTERNFLOWTCPDATAOFFSET.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWTCPDATAOFFSET.oneofs_by_name['_decrement']
_PATTERNFLOWTCPECNNSCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWTCPECNNSCOUNTER.fields_by_name['start'])
_PATTERNFLOWTCPECNNSCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWTCPECNNSCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWTCPECNNSCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWTCPECNNSCOUNTER.fields_by_name['step'])
_PATTERNFLOWTCPECNNSCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWTCPECNNSCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWTCPECNNSCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWTCPECNNSCOUNTER.fields_by_name['count'])
_PATTERNFLOWTCPECNNSCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWTCPECNNSCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWTCPECNNS_CHOICE.containing_type = _PATTERNFLOWTCPECNNS
_PATTERNFLOWTCPECNNS_CHOICE_ENUM.containing_type = _PATTERNFLOWTCPECNNS_CHOICE
_PATTERNFLOWTCPECNNS.fields_by_name['choice'].enum_type = _PATTERNFLOWTCPECNNS_CHOICE_ENUM
_PATTERNFLOWTCPECNNS.fields_by_name['increment'].message_type = _PATTERNFLOWTCPECNNSCOUNTER
_PATTERNFLOWTCPECNNS.fields_by_name['decrement'].message_type = _PATTERNFLOWTCPECNNSCOUNTER
_PATTERNFLOWTCPECNNS.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWTCPECNNS.fields_by_name['choice'])
_PATTERNFLOWTCPECNNS.fields_by_name['choice'].containing_oneof = _PATTERNFLOWTCPECNNS.oneofs_by_name['_choice']
_PATTERNFLOWTCPECNNS.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWTCPECNNS.fields_by_name['value'])
_PATTERNFLOWTCPECNNS.fields_by_name['value'].containing_oneof = _PATTERNFLOWTCPECNNS.oneofs_by_name['_value']
_PATTERNFLOWTCPECNNS.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWTCPECNNS.fields_by_name['metric_group'])
_PATTERNFLOWTCPECNNS.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWTCPECNNS.oneofs_by_name['_metric_group']
_PATTERNFLOWTCPECNNS.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWTCPECNNS.fields_by_name['increment'])
_PATTERNFLOWTCPECNNS.fields_by_name['increment'].containing_oneof = _PATTERNFLOWTCPECNNS.oneofs_by_name['_increment']
_PATTERNFLOWTCPECNNS.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWTCPECNNS.fields_by_name['decrement'])
_PATTERNFLOWTCPECNNS.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWTCPECNNS.oneofs_by_name['_decrement']
_PATTERNFLOWTCPECNCWRCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWTCPECNCWRCOUNTER.fields_by_name['start'])
_PATTERNFLOWTCPECNCWRCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWTCPECNCWRCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWTCPECNCWRCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWTCPECNCWRCOUNTER.fields_by_name['step'])
_PATTERNFLOWTCPECNCWRCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWTCPECNCWRCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWTCPECNCWRCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWTCPECNCWRCOUNTER.fields_by_name['count'])
_PATTERNFLOWTCPECNCWRCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWTCPECNCWRCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWTCPECNCWR_CHOICE.containing_type = _PATTERNFLOWTCPECNCWR
_PATTERNFLOWTCPECNCWR_CHOICE_ENUM.containing_type = _PATTERNFLOWTCPECNCWR_CHOICE
_PATTERNFLOWTCPECNCWR.fields_by_name['choice'].enum_type = _PATTERNFLOWTCPECNCWR_CHOICE_ENUM
_PATTERNFLOWTCPECNCWR.fields_by_name['increment'].message_type = _PATTERNFLOWTCPECNCWRCOUNTER
_PATTERNFLOWTCPECNCWR.fields_by_name['decrement'].message_type = _PATTERNFLOWTCPECNCWRCOUNTER
_PATTERNFLOWTCPECNCWR.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWTCPECNCWR.fields_by_name['choice'])
_PATTERNFLOWTCPECNCWR.fields_by_name['choice'].containing_oneof = _PATTERNFLOWTCPECNCWR.oneofs_by_name['_choice']
_PATTERNFLOWTCPECNCWR.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWTCPECNCWR.fields_by_name['value'])
_PATTERNFLOWTCPECNCWR.fields_by_name['value'].containing_oneof = _PATTERNFLOWTCPECNCWR.oneofs_by_name['_value']
_PATTERNFLOWTCPECNCWR.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWTCPECNCWR.fields_by_name['metric_group'])
_PATTERNFLOWTCPECNCWR.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWTCPECNCWR.oneofs_by_name['_metric_group']
_PATTERNFLOWTCPECNCWR.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWTCPECNCWR.fields_by_name['increment'])
_PATTERNFLOWTCPECNCWR.fields_by_name['increment'].containing_oneof = _PATTERNFLOWTCPECNCWR.oneofs_by_name['_increment']
_PATTERNFLOWTCPECNCWR.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWTCPECNCWR.fields_by_name['decrement'])
_PATTERNFLOWTCPECNCWR.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWTCPECNCWR.oneofs_by_name['_decrement']
_PATTERNFLOWTCPECNECHOCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWTCPECNECHOCOUNTER.fields_by_name['start'])
_PATTERNFLOWTCPECNECHOCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWTCPECNECHOCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWTCPECNECHOCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWTCPECNECHOCOUNTER.fields_by_name['step'])
_PATTERNFLOWTCPECNECHOCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWTCPECNECHOCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWTCPECNECHOCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWTCPECNECHOCOUNTER.fields_by_name['count'])
_PATTERNFLOWTCPECNECHOCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWTCPECNECHOCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWTCPECNECHO_CHOICE.containing_type = _PATTERNFLOWTCPECNECHO
_PATTERNFLOWTCPECNECHO_CHOICE_ENUM.containing_type = _PATTERNFLOWTCPECNECHO_CHOICE
_PATTERNFLOWTCPECNECHO.fields_by_name['choice'].enum_type = _PATTERNFLOWTCPECNECHO_CHOICE_ENUM
_PATTERNFLOWTCPECNECHO.fields_by_name['increment'].message_type = _PATTERNFLOWTCPECNECHOCOUNTER
_PATTERNFLOWTCPECNECHO.fields_by_name['decrement'].message_type = _PATTERNFLOWTCPECNECHOCOUNTER
_PATTERNFLOWTCPECNECHO.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWTCPECNECHO.fields_by_name['choice'])
_PATTERNFLOWTCPECNECHO.fields_by_name['choice'].containing_oneof = _PATTERNFLOWTCPECNECHO.oneofs_by_name['_choice']
_PATTERNFLOWTCPECNECHO.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWTCPECNECHO.fields_by_name['value'])
_PATTERNFLOWTCPECNECHO.fields_by_name['value'].containing_oneof = _PATTERNFLOWTCPECNECHO.oneofs_by_name['_value']
_PATTERNFLOWTCPECNECHO.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWTCPECNECHO.fields_by_name['metric_group'])
_PATTERNFLOWTCPECNECHO.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWTCPECNECHO.oneofs_by_name['_metric_group']
_PATTERNFLOWTCPECNECHO.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWTCPECNECHO.fields_by_name['increment'])
_PATTERNFLOWTCPECNECHO.fields_by_name['increment'].containing_oneof = _PATTERNFLOWTCPECNECHO.oneofs_by_name['_increment']
_PATTERNFLOWTCPECNECHO.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWTCPECNECHO.fields_by_name['decrement'])
_PATTERNFLOWTCPECNECHO.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWTCPECNECHO.oneofs_by_name['_decrement']
_PATTERNFLOWTCPCTLURGCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWTCPCTLURGCOUNTER.fields_by_name['start'])
_PATTERNFLOWTCPCTLURGCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWTCPCTLURGCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWTCPCTLURGCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWTCPCTLURGCOUNTER.fields_by_name['step'])
_PATTERNFLOWTCPCTLURGCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWTCPCTLURGCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWTCPCTLURGCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWTCPCTLURGCOUNTER.fields_by_name['count'])
_PATTERNFLOWTCPCTLURGCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWTCPCTLURGCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWTCPCTLURG_CHOICE.containing_type = _PATTERNFLOWTCPCTLURG
_PATTERNFLOWTCPCTLURG_CHOICE_ENUM.containing_type = _PATTERNFLOWTCPCTLURG_CHOICE
_PATTERNFLOWTCPCTLURG.fields_by_name['choice'].enum_type = _PATTERNFLOWTCPCTLURG_CHOICE_ENUM
_PATTERNFLOWTCPCTLURG.fields_by_name['increment'].message_type = _PATTERNFLOWTCPCTLURGCOUNTER
_PATTERNFLOWTCPCTLURG.fields_by_name['decrement'].message_type = _PATTERNFLOWTCPCTLURGCOUNTER
_PATTERNFLOWTCPCTLURG.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWTCPCTLURG.fields_by_name['choice'])
_PATTERNFLOWTCPCTLURG.fields_by_name['choice'].containing_oneof = _PATTERNFLOWTCPCTLURG.oneofs_by_name['_choice']
_PATTERNFLOWTCPCTLURG.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWTCPCTLURG.fields_by_name['value'])
_PATTERNFLOWTCPCTLURG.fields_by_name['value'].containing_oneof = _PATTERNFLOWTCPCTLURG.oneofs_by_name['_value']
_PATTERNFLOWTCPCTLURG.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWTCPCTLURG.fields_by_name['metric_group'])
_PATTERNFLOWTCPCTLURG.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWTCPCTLURG.oneofs_by_name['_metric_group']
_PATTERNFLOWTCPCTLURG.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWTCPCTLURG.fields_by_name['increment'])
_PATTERNFLOWTCPCTLURG.fields_by_name['increment'].containing_oneof = _PATTERNFLOWTCPCTLURG.oneofs_by_name['_increment']
_PATTERNFLOWTCPCTLURG.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWTCPCTLURG.fields_by_name['decrement'])
_PATTERNFLOWTCPCTLURG.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWTCPCTLURG.oneofs_by_name['_decrement']
_PATTERNFLOWTCPCTLACKCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWTCPCTLACKCOUNTER.fields_by_name['start'])
_PATTERNFLOWTCPCTLACKCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWTCPCTLACKCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWTCPCTLACKCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWTCPCTLACKCOUNTER.fields_by_name['step'])
_PATTERNFLOWTCPCTLACKCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWTCPCTLACKCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWTCPCTLACKCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWTCPCTLACKCOUNTER.fields_by_name['count'])
_PATTERNFLOWTCPCTLACKCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWTCPCTLACKCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWTCPCTLACK_CHOICE.containing_type = _PATTERNFLOWTCPCTLACK
_PATTERNFLOWTCPCTLACK_CHOICE_ENUM.containing_type = _PATTERNFLOWTCPCTLACK_CHOICE
_PATTERNFLOWTCPCTLACK.fields_by_name['choice'].enum_type = _PATTERNFLOWTCPCTLACK_CHOICE_ENUM
_PATTERNFLOWTCPCTLACK.fields_by_name['increment'].message_type = _PATTERNFLOWTCPCTLACKCOUNTER
_PATTERNFLOWTCPCTLACK.fields_by_name['decrement'].message_type = _PATTERNFLOWTCPCTLACKCOUNTER
_PATTERNFLOWTCPCTLACK.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWTCPCTLACK.fields_by_name['choice'])
_PATTERNFLOWTCPCTLACK.fields_by_name['choice'].containing_oneof = _PATTERNFLOWTCPCTLACK.oneofs_by_name['_choice']
_PATTERNFLOWTCPCTLACK.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWTCPCTLACK.fields_by_name['value'])
_PATTERNFLOWTCPCTLACK.fields_by_name['value'].containing_oneof = _PATTERNFLOWTCPCTLACK.oneofs_by_name['_value']
_PATTERNFLOWTCPCTLACK.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWTCPCTLACK.fields_by_name['metric_group'])
_PATTERNFLOWTCPCTLACK.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWTCPCTLACK.oneofs_by_name['_metric_group']
_PATTERNFLOWTCPCTLACK.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWTCPCTLACK.fields_by_name['increment'])
_PATTERNFLOWTCPCTLACK.fields_by_name['increment'].containing_oneof = _PATTERNFLOWTCPCTLACK.oneofs_by_name['_increment']
_PATTERNFLOWTCPCTLACK.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWTCPCTLACK.fields_by_name['decrement'])
_PATTERNFLOWTCPCTLACK.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWTCPCTLACK.oneofs_by_name['_decrement']
_PATTERNFLOWTCPCTLPSHCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWTCPCTLPSHCOUNTER.fields_by_name['start'])
_PATTERNFLOWTCPCTLPSHCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWTCPCTLPSHCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWTCPCTLPSHCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWTCPCTLPSHCOUNTER.fields_by_name['step'])
_PATTERNFLOWTCPCTLPSHCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWTCPCTLPSHCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWTCPCTLPSHCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWTCPCTLPSHCOUNTER.fields_by_name['count'])
_PATTERNFLOWTCPCTLPSHCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWTCPCTLPSHCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWTCPCTLPSH_CHOICE.containing_type = _PATTERNFLOWTCPCTLPSH
_PATTERNFLOWTCPCTLPSH_CHOICE_ENUM.containing_type = _PATTERNFLOWTCPCTLPSH_CHOICE
_PATTERNFLOWTCPCTLPSH.fields_by_name['choice'].enum_type = _PATTERNFLOWTCPCTLPSH_CHOICE_ENUM
_PATTERNFLOWTCPCTLPSH.fields_by_name['increment'].message_type = _PATTERNFLOWTCPCTLPSHCOUNTER
_PATTERNFLOWTCPCTLPSH.fields_by_name['decrement'].message_type = _PATTERNFLOWTCPCTLPSHCOUNTER
_PATTERNFLOWTCPCTLPSH.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWTCPCTLPSH.fields_by_name['choice'])
_PATTERNFLOWTCPCTLPSH.fields_by_name['choice'].containing_oneof = _PATTERNFLOWTCPCTLPSH.oneofs_by_name['_choice']
_PATTERNFLOWTCPCTLPSH.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWTCPCTLPSH.fields_by_name['value'])
_PATTERNFLOWTCPCTLPSH.fields_by_name['value'].containing_oneof = _PATTERNFLOWTCPCTLPSH.oneofs_by_name['_value']
_PATTERNFLOWTCPCTLPSH.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWTCPCTLPSH.fields_by_name['metric_group'])
_PATTERNFLOWTCPCTLPSH.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWTCPCTLPSH.oneofs_by_name['_metric_group']
_PATTERNFLOWTCPCTLPSH.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWTCPCTLPSH.fields_by_name['increment'])
_PATTERNFLOWTCPCTLPSH.fields_by_name['increment'].containing_oneof = _PATTERNFLOWTCPCTLPSH.oneofs_by_name['_increment']
_PATTERNFLOWTCPCTLPSH.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWTCPCTLPSH.fields_by_name['decrement'])
_PATTERNFLOWTCPCTLPSH.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWTCPCTLPSH.oneofs_by_name['_decrement']
_PATTERNFLOWTCPCTLRSTCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWTCPCTLRSTCOUNTER.fields_by_name['start'])
_PATTERNFLOWTCPCTLRSTCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWTCPCTLRSTCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWTCPCTLRSTCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWTCPCTLRSTCOUNTER.fields_by_name['step'])
_PATTERNFLOWTCPCTLRSTCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWTCPCTLRSTCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWTCPCTLRSTCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWTCPCTLRSTCOUNTER.fields_by_name['count'])
_PATTERNFLOWTCPCTLRSTCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWTCPCTLRSTCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWTCPCTLRST_CHOICE.containing_type = _PATTERNFLOWTCPCTLRST
_PATTERNFLOWTCPCTLRST_CHOICE_ENUM.containing_type = _PATTERNFLOWTCPCTLRST_CHOICE
_PATTERNFLOWTCPCTLRST.fields_by_name['choice'].enum_type = _PATTERNFLOWTCPCTLRST_CHOICE_ENUM
_PATTERNFLOWTCPCTLRST.fields_by_name['increment'].message_type = _PATTERNFLOWTCPCTLRSTCOUNTER
_PATTERNFLOWTCPCTLRST.fields_by_name['decrement'].message_type = _PATTERNFLOWTCPCTLRSTCOUNTER
_PATTERNFLOWTCPCTLRST.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWTCPCTLRST.fields_by_name['choice'])
_PATTERNFLOWTCPCTLRST.fields_by_name['choice'].containing_oneof = _PATTERNFLOWTCPCTLRST.oneofs_by_name['_choice']
_PATTERNFLOWTCPCTLRST.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWTCPCTLRST.fields_by_name['value'])
_PATTERNFLOWTCPCTLRST.fields_by_name['value'].containing_oneof = _PATTERNFLOWTCPCTLRST.oneofs_by_name['_value']
_PATTERNFLOWTCPCTLRST.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWTCPCTLRST.fields_by_name['metric_group'])
_PATTERNFLOWTCPCTLRST.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWTCPCTLRST.oneofs_by_name['_metric_group']
_PATTERNFLOWTCPCTLRST.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWTCPCTLRST.fields_by_name['increment'])
_PATTERNFLOWTCPCTLRST.fields_by_name['increment'].containing_oneof = _PATTERNFLOWTCPCTLRST.oneofs_by_name['_increment']
_PATTERNFLOWTCPCTLRST.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWTCPCTLRST.fields_by_name['decrement'])
_PATTERNFLOWTCPCTLRST.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWTCPCTLRST.oneofs_by_name['_decrement']
_PATTERNFLOWTCPCTLSYNCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWTCPCTLSYNCOUNTER.fields_by_name['start'])
_PATTERNFLOWTCPCTLSYNCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWTCPCTLSYNCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWTCPCTLSYNCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWTCPCTLSYNCOUNTER.fields_by_name['step'])
_PATTERNFLOWTCPCTLSYNCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWTCPCTLSYNCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWTCPCTLSYNCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWTCPCTLSYNCOUNTER.fields_by_name['count'])
_PATTERNFLOWTCPCTLSYNCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWTCPCTLSYNCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWTCPCTLSYN_CHOICE.containing_type = _PATTERNFLOWTCPCTLSYN
_PATTERNFLOWTCPCTLSYN_CHOICE_ENUM.containing_type = _PATTERNFLOWTCPCTLSYN_CHOICE
_PATTERNFLOWTCPCTLSYN.fields_by_name['choice'].enum_type = _PATTERNFLOWTCPCTLSYN_CHOICE_ENUM
_PATTERNFLOWTCPCTLSYN.fields_by_name['increment'].message_type = _PATTERNFLOWTCPCTLSYNCOUNTER
_PATTERNFLOWTCPCTLSYN.fields_by_name['decrement'].message_type = _PATTERNFLOWTCPCTLSYNCOUNTER
_PATTERNFLOWTCPCTLSYN.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWTCPCTLSYN.fields_by_name['choice'])
_PATTERNFLOWTCPCTLSYN.fields_by_name['choice'].containing_oneof = _PATTERNFLOWTCPCTLSYN.oneofs_by_name['_choice']
_PATTERNFLOWTCPCTLSYN.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWTCPCTLSYN.fields_by_name['value'])
_PATTERNFLOWTCPCTLSYN.fields_by_name['value'].containing_oneof = _PATTERNFLOWTCPCTLSYN.oneofs_by_name['_value']
_PATTERNFLOWTCPCTLSYN.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWTCPCTLSYN.fields_by_name['metric_group'])
_PATTERNFLOWTCPCTLSYN.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWTCPCTLSYN.oneofs_by_name['_metric_group']
_PATTERNFLOWTCPCTLSYN.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWTCPCTLSYN.fields_by_name['increment'])
_PATTERNFLOWTCPCTLSYN.fields_by_name['increment'].containing_oneof = _PATTERNFLOWTCPCTLSYN.oneofs_by_name['_increment']
_PATTERNFLOWTCPCTLSYN.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWTCPCTLSYN.fields_by_name['decrement'])
_PATTERNFLOWTCPCTLSYN.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWTCPCTLSYN.oneofs_by_name['_decrement']
_PATTERNFLOWTCPCTLFINCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWTCPCTLFINCOUNTER.fields_by_name['start'])
_PATTERNFLOWTCPCTLFINCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWTCPCTLFINCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWTCPCTLFINCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWTCPCTLFINCOUNTER.fields_by_name['step'])
_PATTERNFLOWTCPCTLFINCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWTCPCTLFINCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWTCPCTLFINCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWTCPCTLFINCOUNTER.fields_by_name['count'])
_PATTERNFLOWTCPCTLFINCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWTCPCTLFINCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWTCPCTLFIN_CHOICE.containing_type = _PATTERNFLOWTCPCTLFIN
_PATTERNFLOWTCPCTLFIN_CHOICE_ENUM.containing_type = _PATTERNFLOWTCPCTLFIN_CHOICE
_PATTERNFLOWTCPCTLFIN.fields_by_name['choice'].enum_type = _PATTERNFLOWTCPCTLFIN_CHOICE_ENUM
_PATTERNFLOWTCPCTLFIN.fields_by_name['increment'].message_type = _PATTERNFLOWTCPCTLFINCOUNTER
_PATTERNFLOWTCPCTLFIN.fields_by_name['decrement'].message_type = _PATTERNFLOWTCPCTLFINCOUNTER
_PATTERNFLOWTCPCTLFIN.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWTCPCTLFIN.fields_by_name['choice'])
_PATTERNFLOWTCPCTLFIN.fields_by_name['choice'].containing_oneof = _PATTERNFLOWTCPCTLFIN.oneofs_by_name['_choice']
_PATTERNFLOWTCPCTLFIN.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWTCPCTLFIN.fields_by_name['value'])
_PATTERNFLOWTCPCTLFIN.fields_by_name['value'].containing_oneof = _PATTERNFLOWTCPCTLFIN.oneofs_by_name['_value']
_PATTERNFLOWTCPCTLFIN.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWTCPCTLFIN.fields_by_name['metric_group'])
_PATTERNFLOWTCPCTLFIN.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWTCPCTLFIN.oneofs_by_name['_metric_group']
_PATTERNFLOWTCPCTLFIN.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWTCPCTLFIN.fields_by_name['increment'])
_PATTERNFLOWTCPCTLFIN.fields_by_name['increment'].containing_oneof = _PATTERNFLOWTCPCTLFIN.oneofs_by_name['_increment']
_PATTERNFLOWTCPCTLFIN.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWTCPCTLFIN.fields_by_name['decrement'])
_PATTERNFLOWTCPCTLFIN.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWTCPCTLFIN.oneofs_by_name['_decrement']
_PATTERNFLOWTCPWINDOWCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWTCPWINDOWCOUNTER.fields_by_name['start'])
_PATTERNFLOWTCPWINDOWCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWTCPWINDOWCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWTCPWINDOWCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWTCPWINDOWCOUNTER.fields_by_name['step'])
_PATTERNFLOWTCPWINDOWCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWTCPWINDOWCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWTCPWINDOWCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWTCPWINDOWCOUNTER.fields_by_name['count'])
_PATTERNFLOWTCPWINDOWCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWTCPWINDOWCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWTCPWINDOW_CHOICE.containing_type = _PATTERNFLOWTCPWINDOW
_PATTERNFLOWTCPWINDOW_CHOICE_ENUM.containing_type = _PATTERNFLOWTCPWINDOW_CHOICE
_PATTERNFLOWTCPWINDOW.fields_by_name['choice'].enum_type = _PATTERNFLOWTCPWINDOW_CHOICE_ENUM
_PATTERNFLOWTCPWINDOW.fields_by_name['increment'].message_type = _PATTERNFLOWTCPWINDOWCOUNTER
_PATTERNFLOWTCPWINDOW.fields_by_name['decrement'].message_type = _PATTERNFLOWTCPWINDOWCOUNTER
_PATTERNFLOWTCPWINDOW.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWTCPWINDOW.fields_by_name['choice'])
_PATTERNFLOWTCPWINDOW.fields_by_name['choice'].containing_oneof = _PATTERNFLOWTCPWINDOW.oneofs_by_name['_choice']
_PATTERNFLOWTCPWINDOW.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWTCPWINDOW.fields_by_name['value'])
_PATTERNFLOWTCPWINDOW.fields_by_name['value'].containing_oneof = _PATTERNFLOWTCPWINDOW.oneofs_by_name['_value']
_PATTERNFLOWTCPWINDOW.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWTCPWINDOW.fields_by_name['metric_group'])
_PATTERNFLOWTCPWINDOW.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWTCPWINDOW.oneofs_by_name['_metric_group']
_PATTERNFLOWTCPWINDOW.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWTCPWINDOW.fields_by_name['increment'])
_PATTERNFLOWTCPWINDOW.fields_by_name['increment'].containing_oneof = _PATTERNFLOWTCPWINDOW.oneofs_by_name['_increment']
_PATTERNFLOWTCPWINDOW.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWTCPWINDOW.fields_by_name['decrement'])
_PATTERNFLOWTCPWINDOW.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWTCPWINDOW.oneofs_by_name['_decrement']
_PATTERNFLOWUDPSRCPORTCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWUDPSRCPORTCOUNTER.fields_by_name['start'])
_PATTERNFLOWUDPSRCPORTCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWUDPSRCPORTCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWUDPSRCPORTCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWUDPSRCPORTCOUNTER.fields_by_name['step'])
_PATTERNFLOWUDPSRCPORTCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWUDPSRCPORTCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWUDPSRCPORTCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWUDPSRCPORTCOUNTER.fields_by_name['count'])
_PATTERNFLOWUDPSRCPORTCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWUDPSRCPORTCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWUDPSRCPORT_CHOICE.containing_type = _PATTERNFLOWUDPSRCPORT
_PATTERNFLOWUDPSRCPORT_CHOICE_ENUM.containing_type = _PATTERNFLOWUDPSRCPORT_CHOICE
_PATTERNFLOWUDPSRCPORT.fields_by_name['choice'].enum_type = _PATTERNFLOWUDPSRCPORT_CHOICE_ENUM
_PATTERNFLOWUDPSRCPORT.fields_by_name['increment'].message_type = _PATTERNFLOWUDPSRCPORTCOUNTER
_PATTERNFLOWUDPSRCPORT.fields_by_name['decrement'].message_type = _PATTERNFLOWUDPSRCPORTCOUNTER
_PATTERNFLOWUDPSRCPORT.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWUDPSRCPORT.fields_by_name['choice'])
_PATTERNFLOWUDPSRCPORT.fields_by_name['choice'].containing_oneof = _PATTERNFLOWUDPSRCPORT.oneofs_by_name['_choice']
_PATTERNFLOWUDPSRCPORT.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWUDPSRCPORT.fields_by_name['value'])
_PATTERNFLOWUDPSRCPORT.fields_by_name['value'].containing_oneof = _PATTERNFLOWUDPSRCPORT.oneofs_by_name['_value']
_PATTERNFLOWUDPSRCPORT.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWUDPSRCPORT.fields_by_name['metric_group'])
_PATTERNFLOWUDPSRCPORT.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWUDPSRCPORT.oneofs_by_name['_metric_group']
_PATTERNFLOWUDPSRCPORT.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWUDPSRCPORT.fields_by_name['increment'])
_PATTERNFLOWUDPSRCPORT.fields_by_name['increment'].containing_oneof = _PATTERNFLOWUDPSRCPORT.oneofs_by_name['_increment']
_PATTERNFLOWUDPSRCPORT.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWUDPSRCPORT.fields_by_name['decrement'])
_PATTERNFLOWUDPSRCPORT.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWUDPSRCPORT.oneofs_by_name['_decrement']
_PATTERNFLOWUDPDSTPORTCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWUDPDSTPORTCOUNTER.fields_by_name['start'])
_PATTERNFLOWUDPDSTPORTCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWUDPDSTPORTCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWUDPDSTPORTCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWUDPDSTPORTCOUNTER.fields_by_name['step'])
_PATTERNFLOWUDPDSTPORTCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWUDPDSTPORTCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWUDPDSTPORTCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWUDPDSTPORTCOUNTER.fields_by_name['count'])
_PATTERNFLOWUDPDSTPORTCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWUDPDSTPORTCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWUDPDSTPORT_CHOICE.containing_type = _PATTERNFLOWUDPDSTPORT
_PATTERNFLOWUDPDSTPORT_CHOICE_ENUM.containing_type = _PATTERNFLOWUDPDSTPORT_CHOICE
_PATTERNFLOWUDPDSTPORT.fields_by_name['choice'].enum_type = _PATTERNFLOWUDPDSTPORT_CHOICE_ENUM
_PATTERNFLOWUDPDSTPORT.fields_by_name['increment'].message_type = _PATTERNFLOWUDPDSTPORTCOUNTER
_PATTERNFLOWUDPDSTPORT.fields_by_name['decrement'].message_type = _PATTERNFLOWUDPDSTPORTCOUNTER
_PATTERNFLOWUDPDSTPORT.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWUDPDSTPORT.fields_by_name['choice'])
_PATTERNFLOWUDPDSTPORT.fields_by_name['choice'].containing_oneof = _PATTERNFLOWUDPDSTPORT.oneofs_by_name['_choice']
_PATTERNFLOWUDPDSTPORT.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWUDPDSTPORT.fields_by_name['value'])
_PATTERNFLOWUDPDSTPORT.fields_by_name['value'].containing_oneof = _PATTERNFLOWUDPDSTPORT.oneofs_by_name['_value']
_PATTERNFLOWUDPDSTPORT.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWUDPDSTPORT.fields_by_name['metric_group'])
_PATTERNFLOWUDPDSTPORT.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWUDPDSTPORT.oneofs_by_name['_metric_group']
_PATTERNFLOWUDPDSTPORT.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWUDPDSTPORT.fields_by_name['increment'])
_PATTERNFLOWUDPDSTPORT.fields_by_name['increment'].containing_oneof = _PATTERNFLOWUDPDSTPORT.oneofs_by_name['_increment']
_PATTERNFLOWUDPDSTPORT.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWUDPDSTPORT.fields_by_name['decrement'])
_PATTERNFLOWUDPDSTPORT.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWUDPDSTPORT.oneofs_by_name['_decrement']
_PATTERNFLOWUDPLENGTHCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWUDPLENGTHCOUNTER.fields_by_name['start'])
_PATTERNFLOWUDPLENGTHCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWUDPLENGTHCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWUDPLENGTHCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWUDPLENGTHCOUNTER.fields_by_name['step'])
_PATTERNFLOWUDPLENGTHCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWUDPLENGTHCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWUDPLENGTHCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWUDPLENGTHCOUNTER.fields_by_name['count'])
_PATTERNFLOWUDPLENGTHCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWUDPLENGTHCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWUDPLENGTH_CHOICE.containing_type = _PATTERNFLOWUDPLENGTH
_PATTERNFLOWUDPLENGTH_CHOICE_ENUM.containing_type = _PATTERNFLOWUDPLENGTH_CHOICE
_PATTERNFLOWUDPLENGTH.fields_by_name['choice'].enum_type = _PATTERNFLOWUDPLENGTH_CHOICE_ENUM
_PATTERNFLOWUDPLENGTH.fields_by_name['increment'].message_type = _PATTERNFLOWUDPLENGTHCOUNTER
_PATTERNFLOWUDPLENGTH.fields_by_name['decrement'].message_type = _PATTERNFLOWUDPLENGTHCOUNTER
_PATTERNFLOWUDPLENGTH.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWUDPLENGTH.fields_by_name['choice'])
_PATTERNFLOWUDPLENGTH.fields_by_name['choice'].containing_oneof = _PATTERNFLOWUDPLENGTH.oneofs_by_name['_choice']
_PATTERNFLOWUDPLENGTH.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWUDPLENGTH.fields_by_name['value'])
_PATTERNFLOWUDPLENGTH.fields_by_name['value'].containing_oneof = _PATTERNFLOWUDPLENGTH.oneofs_by_name['_value']
_PATTERNFLOWUDPLENGTH.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWUDPLENGTH.fields_by_name['metric_group'])
_PATTERNFLOWUDPLENGTH.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWUDPLENGTH.oneofs_by_name['_metric_group']
_PATTERNFLOWUDPLENGTH.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWUDPLENGTH.fields_by_name['increment'])
_PATTERNFLOWUDPLENGTH.fields_by_name['increment'].containing_oneof = _PATTERNFLOWUDPLENGTH.oneofs_by_name['_increment']
_PATTERNFLOWUDPLENGTH.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWUDPLENGTH.fields_by_name['decrement'])
_PATTERNFLOWUDPLENGTH.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWUDPLENGTH.oneofs_by_name['_decrement']
_PATTERNFLOWUDPCHECKSUM_CHOICE.containing_type = _PATTERNFLOWUDPCHECKSUM
_PATTERNFLOWUDPCHECKSUM_CHOICE_ENUM.containing_type = _PATTERNFLOWUDPCHECKSUM_CHOICE
_PATTERNFLOWUDPCHECKSUM_GENERATED.containing_type = _PATTERNFLOWUDPCHECKSUM
_PATTERNFLOWUDPCHECKSUM_GENERATED_ENUM.containing_type = _PATTERNFLOWUDPCHECKSUM_GENERATED
_PATTERNFLOWUDPCHECKSUM.fields_by_name['choice'].enum_type = _PATTERNFLOWUDPCHECKSUM_CHOICE_ENUM
_PATTERNFLOWUDPCHECKSUM.fields_by_name['generated'].enum_type = _PATTERNFLOWUDPCHECKSUM_GENERATED_ENUM
_PATTERNFLOWUDPCHECKSUM.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWUDPCHECKSUM.fields_by_name['choice'])
_PATTERNFLOWUDPCHECKSUM.fields_by_name['choice'].containing_oneof = _PATTERNFLOWUDPCHECKSUM.oneofs_by_name['_choice']
_PATTERNFLOWUDPCHECKSUM.oneofs_by_name['_generated'].fields.append(
  _PATTERNFLOWUDPCHECKSUM.fields_by_name['generated'])
_PATTERNFLOWUDPCHECKSUM.fields_by_name['generated'].containing_oneof = _PATTERNFLOWUDPCHECKSUM.oneofs_by_name['_generated']
_PATTERNFLOWUDPCHECKSUM.oneofs_by_name['_custom'].fields.append(
  _PATTERNFLOWUDPCHECKSUM.fields_by_name['custom'])
_PATTERNFLOWUDPCHECKSUM.fields_by_name['custom'].containing_oneof = _PATTERNFLOWUDPCHECKSUM.oneofs_by_name['_custom']
_PATTERNFLOWGRECHECKSUMPRESENTCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWGRECHECKSUMPRESENTCOUNTER.fields_by_name['start'])
_PATTERNFLOWGRECHECKSUMPRESENTCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWGRECHECKSUMPRESENTCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWGRECHECKSUMPRESENTCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWGRECHECKSUMPRESENTCOUNTER.fields_by_name['step'])
_PATTERNFLOWGRECHECKSUMPRESENTCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWGRECHECKSUMPRESENTCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWGRECHECKSUMPRESENTCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWGRECHECKSUMPRESENTCOUNTER.fields_by_name['count'])
_PATTERNFLOWGRECHECKSUMPRESENTCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWGRECHECKSUMPRESENTCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWGRECHECKSUMPRESENT_CHOICE.containing_type = _PATTERNFLOWGRECHECKSUMPRESENT
_PATTERNFLOWGRECHECKSUMPRESENT_CHOICE_ENUM.containing_type = _PATTERNFLOWGRECHECKSUMPRESENT_CHOICE
_PATTERNFLOWGRECHECKSUMPRESENT.fields_by_name['choice'].enum_type = _PATTERNFLOWGRECHECKSUMPRESENT_CHOICE_ENUM
_PATTERNFLOWGRECHECKSUMPRESENT.fields_by_name['increment'].message_type = _PATTERNFLOWGRECHECKSUMPRESENTCOUNTER
_PATTERNFLOWGRECHECKSUMPRESENT.fields_by_name['decrement'].message_type = _PATTERNFLOWGRECHECKSUMPRESENTCOUNTER
_PATTERNFLOWGRECHECKSUMPRESENT.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWGRECHECKSUMPRESENT.fields_by_name['choice'])
_PATTERNFLOWGRECHECKSUMPRESENT.fields_by_name['choice'].containing_oneof = _PATTERNFLOWGRECHECKSUMPRESENT.oneofs_by_name['_choice']
_PATTERNFLOWGRECHECKSUMPRESENT.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWGRECHECKSUMPRESENT.fields_by_name['value'])
_PATTERNFLOWGRECHECKSUMPRESENT.fields_by_name['value'].containing_oneof = _PATTERNFLOWGRECHECKSUMPRESENT.oneofs_by_name['_value']
_PATTERNFLOWGRECHECKSUMPRESENT.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWGRECHECKSUMPRESENT.fields_by_name['metric_group'])
_PATTERNFLOWGRECHECKSUMPRESENT.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWGRECHECKSUMPRESENT.oneofs_by_name['_metric_group']
_PATTERNFLOWGRECHECKSUMPRESENT.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWGRECHECKSUMPRESENT.fields_by_name['increment'])
_PATTERNFLOWGRECHECKSUMPRESENT.fields_by_name['increment'].containing_oneof = _PATTERNFLOWGRECHECKSUMPRESENT.oneofs_by_name['_increment']
_PATTERNFLOWGRECHECKSUMPRESENT.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWGRECHECKSUMPRESENT.fields_by_name['decrement'])
_PATTERNFLOWGRECHECKSUMPRESENT.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWGRECHECKSUMPRESENT.oneofs_by_name['_decrement']
_PATTERNFLOWGRERESERVED0COUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWGRERESERVED0COUNTER.fields_by_name['start'])
_PATTERNFLOWGRERESERVED0COUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWGRERESERVED0COUNTER.oneofs_by_name['_start']
_PATTERNFLOWGRERESERVED0COUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWGRERESERVED0COUNTER.fields_by_name['step'])
_PATTERNFLOWGRERESERVED0COUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWGRERESERVED0COUNTER.oneofs_by_name['_step']
_PATTERNFLOWGRERESERVED0COUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWGRERESERVED0COUNTER.fields_by_name['count'])
_PATTERNFLOWGRERESERVED0COUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWGRERESERVED0COUNTER.oneofs_by_name['_count']
_PATTERNFLOWGRERESERVED0_CHOICE.containing_type = _PATTERNFLOWGRERESERVED0
_PATTERNFLOWGRERESERVED0_CHOICE_ENUM.containing_type = _PATTERNFLOWGRERESERVED0_CHOICE
_PATTERNFLOWGRERESERVED0.fields_by_name['choice'].enum_type = _PATTERNFLOWGRERESERVED0_CHOICE_ENUM
_PATTERNFLOWGRERESERVED0.fields_by_name['increment'].message_type = _PATTERNFLOWGRERESERVED0COUNTER
_PATTERNFLOWGRERESERVED0.fields_by_name['decrement'].message_type = _PATTERNFLOWGRERESERVED0COUNTER
_PATTERNFLOWGRERESERVED0.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWGRERESERVED0.fields_by_name['choice'])
_PATTERNFLOWGRERESERVED0.fields_by_name['choice'].containing_oneof = _PATTERNFLOWGRERESERVED0.oneofs_by_name['_choice']
_PATTERNFLOWGRERESERVED0.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWGRERESERVED0.fields_by_name['value'])
_PATTERNFLOWGRERESERVED0.fields_by_name['value'].containing_oneof = _PATTERNFLOWGRERESERVED0.oneofs_by_name['_value']
_PATTERNFLOWGRERESERVED0.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWGRERESERVED0.fields_by_name['metric_group'])
_PATTERNFLOWGRERESERVED0.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWGRERESERVED0.oneofs_by_name['_metric_group']
_PATTERNFLOWGRERESERVED0.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWGRERESERVED0.fields_by_name['increment'])
_PATTERNFLOWGRERESERVED0.fields_by_name['increment'].containing_oneof = _PATTERNFLOWGRERESERVED0.oneofs_by_name['_increment']
_PATTERNFLOWGRERESERVED0.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWGRERESERVED0.fields_by_name['decrement'])
_PATTERNFLOWGRERESERVED0.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWGRERESERVED0.oneofs_by_name['_decrement']
_PATTERNFLOWGREVERSIONCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWGREVERSIONCOUNTER.fields_by_name['start'])
_PATTERNFLOWGREVERSIONCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWGREVERSIONCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWGREVERSIONCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWGREVERSIONCOUNTER.fields_by_name['step'])
_PATTERNFLOWGREVERSIONCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWGREVERSIONCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWGREVERSIONCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWGREVERSIONCOUNTER.fields_by_name['count'])
_PATTERNFLOWGREVERSIONCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWGREVERSIONCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWGREVERSION_CHOICE.containing_type = _PATTERNFLOWGREVERSION
_PATTERNFLOWGREVERSION_CHOICE_ENUM.containing_type = _PATTERNFLOWGREVERSION_CHOICE
_PATTERNFLOWGREVERSION.fields_by_name['choice'].enum_type = _PATTERNFLOWGREVERSION_CHOICE_ENUM
_PATTERNFLOWGREVERSION.fields_by_name['increment'].message_type = _PATTERNFLOWGREVERSIONCOUNTER
_PATTERNFLOWGREVERSION.fields_by_name['decrement'].message_type = _PATTERNFLOWGREVERSIONCOUNTER
_PATTERNFLOWGREVERSION.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWGREVERSION.fields_by_name['choice'])
_PATTERNFLOWGREVERSION.fields_by_name['choice'].containing_oneof = _PATTERNFLOWGREVERSION.oneofs_by_name['_choice']
_PATTERNFLOWGREVERSION.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWGREVERSION.fields_by_name['value'])
_PATTERNFLOWGREVERSION.fields_by_name['value'].containing_oneof = _PATTERNFLOWGREVERSION.oneofs_by_name['_value']
_PATTERNFLOWGREVERSION.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWGREVERSION.fields_by_name['metric_group'])
_PATTERNFLOWGREVERSION.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWGREVERSION.oneofs_by_name['_metric_group']
_PATTERNFLOWGREVERSION.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWGREVERSION.fields_by_name['increment'])
_PATTERNFLOWGREVERSION.fields_by_name['increment'].containing_oneof = _PATTERNFLOWGREVERSION.oneofs_by_name['_increment']
_PATTERNFLOWGREVERSION.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWGREVERSION.fields_by_name['decrement'])
_PATTERNFLOWGREVERSION.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWGREVERSION.oneofs_by_name['_decrement']
_PATTERNFLOWGREPROTOCOLCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWGREPROTOCOLCOUNTER.fields_by_name['start'])
_PATTERNFLOWGREPROTOCOLCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWGREPROTOCOLCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWGREPROTOCOLCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWGREPROTOCOLCOUNTER.fields_by_name['step'])
_PATTERNFLOWGREPROTOCOLCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWGREPROTOCOLCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWGREPROTOCOLCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWGREPROTOCOLCOUNTER.fields_by_name['count'])
_PATTERNFLOWGREPROTOCOLCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWGREPROTOCOLCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWGREPROTOCOL_CHOICE.containing_type = _PATTERNFLOWGREPROTOCOL
_PATTERNFLOWGREPROTOCOL_CHOICE_ENUM.containing_type = _PATTERNFLOWGREPROTOCOL_CHOICE
_PATTERNFLOWGREPROTOCOL.fields_by_name['choice'].enum_type = _PATTERNFLOWGREPROTOCOL_CHOICE_ENUM
_PATTERNFLOWGREPROTOCOL.fields_by_name['increment'].message_type = _PATTERNFLOWGREPROTOCOLCOUNTER
_PATTERNFLOWGREPROTOCOL.fields_by_name['decrement'].message_type = _PATTERNFLOWGREPROTOCOLCOUNTER
_PATTERNFLOWGREPROTOCOL.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWGREPROTOCOL.fields_by_name['choice'])
_PATTERNFLOWGREPROTOCOL.fields_by_name['choice'].containing_oneof = _PATTERNFLOWGREPROTOCOL.oneofs_by_name['_choice']
_PATTERNFLOWGREPROTOCOL.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWGREPROTOCOL.fields_by_name['value'])
_PATTERNFLOWGREPROTOCOL.fields_by_name['value'].containing_oneof = _PATTERNFLOWGREPROTOCOL.oneofs_by_name['_value']
_PATTERNFLOWGREPROTOCOL.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWGREPROTOCOL.fields_by_name['metric_group'])
_PATTERNFLOWGREPROTOCOL.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWGREPROTOCOL.oneofs_by_name['_metric_group']
_PATTERNFLOWGREPROTOCOL.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWGREPROTOCOL.fields_by_name['increment'])
_PATTERNFLOWGREPROTOCOL.fields_by_name['increment'].containing_oneof = _PATTERNFLOWGREPROTOCOL.oneofs_by_name['_increment']
_PATTERNFLOWGREPROTOCOL.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWGREPROTOCOL.fields_by_name['decrement'])
_PATTERNFLOWGREPROTOCOL.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWGREPROTOCOL.oneofs_by_name['_decrement']
_PATTERNFLOWGRECHECKSUM_CHOICE.containing_type = _PATTERNFLOWGRECHECKSUM
_PATTERNFLOWGRECHECKSUM_CHOICE_ENUM.containing_type = _PATTERNFLOWGRECHECKSUM_CHOICE
_PATTERNFLOWGRECHECKSUM_GENERATED.containing_type = _PATTERNFLOWGRECHECKSUM
_PATTERNFLOWGRECHECKSUM_GENERATED_ENUM.containing_type = _PATTERNFLOWGRECHECKSUM_GENERATED
_PATTERNFLOWGRECHECKSUM.fields_by_name['choice'].enum_type = _PATTERNFLOWGRECHECKSUM_CHOICE_ENUM
_PATTERNFLOWGRECHECKSUM.fields_by_name['generated'].enum_type = _PATTERNFLOWGRECHECKSUM_GENERATED_ENUM
_PATTERNFLOWGRECHECKSUM.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWGRECHECKSUM.fields_by_name['choice'])
_PATTERNFLOWGRECHECKSUM.fields_by_name['choice'].containing_oneof = _PATTERNFLOWGRECHECKSUM.oneofs_by_name['_choice']
_PATTERNFLOWGRECHECKSUM.oneofs_by_name['_generated'].fields.append(
  _PATTERNFLOWGRECHECKSUM.fields_by_name['generated'])
_PATTERNFLOWGRECHECKSUM.fields_by_name['generated'].containing_oneof = _PATTERNFLOWGRECHECKSUM.oneofs_by_name['_generated']
_PATTERNFLOWGRECHECKSUM.oneofs_by_name['_custom'].fields.append(
  _PATTERNFLOWGRECHECKSUM.fields_by_name['custom'])
_PATTERNFLOWGRECHECKSUM.fields_by_name['custom'].containing_oneof = _PATTERNFLOWGRECHECKSUM.oneofs_by_name['_custom']
_PATTERNFLOWGRERESERVED1COUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWGRERESERVED1COUNTER.fields_by_name['start'])
_PATTERNFLOWGRERESERVED1COUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWGRERESERVED1COUNTER.oneofs_by_name['_start']
_PATTERNFLOWGRERESERVED1COUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWGRERESERVED1COUNTER.fields_by_name['step'])
_PATTERNFLOWGRERESERVED1COUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWGRERESERVED1COUNTER.oneofs_by_name['_step']
_PATTERNFLOWGRERESERVED1COUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWGRERESERVED1COUNTER.fields_by_name['count'])
_PATTERNFLOWGRERESERVED1COUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWGRERESERVED1COUNTER.oneofs_by_name['_count']
_PATTERNFLOWGRERESERVED1_CHOICE.containing_type = _PATTERNFLOWGRERESERVED1
_PATTERNFLOWGRERESERVED1_CHOICE_ENUM.containing_type = _PATTERNFLOWGRERESERVED1_CHOICE
_PATTERNFLOWGRERESERVED1.fields_by_name['choice'].enum_type = _PATTERNFLOWGRERESERVED1_CHOICE_ENUM
_PATTERNFLOWGRERESERVED1.fields_by_name['increment'].message_type = _PATTERNFLOWGRERESERVED1COUNTER
_PATTERNFLOWGRERESERVED1.fields_by_name['decrement'].message_type = _PATTERNFLOWGRERESERVED1COUNTER
_PATTERNFLOWGRERESERVED1.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWGRERESERVED1.fields_by_name['choice'])
_PATTERNFLOWGRERESERVED1.fields_by_name['choice'].containing_oneof = _PATTERNFLOWGRERESERVED1.oneofs_by_name['_choice']
_PATTERNFLOWGRERESERVED1.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWGRERESERVED1.fields_by_name['value'])
_PATTERNFLOWGRERESERVED1.fields_by_name['value'].containing_oneof = _PATTERNFLOWGRERESERVED1.oneofs_by_name['_value']
_PATTERNFLOWGRERESERVED1.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWGRERESERVED1.fields_by_name['metric_group'])
_PATTERNFLOWGRERESERVED1.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWGRERESERVED1.oneofs_by_name['_metric_group']
_PATTERNFLOWGRERESERVED1.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWGRERESERVED1.fields_by_name['increment'])
_PATTERNFLOWGRERESERVED1.fields_by_name['increment'].containing_oneof = _PATTERNFLOWGRERESERVED1.oneofs_by_name['_increment']
_PATTERNFLOWGRERESERVED1.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWGRERESERVED1.fields_by_name['decrement'])
_PATTERNFLOWGRERESERVED1.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWGRERESERVED1.oneofs_by_name['_decrement']
_PATTERNFLOWGTPV1VERSIONCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWGTPV1VERSIONCOUNTER.fields_by_name['start'])
_PATTERNFLOWGTPV1VERSIONCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWGTPV1VERSIONCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWGTPV1VERSIONCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWGTPV1VERSIONCOUNTER.fields_by_name['step'])
_PATTERNFLOWGTPV1VERSIONCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWGTPV1VERSIONCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWGTPV1VERSIONCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWGTPV1VERSIONCOUNTER.fields_by_name['count'])
_PATTERNFLOWGTPV1VERSIONCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWGTPV1VERSIONCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWGTPV1VERSION_CHOICE.containing_type = _PATTERNFLOWGTPV1VERSION
_PATTERNFLOWGTPV1VERSION_CHOICE_ENUM.containing_type = _PATTERNFLOWGTPV1VERSION_CHOICE
_PATTERNFLOWGTPV1VERSION.fields_by_name['choice'].enum_type = _PATTERNFLOWGTPV1VERSION_CHOICE_ENUM
_PATTERNFLOWGTPV1VERSION.fields_by_name['increment'].message_type = _PATTERNFLOWGTPV1VERSIONCOUNTER
_PATTERNFLOWGTPV1VERSION.fields_by_name['decrement'].message_type = _PATTERNFLOWGTPV1VERSIONCOUNTER
_PATTERNFLOWGTPV1VERSION.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWGTPV1VERSION.fields_by_name['choice'])
_PATTERNFLOWGTPV1VERSION.fields_by_name['choice'].containing_oneof = _PATTERNFLOWGTPV1VERSION.oneofs_by_name['_choice']
_PATTERNFLOWGTPV1VERSION.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWGTPV1VERSION.fields_by_name['value'])
_PATTERNFLOWGTPV1VERSION.fields_by_name['value'].containing_oneof = _PATTERNFLOWGTPV1VERSION.oneofs_by_name['_value']
_PATTERNFLOWGTPV1VERSION.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWGTPV1VERSION.fields_by_name['metric_group'])
_PATTERNFLOWGTPV1VERSION.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWGTPV1VERSION.oneofs_by_name['_metric_group']
_PATTERNFLOWGTPV1VERSION.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWGTPV1VERSION.fields_by_name['increment'])
_PATTERNFLOWGTPV1VERSION.fields_by_name['increment'].containing_oneof = _PATTERNFLOWGTPV1VERSION.oneofs_by_name['_increment']
_PATTERNFLOWGTPV1VERSION.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWGTPV1VERSION.fields_by_name['decrement'])
_PATTERNFLOWGTPV1VERSION.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWGTPV1VERSION.oneofs_by_name['_decrement']
_PATTERNFLOWGTPV1PROTOCOLTYPECOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWGTPV1PROTOCOLTYPECOUNTER.fields_by_name['start'])
_PATTERNFLOWGTPV1PROTOCOLTYPECOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWGTPV1PROTOCOLTYPECOUNTER.oneofs_by_name['_start']
_PATTERNFLOWGTPV1PROTOCOLTYPECOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWGTPV1PROTOCOLTYPECOUNTER.fields_by_name['step'])
_PATTERNFLOWGTPV1PROTOCOLTYPECOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWGTPV1PROTOCOLTYPECOUNTER.oneofs_by_name['_step']
_PATTERNFLOWGTPV1PROTOCOLTYPECOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWGTPV1PROTOCOLTYPECOUNTER.fields_by_name['count'])
_PATTERNFLOWGTPV1PROTOCOLTYPECOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWGTPV1PROTOCOLTYPECOUNTER.oneofs_by_name['_count']
_PATTERNFLOWGTPV1PROTOCOLTYPE_CHOICE.containing_type = _PATTERNFLOWGTPV1PROTOCOLTYPE
_PATTERNFLOWGTPV1PROTOCOLTYPE_CHOICE_ENUM.containing_type = _PATTERNFLOWGTPV1PROTOCOLTYPE_CHOICE
_PATTERNFLOWGTPV1PROTOCOLTYPE.fields_by_name['choice'].enum_type = _PATTERNFLOWGTPV1PROTOCOLTYPE_CHOICE_ENUM
_PATTERNFLOWGTPV1PROTOCOLTYPE.fields_by_name['increment'].message_type = _PATTERNFLOWGTPV1PROTOCOLTYPECOUNTER
_PATTERNFLOWGTPV1PROTOCOLTYPE.fields_by_name['decrement'].message_type = _PATTERNFLOWGTPV1PROTOCOLTYPECOUNTER
_PATTERNFLOWGTPV1PROTOCOLTYPE.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWGTPV1PROTOCOLTYPE.fields_by_name['choice'])
_PATTERNFLOWGTPV1PROTOCOLTYPE.fields_by_name['choice'].containing_oneof = _PATTERNFLOWGTPV1PROTOCOLTYPE.oneofs_by_name['_choice']
_PATTERNFLOWGTPV1PROTOCOLTYPE.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWGTPV1PROTOCOLTYPE.fields_by_name['value'])
_PATTERNFLOWGTPV1PROTOCOLTYPE.fields_by_name['value'].containing_oneof = _PATTERNFLOWGTPV1PROTOCOLTYPE.oneofs_by_name['_value']
_PATTERNFLOWGTPV1PROTOCOLTYPE.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWGTPV1PROTOCOLTYPE.fields_by_name['metric_group'])
_PATTERNFLOWGTPV1PROTOCOLTYPE.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWGTPV1PROTOCOLTYPE.oneofs_by_name['_metric_group']
_PATTERNFLOWGTPV1PROTOCOLTYPE.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWGTPV1PROTOCOLTYPE.fields_by_name['increment'])
_PATTERNFLOWGTPV1PROTOCOLTYPE.fields_by_name['increment'].containing_oneof = _PATTERNFLOWGTPV1PROTOCOLTYPE.oneofs_by_name['_increment']
_PATTERNFLOWGTPV1PROTOCOLTYPE.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWGTPV1PROTOCOLTYPE.fields_by_name['decrement'])
_PATTERNFLOWGTPV1PROTOCOLTYPE.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWGTPV1PROTOCOLTYPE.oneofs_by_name['_decrement']
_PATTERNFLOWGTPV1RESERVEDCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWGTPV1RESERVEDCOUNTER.fields_by_name['start'])
_PATTERNFLOWGTPV1RESERVEDCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWGTPV1RESERVEDCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWGTPV1RESERVEDCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWGTPV1RESERVEDCOUNTER.fields_by_name['step'])
_PATTERNFLOWGTPV1RESERVEDCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWGTPV1RESERVEDCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWGTPV1RESERVEDCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWGTPV1RESERVEDCOUNTER.fields_by_name['count'])
_PATTERNFLOWGTPV1RESERVEDCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWGTPV1RESERVEDCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWGTPV1RESERVED_CHOICE.containing_type = _PATTERNFLOWGTPV1RESERVED
_PATTERNFLOWGTPV1RESERVED_CHOICE_ENUM.containing_type = _PATTERNFLOWGTPV1RESERVED_CHOICE
_PATTERNFLOWGTPV1RESERVED.fields_by_name['choice'].enum_type = _PATTERNFLOWGTPV1RESERVED_CHOICE_ENUM
_PATTERNFLOWGTPV1RESERVED.fields_by_name['increment'].message_type = _PATTERNFLOWGTPV1RESERVEDCOUNTER
_PATTERNFLOWGTPV1RESERVED.fields_by_name['decrement'].message_type = _PATTERNFLOWGTPV1RESERVEDCOUNTER
_PATTERNFLOWGTPV1RESERVED.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWGTPV1RESERVED.fields_by_name['choice'])
_PATTERNFLOWGTPV1RESERVED.fields_by_name['choice'].containing_oneof = _PATTERNFLOWGTPV1RESERVED.oneofs_by_name['_choice']
_PATTERNFLOWGTPV1RESERVED.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWGTPV1RESERVED.fields_by_name['value'])
_PATTERNFLOWGTPV1RESERVED.fields_by_name['value'].containing_oneof = _PATTERNFLOWGTPV1RESERVED.oneofs_by_name['_value']
_PATTERNFLOWGTPV1RESERVED.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWGTPV1RESERVED.fields_by_name['metric_group'])
_PATTERNFLOWGTPV1RESERVED.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWGTPV1RESERVED.oneofs_by_name['_metric_group']
_PATTERNFLOWGTPV1RESERVED.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWGTPV1RESERVED.fields_by_name['increment'])
_PATTERNFLOWGTPV1RESERVED.fields_by_name['increment'].containing_oneof = _PATTERNFLOWGTPV1RESERVED.oneofs_by_name['_increment']
_PATTERNFLOWGTPV1RESERVED.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWGTPV1RESERVED.fields_by_name['decrement'])
_PATTERNFLOWGTPV1RESERVED.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWGTPV1RESERVED.oneofs_by_name['_decrement']
_PATTERNFLOWGTPV1EFLAGCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWGTPV1EFLAGCOUNTER.fields_by_name['start'])
_PATTERNFLOWGTPV1EFLAGCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWGTPV1EFLAGCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWGTPV1EFLAGCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWGTPV1EFLAGCOUNTER.fields_by_name['step'])
_PATTERNFLOWGTPV1EFLAGCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWGTPV1EFLAGCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWGTPV1EFLAGCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWGTPV1EFLAGCOUNTER.fields_by_name['count'])
_PATTERNFLOWGTPV1EFLAGCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWGTPV1EFLAGCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWGTPV1EFLAG_CHOICE.containing_type = _PATTERNFLOWGTPV1EFLAG
_PATTERNFLOWGTPV1EFLAG_CHOICE_ENUM.containing_type = _PATTERNFLOWGTPV1EFLAG_CHOICE
_PATTERNFLOWGTPV1EFLAG.fields_by_name['choice'].enum_type = _PATTERNFLOWGTPV1EFLAG_CHOICE_ENUM
_PATTERNFLOWGTPV1EFLAG.fields_by_name['increment'].message_type = _PATTERNFLOWGTPV1EFLAGCOUNTER
_PATTERNFLOWGTPV1EFLAG.fields_by_name['decrement'].message_type = _PATTERNFLOWGTPV1EFLAGCOUNTER
_PATTERNFLOWGTPV1EFLAG.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWGTPV1EFLAG.fields_by_name['choice'])
_PATTERNFLOWGTPV1EFLAG.fields_by_name['choice'].containing_oneof = _PATTERNFLOWGTPV1EFLAG.oneofs_by_name['_choice']
_PATTERNFLOWGTPV1EFLAG.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWGTPV1EFLAG.fields_by_name['value'])
_PATTERNFLOWGTPV1EFLAG.fields_by_name['value'].containing_oneof = _PATTERNFLOWGTPV1EFLAG.oneofs_by_name['_value']
_PATTERNFLOWGTPV1EFLAG.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWGTPV1EFLAG.fields_by_name['metric_group'])
_PATTERNFLOWGTPV1EFLAG.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWGTPV1EFLAG.oneofs_by_name['_metric_group']
_PATTERNFLOWGTPV1EFLAG.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWGTPV1EFLAG.fields_by_name['increment'])
_PATTERNFLOWGTPV1EFLAG.fields_by_name['increment'].containing_oneof = _PATTERNFLOWGTPV1EFLAG.oneofs_by_name['_increment']
_PATTERNFLOWGTPV1EFLAG.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWGTPV1EFLAG.fields_by_name['decrement'])
_PATTERNFLOWGTPV1EFLAG.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWGTPV1EFLAG.oneofs_by_name['_decrement']
_PATTERNFLOWGTPV1SFLAGCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWGTPV1SFLAGCOUNTER.fields_by_name['start'])
_PATTERNFLOWGTPV1SFLAGCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWGTPV1SFLAGCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWGTPV1SFLAGCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWGTPV1SFLAGCOUNTER.fields_by_name['step'])
_PATTERNFLOWGTPV1SFLAGCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWGTPV1SFLAGCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWGTPV1SFLAGCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWGTPV1SFLAGCOUNTER.fields_by_name['count'])
_PATTERNFLOWGTPV1SFLAGCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWGTPV1SFLAGCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWGTPV1SFLAG_CHOICE.containing_type = _PATTERNFLOWGTPV1SFLAG
_PATTERNFLOWGTPV1SFLAG_CHOICE_ENUM.containing_type = _PATTERNFLOWGTPV1SFLAG_CHOICE
_PATTERNFLOWGTPV1SFLAG.fields_by_name['choice'].enum_type = _PATTERNFLOWGTPV1SFLAG_CHOICE_ENUM
_PATTERNFLOWGTPV1SFLAG.fields_by_name['increment'].message_type = _PATTERNFLOWGTPV1SFLAGCOUNTER
_PATTERNFLOWGTPV1SFLAG.fields_by_name['decrement'].message_type = _PATTERNFLOWGTPV1SFLAGCOUNTER
_PATTERNFLOWGTPV1SFLAG.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWGTPV1SFLAG.fields_by_name['choice'])
_PATTERNFLOWGTPV1SFLAG.fields_by_name['choice'].containing_oneof = _PATTERNFLOWGTPV1SFLAG.oneofs_by_name['_choice']
_PATTERNFLOWGTPV1SFLAG.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWGTPV1SFLAG.fields_by_name['value'])
_PATTERNFLOWGTPV1SFLAG.fields_by_name['value'].containing_oneof = _PATTERNFLOWGTPV1SFLAG.oneofs_by_name['_value']
_PATTERNFLOWGTPV1SFLAG.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWGTPV1SFLAG.fields_by_name['metric_group'])
_PATTERNFLOWGTPV1SFLAG.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWGTPV1SFLAG.oneofs_by_name['_metric_group']
_PATTERNFLOWGTPV1SFLAG.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWGTPV1SFLAG.fields_by_name['increment'])
_PATTERNFLOWGTPV1SFLAG.fields_by_name['increment'].containing_oneof = _PATTERNFLOWGTPV1SFLAG.oneofs_by_name['_increment']
_PATTERNFLOWGTPV1SFLAG.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWGTPV1SFLAG.fields_by_name['decrement'])
_PATTERNFLOWGTPV1SFLAG.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWGTPV1SFLAG.oneofs_by_name['_decrement']
_PATTERNFLOWGTPV1PNFLAGCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWGTPV1PNFLAGCOUNTER.fields_by_name['start'])
_PATTERNFLOWGTPV1PNFLAGCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWGTPV1PNFLAGCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWGTPV1PNFLAGCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWGTPV1PNFLAGCOUNTER.fields_by_name['step'])
_PATTERNFLOWGTPV1PNFLAGCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWGTPV1PNFLAGCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWGTPV1PNFLAGCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWGTPV1PNFLAGCOUNTER.fields_by_name['count'])
_PATTERNFLOWGTPV1PNFLAGCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWGTPV1PNFLAGCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWGTPV1PNFLAG_CHOICE.containing_type = _PATTERNFLOWGTPV1PNFLAG
_PATTERNFLOWGTPV1PNFLAG_CHOICE_ENUM.containing_type = _PATTERNFLOWGTPV1PNFLAG_CHOICE
_PATTERNFLOWGTPV1PNFLAG.fields_by_name['choice'].enum_type = _PATTERNFLOWGTPV1PNFLAG_CHOICE_ENUM
_PATTERNFLOWGTPV1PNFLAG.fields_by_name['increment'].message_type = _PATTERNFLOWGTPV1PNFLAGCOUNTER
_PATTERNFLOWGTPV1PNFLAG.fields_by_name['decrement'].message_type = _PATTERNFLOWGTPV1PNFLAGCOUNTER
_PATTERNFLOWGTPV1PNFLAG.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWGTPV1PNFLAG.fields_by_name['choice'])
_PATTERNFLOWGTPV1PNFLAG.fields_by_name['choice'].containing_oneof = _PATTERNFLOWGTPV1PNFLAG.oneofs_by_name['_choice']
_PATTERNFLOWGTPV1PNFLAG.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWGTPV1PNFLAG.fields_by_name['value'])
_PATTERNFLOWGTPV1PNFLAG.fields_by_name['value'].containing_oneof = _PATTERNFLOWGTPV1PNFLAG.oneofs_by_name['_value']
_PATTERNFLOWGTPV1PNFLAG.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWGTPV1PNFLAG.fields_by_name['metric_group'])
_PATTERNFLOWGTPV1PNFLAG.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWGTPV1PNFLAG.oneofs_by_name['_metric_group']
_PATTERNFLOWGTPV1PNFLAG.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWGTPV1PNFLAG.fields_by_name['increment'])
_PATTERNFLOWGTPV1PNFLAG.fields_by_name['increment'].containing_oneof = _PATTERNFLOWGTPV1PNFLAG.oneofs_by_name['_increment']
_PATTERNFLOWGTPV1PNFLAG.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWGTPV1PNFLAG.fields_by_name['decrement'])
_PATTERNFLOWGTPV1PNFLAG.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWGTPV1PNFLAG.oneofs_by_name['_decrement']
_PATTERNFLOWGTPV1MESSAGETYPECOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWGTPV1MESSAGETYPECOUNTER.fields_by_name['start'])
_PATTERNFLOWGTPV1MESSAGETYPECOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWGTPV1MESSAGETYPECOUNTER.oneofs_by_name['_start']
_PATTERNFLOWGTPV1MESSAGETYPECOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWGTPV1MESSAGETYPECOUNTER.fields_by_name['step'])
_PATTERNFLOWGTPV1MESSAGETYPECOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWGTPV1MESSAGETYPECOUNTER.oneofs_by_name['_step']
_PATTERNFLOWGTPV1MESSAGETYPECOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWGTPV1MESSAGETYPECOUNTER.fields_by_name['count'])
_PATTERNFLOWGTPV1MESSAGETYPECOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWGTPV1MESSAGETYPECOUNTER.oneofs_by_name['_count']
_PATTERNFLOWGTPV1MESSAGETYPE_CHOICE.containing_type = _PATTERNFLOWGTPV1MESSAGETYPE
_PATTERNFLOWGTPV1MESSAGETYPE_CHOICE_ENUM.containing_type = _PATTERNFLOWGTPV1MESSAGETYPE_CHOICE
_PATTERNFLOWGTPV1MESSAGETYPE.fields_by_name['choice'].enum_type = _PATTERNFLOWGTPV1MESSAGETYPE_CHOICE_ENUM
_PATTERNFLOWGTPV1MESSAGETYPE.fields_by_name['increment'].message_type = _PATTERNFLOWGTPV1MESSAGETYPECOUNTER
_PATTERNFLOWGTPV1MESSAGETYPE.fields_by_name['decrement'].message_type = _PATTERNFLOWGTPV1MESSAGETYPECOUNTER
_PATTERNFLOWGTPV1MESSAGETYPE.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWGTPV1MESSAGETYPE.fields_by_name['choice'])
_PATTERNFLOWGTPV1MESSAGETYPE.fields_by_name['choice'].containing_oneof = _PATTERNFLOWGTPV1MESSAGETYPE.oneofs_by_name['_choice']
_PATTERNFLOWGTPV1MESSAGETYPE.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWGTPV1MESSAGETYPE.fields_by_name['value'])
_PATTERNFLOWGTPV1MESSAGETYPE.fields_by_name['value'].containing_oneof = _PATTERNFLOWGTPV1MESSAGETYPE.oneofs_by_name['_value']
_PATTERNFLOWGTPV1MESSAGETYPE.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWGTPV1MESSAGETYPE.fields_by_name['metric_group'])
_PATTERNFLOWGTPV1MESSAGETYPE.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWGTPV1MESSAGETYPE.oneofs_by_name['_metric_group']
_PATTERNFLOWGTPV1MESSAGETYPE.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWGTPV1MESSAGETYPE.fields_by_name['increment'])
_PATTERNFLOWGTPV1MESSAGETYPE.fields_by_name['increment'].containing_oneof = _PATTERNFLOWGTPV1MESSAGETYPE.oneofs_by_name['_increment']
_PATTERNFLOWGTPV1MESSAGETYPE.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWGTPV1MESSAGETYPE.fields_by_name['decrement'])
_PATTERNFLOWGTPV1MESSAGETYPE.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWGTPV1MESSAGETYPE.oneofs_by_name['_decrement']
_PATTERNFLOWGTPV1MESSAGELENGTHCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWGTPV1MESSAGELENGTHCOUNTER.fields_by_name['start'])
_PATTERNFLOWGTPV1MESSAGELENGTHCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWGTPV1MESSAGELENGTHCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWGTPV1MESSAGELENGTHCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWGTPV1MESSAGELENGTHCOUNTER.fields_by_name['step'])
_PATTERNFLOWGTPV1MESSAGELENGTHCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWGTPV1MESSAGELENGTHCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWGTPV1MESSAGELENGTHCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWGTPV1MESSAGELENGTHCOUNTER.fields_by_name['count'])
_PATTERNFLOWGTPV1MESSAGELENGTHCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWGTPV1MESSAGELENGTHCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWGTPV1MESSAGELENGTH_CHOICE.containing_type = _PATTERNFLOWGTPV1MESSAGELENGTH
_PATTERNFLOWGTPV1MESSAGELENGTH_CHOICE_ENUM.containing_type = _PATTERNFLOWGTPV1MESSAGELENGTH_CHOICE
_PATTERNFLOWGTPV1MESSAGELENGTH.fields_by_name['choice'].enum_type = _PATTERNFLOWGTPV1MESSAGELENGTH_CHOICE_ENUM
_PATTERNFLOWGTPV1MESSAGELENGTH.fields_by_name['increment'].message_type = _PATTERNFLOWGTPV1MESSAGELENGTHCOUNTER
_PATTERNFLOWGTPV1MESSAGELENGTH.fields_by_name['decrement'].message_type = _PATTERNFLOWGTPV1MESSAGELENGTHCOUNTER
_PATTERNFLOWGTPV1MESSAGELENGTH.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWGTPV1MESSAGELENGTH.fields_by_name['choice'])
_PATTERNFLOWGTPV1MESSAGELENGTH.fields_by_name['choice'].containing_oneof = _PATTERNFLOWGTPV1MESSAGELENGTH.oneofs_by_name['_choice']
_PATTERNFLOWGTPV1MESSAGELENGTH.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWGTPV1MESSAGELENGTH.fields_by_name['value'])
_PATTERNFLOWGTPV1MESSAGELENGTH.fields_by_name['value'].containing_oneof = _PATTERNFLOWGTPV1MESSAGELENGTH.oneofs_by_name['_value']
_PATTERNFLOWGTPV1MESSAGELENGTH.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWGTPV1MESSAGELENGTH.fields_by_name['metric_group'])
_PATTERNFLOWGTPV1MESSAGELENGTH.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWGTPV1MESSAGELENGTH.oneofs_by_name['_metric_group']
_PATTERNFLOWGTPV1MESSAGELENGTH.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWGTPV1MESSAGELENGTH.fields_by_name['increment'])
_PATTERNFLOWGTPV1MESSAGELENGTH.fields_by_name['increment'].containing_oneof = _PATTERNFLOWGTPV1MESSAGELENGTH.oneofs_by_name['_increment']
_PATTERNFLOWGTPV1MESSAGELENGTH.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWGTPV1MESSAGELENGTH.fields_by_name['decrement'])
_PATTERNFLOWGTPV1MESSAGELENGTH.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWGTPV1MESSAGELENGTH.oneofs_by_name['_decrement']
_PATTERNFLOWGTPV1TEIDCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWGTPV1TEIDCOUNTER.fields_by_name['start'])
_PATTERNFLOWGTPV1TEIDCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWGTPV1TEIDCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWGTPV1TEIDCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWGTPV1TEIDCOUNTER.fields_by_name['step'])
_PATTERNFLOWGTPV1TEIDCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWGTPV1TEIDCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWGTPV1TEIDCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWGTPV1TEIDCOUNTER.fields_by_name['count'])
_PATTERNFLOWGTPV1TEIDCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWGTPV1TEIDCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWGTPV1TEID_CHOICE.containing_type = _PATTERNFLOWGTPV1TEID
_PATTERNFLOWGTPV1TEID_CHOICE_ENUM.containing_type = _PATTERNFLOWGTPV1TEID_CHOICE
_PATTERNFLOWGTPV1TEID.fields_by_name['choice'].enum_type = _PATTERNFLOWGTPV1TEID_CHOICE_ENUM
_PATTERNFLOWGTPV1TEID.fields_by_name['increment'].message_type = _PATTERNFLOWGTPV1TEIDCOUNTER
_PATTERNFLOWGTPV1TEID.fields_by_name['decrement'].message_type = _PATTERNFLOWGTPV1TEIDCOUNTER
_PATTERNFLOWGTPV1TEID.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWGTPV1TEID.fields_by_name['choice'])
_PATTERNFLOWGTPV1TEID.fields_by_name['choice'].containing_oneof = _PATTERNFLOWGTPV1TEID.oneofs_by_name['_choice']
_PATTERNFLOWGTPV1TEID.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWGTPV1TEID.fields_by_name['value'])
_PATTERNFLOWGTPV1TEID.fields_by_name['value'].containing_oneof = _PATTERNFLOWGTPV1TEID.oneofs_by_name['_value']
_PATTERNFLOWGTPV1TEID.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWGTPV1TEID.fields_by_name['metric_group'])
_PATTERNFLOWGTPV1TEID.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWGTPV1TEID.oneofs_by_name['_metric_group']
_PATTERNFLOWGTPV1TEID.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWGTPV1TEID.fields_by_name['increment'])
_PATTERNFLOWGTPV1TEID.fields_by_name['increment'].containing_oneof = _PATTERNFLOWGTPV1TEID.oneofs_by_name['_increment']
_PATTERNFLOWGTPV1TEID.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWGTPV1TEID.fields_by_name['decrement'])
_PATTERNFLOWGTPV1TEID.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWGTPV1TEID.oneofs_by_name['_decrement']
_PATTERNFLOWGTPV1SQUENCENUMBERCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWGTPV1SQUENCENUMBERCOUNTER.fields_by_name['start'])
_PATTERNFLOWGTPV1SQUENCENUMBERCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWGTPV1SQUENCENUMBERCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWGTPV1SQUENCENUMBERCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWGTPV1SQUENCENUMBERCOUNTER.fields_by_name['step'])
_PATTERNFLOWGTPV1SQUENCENUMBERCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWGTPV1SQUENCENUMBERCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWGTPV1SQUENCENUMBERCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWGTPV1SQUENCENUMBERCOUNTER.fields_by_name['count'])
_PATTERNFLOWGTPV1SQUENCENUMBERCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWGTPV1SQUENCENUMBERCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWGTPV1SQUENCENUMBER_CHOICE.containing_type = _PATTERNFLOWGTPV1SQUENCENUMBER
_PATTERNFLOWGTPV1SQUENCENUMBER_CHOICE_ENUM.containing_type = _PATTERNFLOWGTPV1SQUENCENUMBER_CHOICE
_PATTERNFLOWGTPV1SQUENCENUMBER.fields_by_name['choice'].enum_type = _PATTERNFLOWGTPV1SQUENCENUMBER_CHOICE_ENUM
_PATTERNFLOWGTPV1SQUENCENUMBER.fields_by_name['increment'].message_type = _PATTERNFLOWGTPV1SQUENCENUMBERCOUNTER
_PATTERNFLOWGTPV1SQUENCENUMBER.fields_by_name['decrement'].message_type = _PATTERNFLOWGTPV1SQUENCENUMBERCOUNTER
_PATTERNFLOWGTPV1SQUENCENUMBER.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWGTPV1SQUENCENUMBER.fields_by_name['choice'])
_PATTERNFLOWGTPV1SQUENCENUMBER.fields_by_name['choice'].containing_oneof = _PATTERNFLOWGTPV1SQUENCENUMBER.oneofs_by_name['_choice']
_PATTERNFLOWGTPV1SQUENCENUMBER.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWGTPV1SQUENCENUMBER.fields_by_name['value'])
_PATTERNFLOWGTPV1SQUENCENUMBER.fields_by_name['value'].containing_oneof = _PATTERNFLOWGTPV1SQUENCENUMBER.oneofs_by_name['_value']
_PATTERNFLOWGTPV1SQUENCENUMBER.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWGTPV1SQUENCENUMBER.fields_by_name['metric_group'])
_PATTERNFLOWGTPV1SQUENCENUMBER.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWGTPV1SQUENCENUMBER.oneofs_by_name['_metric_group']
_PATTERNFLOWGTPV1SQUENCENUMBER.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWGTPV1SQUENCENUMBER.fields_by_name['increment'])
_PATTERNFLOWGTPV1SQUENCENUMBER.fields_by_name['increment'].containing_oneof = _PATTERNFLOWGTPV1SQUENCENUMBER.oneofs_by_name['_increment']
_PATTERNFLOWGTPV1SQUENCENUMBER.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWGTPV1SQUENCENUMBER.fields_by_name['decrement'])
_PATTERNFLOWGTPV1SQUENCENUMBER.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWGTPV1SQUENCENUMBER.oneofs_by_name['_decrement']
_PATTERNFLOWGTPV1NPDUNUMBERCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWGTPV1NPDUNUMBERCOUNTER.fields_by_name['start'])
_PATTERNFLOWGTPV1NPDUNUMBERCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWGTPV1NPDUNUMBERCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWGTPV1NPDUNUMBERCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWGTPV1NPDUNUMBERCOUNTER.fields_by_name['step'])
_PATTERNFLOWGTPV1NPDUNUMBERCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWGTPV1NPDUNUMBERCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWGTPV1NPDUNUMBERCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWGTPV1NPDUNUMBERCOUNTER.fields_by_name['count'])
_PATTERNFLOWGTPV1NPDUNUMBERCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWGTPV1NPDUNUMBERCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWGTPV1NPDUNUMBER_CHOICE.containing_type = _PATTERNFLOWGTPV1NPDUNUMBER
_PATTERNFLOWGTPV1NPDUNUMBER_CHOICE_ENUM.containing_type = _PATTERNFLOWGTPV1NPDUNUMBER_CHOICE
_PATTERNFLOWGTPV1NPDUNUMBER.fields_by_name['choice'].enum_type = _PATTERNFLOWGTPV1NPDUNUMBER_CHOICE_ENUM
_PATTERNFLOWGTPV1NPDUNUMBER.fields_by_name['increment'].message_type = _PATTERNFLOWGTPV1NPDUNUMBERCOUNTER
_PATTERNFLOWGTPV1NPDUNUMBER.fields_by_name['decrement'].message_type = _PATTERNFLOWGTPV1NPDUNUMBERCOUNTER
_PATTERNFLOWGTPV1NPDUNUMBER.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWGTPV1NPDUNUMBER.fields_by_name['choice'])
_PATTERNFLOWGTPV1NPDUNUMBER.fields_by_name['choice'].containing_oneof = _PATTERNFLOWGTPV1NPDUNUMBER.oneofs_by_name['_choice']
_PATTERNFLOWGTPV1NPDUNUMBER.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWGTPV1NPDUNUMBER.fields_by_name['value'])
_PATTERNFLOWGTPV1NPDUNUMBER.fields_by_name['value'].containing_oneof = _PATTERNFLOWGTPV1NPDUNUMBER.oneofs_by_name['_value']
_PATTERNFLOWGTPV1NPDUNUMBER.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWGTPV1NPDUNUMBER.fields_by_name['metric_group'])
_PATTERNFLOWGTPV1NPDUNUMBER.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWGTPV1NPDUNUMBER.oneofs_by_name['_metric_group']
_PATTERNFLOWGTPV1NPDUNUMBER.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWGTPV1NPDUNUMBER.fields_by_name['increment'])
_PATTERNFLOWGTPV1NPDUNUMBER.fields_by_name['increment'].containing_oneof = _PATTERNFLOWGTPV1NPDUNUMBER.oneofs_by_name['_increment']
_PATTERNFLOWGTPV1NPDUNUMBER.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWGTPV1NPDUNUMBER.fields_by_name['decrement'])
_PATTERNFLOWGTPV1NPDUNUMBER.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWGTPV1NPDUNUMBER.oneofs_by_name['_decrement']
_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPECOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPECOUNTER.fields_by_name['start'])
_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPECOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPECOUNTER.oneofs_by_name['_start']
_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPECOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPECOUNTER.fields_by_name['step'])
_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPECOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPECOUNTER.oneofs_by_name['_step']
_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPECOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPECOUNTER.fields_by_name['count'])
_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPECOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPECOUNTER.oneofs_by_name['_count']
_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE_CHOICE.containing_type = _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE
_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE_CHOICE_ENUM.containing_type = _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE_CHOICE
_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE.fields_by_name['choice'].enum_type = _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE_CHOICE_ENUM
_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE.fields_by_name['increment'].message_type = _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPECOUNTER
_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE.fields_by_name['decrement'].message_type = _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPECOUNTER
_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE.fields_by_name['choice'])
_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE.fields_by_name['choice'].containing_oneof = _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE.oneofs_by_name['_choice']
_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE.fields_by_name['value'])
_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE.fields_by_name['value'].containing_oneof = _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE.oneofs_by_name['_value']
_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE.fields_by_name['metric_group'])
_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE.oneofs_by_name['_metric_group']
_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE.fields_by_name['increment'])
_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE.fields_by_name['increment'].containing_oneof = _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE.oneofs_by_name['_increment']
_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE.fields_by_name['decrement'])
_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE.oneofs_by_name['_decrement']
_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHCOUNTER.fields_by_name['start'])
_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHCOUNTER.fields_by_name['step'])
_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHCOUNTER.fields_by_name['count'])
_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH_CHOICE.containing_type = _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH
_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH_CHOICE_ENUM.containing_type = _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH_CHOICE
_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH.fields_by_name['choice'].enum_type = _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH_CHOICE_ENUM
_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH.fields_by_name['increment'].message_type = _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHCOUNTER
_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH.fields_by_name['decrement'].message_type = _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHCOUNTER
_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH.fields_by_name['choice'])
_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH.fields_by_name['choice'].containing_oneof = _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH.oneofs_by_name['_choice']
_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH.fields_by_name['value'])
_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH.fields_by_name['value'].containing_oneof = _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH.oneofs_by_name['_value']
_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH.fields_by_name['metric_group'])
_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH.oneofs_by_name['_metric_group']
_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH.fields_by_name['increment'])
_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH.fields_by_name['increment'].containing_oneof = _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH.oneofs_by_name['_increment']
_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH.fields_by_name['decrement'])
_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH.oneofs_by_name['_decrement']
_PATTERNFLOWGTPEXTENSIONCONTENTSCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWGTPEXTENSIONCONTENTSCOUNTER.fields_by_name['start'])
_PATTERNFLOWGTPEXTENSIONCONTENTSCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWGTPEXTENSIONCONTENTSCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWGTPEXTENSIONCONTENTSCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWGTPEXTENSIONCONTENTSCOUNTER.fields_by_name['step'])
_PATTERNFLOWGTPEXTENSIONCONTENTSCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWGTPEXTENSIONCONTENTSCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWGTPEXTENSIONCONTENTSCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWGTPEXTENSIONCONTENTSCOUNTER.fields_by_name['count'])
_PATTERNFLOWGTPEXTENSIONCONTENTSCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWGTPEXTENSIONCONTENTSCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWGTPEXTENSIONCONTENTS_CHOICE.containing_type = _PATTERNFLOWGTPEXTENSIONCONTENTS
_PATTERNFLOWGTPEXTENSIONCONTENTS_CHOICE_ENUM.containing_type = _PATTERNFLOWGTPEXTENSIONCONTENTS_CHOICE
_PATTERNFLOWGTPEXTENSIONCONTENTS.fields_by_name['choice'].enum_type = _PATTERNFLOWGTPEXTENSIONCONTENTS_CHOICE_ENUM
_PATTERNFLOWGTPEXTENSIONCONTENTS.fields_by_name['increment'].message_type = _PATTERNFLOWGTPEXTENSIONCONTENTSCOUNTER
_PATTERNFLOWGTPEXTENSIONCONTENTS.fields_by_name['decrement'].message_type = _PATTERNFLOWGTPEXTENSIONCONTENTSCOUNTER
_PATTERNFLOWGTPEXTENSIONCONTENTS.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWGTPEXTENSIONCONTENTS.fields_by_name['choice'])
_PATTERNFLOWGTPEXTENSIONCONTENTS.fields_by_name['choice'].containing_oneof = _PATTERNFLOWGTPEXTENSIONCONTENTS.oneofs_by_name['_choice']
_PATTERNFLOWGTPEXTENSIONCONTENTS.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWGTPEXTENSIONCONTENTS.fields_by_name['value'])
_PATTERNFLOWGTPEXTENSIONCONTENTS.fields_by_name['value'].containing_oneof = _PATTERNFLOWGTPEXTENSIONCONTENTS.oneofs_by_name['_value']
_PATTERNFLOWGTPEXTENSIONCONTENTS.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWGTPEXTENSIONCONTENTS.fields_by_name['metric_group'])
_PATTERNFLOWGTPEXTENSIONCONTENTS.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWGTPEXTENSIONCONTENTS.oneofs_by_name['_metric_group']
_PATTERNFLOWGTPEXTENSIONCONTENTS.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWGTPEXTENSIONCONTENTS.fields_by_name['increment'])
_PATTERNFLOWGTPEXTENSIONCONTENTS.fields_by_name['increment'].containing_oneof = _PATTERNFLOWGTPEXTENSIONCONTENTS.oneofs_by_name['_increment']
_PATTERNFLOWGTPEXTENSIONCONTENTS.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWGTPEXTENSIONCONTENTS.fields_by_name['decrement'])
_PATTERNFLOWGTPEXTENSIONCONTENTS.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWGTPEXTENSIONCONTENTS.oneofs_by_name['_decrement']
_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERCOUNTER.fields_by_name['start'])
_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERCOUNTER.fields_by_name['step'])
_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERCOUNTER.fields_by_name['count'])
_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER_CHOICE.containing_type = _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER
_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER_CHOICE_ENUM.containing_type = _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER_CHOICE
_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER.fields_by_name['choice'].enum_type = _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER_CHOICE_ENUM
_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER.fields_by_name['increment'].message_type = _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERCOUNTER
_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER.fields_by_name['decrement'].message_type = _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERCOUNTER
_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER.fields_by_name['choice'])
_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER.fields_by_name['choice'].containing_oneof = _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER.oneofs_by_name['_choice']
_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER.fields_by_name['value'])
_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER.fields_by_name['value'].containing_oneof = _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER.oneofs_by_name['_value']
_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER.fields_by_name['metric_group'])
_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER.oneofs_by_name['_metric_group']
_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER.fields_by_name['increment'])
_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER.fields_by_name['increment'].containing_oneof = _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER.oneofs_by_name['_increment']
_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER.fields_by_name['decrement'])
_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER.oneofs_by_name['_decrement']
_PATTERNFLOWGTPV2VERSIONCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWGTPV2VERSIONCOUNTER.fields_by_name['start'])
_PATTERNFLOWGTPV2VERSIONCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWGTPV2VERSIONCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWGTPV2VERSIONCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWGTPV2VERSIONCOUNTER.fields_by_name['step'])
_PATTERNFLOWGTPV2VERSIONCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWGTPV2VERSIONCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWGTPV2VERSIONCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWGTPV2VERSIONCOUNTER.fields_by_name['count'])
_PATTERNFLOWGTPV2VERSIONCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWGTPV2VERSIONCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWGTPV2VERSION_CHOICE.containing_type = _PATTERNFLOWGTPV2VERSION
_PATTERNFLOWGTPV2VERSION_CHOICE_ENUM.containing_type = _PATTERNFLOWGTPV2VERSION_CHOICE
_PATTERNFLOWGTPV2VERSION.fields_by_name['choice'].enum_type = _PATTERNFLOWGTPV2VERSION_CHOICE_ENUM
_PATTERNFLOWGTPV2VERSION.fields_by_name['increment'].message_type = _PATTERNFLOWGTPV2VERSIONCOUNTER
_PATTERNFLOWGTPV2VERSION.fields_by_name['decrement'].message_type = _PATTERNFLOWGTPV2VERSIONCOUNTER
_PATTERNFLOWGTPV2VERSION.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWGTPV2VERSION.fields_by_name['choice'])
_PATTERNFLOWGTPV2VERSION.fields_by_name['choice'].containing_oneof = _PATTERNFLOWGTPV2VERSION.oneofs_by_name['_choice']
_PATTERNFLOWGTPV2VERSION.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWGTPV2VERSION.fields_by_name['value'])
_PATTERNFLOWGTPV2VERSION.fields_by_name['value'].containing_oneof = _PATTERNFLOWGTPV2VERSION.oneofs_by_name['_value']
_PATTERNFLOWGTPV2VERSION.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWGTPV2VERSION.fields_by_name['metric_group'])
_PATTERNFLOWGTPV2VERSION.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWGTPV2VERSION.oneofs_by_name['_metric_group']
_PATTERNFLOWGTPV2VERSION.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWGTPV2VERSION.fields_by_name['increment'])
_PATTERNFLOWGTPV2VERSION.fields_by_name['increment'].containing_oneof = _PATTERNFLOWGTPV2VERSION.oneofs_by_name['_increment']
_PATTERNFLOWGTPV2VERSION.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWGTPV2VERSION.fields_by_name['decrement'])
_PATTERNFLOWGTPV2VERSION.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWGTPV2VERSION.oneofs_by_name['_decrement']
_PATTERNFLOWGTPV2PIGGYBACKINGFLAGCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWGTPV2PIGGYBACKINGFLAGCOUNTER.fields_by_name['start'])
_PATTERNFLOWGTPV2PIGGYBACKINGFLAGCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWGTPV2PIGGYBACKINGFLAGCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWGTPV2PIGGYBACKINGFLAGCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWGTPV2PIGGYBACKINGFLAGCOUNTER.fields_by_name['step'])
_PATTERNFLOWGTPV2PIGGYBACKINGFLAGCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWGTPV2PIGGYBACKINGFLAGCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWGTPV2PIGGYBACKINGFLAGCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWGTPV2PIGGYBACKINGFLAGCOUNTER.fields_by_name['count'])
_PATTERNFLOWGTPV2PIGGYBACKINGFLAGCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWGTPV2PIGGYBACKINGFLAGCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWGTPV2PIGGYBACKINGFLAG_CHOICE.containing_type = _PATTERNFLOWGTPV2PIGGYBACKINGFLAG
_PATTERNFLOWGTPV2PIGGYBACKINGFLAG_CHOICE_ENUM.containing_type = _PATTERNFLOWGTPV2PIGGYBACKINGFLAG_CHOICE
_PATTERNFLOWGTPV2PIGGYBACKINGFLAG.fields_by_name['choice'].enum_type = _PATTERNFLOWGTPV2PIGGYBACKINGFLAG_CHOICE_ENUM
_PATTERNFLOWGTPV2PIGGYBACKINGFLAG.fields_by_name['increment'].message_type = _PATTERNFLOWGTPV2PIGGYBACKINGFLAGCOUNTER
_PATTERNFLOWGTPV2PIGGYBACKINGFLAG.fields_by_name['decrement'].message_type = _PATTERNFLOWGTPV2PIGGYBACKINGFLAGCOUNTER
_PATTERNFLOWGTPV2PIGGYBACKINGFLAG.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWGTPV2PIGGYBACKINGFLAG.fields_by_name['choice'])
_PATTERNFLOWGTPV2PIGGYBACKINGFLAG.fields_by_name['choice'].containing_oneof = _PATTERNFLOWGTPV2PIGGYBACKINGFLAG.oneofs_by_name['_choice']
_PATTERNFLOWGTPV2PIGGYBACKINGFLAG.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWGTPV2PIGGYBACKINGFLAG.fields_by_name['value'])
_PATTERNFLOWGTPV2PIGGYBACKINGFLAG.fields_by_name['value'].containing_oneof = _PATTERNFLOWGTPV2PIGGYBACKINGFLAG.oneofs_by_name['_value']
_PATTERNFLOWGTPV2PIGGYBACKINGFLAG.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWGTPV2PIGGYBACKINGFLAG.fields_by_name['metric_group'])
_PATTERNFLOWGTPV2PIGGYBACKINGFLAG.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWGTPV2PIGGYBACKINGFLAG.oneofs_by_name['_metric_group']
_PATTERNFLOWGTPV2PIGGYBACKINGFLAG.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWGTPV2PIGGYBACKINGFLAG.fields_by_name['increment'])
_PATTERNFLOWGTPV2PIGGYBACKINGFLAG.fields_by_name['increment'].containing_oneof = _PATTERNFLOWGTPV2PIGGYBACKINGFLAG.oneofs_by_name['_increment']
_PATTERNFLOWGTPV2PIGGYBACKINGFLAG.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWGTPV2PIGGYBACKINGFLAG.fields_by_name['decrement'])
_PATTERNFLOWGTPV2PIGGYBACKINGFLAG.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWGTPV2PIGGYBACKINGFLAG.oneofs_by_name['_decrement']
_PATTERNFLOWGTPV2TEIDFLAGCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWGTPV2TEIDFLAGCOUNTER.fields_by_name['start'])
_PATTERNFLOWGTPV2TEIDFLAGCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWGTPV2TEIDFLAGCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWGTPV2TEIDFLAGCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWGTPV2TEIDFLAGCOUNTER.fields_by_name['step'])
_PATTERNFLOWGTPV2TEIDFLAGCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWGTPV2TEIDFLAGCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWGTPV2TEIDFLAGCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWGTPV2TEIDFLAGCOUNTER.fields_by_name['count'])
_PATTERNFLOWGTPV2TEIDFLAGCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWGTPV2TEIDFLAGCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWGTPV2TEIDFLAG_CHOICE.containing_type = _PATTERNFLOWGTPV2TEIDFLAG
_PATTERNFLOWGTPV2TEIDFLAG_CHOICE_ENUM.containing_type = _PATTERNFLOWGTPV2TEIDFLAG_CHOICE
_PATTERNFLOWGTPV2TEIDFLAG.fields_by_name['choice'].enum_type = _PATTERNFLOWGTPV2TEIDFLAG_CHOICE_ENUM
_PATTERNFLOWGTPV2TEIDFLAG.fields_by_name['increment'].message_type = _PATTERNFLOWGTPV2TEIDFLAGCOUNTER
_PATTERNFLOWGTPV2TEIDFLAG.fields_by_name['decrement'].message_type = _PATTERNFLOWGTPV2TEIDFLAGCOUNTER
_PATTERNFLOWGTPV2TEIDFLAG.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWGTPV2TEIDFLAG.fields_by_name['choice'])
_PATTERNFLOWGTPV2TEIDFLAG.fields_by_name['choice'].containing_oneof = _PATTERNFLOWGTPV2TEIDFLAG.oneofs_by_name['_choice']
_PATTERNFLOWGTPV2TEIDFLAG.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWGTPV2TEIDFLAG.fields_by_name['value'])
_PATTERNFLOWGTPV2TEIDFLAG.fields_by_name['value'].containing_oneof = _PATTERNFLOWGTPV2TEIDFLAG.oneofs_by_name['_value']
_PATTERNFLOWGTPV2TEIDFLAG.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWGTPV2TEIDFLAG.fields_by_name['metric_group'])
_PATTERNFLOWGTPV2TEIDFLAG.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWGTPV2TEIDFLAG.oneofs_by_name['_metric_group']
_PATTERNFLOWGTPV2TEIDFLAG.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWGTPV2TEIDFLAG.fields_by_name['increment'])
_PATTERNFLOWGTPV2TEIDFLAG.fields_by_name['increment'].containing_oneof = _PATTERNFLOWGTPV2TEIDFLAG.oneofs_by_name['_increment']
_PATTERNFLOWGTPV2TEIDFLAG.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWGTPV2TEIDFLAG.fields_by_name['decrement'])
_PATTERNFLOWGTPV2TEIDFLAG.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWGTPV2TEIDFLAG.oneofs_by_name['_decrement']
_PATTERNFLOWGTPV2SPARE1COUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWGTPV2SPARE1COUNTER.fields_by_name['start'])
_PATTERNFLOWGTPV2SPARE1COUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWGTPV2SPARE1COUNTER.oneofs_by_name['_start']
_PATTERNFLOWGTPV2SPARE1COUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWGTPV2SPARE1COUNTER.fields_by_name['step'])
_PATTERNFLOWGTPV2SPARE1COUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWGTPV2SPARE1COUNTER.oneofs_by_name['_step']
_PATTERNFLOWGTPV2SPARE1COUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWGTPV2SPARE1COUNTER.fields_by_name['count'])
_PATTERNFLOWGTPV2SPARE1COUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWGTPV2SPARE1COUNTER.oneofs_by_name['_count']
_PATTERNFLOWGTPV2SPARE1_CHOICE.containing_type = _PATTERNFLOWGTPV2SPARE1
_PATTERNFLOWGTPV2SPARE1_CHOICE_ENUM.containing_type = _PATTERNFLOWGTPV2SPARE1_CHOICE
_PATTERNFLOWGTPV2SPARE1.fields_by_name['choice'].enum_type = _PATTERNFLOWGTPV2SPARE1_CHOICE_ENUM
_PATTERNFLOWGTPV2SPARE1.fields_by_name['increment'].message_type = _PATTERNFLOWGTPV2SPARE1COUNTER
_PATTERNFLOWGTPV2SPARE1.fields_by_name['decrement'].message_type = _PATTERNFLOWGTPV2SPARE1COUNTER
_PATTERNFLOWGTPV2SPARE1.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWGTPV2SPARE1.fields_by_name['choice'])
_PATTERNFLOWGTPV2SPARE1.fields_by_name['choice'].containing_oneof = _PATTERNFLOWGTPV2SPARE1.oneofs_by_name['_choice']
_PATTERNFLOWGTPV2SPARE1.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWGTPV2SPARE1.fields_by_name['value'])
_PATTERNFLOWGTPV2SPARE1.fields_by_name['value'].containing_oneof = _PATTERNFLOWGTPV2SPARE1.oneofs_by_name['_value']
_PATTERNFLOWGTPV2SPARE1.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWGTPV2SPARE1.fields_by_name['metric_group'])
_PATTERNFLOWGTPV2SPARE1.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWGTPV2SPARE1.oneofs_by_name['_metric_group']
_PATTERNFLOWGTPV2SPARE1.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWGTPV2SPARE1.fields_by_name['increment'])
_PATTERNFLOWGTPV2SPARE1.fields_by_name['increment'].containing_oneof = _PATTERNFLOWGTPV2SPARE1.oneofs_by_name['_increment']
_PATTERNFLOWGTPV2SPARE1.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWGTPV2SPARE1.fields_by_name['decrement'])
_PATTERNFLOWGTPV2SPARE1.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWGTPV2SPARE1.oneofs_by_name['_decrement']
_PATTERNFLOWGTPV2MESSAGETYPECOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWGTPV2MESSAGETYPECOUNTER.fields_by_name['start'])
_PATTERNFLOWGTPV2MESSAGETYPECOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWGTPV2MESSAGETYPECOUNTER.oneofs_by_name['_start']
_PATTERNFLOWGTPV2MESSAGETYPECOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWGTPV2MESSAGETYPECOUNTER.fields_by_name['step'])
_PATTERNFLOWGTPV2MESSAGETYPECOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWGTPV2MESSAGETYPECOUNTER.oneofs_by_name['_step']
_PATTERNFLOWGTPV2MESSAGETYPECOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWGTPV2MESSAGETYPECOUNTER.fields_by_name['count'])
_PATTERNFLOWGTPV2MESSAGETYPECOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWGTPV2MESSAGETYPECOUNTER.oneofs_by_name['_count']
_PATTERNFLOWGTPV2MESSAGETYPE_CHOICE.containing_type = _PATTERNFLOWGTPV2MESSAGETYPE
_PATTERNFLOWGTPV2MESSAGETYPE_CHOICE_ENUM.containing_type = _PATTERNFLOWGTPV2MESSAGETYPE_CHOICE
_PATTERNFLOWGTPV2MESSAGETYPE.fields_by_name['choice'].enum_type = _PATTERNFLOWGTPV2MESSAGETYPE_CHOICE_ENUM
_PATTERNFLOWGTPV2MESSAGETYPE.fields_by_name['increment'].message_type = _PATTERNFLOWGTPV2MESSAGETYPECOUNTER
_PATTERNFLOWGTPV2MESSAGETYPE.fields_by_name['decrement'].message_type = _PATTERNFLOWGTPV2MESSAGETYPECOUNTER
_PATTERNFLOWGTPV2MESSAGETYPE.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWGTPV2MESSAGETYPE.fields_by_name['choice'])
_PATTERNFLOWGTPV2MESSAGETYPE.fields_by_name['choice'].containing_oneof = _PATTERNFLOWGTPV2MESSAGETYPE.oneofs_by_name['_choice']
_PATTERNFLOWGTPV2MESSAGETYPE.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWGTPV2MESSAGETYPE.fields_by_name['value'])
_PATTERNFLOWGTPV2MESSAGETYPE.fields_by_name['value'].containing_oneof = _PATTERNFLOWGTPV2MESSAGETYPE.oneofs_by_name['_value']
_PATTERNFLOWGTPV2MESSAGETYPE.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWGTPV2MESSAGETYPE.fields_by_name['metric_group'])
_PATTERNFLOWGTPV2MESSAGETYPE.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWGTPV2MESSAGETYPE.oneofs_by_name['_metric_group']
_PATTERNFLOWGTPV2MESSAGETYPE.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWGTPV2MESSAGETYPE.fields_by_name['increment'])
_PATTERNFLOWGTPV2MESSAGETYPE.fields_by_name['increment'].containing_oneof = _PATTERNFLOWGTPV2MESSAGETYPE.oneofs_by_name['_increment']
_PATTERNFLOWGTPV2MESSAGETYPE.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWGTPV2MESSAGETYPE.fields_by_name['decrement'])
_PATTERNFLOWGTPV2MESSAGETYPE.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWGTPV2MESSAGETYPE.oneofs_by_name['_decrement']
_PATTERNFLOWGTPV2MESSAGELENGTHCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWGTPV2MESSAGELENGTHCOUNTER.fields_by_name['start'])
_PATTERNFLOWGTPV2MESSAGELENGTHCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWGTPV2MESSAGELENGTHCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWGTPV2MESSAGELENGTHCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWGTPV2MESSAGELENGTHCOUNTER.fields_by_name['step'])
_PATTERNFLOWGTPV2MESSAGELENGTHCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWGTPV2MESSAGELENGTHCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWGTPV2MESSAGELENGTHCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWGTPV2MESSAGELENGTHCOUNTER.fields_by_name['count'])
_PATTERNFLOWGTPV2MESSAGELENGTHCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWGTPV2MESSAGELENGTHCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWGTPV2MESSAGELENGTH_CHOICE.containing_type = _PATTERNFLOWGTPV2MESSAGELENGTH
_PATTERNFLOWGTPV2MESSAGELENGTH_CHOICE_ENUM.containing_type = _PATTERNFLOWGTPV2MESSAGELENGTH_CHOICE
_PATTERNFLOWGTPV2MESSAGELENGTH.fields_by_name['choice'].enum_type = _PATTERNFLOWGTPV2MESSAGELENGTH_CHOICE_ENUM
_PATTERNFLOWGTPV2MESSAGELENGTH.fields_by_name['increment'].message_type = _PATTERNFLOWGTPV2MESSAGELENGTHCOUNTER
_PATTERNFLOWGTPV2MESSAGELENGTH.fields_by_name['decrement'].message_type = _PATTERNFLOWGTPV2MESSAGELENGTHCOUNTER
_PATTERNFLOWGTPV2MESSAGELENGTH.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWGTPV2MESSAGELENGTH.fields_by_name['choice'])
_PATTERNFLOWGTPV2MESSAGELENGTH.fields_by_name['choice'].containing_oneof = _PATTERNFLOWGTPV2MESSAGELENGTH.oneofs_by_name['_choice']
_PATTERNFLOWGTPV2MESSAGELENGTH.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWGTPV2MESSAGELENGTH.fields_by_name['value'])
_PATTERNFLOWGTPV2MESSAGELENGTH.fields_by_name['value'].containing_oneof = _PATTERNFLOWGTPV2MESSAGELENGTH.oneofs_by_name['_value']
_PATTERNFLOWGTPV2MESSAGELENGTH.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWGTPV2MESSAGELENGTH.fields_by_name['metric_group'])
_PATTERNFLOWGTPV2MESSAGELENGTH.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWGTPV2MESSAGELENGTH.oneofs_by_name['_metric_group']
_PATTERNFLOWGTPV2MESSAGELENGTH.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWGTPV2MESSAGELENGTH.fields_by_name['increment'])
_PATTERNFLOWGTPV2MESSAGELENGTH.fields_by_name['increment'].containing_oneof = _PATTERNFLOWGTPV2MESSAGELENGTH.oneofs_by_name['_increment']
_PATTERNFLOWGTPV2MESSAGELENGTH.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWGTPV2MESSAGELENGTH.fields_by_name['decrement'])
_PATTERNFLOWGTPV2MESSAGELENGTH.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWGTPV2MESSAGELENGTH.oneofs_by_name['_decrement']
_PATTERNFLOWGTPV2TEIDCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWGTPV2TEIDCOUNTER.fields_by_name['start'])
_PATTERNFLOWGTPV2TEIDCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWGTPV2TEIDCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWGTPV2TEIDCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWGTPV2TEIDCOUNTER.fields_by_name['step'])
_PATTERNFLOWGTPV2TEIDCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWGTPV2TEIDCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWGTPV2TEIDCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWGTPV2TEIDCOUNTER.fields_by_name['count'])
_PATTERNFLOWGTPV2TEIDCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWGTPV2TEIDCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWGTPV2TEID_CHOICE.containing_type = _PATTERNFLOWGTPV2TEID
_PATTERNFLOWGTPV2TEID_CHOICE_ENUM.containing_type = _PATTERNFLOWGTPV2TEID_CHOICE
_PATTERNFLOWGTPV2TEID.fields_by_name['choice'].enum_type = _PATTERNFLOWGTPV2TEID_CHOICE_ENUM
_PATTERNFLOWGTPV2TEID.fields_by_name['increment'].message_type = _PATTERNFLOWGTPV2TEIDCOUNTER
_PATTERNFLOWGTPV2TEID.fields_by_name['decrement'].message_type = _PATTERNFLOWGTPV2TEIDCOUNTER
_PATTERNFLOWGTPV2TEID.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWGTPV2TEID.fields_by_name['choice'])
_PATTERNFLOWGTPV2TEID.fields_by_name['choice'].containing_oneof = _PATTERNFLOWGTPV2TEID.oneofs_by_name['_choice']
_PATTERNFLOWGTPV2TEID.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWGTPV2TEID.fields_by_name['value'])
_PATTERNFLOWGTPV2TEID.fields_by_name['value'].containing_oneof = _PATTERNFLOWGTPV2TEID.oneofs_by_name['_value']
_PATTERNFLOWGTPV2TEID.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWGTPV2TEID.fields_by_name['metric_group'])
_PATTERNFLOWGTPV2TEID.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWGTPV2TEID.oneofs_by_name['_metric_group']
_PATTERNFLOWGTPV2TEID.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWGTPV2TEID.fields_by_name['increment'])
_PATTERNFLOWGTPV2TEID.fields_by_name['increment'].containing_oneof = _PATTERNFLOWGTPV2TEID.oneofs_by_name['_increment']
_PATTERNFLOWGTPV2TEID.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWGTPV2TEID.fields_by_name['decrement'])
_PATTERNFLOWGTPV2TEID.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWGTPV2TEID.oneofs_by_name['_decrement']
_PATTERNFLOWGTPV2SEQUENCENUMBERCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWGTPV2SEQUENCENUMBERCOUNTER.fields_by_name['start'])
_PATTERNFLOWGTPV2SEQUENCENUMBERCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWGTPV2SEQUENCENUMBERCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWGTPV2SEQUENCENUMBERCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWGTPV2SEQUENCENUMBERCOUNTER.fields_by_name['step'])
_PATTERNFLOWGTPV2SEQUENCENUMBERCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWGTPV2SEQUENCENUMBERCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWGTPV2SEQUENCENUMBERCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWGTPV2SEQUENCENUMBERCOUNTER.fields_by_name['count'])
_PATTERNFLOWGTPV2SEQUENCENUMBERCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWGTPV2SEQUENCENUMBERCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWGTPV2SEQUENCENUMBER_CHOICE.containing_type = _PATTERNFLOWGTPV2SEQUENCENUMBER
_PATTERNFLOWGTPV2SEQUENCENUMBER_CHOICE_ENUM.containing_type = _PATTERNFLOWGTPV2SEQUENCENUMBER_CHOICE
_PATTERNFLOWGTPV2SEQUENCENUMBER.fields_by_name['choice'].enum_type = _PATTERNFLOWGTPV2SEQUENCENUMBER_CHOICE_ENUM
_PATTERNFLOWGTPV2SEQUENCENUMBER.fields_by_name['increment'].message_type = _PATTERNFLOWGTPV2SEQUENCENUMBERCOUNTER
_PATTERNFLOWGTPV2SEQUENCENUMBER.fields_by_name['decrement'].message_type = _PATTERNFLOWGTPV2SEQUENCENUMBERCOUNTER
_PATTERNFLOWGTPV2SEQUENCENUMBER.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWGTPV2SEQUENCENUMBER.fields_by_name['choice'])
_PATTERNFLOWGTPV2SEQUENCENUMBER.fields_by_name['choice'].containing_oneof = _PATTERNFLOWGTPV2SEQUENCENUMBER.oneofs_by_name['_choice']
_PATTERNFLOWGTPV2SEQUENCENUMBER.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWGTPV2SEQUENCENUMBER.fields_by_name['value'])
_PATTERNFLOWGTPV2SEQUENCENUMBER.fields_by_name['value'].containing_oneof = _PATTERNFLOWGTPV2SEQUENCENUMBER.oneofs_by_name['_value']
_PATTERNFLOWGTPV2SEQUENCENUMBER.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWGTPV2SEQUENCENUMBER.fields_by_name['metric_group'])
_PATTERNFLOWGTPV2SEQUENCENUMBER.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWGTPV2SEQUENCENUMBER.oneofs_by_name['_metric_group']
_PATTERNFLOWGTPV2SEQUENCENUMBER.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWGTPV2SEQUENCENUMBER.fields_by_name['increment'])
_PATTERNFLOWGTPV2SEQUENCENUMBER.fields_by_name['increment'].containing_oneof = _PATTERNFLOWGTPV2SEQUENCENUMBER.oneofs_by_name['_increment']
_PATTERNFLOWGTPV2SEQUENCENUMBER.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWGTPV2SEQUENCENUMBER.fields_by_name['decrement'])
_PATTERNFLOWGTPV2SEQUENCENUMBER.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWGTPV2SEQUENCENUMBER.oneofs_by_name['_decrement']
_PATTERNFLOWGTPV2SPARE2COUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWGTPV2SPARE2COUNTER.fields_by_name['start'])
_PATTERNFLOWGTPV2SPARE2COUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWGTPV2SPARE2COUNTER.oneofs_by_name['_start']
_PATTERNFLOWGTPV2SPARE2COUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWGTPV2SPARE2COUNTER.fields_by_name['step'])
_PATTERNFLOWGTPV2SPARE2COUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWGTPV2SPARE2COUNTER.oneofs_by_name['_step']
_PATTERNFLOWGTPV2SPARE2COUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWGTPV2SPARE2COUNTER.fields_by_name['count'])
_PATTERNFLOWGTPV2SPARE2COUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWGTPV2SPARE2COUNTER.oneofs_by_name['_count']
_PATTERNFLOWGTPV2SPARE2_CHOICE.containing_type = _PATTERNFLOWGTPV2SPARE2
_PATTERNFLOWGTPV2SPARE2_CHOICE_ENUM.containing_type = _PATTERNFLOWGTPV2SPARE2_CHOICE
_PATTERNFLOWGTPV2SPARE2.fields_by_name['choice'].enum_type = _PATTERNFLOWGTPV2SPARE2_CHOICE_ENUM
_PATTERNFLOWGTPV2SPARE2.fields_by_name['increment'].message_type = _PATTERNFLOWGTPV2SPARE2COUNTER
_PATTERNFLOWGTPV2SPARE2.fields_by_name['decrement'].message_type = _PATTERNFLOWGTPV2SPARE2COUNTER
_PATTERNFLOWGTPV2SPARE2.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWGTPV2SPARE2.fields_by_name['choice'])
_PATTERNFLOWGTPV2SPARE2.fields_by_name['choice'].containing_oneof = _PATTERNFLOWGTPV2SPARE2.oneofs_by_name['_choice']
_PATTERNFLOWGTPV2SPARE2.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWGTPV2SPARE2.fields_by_name['value'])
_PATTERNFLOWGTPV2SPARE2.fields_by_name['value'].containing_oneof = _PATTERNFLOWGTPV2SPARE2.oneofs_by_name['_value']
_PATTERNFLOWGTPV2SPARE2.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWGTPV2SPARE2.fields_by_name['metric_group'])
_PATTERNFLOWGTPV2SPARE2.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWGTPV2SPARE2.oneofs_by_name['_metric_group']
_PATTERNFLOWGTPV2SPARE2.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWGTPV2SPARE2.fields_by_name['increment'])
_PATTERNFLOWGTPV2SPARE2.fields_by_name['increment'].containing_oneof = _PATTERNFLOWGTPV2SPARE2.oneofs_by_name['_increment']
_PATTERNFLOWGTPV2SPARE2.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWGTPV2SPARE2.fields_by_name['decrement'])
_PATTERNFLOWGTPV2SPARE2.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWGTPV2SPARE2.oneofs_by_name['_decrement']
_PATTERNFLOWARPHARDWARETYPECOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWARPHARDWARETYPECOUNTER.fields_by_name['start'])
_PATTERNFLOWARPHARDWARETYPECOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWARPHARDWARETYPECOUNTER.oneofs_by_name['_start']
_PATTERNFLOWARPHARDWARETYPECOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWARPHARDWARETYPECOUNTER.fields_by_name['step'])
_PATTERNFLOWARPHARDWARETYPECOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWARPHARDWARETYPECOUNTER.oneofs_by_name['_step']
_PATTERNFLOWARPHARDWARETYPECOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWARPHARDWARETYPECOUNTER.fields_by_name['count'])
_PATTERNFLOWARPHARDWARETYPECOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWARPHARDWARETYPECOUNTER.oneofs_by_name['_count']
_PATTERNFLOWARPHARDWARETYPE_CHOICE.containing_type = _PATTERNFLOWARPHARDWARETYPE
_PATTERNFLOWARPHARDWARETYPE_CHOICE_ENUM.containing_type = _PATTERNFLOWARPHARDWARETYPE_CHOICE
_PATTERNFLOWARPHARDWARETYPE.fields_by_name['choice'].enum_type = _PATTERNFLOWARPHARDWARETYPE_CHOICE_ENUM
_PATTERNFLOWARPHARDWARETYPE.fields_by_name['increment'].message_type = _PATTERNFLOWARPHARDWARETYPECOUNTER
_PATTERNFLOWARPHARDWARETYPE.fields_by_name['decrement'].message_type = _PATTERNFLOWARPHARDWARETYPECOUNTER
_PATTERNFLOWARPHARDWARETYPE.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWARPHARDWARETYPE.fields_by_name['choice'])
_PATTERNFLOWARPHARDWARETYPE.fields_by_name['choice'].containing_oneof = _PATTERNFLOWARPHARDWARETYPE.oneofs_by_name['_choice']
_PATTERNFLOWARPHARDWARETYPE.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWARPHARDWARETYPE.fields_by_name['value'])
_PATTERNFLOWARPHARDWARETYPE.fields_by_name['value'].containing_oneof = _PATTERNFLOWARPHARDWARETYPE.oneofs_by_name['_value']
_PATTERNFLOWARPHARDWARETYPE.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWARPHARDWARETYPE.fields_by_name['metric_group'])
_PATTERNFLOWARPHARDWARETYPE.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWARPHARDWARETYPE.oneofs_by_name['_metric_group']
_PATTERNFLOWARPHARDWARETYPE.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWARPHARDWARETYPE.fields_by_name['increment'])
_PATTERNFLOWARPHARDWARETYPE.fields_by_name['increment'].containing_oneof = _PATTERNFLOWARPHARDWARETYPE.oneofs_by_name['_increment']
_PATTERNFLOWARPHARDWARETYPE.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWARPHARDWARETYPE.fields_by_name['decrement'])
_PATTERNFLOWARPHARDWARETYPE.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWARPHARDWARETYPE.oneofs_by_name['_decrement']
_PATTERNFLOWARPPROTOCOLTYPECOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWARPPROTOCOLTYPECOUNTER.fields_by_name['start'])
_PATTERNFLOWARPPROTOCOLTYPECOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWARPPROTOCOLTYPECOUNTER.oneofs_by_name['_start']
_PATTERNFLOWARPPROTOCOLTYPECOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWARPPROTOCOLTYPECOUNTER.fields_by_name['step'])
_PATTERNFLOWARPPROTOCOLTYPECOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWARPPROTOCOLTYPECOUNTER.oneofs_by_name['_step']
_PATTERNFLOWARPPROTOCOLTYPECOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWARPPROTOCOLTYPECOUNTER.fields_by_name['count'])
_PATTERNFLOWARPPROTOCOLTYPECOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWARPPROTOCOLTYPECOUNTER.oneofs_by_name['_count']
_PATTERNFLOWARPPROTOCOLTYPE_CHOICE.containing_type = _PATTERNFLOWARPPROTOCOLTYPE
_PATTERNFLOWARPPROTOCOLTYPE_CHOICE_ENUM.containing_type = _PATTERNFLOWARPPROTOCOLTYPE_CHOICE
_PATTERNFLOWARPPROTOCOLTYPE.fields_by_name['choice'].enum_type = _PATTERNFLOWARPPROTOCOLTYPE_CHOICE_ENUM
_PATTERNFLOWARPPROTOCOLTYPE.fields_by_name['increment'].message_type = _PATTERNFLOWARPPROTOCOLTYPECOUNTER
_PATTERNFLOWARPPROTOCOLTYPE.fields_by_name['decrement'].message_type = _PATTERNFLOWARPPROTOCOLTYPECOUNTER
_PATTERNFLOWARPPROTOCOLTYPE.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWARPPROTOCOLTYPE.fields_by_name['choice'])
_PATTERNFLOWARPPROTOCOLTYPE.fields_by_name['choice'].containing_oneof = _PATTERNFLOWARPPROTOCOLTYPE.oneofs_by_name['_choice']
_PATTERNFLOWARPPROTOCOLTYPE.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWARPPROTOCOLTYPE.fields_by_name['value'])
_PATTERNFLOWARPPROTOCOLTYPE.fields_by_name['value'].containing_oneof = _PATTERNFLOWARPPROTOCOLTYPE.oneofs_by_name['_value']
_PATTERNFLOWARPPROTOCOLTYPE.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWARPPROTOCOLTYPE.fields_by_name['metric_group'])
_PATTERNFLOWARPPROTOCOLTYPE.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWARPPROTOCOLTYPE.oneofs_by_name['_metric_group']
_PATTERNFLOWARPPROTOCOLTYPE.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWARPPROTOCOLTYPE.fields_by_name['increment'])
_PATTERNFLOWARPPROTOCOLTYPE.fields_by_name['increment'].containing_oneof = _PATTERNFLOWARPPROTOCOLTYPE.oneofs_by_name['_increment']
_PATTERNFLOWARPPROTOCOLTYPE.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWARPPROTOCOLTYPE.fields_by_name['decrement'])
_PATTERNFLOWARPPROTOCOLTYPE.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWARPPROTOCOLTYPE.oneofs_by_name['_decrement']
_PATTERNFLOWARPHARDWARELENGTHCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWARPHARDWARELENGTHCOUNTER.fields_by_name['start'])
_PATTERNFLOWARPHARDWARELENGTHCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWARPHARDWARELENGTHCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWARPHARDWARELENGTHCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWARPHARDWARELENGTHCOUNTER.fields_by_name['step'])
_PATTERNFLOWARPHARDWARELENGTHCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWARPHARDWARELENGTHCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWARPHARDWARELENGTHCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWARPHARDWARELENGTHCOUNTER.fields_by_name['count'])
_PATTERNFLOWARPHARDWARELENGTHCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWARPHARDWARELENGTHCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWARPHARDWARELENGTH_CHOICE.containing_type = _PATTERNFLOWARPHARDWARELENGTH
_PATTERNFLOWARPHARDWARELENGTH_CHOICE_ENUM.containing_type = _PATTERNFLOWARPHARDWARELENGTH_CHOICE
_PATTERNFLOWARPHARDWARELENGTH.fields_by_name['choice'].enum_type = _PATTERNFLOWARPHARDWARELENGTH_CHOICE_ENUM
_PATTERNFLOWARPHARDWARELENGTH.fields_by_name['increment'].message_type = _PATTERNFLOWARPHARDWARELENGTHCOUNTER
_PATTERNFLOWARPHARDWARELENGTH.fields_by_name['decrement'].message_type = _PATTERNFLOWARPHARDWARELENGTHCOUNTER
_PATTERNFLOWARPHARDWARELENGTH.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWARPHARDWARELENGTH.fields_by_name['choice'])
_PATTERNFLOWARPHARDWARELENGTH.fields_by_name['choice'].containing_oneof = _PATTERNFLOWARPHARDWARELENGTH.oneofs_by_name['_choice']
_PATTERNFLOWARPHARDWARELENGTH.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWARPHARDWARELENGTH.fields_by_name['value'])
_PATTERNFLOWARPHARDWARELENGTH.fields_by_name['value'].containing_oneof = _PATTERNFLOWARPHARDWARELENGTH.oneofs_by_name['_value']
_PATTERNFLOWARPHARDWARELENGTH.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWARPHARDWARELENGTH.fields_by_name['metric_group'])
_PATTERNFLOWARPHARDWARELENGTH.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWARPHARDWARELENGTH.oneofs_by_name['_metric_group']
_PATTERNFLOWARPHARDWARELENGTH.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWARPHARDWARELENGTH.fields_by_name['increment'])
_PATTERNFLOWARPHARDWARELENGTH.fields_by_name['increment'].containing_oneof = _PATTERNFLOWARPHARDWARELENGTH.oneofs_by_name['_increment']
_PATTERNFLOWARPHARDWARELENGTH.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWARPHARDWARELENGTH.fields_by_name['decrement'])
_PATTERNFLOWARPHARDWARELENGTH.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWARPHARDWARELENGTH.oneofs_by_name['_decrement']
_PATTERNFLOWARPPROTOCOLLENGTHCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWARPPROTOCOLLENGTHCOUNTER.fields_by_name['start'])
_PATTERNFLOWARPPROTOCOLLENGTHCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWARPPROTOCOLLENGTHCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWARPPROTOCOLLENGTHCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWARPPROTOCOLLENGTHCOUNTER.fields_by_name['step'])
_PATTERNFLOWARPPROTOCOLLENGTHCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWARPPROTOCOLLENGTHCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWARPPROTOCOLLENGTHCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWARPPROTOCOLLENGTHCOUNTER.fields_by_name['count'])
_PATTERNFLOWARPPROTOCOLLENGTHCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWARPPROTOCOLLENGTHCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWARPPROTOCOLLENGTH_CHOICE.containing_type = _PATTERNFLOWARPPROTOCOLLENGTH
_PATTERNFLOWARPPROTOCOLLENGTH_CHOICE_ENUM.containing_type = _PATTERNFLOWARPPROTOCOLLENGTH_CHOICE
_PATTERNFLOWARPPROTOCOLLENGTH.fields_by_name['choice'].enum_type = _PATTERNFLOWARPPROTOCOLLENGTH_CHOICE_ENUM
_PATTERNFLOWARPPROTOCOLLENGTH.fields_by_name['increment'].message_type = _PATTERNFLOWARPPROTOCOLLENGTHCOUNTER
_PATTERNFLOWARPPROTOCOLLENGTH.fields_by_name['decrement'].message_type = _PATTERNFLOWARPPROTOCOLLENGTHCOUNTER
_PATTERNFLOWARPPROTOCOLLENGTH.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWARPPROTOCOLLENGTH.fields_by_name['choice'])
_PATTERNFLOWARPPROTOCOLLENGTH.fields_by_name['choice'].containing_oneof = _PATTERNFLOWARPPROTOCOLLENGTH.oneofs_by_name['_choice']
_PATTERNFLOWARPPROTOCOLLENGTH.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWARPPROTOCOLLENGTH.fields_by_name['value'])
_PATTERNFLOWARPPROTOCOLLENGTH.fields_by_name['value'].containing_oneof = _PATTERNFLOWARPPROTOCOLLENGTH.oneofs_by_name['_value']
_PATTERNFLOWARPPROTOCOLLENGTH.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWARPPROTOCOLLENGTH.fields_by_name['metric_group'])
_PATTERNFLOWARPPROTOCOLLENGTH.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWARPPROTOCOLLENGTH.oneofs_by_name['_metric_group']
_PATTERNFLOWARPPROTOCOLLENGTH.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWARPPROTOCOLLENGTH.fields_by_name['increment'])
_PATTERNFLOWARPPROTOCOLLENGTH.fields_by_name['increment'].containing_oneof = _PATTERNFLOWARPPROTOCOLLENGTH.oneofs_by_name['_increment']
_PATTERNFLOWARPPROTOCOLLENGTH.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWARPPROTOCOLLENGTH.fields_by_name['decrement'])
_PATTERNFLOWARPPROTOCOLLENGTH.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWARPPROTOCOLLENGTH.oneofs_by_name['_decrement']
_PATTERNFLOWARPOPERATIONCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWARPOPERATIONCOUNTER.fields_by_name['start'])
_PATTERNFLOWARPOPERATIONCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWARPOPERATIONCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWARPOPERATIONCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWARPOPERATIONCOUNTER.fields_by_name['step'])
_PATTERNFLOWARPOPERATIONCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWARPOPERATIONCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWARPOPERATIONCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWARPOPERATIONCOUNTER.fields_by_name['count'])
_PATTERNFLOWARPOPERATIONCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWARPOPERATIONCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWARPOPERATION_CHOICE.containing_type = _PATTERNFLOWARPOPERATION
_PATTERNFLOWARPOPERATION_CHOICE_ENUM.containing_type = _PATTERNFLOWARPOPERATION_CHOICE
_PATTERNFLOWARPOPERATION.fields_by_name['choice'].enum_type = _PATTERNFLOWARPOPERATION_CHOICE_ENUM
_PATTERNFLOWARPOPERATION.fields_by_name['increment'].message_type = _PATTERNFLOWARPOPERATIONCOUNTER
_PATTERNFLOWARPOPERATION.fields_by_name['decrement'].message_type = _PATTERNFLOWARPOPERATIONCOUNTER
_PATTERNFLOWARPOPERATION.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWARPOPERATION.fields_by_name['choice'])
_PATTERNFLOWARPOPERATION.fields_by_name['choice'].containing_oneof = _PATTERNFLOWARPOPERATION.oneofs_by_name['_choice']
_PATTERNFLOWARPOPERATION.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWARPOPERATION.fields_by_name['value'])
_PATTERNFLOWARPOPERATION.fields_by_name['value'].containing_oneof = _PATTERNFLOWARPOPERATION.oneofs_by_name['_value']
_PATTERNFLOWARPOPERATION.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWARPOPERATION.fields_by_name['metric_group'])
_PATTERNFLOWARPOPERATION.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWARPOPERATION.oneofs_by_name['_metric_group']
_PATTERNFLOWARPOPERATION.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWARPOPERATION.fields_by_name['increment'])
_PATTERNFLOWARPOPERATION.fields_by_name['increment'].containing_oneof = _PATTERNFLOWARPOPERATION.oneofs_by_name['_increment']
_PATTERNFLOWARPOPERATION.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWARPOPERATION.fields_by_name['decrement'])
_PATTERNFLOWARPOPERATION.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWARPOPERATION.oneofs_by_name['_decrement']
_PATTERNFLOWARPSENDERHARDWAREADDRCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWARPSENDERHARDWAREADDRCOUNTER.fields_by_name['start'])
_PATTERNFLOWARPSENDERHARDWAREADDRCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWARPSENDERHARDWAREADDRCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWARPSENDERHARDWAREADDRCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWARPSENDERHARDWAREADDRCOUNTER.fields_by_name['step'])
_PATTERNFLOWARPSENDERHARDWAREADDRCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWARPSENDERHARDWAREADDRCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWARPSENDERHARDWAREADDRCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWARPSENDERHARDWAREADDRCOUNTER.fields_by_name['count'])
_PATTERNFLOWARPSENDERHARDWAREADDRCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWARPSENDERHARDWAREADDRCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWARPSENDERHARDWAREADDR_CHOICE.containing_type = _PATTERNFLOWARPSENDERHARDWAREADDR
_PATTERNFLOWARPSENDERHARDWAREADDR_CHOICE_ENUM.containing_type = _PATTERNFLOWARPSENDERHARDWAREADDR_CHOICE
_PATTERNFLOWARPSENDERHARDWAREADDR.fields_by_name['choice'].enum_type = _PATTERNFLOWARPSENDERHARDWAREADDR_CHOICE_ENUM
_PATTERNFLOWARPSENDERHARDWAREADDR.fields_by_name['increment'].message_type = _PATTERNFLOWARPSENDERHARDWAREADDRCOUNTER
_PATTERNFLOWARPSENDERHARDWAREADDR.fields_by_name['decrement'].message_type = _PATTERNFLOWARPSENDERHARDWAREADDRCOUNTER
_PATTERNFLOWARPSENDERHARDWAREADDR.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWARPSENDERHARDWAREADDR.fields_by_name['choice'])
_PATTERNFLOWARPSENDERHARDWAREADDR.fields_by_name['choice'].containing_oneof = _PATTERNFLOWARPSENDERHARDWAREADDR.oneofs_by_name['_choice']
_PATTERNFLOWARPSENDERHARDWAREADDR.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWARPSENDERHARDWAREADDR.fields_by_name['value'])
_PATTERNFLOWARPSENDERHARDWAREADDR.fields_by_name['value'].containing_oneof = _PATTERNFLOWARPSENDERHARDWAREADDR.oneofs_by_name['_value']
_PATTERNFLOWARPSENDERHARDWAREADDR.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWARPSENDERHARDWAREADDR.fields_by_name['metric_group'])
_PATTERNFLOWARPSENDERHARDWAREADDR.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWARPSENDERHARDWAREADDR.oneofs_by_name['_metric_group']
_PATTERNFLOWARPSENDERHARDWAREADDR.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWARPSENDERHARDWAREADDR.fields_by_name['increment'])
_PATTERNFLOWARPSENDERHARDWAREADDR.fields_by_name['increment'].containing_oneof = _PATTERNFLOWARPSENDERHARDWAREADDR.oneofs_by_name['_increment']
_PATTERNFLOWARPSENDERHARDWAREADDR.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWARPSENDERHARDWAREADDR.fields_by_name['decrement'])
_PATTERNFLOWARPSENDERHARDWAREADDR.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWARPSENDERHARDWAREADDR.oneofs_by_name['_decrement']
_PATTERNFLOWARPSENDERPROTOCOLADDRCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWARPSENDERPROTOCOLADDRCOUNTER.fields_by_name['start'])
_PATTERNFLOWARPSENDERPROTOCOLADDRCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWARPSENDERPROTOCOLADDRCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWARPSENDERPROTOCOLADDRCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWARPSENDERPROTOCOLADDRCOUNTER.fields_by_name['step'])
_PATTERNFLOWARPSENDERPROTOCOLADDRCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWARPSENDERPROTOCOLADDRCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWARPSENDERPROTOCOLADDRCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWARPSENDERPROTOCOLADDRCOUNTER.fields_by_name['count'])
_PATTERNFLOWARPSENDERPROTOCOLADDRCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWARPSENDERPROTOCOLADDRCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWARPSENDERPROTOCOLADDR_CHOICE.containing_type = _PATTERNFLOWARPSENDERPROTOCOLADDR
_PATTERNFLOWARPSENDERPROTOCOLADDR_CHOICE_ENUM.containing_type = _PATTERNFLOWARPSENDERPROTOCOLADDR_CHOICE
_PATTERNFLOWARPSENDERPROTOCOLADDR.fields_by_name['choice'].enum_type = _PATTERNFLOWARPSENDERPROTOCOLADDR_CHOICE_ENUM
_PATTERNFLOWARPSENDERPROTOCOLADDR.fields_by_name['increment'].message_type = _PATTERNFLOWARPSENDERPROTOCOLADDRCOUNTER
_PATTERNFLOWARPSENDERPROTOCOLADDR.fields_by_name['decrement'].message_type = _PATTERNFLOWARPSENDERPROTOCOLADDRCOUNTER
_PATTERNFLOWARPSENDERPROTOCOLADDR.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWARPSENDERPROTOCOLADDR.fields_by_name['choice'])
_PATTERNFLOWARPSENDERPROTOCOLADDR.fields_by_name['choice'].containing_oneof = _PATTERNFLOWARPSENDERPROTOCOLADDR.oneofs_by_name['_choice']
_PATTERNFLOWARPSENDERPROTOCOLADDR.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWARPSENDERPROTOCOLADDR.fields_by_name['value'])
_PATTERNFLOWARPSENDERPROTOCOLADDR.fields_by_name['value'].containing_oneof = _PATTERNFLOWARPSENDERPROTOCOLADDR.oneofs_by_name['_value']
_PATTERNFLOWARPSENDERPROTOCOLADDR.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWARPSENDERPROTOCOLADDR.fields_by_name['metric_group'])
_PATTERNFLOWARPSENDERPROTOCOLADDR.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWARPSENDERPROTOCOLADDR.oneofs_by_name['_metric_group']
_PATTERNFLOWARPSENDERPROTOCOLADDR.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWARPSENDERPROTOCOLADDR.fields_by_name['increment'])
_PATTERNFLOWARPSENDERPROTOCOLADDR.fields_by_name['increment'].containing_oneof = _PATTERNFLOWARPSENDERPROTOCOLADDR.oneofs_by_name['_increment']
_PATTERNFLOWARPSENDERPROTOCOLADDR.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWARPSENDERPROTOCOLADDR.fields_by_name['decrement'])
_PATTERNFLOWARPSENDERPROTOCOLADDR.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWARPSENDERPROTOCOLADDR.oneofs_by_name['_decrement']
_PATTERNFLOWARPTARGETHARDWAREADDRCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWARPTARGETHARDWAREADDRCOUNTER.fields_by_name['start'])
_PATTERNFLOWARPTARGETHARDWAREADDRCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWARPTARGETHARDWAREADDRCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWARPTARGETHARDWAREADDRCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWARPTARGETHARDWAREADDRCOUNTER.fields_by_name['step'])
_PATTERNFLOWARPTARGETHARDWAREADDRCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWARPTARGETHARDWAREADDRCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWARPTARGETHARDWAREADDRCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWARPTARGETHARDWAREADDRCOUNTER.fields_by_name['count'])
_PATTERNFLOWARPTARGETHARDWAREADDRCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWARPTARGETHARDWAREADDRCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWARPTARGETHARDWAREADDR_CHOICE.containing_type = _PATTERNFLOWARPTARGETHARDWAREADDR
_PATTERNFLOWARPTARGETHARDWAREADDR_CHOICE_ENUM.containing_type = _PATTERNFLOWARPTARGETHARDWAREADDR_CHOICE
_PATTERNFLOWARPTARGETHARDWAREADDR.fields_by_name['choice'].enum_type = _PATTERNFLOWARPTARGETHARDWAREADDR_CHOICE_ENUM
_PATTERNFLOWARPTARGETHARDWAREADDR.fields_by_name['increment'].message_type = _PATTERNFLOWARPTARGETHARDWAREADDRCOUNTER
_PATTERNFLOWARPTARGETHARDWAREADDR.fields_by_name['decrement'].message_type = _PATTERNFLOWARPTARGETHARDWAREADDRCOUNTER
_PATTERNFLOWARPTARGETHARDWAREADDR.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWARPTARGETHARDWAREADDR.fields_by_name['choice'])
_PATTERNFLOWARPTARGETHARDWAREADDR.fields_by_name['choice'].containing_oneof = _PATTERNFLOWARPTARGETHARDWAREADDR.oneofs_by_name['_choice']
_PATTERNFLOWARPTARGETHARDWAREADDR.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWARPTARGETHARDWAREADDR.fields_by_name['value'])
_PATTERNFLOWARPTARGETHARDWAREADDR.fields_by_name['value'].containing_oneof = _PATTERNFLOWARPTARGETHARDWAREADDR.oneofs_by_name['_value']
_PATTERNFLOWARPTARGETHARDWAREADDR.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWARPTARGETHARDWAREADDR.fields_by_name['metric_group'])
_PATTERNFLOWARPTARGETHARDWAREADDR.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWARPTARGETHARDWAREADDR.oneofs_by_name['_metric_group']
_PATTERNFLOWARPTARGETHARDWAREADDR.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWARPTARGETHARDWAREADDR.fields_by_name['increment'])
_PATTERNFLOWARPTARGETHARDWAREADDR.fields_by_name['increment'].containing_oneof = _PATTERNFLOWARPTARGETHARDWAREADDR.oneofs_by_name['_increment']
_PATTERNFLOWARPTARGETHARDWAREADDR.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWARPTARGETHARDWAREADDR.fields_by_name['decrement'])
_PATTERNFLOWARPTARGETHARDWAREADDR.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWARPTARGETHARDWAREADDR.oneofs_by_name['_decrement']
_PATTERNFLOWARPTARGETPROTOCOLADDRCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWARPTARGETPROTOCOLADDRCOUNTER.fields_by_name['start'])
_PATTERNFLOWARPTARGETPROTOCOLADDRCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWARPTARGETPROTOCOLADDRCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWARPTARGETPROTOCOLADDRCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWARPTARGETPROTOCOLADDRCOUNTER.fields_by_name['step'])
_PATTERNFLOWARPTARGETPROTOCOLADDRCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWARPTARGETPROTOCOLADDRCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWARPTARGETPROTOCOLADDRCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWARPTARGETPROTOCOLADDRCOUNTER.fields_by_name['count'])
_PATTERNFLOWARPTARGETPROTOCOLADDRCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWARPTARGETPROTOCOLADDRCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWARPTARGETPROTOCOLADDR_CHOICE.containing_type = _PATTERNFLOWARPTARGETPROTOCOLADDR
_PATTERNFLOWARPTARGETPROTOCOLADDR_CHOICE_ENUM.containing_type = _PATTERNFLOWARPTARGETPROTOCOLADDR_CHOICE
_PATTERNFLOWARPTARGETPROTOCOLADDR.fields_by_name['choice'].enum_type = _PATTERNFLOWARPTARGETPROTOCOLADDR_CHOICE_ENUM
_PATTERNFLOWARPTARGETPROTOCOLADDR.fields_by_name['increment'].message_type = _PATTERNFLOWARPTARGETPROTOCOLADDRCOUNTER
_PATTERNFLOWARPTARGETPROTOCOLADDR.fields_by_name['decrement'].message_type = _PATTERNFLOWARPTARGETPROTOCOLADDRCOUNTER
_PATTERNFLOWARPTARGETPROTOCOLADDR.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWARPTARGETPROTOCOLADDR.fields_by_name['choice'])
_PATTERNFLOWARPTARGETPROTOCOLADDR.fields_by_name['choice'].containing_oneof = _PATTERNFLOWARPTARGETPROTOCOLADDR.oneofs_by_name['_choice']
_PATTERNFLOWARPTARGETPROTOCOLADDR.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWARPTARGETPROTOCOLADDR.fields_by_name['value'])
_PATTERNFLOWARPTARGETPROTOCOLADDR.fields_by_name['value'].containing_oneof = _PATTERNFLOWARPTARGETPROTOCOLADDR.oneofs_by_name['_value']
_PATTERNFLOWARPTARGETPROTOCOLADDR.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWARPTARGETPROTOCOLADDR.fields_by_name['metric_group'])
_PATTERNFLOWARPTARGETPROTOCOLADDR.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWARPTARGETPROTOCOLADDR.oneofs_by_name['_metric_group']
_PATTERNFLOWARPTARGETPROTOCOLADDR.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWARPTARGETPROTOCOLADDR.fields_by_name['increment'])
_PATTERNFLOWARPTARGETPROTOCOLADDR.fields_by_name['increment'].containing_oneof = _PATTERNFLOWARPTARGETPROTOCOLADDR.oneofs_by_name['_increment']
_PATTERNFLOWARPTARGETPROTOCOLADDR.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWARPTARGETPROTOCOLADDR.fields_by_name['decrement'])
_PATTERNFLOWARPTARGETPROTOCOLADDR.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWARPTARGETPROTOCOLADDR.oneofs_by_name['_decrement']
_PATTERNFLOWICMPECHOTYPECOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWICMPECHOTYPECOUNTER.fields_by_name['start'])
_PATTERNFLOWICMPECHOTYPECOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWICMPECHOTYPECOUNTER.oneofs_by_name['_start']
_PATTERNFLOWICMPECHOTYPECOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWICMPECHOTYPECOUNTER.fields_by_name['step'])
_PATTERNFLOWICMPECHOTYPECOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWICMPECHOTYPECOUNTER.oneofs_by_name['_step']
_PATTERNFLOWICMPECHOTYPECOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWICMPECHOTYPECOUNTER.fields_by_name['count'])
_PATTERNFLOWICMPECHOTYPECOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWICMPECHOTYPECOUNTER.oneofs_by_name['_count']
_PATTERNFLOWICMPECHOTYPE_CHOICE.containing_type = _PATTERNFLOWICMPECHOTYPE
_PATTERNFLOWICMPECHOTYPE_CHOICE_ENUM.containing_type = _PATTERNFLOWICMPECHOTYPE_CHOICE
_PATTERNFLOWICMPECHOTYPE.fields_by_name['choice'].enum_type = _PATTERNFLOWICMPECHOTYPE_CHOICE_ENUM
_PATTERNFLOWICMPECHOTYPE.fields_by_name['increment'].message_type = _PATTERNFLOWICMPECHOTYPECOUNTER
_PATTERNFLOWICMPECHOTYPE.fields_by_name['decrement'].message_type = _PATTERNFLOWICMPECHOTYPECOUNTER
_PATTERNFLOWICMPECHOTYPE.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWICMPECHOTYPE.fields_by_name['choice'])
_PATTERNFLOWICMPECHOTYPE.fields_by_name['choice'].containing_oneof = _PATTERNFLOWICMPECHOTYPE.oneofs_by_name['_choice']
_PATTERNFLOWICMPECHOTYPE.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWICMPECHOTYPE.fields_by_name['value'])
_PATTERNFLOWICMPECHOTYPE.fields_by_name['value'].containing_oneof = _PATTERNFLOWICMPECHOTYPE.oneofs_by_name['_value']
_PATTERNFLOWICMPECHOTYPE.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWICMPECHOTYPE.fields_by_name['metric_group'])
_PATTERNFLOWICMPECHOTYPE.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWICMPECHOTYPE.oneofs_by_name['_metric_group']
_PATTERNFLOWICMPECHOTYPE.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWICMPECHOTYPE.fields_by_name['increment'])
_PATTERNFLOWICMPECHOTYPE.fields_by_name['increment'].containing_oneof = _PATTERNFLOWICMPECHOTYPE.oneofs_by_name['_increment']
_PATTERNFLOWICMPECHOTYPE.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWICMPECHOTYPE.fields_by_name['decrement'])
_PATTERNFLOWICMPECHOTYPE.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWICMPECHOTYPE.oneofs_by_name['_decrement']
_PATTERNFLOWICMPECHOCODECOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWICMPECHOCODECOUNTER.fields_by_name['start'])
_PATTERNFLOWICMPECHOCODECOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWICMPECHOCODECOUNTER.oneofs_by_name['_start']
_PATTERNFLOWICMPECHOCODECOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWICMPECHOCODECOUNTER.fields_by_name['step'])
_PATTERNFLOWICMPECHOCODECOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWICMPECHOCODECOUNTER.oneofs_by_name['_step']
_PATTERNFLOWICMPECHOCODECOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWICMPECHOCODECOUNTER.fields_by_name['count'])
_PATTERNFLOWICMPECHOCODECOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWICMPECHOCODECOUNTER.oneofs_by_name['_count']
_PATTERNFLOWICMPECHOCODE_CHOICE.containing_type = _PATTERNFLOWICMPECHOCODE
_PATTERNFLOWICMPECHOCODE_CHOICE_ENUM.containing_type = _PATTERNFLOWICMPECHOCODE_CHOICE
_PATTERNFLOWICMPECHOCODE.fields_by_name['choice'].enum_type = _PATTERNFLOWICMPECHOCODE_CHOICE_ENUM
_PATTERNFLOWICMPECHOCODE.fields_by_name['increment'].message_type = _PATTERNFLOWICMPECHOCODECOUNTER
_PATTERNFLOWICMPECHOCODE.fields_by_name['decrement'].message_type = _PATTERNFLOWICMPECHOCODECOUNTER
_PATTERNFLOWICMPECHOCODE.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWICMPECHOCODE.fields_by_name['choice'])
_PATTERNFLOWICMPECHOCODE.fields_by_name['choice'].containing_oneof = _PATTERNFLOWICMPECHOCODE.oneofs_by_name['_choice']
_PATTERNFLOWICMPECHOCODE.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWICMPECHOCODE.fields_by_name['value'])
_PATTERNFLOWICMPECHOCODE.fields_by_name['value'].containing_oneof = _PATTERNFLOWICMPECHOCODE.oneofs_by_name['_value']
_PATTERNFLOWICMPECHOCODE.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWICMPECHOCODE.fields_by_name['metric_group'])
_PATTERNFLOWICMPECHOCODE.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWICMPECHOCODE.oneofs_by_name['_metric_group']
_PATTERNFLOWICMPECHOCODE.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWICMPECHOCODE.fields_by_name['increment'])
_PATTERNFLOWICMPECHOCODE.fields_by_name['increment'].containing_oneof = _PATTERNFLOWICMPECHOCODE.oneofs_by_name['_increment']
_PATTERNFLOWICMPECHOCODE.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWICMPECHOCODE.fields_by_name['decrement'])
_PATTERNFLOWICMPECHOCODE.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWICMPECHOCODE.oneofs_by_name['_decrement']
_PATTERNFLOWICMPECHOCHECKSUM_CHOICE.containing_type = _PATTERNFLOWICMPECHOCHECKSUM
_PATTERNFLOWICMPECHOCHECKSUM_CHOICE_ENUM.containing_type = _PATTERNFLOWICMPECHOCHECKSUM_CHOICE
_PATTERNFLOWICMPECHOCHECKSUM_GENERATED.containing_type = _PATTERNFLOWICMPECHOCHECKSUM
_PATTERNFLOWICMPECHOCHECKSUM_GENERATED_ENUM.containing_type = _PATTERNFLOWICMPECHOCHECKSUM_GENERATED
_PATTERNFLOWICMPECHOCHECKSUM.fields_by_name['choice'].enum_type = _PATTERNFLOWICMPECHOCHECKSUM_CHOICE_ENUM
_PATTERNFLOWICMPECHOCHECKSUM.fields_by_name['generated'].enum_type = _PATTERNFLOWICMPECHOCHECKSUM_GENERATED_ENUM
_PATTERNFLOWICMPECHOCHECKSUM.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWICMPECHOCHECKSUM.fields_by_name['choice'])
_PATTERNFLOWICMPECHOCHECKSUM.fields_by_name['choice'].containing_oneof = _PATTERNFLOWICMPECHOCHECKSUM.oneofs_by_name['_choice']
_PATTERNFLOWICMPECHOCHECKSUM.oneofs_by_name['_generated'].fields.append(
  _PATTERNFLOWICMPECHOCHECKSUM.fields_by_name['generated'])
_PATTERNFLOWICMPECHOCHECKSUM.fields_by_name['generated'].containing_oneof = _PATTERNFLOWICMPECHOCHECKSUM.oneofs_by_name['_generated']
_PATTERNFLOWICMPECHOCHECKSUM.oneofs_by_name['_custom'].fields.append(
  _PATTERNFLOWICMPECHOCHECKSUM.fields_by_name['custom'])
_PATTERNFLOWICMPECHOCHECKSUM.fields_by_name['custom'].containing_oneof = _PATTERNFLOWICMPECHOCHECKSUM.oneofs_by_name['_custom']
_PATTERNFLOWICMPECHOIDENTIFIERCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWICMPECHOIDENTIFIERCOUNTER.fields_by_name['start'])
_PATTERNFLOWICMPECHOIDENTIFIERCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWICMPECHOIDENTIFIERCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWICMPECHOIDENTIFIERCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWICMPECHOIDENTIFIERCOUNTER.fields_by_name['step'])
_PATTERNFLOWICMPECHOIDENTIFIERCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWICMPECHOIDENTIFIERCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWICMPECHOIDENTIFIERCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWICMPECHOIDENTIFIERCOUNTER.fields_by_name['count'])
_PATTERNFLOWICMPECHOIDENTIFIERCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWICMPECHOIDENTIFIERCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWICMPECHOIDENTIFIER_CHOICE.containing_type = _PATTERNFLOWICMPECHOIDENTIFIER
_PATTERNFLOWICMPECHOIDENTIFIER_CHOICE_ENUM.containing_type = _PATTERNFLOWICMPECHOIDENTIFIER_CHOICE
_PATTERNFLOWICMPECHOIDENTIFIER.fields_by_name['choice'].enum_type = _PATTERNFLOWICMPECHOIDENTIFIER_CHOICE_ENUM
_PATTERNFLOWICMPECHOIDENTIFIER.fields_by_name['increment'].message_type = _PATTERNFLOWICMPECHOIDENTIFIERCOUNTER
_PATTERNFLOWICMPECHOIDENTIFIER.fields_by_name['decrement'].message_type = _PATTERNFLOWICMPECHOIDENTIFIERCOUNTER
_PATTERNFLOWICMPECHOIDENTIFIER.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWICMPECHOIDENTIFIER.fields_by_name['choice'])
_PATTERNFLOWICMPECHOIDENTIFIER.fields_by_name['choice'].containing_oneof = _PATTERNFLOWICMPECHOIDENTIFIER.oneofs_by_name['_choice']
_PATTERNFLOWICMPECHOIDENTIFIER.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWICMPECHOIDENTIFIER.fields_by_name['value'])
_PATTERNFLOWICMPECHOIDENTIFIER.fields_by_name['value'].containing_oneof = _PATTERNFLOWICMPECHOIDENTIFIER.oneofs_by_name['_value']
_PATTERNFLOWICMPECHOIDENTIFIER.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWICMPECHOIDENTIFIER.fields_by_name['metric_group'])
_PATTERNFLOWICMPECHOIDENTIFIER.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWICMPECHOIDENTIFIER.oneofs_by_name['_metric_group']
_PATTERNFLOWICMPECHOIDENTIFIER.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWICMPECHOIDENTIFIER.fields_by_name['increment'])
_PATTERNFLOWICMPECHOIDENTIFIER.fields_by_name['increment'].containing_oneof = _PATTERNFLOWICMPECHOIDENTIFIER.oneofs_by_name['_increment']
_PATTERNFLOWICMPECHOIDENTIFIER.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWICMPECHOIDENTIFIER.fields_by_name['decrement'])
_PATTERNFLOWICMPECHOIDENTIFIER.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWICMPECHOIDENTIFIER.oneofs_by_name['_decrement']
_PATTERNFLOWICMPECHOSEQUENCENUMBERCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWICMPECHOSEQUENCENUMBERCOUNTER.fields_by_name['start'])
_PATTERNFLOWICMPECHOSEQUENCENUMBERCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWICMPECHOSEQUENCENUMBERCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWICMPECHOSEQUENCENUMBERCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWICMPECHOSEQUENCENUMBERCOUNTER.fields_by_name['step'])
_PATTERNFLOWICMPECHOSEQUENCENUMBERCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWICMPECHOSEQUENCENUMBERCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWICMPECHOSEQUENCENUMBERCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWICMPECHOSEQUENCENUMBERCOUNTER.fields_by_name['count'])
_PATTERNFLOWICMPECHOSEQUENCENUMBERCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWICMPECHOSEQUENCENUMBERCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWICMPECHOSEQUENCENUMBER_CHOICE.containing_type = _PATTERNFLOWICMPECHOSEQUENCENUMBER
_PATTERNFLOWICMPECHOSEQUENCENUMBER_CHOICE_ENUM.containing_type = _PATTERNFLOWICMPECHOSEQUENCENUMBER_CHOICE
_PATTERNFLOWICMPECHOSEQUENCENUMBER.fields_by_name['choice'].enum_type = _PATTERNFLOWICMPECHOSEQUENCENUMBER_CHOICE_ENUM
_PATTERNFLOWICMPECHOSEQUENCENUMBER.fields_by_name['increment'].message_type = _PATTERNFLOWICMPECHOSEQUENCENUMBERCOUNTER
_PATTERNFLOWICMPECHOSEQUENCENUMBER.fields_by_name['decrement'].message_type = _PATTERNFLOWICMPECHOSEQUENCENUMBERCOUNTER
_PATTERNFLOWICMPECHOSEQUENCENUMBER.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWICMPECHOSEQUENCENUMBER.fields_by_name['choice'])
_PATTERNFLOWICMPECHOSEQUENCENUMBER.fields_by_name['choice'].containing_oneof = _PATTERNFLOWICMPECHOSEQUENCENUMBER.oneofs_by_name['_choice']
_PATTERNFLOWICMPECHOSEQUENCENUMBER.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWICMPECHOSEQUENCENUMBER.fields_by_name['value'])
_PATTERNFLOWICMPECHOSEQUENCENUMBER.fields_by_name['value'].containing_oneof = _PATTERNFLOWICMPECHOSEQUENCENUMBER.oneofs_by_name['_value']
_PATTERNFLOWICMPECHOSEQUENCENUMBER.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWICMPECHOSEQUENCENUMBER.fields_by_name['metric_group'])
_PATTERNFLOWICMPECHOSEQUENCENUMBER.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWICMPECHOSEQUENCENUMBER.oneofs_by_name['_metric_group']
_PATTERNFLOWICMPECHOSEQUENCENUMBER.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWICMPECHOSEQUENCENUMBER.fields_by_name['increment'])
_PATTERNFLOWICMPECHOSEQUENCENUMBER.fields_by_name['increment'].containing_oneof = _PATTERNFLOWICMPECHOSEQUENCENUMBER.oneofs_by_name['_increment']
_PATTERNFLOWICMPECHOSEQUENCENUMBER.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWICMPECHOSEQUENCENUMBER.fields_by_name['decrement'])
_PATTERNFLOWICMPECHOSEQUENCENUMBER.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWICMPECHOSEQUENCENUMBER.oneofs_by_name['_decrement']
_PATTERNFLOWICMPCOMMONCHECKSUM_CHOICE.containing_type = _PATTERNFLOWICMPCOMMONCHECKSUM
_PATTERNFLOWICMPCOMMONCHECKSUM_CHOICE_ENUM.containing_type = _PATTERNFLOWICMPCOMMONCHECKSUM_CHOICE
_PATTERNFLOWICMPCOMMONCHECKSUM_GENERATED.containing_type = _PATTERNFLOWICMPCOMMONCHECKSUM
_PATTERNFLOWICMPCOMMONCHECKSUM_GENERATED_ENUM.containing_type = _PATTERNFLOWICMPCOMMONCHECKSUM_GENERATED
_PATTERNFLOWICMPCOMMONCHECKSUM.fields_by_name['choice'].enum_type = _PATTERNFLOWICMPCOMMONCHECKSUM_CHOICE_ENUM
_PATTERNFLOWICMPCOMMONCHECKSUM.fields_by_name['generated'].enum_type = _PATTERNFLOWICMPCOMMONCHECKSUM_GENERATED_ENUM
_PATTERNFLOWICMPCOMMONCHECKSUM.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWICMPCOMMONCHECKSUM.fields_by_name['choice'])
_PATTERNFLOWICMPCOMMONCHECKSUM.fields_by_name['choice'].containing_oneof = _PATTERNFLOWICMPCOMMONCHECKSUM.oneofs_by_name['_choice']
_PATTERNFLOWICMPCOMMONCHECKSUM.oneofs_by_name['_generated'].fields.append(
  _PATTERNFLOWICMPCOMMONCHECKSUM.fields_by_name['generated'])
_PATTERNFLOWICMPCOMMONCHECKSUM.fields_by_name['generated'].containing_oneof = _PATTERNFLOWICMPCOMMONCHECKSUM.oneofs_by_name['_generated']
_PATTERNFLOWICMPCOMMONCHECKSUM.oneofs_by_name['_custom'].fields.append(
  _PATTERNFLOWICMPCOMMONCHECKSUM.fields_by_name['custom'])
_PATTERNFLOWICMPCOMMONCHECKSUM.fields_by_name['custom'].containing_oneof = _PATTERNFLOWICMPCOMMONCHECKSUM.oneofs_by_name['_custom']
_PATTERNFLOWICMPNEXTFIELDSIDENTIFIERCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWICMPNEXTFIELDSIDENTIFIERCOUNTER.fields_by_name['start'])
_PATTERNFLOWICMPNEXTFIELDSIDENTIFIERCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWICMPNEXTFIELDSIDENTIFIERCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWICMPNEXTFIELDSIDENTIFIERCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWICMPNEXTFIELDSIDENTIFIERCOUNTER.fields_by_name['step'])
_PATTERNFLOWICMPNEXTFIELDSIDENTIFIERCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWICMPNEXTFIELDSIDENTIFIERCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWICMPNEXTFIELDSIDENTIFIERCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWICMPNEXTFIELDSIDENTIFIERCOUNTER.fields_by_name['count'])
_PATTERNFLOWICMPNEXTFIELDSIDENTIFIERCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWICMPNEXTFIELDSIDENTIFIERCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER_CHOICE.containing_type = _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER
_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER_CHOICE_ENUM.containing_type = _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER_CHOICE
_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER.fields_by_name['choice'].enum_type = _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER_CHOICE_ENUM
_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER.fields_by_name['increment'].message_type = _PATTERNFLOWICMPNEXTFIELDSIDENTIFIERCOUNTER
_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER.fields_by_name['decrement'].message_type = _PATTERNFLOWICMPNEXTFIELDSIDENTIFIERCOUNTER
_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER.fields_by_name['choice'])
_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER.fields_by_name['choice'].containing_oneof = _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER.oneofs_by_name['_choice']
_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER.fields_by_name['value'])
_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER.fields_by_name['value'].containing_oneof = _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER.oneofs_by_name['_value']
_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER.fields_by_name['metric_group'])
_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER.oneofs_by_name['_metric_group']
_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER.fields_by_name['increment'])
_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER.fields_by_name['increment'].containing_oneof = _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER.oneofs_by_name['_increment']
_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER.fields_by_name['decrement'])
_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER.oneofs_by_name['_decrement']
_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERCOUNTER.fields_by_name['start'])
_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERCOUNTER.fields_by_name['step'])
_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERCOUNTER.fields_by_name['count'])
_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER_CHOICE.containing_type = _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER
_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER_CHOICE_ENUM.containing_type = _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER_CHOICE
_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER.fields_by_name['choice'].enum_type = _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER_CHOICE_ENUM
_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER.fields_by_name['increment'].message_type = _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERCOUNTER
_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER.fields_by_name['decrement'].message_type = _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERCOUNTER
_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER.fields_by_name['choice'])
_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER.fields_by_name['choice'].containing_oneof = _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER.oneofs_by_name['_choice']
_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER.fields_by_name['value'])
_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER.fields_by_name['value'].containing_oneof = _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER.oneofs_by_name['_value']
_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER.fields_by_name['metric_group'])
_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER.oneofs_by_name['_metric_group']
_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER.fields_by_name['increment'])
_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER.fields_by_name['increment'].containing_oneof = _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER.oneofs_by_name['_increment']
_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER.fields_by_name['decrement'])
_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER.oneofs_by_name['_decrement']
_PATTERNFLOWICMPV6ECHOTYPECOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWICMPV6ECHOTYPECOUNTER.fields_by_name['start'])
_PATTERNFLOWICMPV6ECHOTYPECOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWICMPV6ECHOTYPECOUNTER.oneofs_by_name['_start']
_PATTERNFLOWICMPV6ECHOTYPECOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWICMPV6ECHOTYPECOUNTER.fields_by_name['step'])
_PATTERNFLOWICMPV6ECHOTYPECOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWICMPV6ECHOTYPECOUNTER.oneofs_by_name['_step']
_PATTERNFLOWICMPV6ECHOTYPECOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWICMPV6ECHOTYPECOUNTER.fields_by_name['count'])
_PATTERNFLOWICMPV6ECHOTYPECOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWICMPV6ECHOTYPECOUNTER.oneofs_by_name['_count']
_PATTERNFLOWICMPV6ECHOTYPE_CHOICE.containing_type = _PATTERNFLOWICMPV6ECHOTYPE
_PATTERNFLOWICMPV6ECHOTYPE_CHOICE_ENUM.containing_type = _PATTERNFLOWICMPV6ECHOTYPE_CHOICE
_PATTERNFLOWICMPV6ECHOTYPE.fields_by_name['choice'].enum_type = _PATTERNFLOWICMPV6ECHOTYPE_CHOICE_ENUM
_PATTERNFLOWICMPV6ECHOTYPE.fields_by_name['increment'].message_type = _PATTERNFLOWICMPV6ECHOTYPECOUNTER
_PATTERNFLOWICMPV6ECHOTYPE.fields_by_name['decrement'].message_type = _PATTERNFLOWICMPV6ECHOTYPECOUNTER
_PATTERNFLOWICMPV6ECHOTYPE.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWICMPV6ECHOTYPE.fields_by_name['choice'])
_PATTERNFLOWICMPV6ECHOTYPE.fields_by_name['choice'].containing_oneof = _PATTERNFLOWICMPV6ECHOTYPE.oneofs_by_name['_choice']
_PATTERNFLOWICMPV6ECHOTYPE.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWICMPV6ECHOTYPE.fields_by_name['value'])
_PATTERNFLOWICMPV6ECHOTYPE.fields_by_name['value'].containing_oneof = _PATTERNFLOWICMPV6ECHOTYPE.oneofs_by_name['_value']
_PATTERNFLOWICMPV6ECHOTYPE.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWICMPV6ECHOTYPE.fields_by_name['metric_group'])
_PATTERNFLOWICMPV6ECHOTYPE.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWICMPV6ECHOTYPE.oneofs_by_name['_metric_group']
_PATTERNFLOWICMPV6ECHOTYPE.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWICMPV6ECHOTYPE.fields_by_name['increment'])
_PATTERNFLOWICMPV6ECHOTYPE.fields_by_name['increment'].containing_oneof = _PATTERNFLOWICMPV6ECHOTYPE.oneofs_by_name['_increment']
_PATTERNFLOWICMPV6ECHOTYPE.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWICMPV6ECHOTYPE.fields_by_name['decrement'])
_PATTERNFLOWICMPV6ECHOTYPE.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWICMPV6ECHOTYPE.oneofs_by_name['_decrement']
_PATTERNFLOWICMPV6ECHOCODECOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWICMPV6ECHOCODECOUNTER.fields_by_name['start'])
_PATTERNFLOWICMPV6ECHOCODECOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWICMPV6ECHOCODECOUNTER.oneofs_by_name['_start']
_PATTERNFLOWICMPV6ECHOCODECOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWICMPV6ECHOCODECOUNTER.fields_by_name['step'])
_PATTERNFLOWICMPV6ECHOCODECOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWICMPV6ECHOCODECOUNTER.oneofs_by_name['_step']
_PATTERNFLOWICMPV6ECHOCODECOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWICMPV6ECHOCODECOUNTER.fields_by_name['count'])
_PATTERNFLOWICMPV6ECHOCODECOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWICMPV6ECHOCODECOUNTER.oneofs_by_name['_count']
_PATTERNFLOWICMPV6ECHOCODE_CHOICE.containing_type = _PATTERNFLOWICMPV6ECHOCODE
_PATTERNFLOWICMPV6ECHOCODE_CHOICE_ENUM.containing_type = _PATTERNFLOWICMPV6ECHOCODE_CHOICE
_PATTERNFLOWICMPV6ECHOCODE.fields_by_name['choice'].enum_type = _PATTERNFLOWICMPV6ECHOCODE_CHOICE_ENUM
_PATTERNFLOWICMPV6ECHOCODE.fields_by_name['increment'].message_type = _PATTERNFLOWICMPV6ECHOCODECOUNTER
_PATTERNFLOWICMPV6ECHOCODE.fields_by_name['decrement'].message_type = _PATTERNFLOWICMPV6ECHOCODECOUNTER
_PATTERNFLOWICMPV6ECHOCODE.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWICMPV6ECHOCODE.fields_by_name['choice'])
_PATTERNFLOWICMPV6ECHOCODE.fields_by_name['choice'].containing_oneof = _PATTERNFLOWICMPV6ECHOCODE.oneofs_by_name['_choice']
_PATTERNFLOWICMPV6ECHOCODE.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWICMPV6ECHOCODE.fields_by_name['value'])
_PATTERNFLOWICMPV6ECHOCODE.fields_by_name['value'].containing_oneof = _PATTERNFLOWICMPV6ECHOCODE.oneofs_by_name['_value']
_PATTERNFLOWICMPV6ECHOCODE.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWICMPV6ECHOCODE.fields_by_name['metric_group'])
_PATTERNFLOWICMPV6ECHOCODE.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWICMPV6ECHOCODE.oneofs_by_name['_metric_group']
_PATTERNFLOWICMPV6ECHOCODE.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWICMPV6ECHOCODE.fields_by_name['increment'])
_PATTERNFLOWICMPV6ECHOCODE.fields_by_name['increment'].containing_oneof = _PATTERNFLOWICMPV6ECHOCODE.oneofs_by_name['_increment']
_PATTERNFLOWICMPV6ECHOCODE.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWICMPV6ECHOCODE.fields_by_name['decrement'])
_PATTERNFLOWICMPV6ECHOCODE.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWICMPV6ECHOCODE.oneofs_by_name['_decrement']
_PATTERNFLOWICMPV6ECHOIDENTIFIERCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWICMPV6ECHOIDENTIFIERCOUNTER.fields_by_name['start'])
_PATTERNFLOWICMPV6ECHOIDENTIFIERCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWICMPV6ECHOIDENTIFIERCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWICMPV6ECHOIDENTIFIERCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWICMPV6ECHOIDENTIFIERCOUNTER.fields_by_name['step'])
_PATTERNFLOWICMPV6ECHOIDENTIFIERCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWICMPV6ECHOIDENTIFIERCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWICMPV6ECHOIDENTIFIERCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWICMPV6ECHOIDENTIFIERCOUNTER.fields_by_name['count'])
_PATTERNFLOWICMPV6ECHOIDENTIFIERCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWICMPV6ECHOIDENTIFIERCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWICMPV6ECHOIDENTIFIER_CHOICE.containing_type = _PATTERNFLOWICMPV6ECHOIDENTIFIER
_PATTERNFLOWICMPV6ECHOIDENTIFIER_CHOICE_ENUM.containing_type = _PATTERNFLOWICMPV6ECHOIDENTIFIER_CHOICE
_PATTERNFLOWICMPV6ECHOIDENTIFIER.fields_by_name['choice'].enum_type = _PATTERNFLOWICMPV6ECHOIDENTIFIER_CHOICE_ENUM
_PATTERNFLOWICMPV6ECHOIDENTIFIER.fields_by_name['increment'].message_type = _PATTERNFLOWICMPV6ECHOIDENTIFIERCOUNTER
_PATTERNFLOWICMPV6ECHOIDENTIFIER.fields_by_name['decrement'].message_type = _PATTERNFLOWICMPV6ECHOIDENTIFIERCOUNTER
_PATTERNFLOWICMPV6ECHOIDENTIFIER.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWICMPV6ECHOIDENTIFIER.fields_by_name['choice'])
_PATTERNFLOWICMPV6ECHOIDENTIFIER.fields_by_name['choice'].containing_oneof = _PATTERNFLOWICMPV6ECHOIDENTIFIER.oneofs_by_name['_choice']
_PATTERNFLOWICMPV6ECHOIDENTIFIER.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWICMPV6ECHOIDENTIFIER.fields_by_name['value'])
_PATTERNFLOWICMPV6ECHOIDENTIFIER.fields_by_name['value'].containing_oneof = _PATTERNFLOWICMPV6ECHOIDENTIFIER.oneofs_by_name['_value']
_PATTERNFLOWICMPV6ECHOIDENTIFIER.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWICMPV6ECHOIDENTIFIER.fields_by_name['metric_group'])
_PATTERNFLOWICMPV6ECHOIDENTIFIER.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWICMPV6ECHOIDENTIFIER.oneofs_by_name['_metric_group']
_PATTERNFLOWICMPV6ECHOIDENTIFIER.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWICMPV6ECHOIDENTIFIER.fields_by_name['increment'])
_PATTERNFLOWICMPV6ECHOIDENTIFIER.fields_by_name['increment'].containing_oneof = _PATTERNFLOWICMPV6ECHOIDENTIFIER.oneofs_by_name['_increment']
_PATTERNFLOWICMPV6ECHOIDENTIFIER.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWICMPV6ECHOIDENTIFIER.fields_by_name['decrement'])
_PATTERNFLOWICMPV6ECHOIDENTIFIER.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWICMPV6ECHOIDENTIFIER.oneofs_by_name['_decrement']
_PATTERNFLOWICMPV6ECHOSEQUENCENUMBERCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWICMPV6ECHOSEQUENCENUMBERCOUNTER.fields_by_name['start'])
_PATTERNFLOWICMPV6ECHOSEQUENCENUMBERCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWICMPV6ECHOSEQUENCENUMBERCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWICMPV6ECHOSEQUENCENUMBERCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWICMPV6ECHOSEQUENCENUMBERCOUNTER.fields_by_name['step'])
_PATTERNFLOWICMPV6ECHOSEQUENCENUMBERCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWICMPV6ECHOSEQUENCENUMBERCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWICMPV6ECHOSEQUENCENUMBERCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWICMPV6ECHOSEQUENCENUMBERCOUNTER.fields_by_name['count'])
_PATTERNFLOWICMPV6ECHOSEQUENCENUMBERCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWICMPV6ECHOSEQUENCENUMBERCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER_CHOICE.containing_type = _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER
_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER_CHOICE_ENUM.containing_type = _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER_CHOICE
_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER.fields_by_name['choice'].enum_type = _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER_CHOICE_ENUM
_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER.fields_by_name['increment'].message_type = _PATTERNFLOWICMPV6ECHOSEQUENCENUMBERCOUNTER
_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER.fields_by_name['decrement'].message_type = _PATTERNFLOWICMPV6ECHOSEQUENCENUMBERCOUNTER
_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER.fields_by_name['choice'])
_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER.fields_by_name['choice'].containing_oneof = _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER.oneofs_by_name['_choice']
_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER.fields_by_name['value'])
_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER.fields_by_name['value'].containing_oneof = _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER.oneofs_by_name['_value']
_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER.fields_by_name['metric_group'])
_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER.oneofs_by_name['_metric_group']
_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER.fields_by_name['increment'])
_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER.fields_by_name['increment'].containing_oneof = _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER.oneofs_by_name['_increment']
_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER.fields_by_name['decrement'])
_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER.oneofs_by_name['_decrement']
_PATTERNFLOWICMPV6ECHOCHECKSUM_CHOICE.containing_type = _PATTERNFLOWICMPV6ECHOCHECKSUM
_PATTERNFLOWICMPV6ECHOCHECKSUM_CHOICE_ENUM.containing_type = _PATTERNFLOWICMPV6ECHOCHECKSUM_CHOICE
_PATTERNFLOWICMPV6ECHOCHECKSUM_GENERATED.containing_type = _PATTERNFLOWICMPV6ECHOCHECKSUM
_PATTERNFLOWICMPV6ECHOCHECKSUM_GENERATED_ENUM.containing_type = _PATTERNFLOWICMPV6ECHOCHECKSUM_GENERATED
_PATTERNFLOWICMPV6ECHOCHECKSUM.fields_by_name['choice'].enum_type = _PATTERNFLOWICMPV6ECHOCHECKSUM_CHOICE_ENUM
_PATTERNFLOWICMPV6ECHOCHECKSUM.fields_by_name['generated'].enum_type = _PATTERNFLOWICMPV6ECHOCHECKSUM_GENERATED_ENUM
_PATTERNFLOWICMPV6ECHOCHECKSUM.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWICMPV6ECHOCHECKSUM.fields_by_name['choice'])
_PATTERNFLOWICMPV6ECHOCHECKSUM.fields_by_name['choice'].containing_oneof = _PATTERNFLOWICMPV6ECHOCHECKSUM.oneofs_by_name['_choice']
_PATTERNFLOWICMPV6ECHOCHECKSUM.oneofs_by_name['_generated'].fields.append(
  _PATTERNFLOWICMPV6ECHOCHECKSUM.fields_by_name['generated'])
_PATTERNFLOWICMPV6ECHOCHECKSUM.fields_by_name['generated'].containing_oneof = _PATTERNFLOWICMPV6ECHOCHECKSUM.oneofs_by_name['_generated']
_PATTERNFLOWICMPV6ECHOCHECKSUM.oneofs_by_name['_custom'].fields.append(
  _PATTERNFLOWICMPV6ECHOCHECKSUM.fields_by_name['custom'])
_PATTERNFLOWICMPV6ECHOCHECKSUM.fields_by_name['custom'].containing_oneof = _PATTERNFLOWICMPV6ECHOCHECKSUM.oneofs_by_name['_custom']
_PATTERNFLOWICMPV6COMMONCHECKSUM_CHOICE.containing_type = _PATTERNFLOWICMPV6COMMONCHECKSUM
_PATTERNFLOWICMPV6COMMONCHECKSUM_CHOICE_ENUM.containing_type = _PATTERNFLOWICMPV6COMMONCHECKSUM_CHOICE
_PATTERNFLOWICMPV6COMMONCHECKSUM_GENERATED.containing_type = _PATTERNFLOWICMPV6COMMONCHECKSUM
_PATTERNFLOWICMPV6COMMONCHECKSUM_GENERATED_ENUM.containing_type = _PATTERNFLOWICMPV6COMMONCHECKSUM_GENERATED
_PATTERNFLOWICMPV6COMMONCHECKSUM.fields_by_name['choice'].enum_type = _PATTERNFLOWICMPV6COMMONCHECKSUM_CHOICE_ENUM
_PATTERNFLOWICMPV6COMMONCHECKSUM.fields_by_name['generated'].enum_type = _PATTERNFLOWICMPV6COMMONCHECKSUM_GENERATED_ENUM
_PATTERNFLOWICMPV6COMMONCHECKSUM.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWICMPV6COMMONCHECKSUM.fields_by_name['choice'])
_PATTERNFLOWICMPV6COMMONCHECKSUM.fields_by_name['choice'].containing_oneof = _PATTERNFLOWICMPV6COMMONCHECKSUM.oneofs_by_name['_choice']
_PATTERNFLOWICMPV6COMMONCHECKSUM.oneofs_by_name['_generated'].fields.append(
  _PATTERNFLOWICMPV6COMMONCHECKSUM.fields_by_name['generated'])
_PATTERNFLOWICMPV6COMMONCHECKSUM.fields_by_name['generated'].containing_oneof = _PATTERNFLOWICMPV6COMMONCHECKSUM.oneofs_by_name['_generated']
_PATTERNFLOWICMPV6COMMONCHECKSUM.oneofs_by_name['_custom'].fields.append(
  _PATTERNFLOWICMPV6COMMONCHECKSUM.fields_by_name['custom'])
_PATTERNFLOWICMPV6COMMONCHECKSUM.fields_by_name['custom'].containing_oneof = _PATTERNFLOWICMPV6COMMONCHECKSUM.oneofs_by_name['_custom']
_PATTERNFLOWPPPADDRESSCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWPPPADDRESSCOUNTER.fields_by_name['start'])
_PATTERNFLOWPPPADDRESSCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWPPPADDRESSCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWPPPADDRESSCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWPPPADDRESSCOUNTER.fields_by_name['step'])
_PATTERNFLOWPPPADDRESSCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWPPPADDRESSCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWPPPADDRESSCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWPPPADDRESSCOUNTER.fields_by_name['count'])
_PATTERNFLOWPPPADDRESSCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWPPPADDRESSCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWPPPADDRESS_CHOICE.containing_type = _PATTERNFLOWPPPADDRESS
_PATTERNFLOWPPPADDRESS_CHOICE_ENUM.containing_type = _PATTERNFLOWPPPADDRESS_CHOICE
_PATTERNFLOWPPPADDRESS.fields_by_name['choice'].enum_type = _PATTERNFLOWPPPADDRESS_CHOICE_ENUM
_PATTERNFLOWPPPADDRESS.fields_by_name['increment'].message_type = _PATTERNFLOWPPPADDRESSCOUNTER
_PATTERNFLOWPPPADDRESS.fields_by_name['decrement'].message_type = _PATTERNFLOWPPPADDRESSCOUNTER
_PATTERNFLOWPPPADDRESS.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWPPPADDRESS.fields_by_name['choice'])
_PATTERNFLOWPPPADDRESS.fields_by_name['choice'].containing_oneof = _PATTERNFLOWPPPADDRESS.oneofs_by_name['_choice']
_PATTERNFLOWPPPADDRESS.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWPPPADDRESS.fields_by_name['value'])
_PATTERNFLOWPPPADDRESS.fields_by_name['value'].containing_oneof = _PATTERNFLOWPPPADDRESS.oneofs_by_name['_value']
_PATTERNFLOWPPPADDRESS.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWPPPADDRESS.fields_by_name['metric_group'])
_PATTERNFLOWPPPADDRESS.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWPPPADDRESS.oneofs_by_name['_metric_group']
_PATTERNFLOWPPPADDRESS.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWPPPADDRESS.fields_by_name['increment'])
_PATTERNFLOWPPPADDRESS.fields_by_name['increment'].containing_oneof = _PATTERNFLOWPPPADDRESS.oneofs_by_name['_increment']
_PATTERNFLOWPPPADDRESS.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWPPPADDRESS.fields_by_name['decrement'])
_PATTERNFLOWPPPADDRESS.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWPPPADDRESS.oneofs_by_name['_decrement']
_PATTERNFLOWPPPCONTROLCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWPPPCONTROLCOUNTER.fields_by_name['start'])
_PATTERNFLOWPPPCONTROLCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWPPPCONTROLCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWPPPCONTROLCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWPPPCONTROLCOUNTER.fields_by_name['step'])
_PATTERNFLOWPPPCONTROLCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWPPPCONTROLCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWPPPCONTROLCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWPPPCONTROLCOUNTER.fields_by_name['count'])
_PATTERNFLOWPPPCONTROLCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWPPPCONTROLCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWPPPCONTROL_CHOICE.containing_type = _PATTERNFLOWPPPCONTROL
_PATTERNFLOWPPPCONTROL_CHOICE_ENUM.containing_type = _PATTERNFLOWPPPCONTROL_CHOICE
_PATTERNFLOWPPPCONTROL.fields_by_name['choice'].enum_type = _PATTERNFLOWPPPCONTROL_CHOICE_ENUM
_PATTERNFLOWPPPCONTROL.fields_by_name['increment'].message_type = _PATTERNFLOWPPPCONTROLCOUNTER
_PATTERNFLOWPPPCONTROL.fields_by_name['decrement'].message_type = _PATTERNFLOWPPPCONTROLCOUNTER
_PATTERNFLOWPPPCONTROL.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWPPPCONTROL.fields_by_name['choice'])
_PATTERNFLOWPPPCONTROL.fields_by_name['choice'].containing_oneof = _PATTERNFLOWPPPCONTROL.oneofs_by_name['_choice']
_PATTERNFLOWPPPCONTROL.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWPPPCONTROL.fields_by_name['value'])
_PATTERNFLOWPPPCONTROL.fields_by_name['value'].containing_oneof = _PATTERNFLOWPPPCONTROL.oneofs_by_name['_value']
_PATTERNFLOWPPPCONTROL.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWPPPCONTROL.fields_by_name['metric_group'])
_PATTERNFLOWPPPCONTROL.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWPPPCONTROL.oneofs_by_name['_metric_group']
_PATTERNFLOWPPPCONTROL.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWPPPCONTROL.fields_by_name['increment'])
_PATTERNFLOWPPPCONTROL.fields_by_name['increment'].containing_oneof = _PATTERNFLOWPPPCONTROL.oneofs_by_name['_increment']
_PATTERNFLOWPPPCONTROL.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWPPPCONTROL.fields_by_name['decrement'])
_PATTERNFLOWPPPCONTROL.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWPPPCONTROL.oneofs_by_name['_decrement']
_PATTERNFLOWPPPPROTOCOLTYPECOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWPPPPROTOCOLTYPECOUNTER.fields_by_name['start'])
_PATTERNFLOWPPPPROTOCOLTYPECOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWPPPPROTOCOLTYPECOUNTER.oneofs_by_name['_start']
_PATTERNFLOWPPPPROTOCOLTYPECOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWPPPPROTOCOLTYPECOUNTER.fields_by_name['step'])
_PATTERNFLOWPPPPROTOCOLTYPECOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWPPPPROTOCOLTYPECOUNTER.oneofs_by_name['_step']
_PATTERNFLOWPPPPROTOCOLTYPECOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWPPPPROTOCOLTYPECOUNTER.fields_by_name['count'])
_PATTERNFLOWPPPPROTOCOLTYPECOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWPPPPROTOCOLTYPECOUNTER.oneofs_by_name['_count']
_PATTERNFLOWPPPPROTOCOLTYPE_CHOICE.containing_type = _PATTERNFLOWPPPPROTOCOLTYPE
_PATTERNFLOWPPPPROTOCOLTYPE_CHOICE_ENUM.containing_type = _PATTERNFLOWPPPPROTOCOLTYPE_CHOICE
_PATTERNFLOWPPPPROTOCOLTYPE_AUTO.containing_type = _PATTERNFLOWPPPPROTOCOLTYPE
_PATTERNFLOWPPPPROTOCOLTYPE_AUTO_ENUM.containing_type = _PATTERNFLOWPPPPROTOCOLTYPE_AUTO
_PATTERNFLOWPPPPROTOCOLTYPE.fields_by_name['choice'].enum_type = _PATTERNFLOWPPPPROTOCOLTYPE_CHOICE_ENUM
_PATTERNFLOWPPPPROTOCOLTYPE.fields_by_name['auto'].enum_type = _PATTERNFLOWPPPPROTOCOLTYPE_AUTO_ENUM
_PATTERNFLOWPPPPROTOCOLTYPE.fields_by_name['increment'].message_type = _PATTERNFLOWPPPPROTOCOLTYPECOUNTER
_PATTERNFLOWPPPPROTOCOLTYPE.fields_by_name['decrement'].message_type = _PATTERNFLOWPPPPROTOCOLTYPECOUNTER
_PATTERNFLOWPPPPROTOCOLTYPE.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWPPPPROTOCOLTYPE.fields_by_name['choice'])
_PATTERNFLOWPPPPROTOCOLTYPE.fields_by_name['choice'].containing_oneof = _PATTERNFLOWPPPPROTOCOLTYPE.oneofs_by_name['_choice']
_PATTERNFLOWPPPPROTOCOLTYPE.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWPPPPROTOCOLTYPE.fields_by_name['value'])
_PATTERNFLOWPPPPROTOCOLTYPE.fields_by_name['value'].containing_oneof = _PATTERNFLOWPPPPROTOCOLTYPE.oneofs_by_name['_value']
_PATTERNFLOWPPPPROTOCOLTYPE.oneofs_by_name['_auto'].fields.append(
  _PATTERNFLOWPPPPROTOCOLTYPE.fields_by_name['auto'])
_PATTERNFLOWPPPPROTOCOLTYPE.fields_by_name['auto'].containing_oneof = _PATTERNFLOWPPPPROTOCOLTYPE.oneofs_by_name['_auto']
_PATTERNFLOWPPPPROTOCOLTYPE.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWPPPPROTOCOLTYPE.fields_by_name['metric_group'])
_PATTERNFLOWPPPPROTOCOLTYPE.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWPPPPROTOCOLTYPE.oneofs_by_name['_metric_group']
_PATTERNFLOWPPPPROTOCOLTYPE.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWPPPPROTOCOLTYPE.fields_by_name['increment'])
_PATTERNFLOWPPPPROTOCOLTYPE.fields_by_name['increment'].containing_oneof = _PATTERNFLOWPPPPROTOCOLTYPE.oneofs_by_name['_increment']
_PATTERNFLOWPPPPROTOCOLTYPE.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWPPPPROTOCOLTYPE.fields_by_name['decrement'])
_PATTERNFLOWPPPPROTOCOLTYPE.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWPPPPROTOCOLTYPE.oneofs_by_name['_decrement']
_PATTERNFLOWIGMPV1VERSIONCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWIGMPV1VERSIONCOUNTER.fields_by_name['start'])
_PATTERNFLOWIGMPV1VERSIONCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWIGMPV1VERSIONCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWIGMPV1VERSIONCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWIGMPV1VERSIONCOUNTER.fields_by_name['step'])
_PATTERNFLOWIGMPV1VERSIONCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWIGMPV1VERSIONCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWIGMPV1VERSIONCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWIGMPV1VERSIONCOUNTER.fields_by_name['count'])
_PATTERNFLOWIGMPV1VERSIONCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWIGMPV1VERSIONCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWIGMPV1VERSION_CHOICE.containing_type = _PATTERNFLOWIGMPV1VERSION
_PATTERNFLOWIGMPV1VERSION_CHOICE_ENUM.containing_type = _PATTERNFLOWIGMPV1VERSION_CHOICE
_PATTERNFLOWIGMPV1VERSION.fields_by_name['choice'].enum_type = _PATTERNFLOWIGMPV1VERSION_CHOICE_ENUM
_PATTERNFLOWIGMPV1VERSION.fields_by_name['increment'].message_type = _PATTERNFLOWIGMPV1VERSIONCOUNTER
_PATTERNFLOWIGMPV1VERSION.fields_by_name['decrement'].message_type = _PATTERNFLOWIGMPV1VERSIONCOUNTER
_PATTERNFLOWIGMPV1VERSION.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWIGMPV1VERSION.fields_by_name['choice'])
_PATTERNFLOWIGMPV1VERSION.fields_by_name['choice'].containing_oneof = _PATTERNFLOWIGMPV1VERSION.oneofs_by_name['_choice']
_PATTERNFLOWIGMPV1VERSION.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWIGMPV1VERSION.fields_by_name['value'])
_PATTERNFLOWIGMPV1VERSION.fields_by_name['value'].containing_oneof = _PATTERNFLOWIGMPV1VERSION.oneofs_by_name['_value']
_PATTERNFLOWIGMPV1VERSION.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWIGMPV1VERSION.fields_by_name['metric_group'])
_PATTERNFLOWIGMPV1VERSION.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWIGMPV1VERSION.oneofs_by_name['_metric_group']
_PATTERNFLOWIGMPV1VERSION.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWIGMPV1VERSION.fields_by_name['increment'])
_PATTERNFLOWIGMPV1VERSION.fields_by_name['increment'].containing_oneof = _PATTERNFLOWIGMPV1VERSION.oneofs_by_name['_increment']
_PATTERNFLOWIGMPV1VERSION.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWIGMPV1VERSION.fields_by_name['decrement'])
_PATTERNFLOWIGMPV1VERSION.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWIGMPV1VERSION.oneofs_by_name['_decrement']
_PATTERNFLOWIGMPV1TYPECOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWIGMPV1TYPECOUNTER.fields_by_name['start'])
_PATTERNFLOWIGMPV1TYPECOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWIGMPV1TYPECOUNTER.oneofs_by_name['_start']
_PATTERNFLOWIGMPV1TYPECOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWIGMPV1TYPECOUNTER.fields_by_name['step'])
_PATTERNFLOWIGMPV1TYPECOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWIGMPV1TYPECOUNTER.oneofs_by_name['_step']
_PATTERNFLOWIGMPV1TYPECOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWIGMPV1TYPECOUNTER.fields_by_name['count'])
_PATTERNFLOWIGMPV1TYPECOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWIGMPV1TYPECOUNTER.oneofs_by_name['_count']
_PATTERNFLOWIGMPV1TYPE_CHOICE.containing_type = _PATTERNFLOWIGMPV1TYPE
_PATTERNFLOWIGMPV1TYPE_CHOICE_ENUM.containing_type = _PATTERNFLOWIGMPV1TYPE_CHOICE
_PATTERNFLOWIGMPV1TYPE.fields_by_name['choice'].enum_type = _PATTERNFLOWIGMPV1TYPE_CHOICE_ENUM
_PATTERNFLOWIGMPV1TYPE.fields_by_name['increment'].message_type = _PATTERNFLOWIGMPV1TYPECOUNTER
_PATTERNFLOWIGMPV1TYPE.fields_by_name['decrement'].message_type = _PATTERNFLOWIGMPV1TYPECOUNTER
_PATTERNFLOWIGMPV1TYPE.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWIGMPV1TYPE.fields_by_name['choice'])
_PATTERNFLOWIGMPV1TYPE.fields_by_name['choice'].containing_oneof = _PATTERNFLOWIGMPV1TYPE.oneofs_by_name['_choice']
_PATTERNFLOWIGMPV1TYPE.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWIGMPV1TYPE.fields_by_name['value'])
_PATTERNFLOWIGMPV1TYPE.fields_by_name['value'].containing_oneof = _PATTERNFLOWIGMPV1TYPE.oneofs_by_name['_value']
_PATTERNFLOWIGMPV1TYPE.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWIGMPV1TYPE.fields_by_name['metric_group'])
_PATTERNFLOWIGMPV1TYPE.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWIGMPV1TYPE.oneofs_by_name['_metric_group']
_PATTERNFLOWIGMPV1TYPE.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWIGMPV1TYPE.fields_by_name['increment'])
_PATTERNFLOWIGMPV1TYPE.fields_by_name['increment'].containing_oneof = _PATTERNFLOWIGMPV1TYPE.oneofs_by_name['_increment']
_PATTERNFLOWIGMPV1TYPE.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWIGMPV1TYPE.fields_by_name['decrement'])
_PATTERNFLOWIGMPV1TYPE.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWIGMPV1TYPE.oneofs_by_name['_decrement']
_PATTERNFLOWIGMPV1UNUSEDCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWIGMPV1UNUSEDCOUNTER.fields_by_name['start'])
_PATTERNFLOWIGMPV1UNUSEDCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWIGMPV1UNUSEDCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWIGMPV1UNUSEDCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWIGMPV1UNUSEDCOUNTER.fields_by_name['step'])
_PATTERNFLOWIGMPV1UNUSEDCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWIGMPV1UNUSEDCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWIGMPV1UNUSEDCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWIGMPV1UNUSEDCOUNTER.fields_by_name['count'])
_PATTERNFLOWIGMPV1UNUSEDCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWIGMPV1UNUSEDCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWIGMPV1UNUSED_CHOICE.containing_type = _PATTERNFLOWIGMPV1UNUSED
_PATTERNFLOWIGMPV1UNUSED_CHOICE_ENUM.containing_type = _PATTERNFLOWIGMPV1UNUSED_CHOICE
_PATTERNFLOWIGMPV1UNUSED.fields_by_name['choice'].enum_type = _PATTERNFLOWIGMPV1UNUSED_CHOICE_ENUM
_PATTERNFLOWIGMPV1UNUSED.fields_by_name['increment'].message_type = _PATTERNFLOWIGMPV1UNUSEDCOUNTER
_PATTERNFLOWIGMPV1UNUSED.fields_by_name['decrement'].message_type = _PATTERNFLOWIGMPV1UNUSEDCOUNTER
_PATTERNFLOWIGMPV1UNUSED.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWIGMPV1UNUSED.fields_by_name['choice'])
_PATTERNFLOWIGMPV1UNUSED.fields_by_name['choice'].containing_oneof = _PATTERNFLOWIGMPV1UNUSED.oneofs_by_name['_choice']
_PATTERNFLOWIGMPV1UNUSED.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWIGMPV1UNUSED.fields_by_name['value'])
_PATTERNFLOWIGMPV1UNUSED.fields_by_name['value'].containing_oneof = _PATTERNFLOWIGMPV1UNUSED.oneofs_by_name['_value']
_PATTERNFLOWIGMPV1UNUSED.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWIGMPV1UNUSED.fields_by_name['metric_group'])
_PATTERNFLOWIGMPV1UNUSED.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWIGMPV1UNUSED.oneofs_by_name['_metric_group']
_PATTERNFLOWIGMPV1UNUSED.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWIGMPV1UNUSED.fields_by_name['increment'])
_PATTERNFLOWIGMPV1UNUSED.fields_by_name['increment'].containing_oneof = _PATTERNFLOWIGMPV1UNUSED.oneofs_by_name['_increment']
_PATTERNFLOWIGMPV1UNUSED.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWIGMPV1UNUSED.fields_by_name['decrement'])
_PATTERNFLOWIGMPV1UNUSED.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWIGMPV1UNUSED.oneofs_by_name['_decrement']
_PATTERNFLOWIGMPV1CHECKSUM_CHOICE.containing_type = _PATTERNFLOWIGMPV1CHECKSUM
_PATTERNFLOWIGMPV1CHECKSUM_CHOICE_ENUM.containing_type = _PATTERNFLOWIGMPV1CHECKSUM_CHOICE
_PATTERNFLOWIGMPV1CHECKSUM_GENERATED.containing_type = _PATTERNFLOWIGMPV1CHECKSUM
_PATTERNFLOWIGMPV1CHECKSUM_GENERATED_ENUM.containing_type = _PATTERNFLOWIGMPV1CHECKSUM_GENERATED
_PATTERNFLOWIGMPV1CHECKSUM.fields_by_name['choice'].enum_type = _PATTERNFLOWIGMPV1CHECKSUM_CHOICE_ENUM
_PATTERNFLOWIGMPV1CHECKSUM.fields_by_name['generated'].enum_type = _PATTERNFLOWIGMPV1CHECKSUM_GENERATED_ENUM
_PATTERNFLOWIGMPV1CHECKSUM.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWIGMPV1CHECKSUM.fields_by_name['choice'])
_PATTERNFLOWIGMPV1CHECKSUM.fields_by_name['choice'].containing_oneof = _PATTERNFLOWIGMPV1CHECKSUM.oneofs_by_name['_choice']
_PATTERNFLOWIGMPV1CHECKSUM.oneofs_by_name['_generated'].fields.append(
  _PATTERNFLOWIGMPV1CHECKSUM.fields_by_name['generated'])
_PATTERNFLOWIGMPV1CHECKSUM.fields_by_name['generated'].containing_oneof = _PATTERNFLOWIGMPV1CHECKSUM.oneofs_by_name['_generated']
_PATTERNFLOWIGMPV1CHECKSUM.oneofs_by_name['_custom'].fields.append(
  _PATTERNFLOWIGMPV1CHECKSUM.fields_by_name['custom'])
_PATTERNFLOWIGMPV1CHECKSUM.fields_by_name['custom'].containing_oneof = _PATTERNFLOWIGMPV1CHECKSUM.oneofs_by_name['_custom']
_PATTERNFLOWIGMPV1GROUPADDRESSCOUNTER.oneofs_by_name['_start'].fields.append(
  _PATTERNFLOWIGMPV1GROUPADDRESSCOUNTER.fields_by_name['start'])
_PATTERNFLOWIGMPV1GROUPADDRESSCOUNTER.fields_by_name['start'].containing_oneof = _PATTERNFLOWIGMPV1GROUPADDRESSCOUNTER.oneofs_by_name['_start']
_PATTERNFLOWIGMPV1GROUPADDRESSCOUNTER.oneofs_by_name['_step'].fields.append(
  _PATTERNFLOWIGMPV1GROUPADDRESSCOUNTER.fields_by_name['step'])
_PATTERNFLOWIGMPV1GROUPADDRESSCOUNTER.fields_by_name['step'].containing_oneof = _PATTERNFLOWIGMPV1GROUPADDRESSCOUNTER.oneofs_by_name['_step']
_PATTERNFLOWIGMPV1GROUPADDRESSCOUNTER.oneofs_by_name['_count'].fields.append(
  _PATTERNFLOWIGMPV1GROUPADDRESSCOUNTER.fields_by_name['count'])
_PATTERNFLOWIGMPV1GROUPADDRESSCOUNTER.fields_by_name['count'].containing_oneof = _PATTERNFLOWIGMPV1GROUPADDRESSCOUNTER.oneofs_by_name['_count']
_PATTERNFLOWIGMPV1GROUPADDRESS_CHOICE.containing_type = _PATTERNFLOWIGMPV1GROUPADDRESS
_PATTERNFLOWIGMPV1GROUPADDRESS_CHOICE_ENUM.containing_type = _PATTERNFLOWIGMPV1GROUPADDRESS_CHOICE
_PATTERNFLOWIGMPV1GROUPADDRESS.fields_by_name['choice'].enum_type = _PATTERNFLOWIGMPV1GROUPADDRESS_CHOICE_ENUM
_PATTERNFLOWIGMPV1GROUPADDRESS.fields_by_name['increment'].message_type = _PATTERNFLOWIGMPV1GROUPADDRESSCOUNTER
_PATTERNFLOWIGMPV1GROUPADDRESS.fields_by_name['decrement'].message_type = _PATTERNFLOWIGMPV1GROUPADDRESSCOUNTER
_PATTERNFLOWIGMPV1GROUPADDRESS.oneofs_by_name['_choice'].fields.append(
  _PATTERNFLOWIGMPV1GROUPADDRESS.fields_by_name['choice'])
_PATTERNFLOWIGMPV1GROUPADDRESS.fields_by_name['choice'].containing_oneof = _PATTERNFLOWIGMPV1GROUPADDRESS.oneofs_by_name['_choice']
_PATTERNFLOWIGMPV1GROUPADDRESS.oneofs_by_name['_value'].fields.append(
  _PATTERNFLOWIGMPV1GROUPADDRESS.fields_by_name['value'])
_PATTERNFLOWIGMPV1GROUPADDRESS.fields_by_name['value'].containing_oneof = _PATTERNFLOWIGMPV1GROUPADDRESS.oneofs_by_name['_value']
_PATTERNFLOWIGMPV1GROUPADDRESS.oneofs_by_name['_metric_group'].fields.append(
  _PATTERNFLOWIGMPV1GROUPADDRESS.fields_by_name['metric_group'])
_PATTERNFLOWIGMPV1GROUPADDRESS.fields_by_name['metric_group'].containing_oneof = _PATTERNFLOWIGMPV1GROUPADDRESS.oneofs_by_name['_metric_group']
_PATTERNFLOWIGMPV1GROUPADDRESS.oneofs_by_name['_increment'].fields.append(
  _PATTERNFLOWIGMPV1GROUPADDRESS.fields_by_name['increment'])
_PATTERNFLOWIGMPV1GROUPADDRESS.fields_by_name['increment'].containing_oneof = _PATTERNFLOWIGMPV1GROUPADDRESS.oneofs_by_name['_increment']
_PATTERNFLOWIGMPV1GROUPADDRESS.oneofs_by_name['_decrement'].fields.append(
  _PATTERNFLOWIGMPV1GROUPADDRESS.fields_by_name['decrement'])
_PATTERNFLOWIGMPV1GROUPADDRESS.fields_by_name['decrement'].containing_oneof = _PATTERNFLOWIGMPV1GROUPADDRESS.oneofs_by_name['_decrement']
_SUCCESS.fields_by_name['response_warning'].message_type = _RESPONSEWARNING
_BADREQUEST.fields_by_name['response_error'].message_type = _RESPONSEERROR
_INTERNALSERVERERROR.fields_by_name['response_error'].message_type = _RESPONSEERROR
_SETCONFIGREQUEST.fields_by_name['config'].message_type = _CONFIG
_SETCONFIGRESPONSE.fields_by_name['status_code_200'].message_type = _RESPONSEWARNING
_SETCONFIGRESPONSE.fields_by_name['status_code_400'].message_type = _RESPONSEERROR
_SETCONFIGRESPONSE.fields_by_name['status_code_500'].message_type = _RESPONSEERROR
_SETCONFIGRESPONSE.oneofs_by_name['_status_code_200'].fields.append(
  _SETCONFIGRESPONSE.fields_by_name['status_code_200'])
_SETCONFIGRESPONSE.fields_by_name['status_code_200'].containing_oneof = _SETCONFIGRESPONSE.oneofs_by_name['_status_code_200']
_SETCONFIGRESPONSE.oneofs_by_name['_status_code_400'].fields.append(
  _SETCONFIGRESPONSE.fields_by_name['status_code_400'])
_SETCONFIGRESPONSE.fields_by_name['status_code_400'].containing_oneof = _SETCONFIGRESPONSE.oneofs_by_name['_status_code_400']
_SETCONFIGRESPONSE.oneofs_by_name['_status_code_500'].fields.append(
  _SETCONFIGRESPONSE.fields_by_name['status_code_500'])
_SETCONFIGRESPONSE.fields_by_name['status_code_500'].containing_oneof = _SETCONFIGRESPONSE.oneofs_by_name['_status_code_500']
_GETCONFIGRESPONSE.fields_by_name['status_code_200'].message_type = _CONFIG
_GETCONFIGRESPONSE.fields_by_name['status_code_400'].message_type = _RESPONSEERROR
_GETCONFIGRESPONSE.fields_by_name['status_code_500'].message_type = _RESPONSEERROR
_GETCONFIGRESPONSE.oneofs_by_name['_status_code_200'].fields.append(
  _GETCONFIGRESPONSE.fields_by_name['status_code_200'])
_GETCONFIGRESPONSE.fields_by_name['status_code_200'].containing_oneof = _GETCONFIGRESPONSE.oneofs_by_name['_status_code_200']
_GETCONFIGRESPONSE.oneofs_by_name['_status_code_400'].fields.append(
  _GETCONFIGRESPONSE.fields_by_name['status_code_400'])
_GETCONFIGRESPONSE.fields_by_name['status_code_400'].containing_oneof = _GETCONFIGRESPONSE.oneofs_by_name['_status_code_400']
_GETCONFIGRESPONSE.oneofs_by_name['_status_code_500'].fields.append(
  _GETCONFIGRESPONSE.fields_by_name['status_code_500'])
_GETCONFIGRESPONSE.fields_by_name['status_code_500'].containing_oneof = _GETCONFIGRESPONSE.oneofs_by_name['_status_code_500']
_SETTRANSMITSTATEREQUEST.fields_by_name['transmit_state'].message_type = _TRANSMITSTATE
_SETTRANSMITSTATERESPONSE.fields_by_name['status_code_200'].message_type = _RESPONSEWARNING
_SETTRANSMITSTATERESPONSE.fields_by_name['status_code_400'].message_type = _RESPONSEERROR
_SETTRANSMITSTATERESPONSE.fields_by_name['status_code_500'].message_type = _RESPONSEERROR
_SETTRANSMITSTATERESPONSE.oneofs_by_name['_status_code_200'].fields.append(
  _SETTRANSMITSTATERESPONSE.fields_by_name['status_code_200'])
_SETTRANSMITSTATERESPONSE.fields_by_name['status_code_200'].containing_oneof = _SETTRANSMITSTATERESPONSE.oneofs_by_name['_status_code_200']
_SETTRANSMITSTATERESPONSE.oneofs_by_name['_status_code_400'].fields.append(
  _SETTRANSMITSTATERESPONSE.fields_by_name['status_code_400'])
_SETTRANSMITSTATERESPONSE.fields_by_name['status_code_400'].containing_oneof = _SETTRANSMITSTATERESPONSE.oneofs_by_name['_status_code_400']
_SETTRANSMITSTATERESPONSE.oneofs_by_name['_status_code_500'].fields.append(
  _SETTRANSMITSTATERESPONSE.fields_by_name['status_code_500'])
_SETTRANSMITSTATERESPONSE.fields_by_name['status_code_500'].containing_oneof = _SETTRANSMITSTATERESPONSE.oneofs_by_name['_status_code_500']
_SETLINKSTATEREQUEST.fields_by_name['link_state'].message_type = _LINKSTATE
_SETLINKSTATERESPONSE.fields_by_name['status_code_200'].message_type = _RESPONSEWARNING
_SETLINKSTATERESPONSE.fields_by_name['status_code_400'].message_type = _RESPONSEERROR
_SETLINKSTATERESPONSE.fields_by_name['status_code_500'].message_type = _RESPONSEERROR
_SETLINKSTATERESPONSE.oneofs_by_name['_status_code_200'].fields.append(
  _SETLINKSTATERESPONSE.fields_by_name['status_code_200'])
_SETLINKSTATERESPONSE.fields_by_name['status_code_200'].containing_oneof = _SETLINKSTATERESPONSE.oneofs_by_name['_status_code_200']
_SETLINKSTATERESPONSE.oneofs_by_name['_status_code_400'].fields.append(
  _SETLINKSTATERESPONSE.fields_by_name['status_code_400'])
_SETLINKSTATERESPONSE.fields_by_name['status_code_400'].containing_oneof = _SETLINKSTATERESPONSE.oneofs_by_name['_status_code_400']
_SETLINKSTATERESPONSE.oneofs_by_name['_status_code_500'].fields.append(
  _SETLINKSTATERESPONSE.fields_by_name['status_code_500'])
_SETLINKSTATERESPONSE.fields_by_name['status_code_500'].containing_oneof = _SETLINKSTATERESPONSE.oneofs_by_name['_status_code_500']
_SETCAPTURESTATEREQUEST.fields_by_name['capture_state'].message_type = _CAPTURESTATE
_SETCAPTURESTATERESPONSE.fields_by_name['status_code_200'].message_type = _RESPONSEWARNING
_SETCAPTURESTATERESPONSE.fields_by_name['status_code_400'].message_type = _RESPONSEERROR
_SETCAPTURESTATERESPONSE.fields_by_name['status_code_500'].message_type = _RESPONSEERROR
_SETCAPTURESTATERESPONSE.oneofs_by_name['_status_code_200'].fields.append(
  _SETCAPTURESTATERESPONSE.fields_by_name['status_code_200'])
_SETCAPTURESTATERESPONSE.fields_by_name['status_code_200'].containing_oneof = _SETCAPTURESTATERESPONSE.oneofs_by_name['_status_code_200']
_SETCAPTURESTATERESPONSE.oneofs_by_name['_status_code_400'].fields.append(
  _SETCAPTURESTATERESPONSE.fields_by_name['status_code_400'])
_SETCAPTURESTATERESPONSE.fields_by_name['status_code_400'].containing_oneof = _SETCAPTURESTATERESPONSE.oneofs_by_name['_status_code_400']
_SETCAPTURESTATERESPONSE.oneofs_by_name['_status_code_500'].fields.append(
  _SETCAPTURESTATERESPONSE.fields_by_name['status_code_500'])
_SETCAPTURESTATERESPONSE.fields_by_name['status_code_500'].containing_oneof = _SETCAPTURESTATERESPONSE.oneofs_by_name['_status_code_500']
_UPDATEFLOWSREQUEST.fields_by_name['flows_update'].message_type = _FLOWSUPDATE
_UPDATEFLOWSRESPONSE.fields_by_name['status_code_200'].message_type = _CONFIG
_UPDATEFLOWSRESPONSE.fields_by_name['status_code_400'].message_type = _RESPONSEERROR
_UPDATEFLOWSRESPONSE.fields_by_name['status_code_500'].message_type = _RESPONSEERROR
_UPDATEFLOWSRESPONSE.oneofs_by_name['_status_code_200'].fields.append(
  _UPDATEFLOWSRESPONSE.fields_by_name['status_code_200'])
_UPDATEFLOWSRESPONSE.fields_by_name['status_code_200'].containing_oneof = _UPDATEFLOWSRESPONSE.oneofs_by_name['_status_code_200']
_UPDATEFLOWSRESPONSE.oneofs_by_name['_status_code_400'].fields.append(
  _UPDATEFLOWSRESPONSE.fields_by_name['status_code_400'])
_UPDATEFLOWSRESPONSE.fields_by_name['status_code_400'].containing_oneof = _UPDATEFLOWSRESPONSE.oneofs_by_name['_status_code_400']
_UPDATEFLOWSRESPONSE.oneofs_by_name['_status_code_500'].fields.append(
  _UPDATEFLOWSRESPONSE.fields_by_name['status_code_500'])
_UPDATEFLOWSRESPONSE.fields_by_name['status_code_500'].containing_oneof = _UPDATEFLOWSRESPONSE.oneofs_by_name['_status_code_500']
_SETROUTESTATEREQUEST.fields_by_name['route_state'].message_type = _ROUTESTATE
_SETROUTESTATERESPONSE.fields_by_name['status_code_200'].message_type = _RESPONSEWARNING
_SETROUTESTATERESPONSE.fields_by_name['status_code_400'].message_type = _RESPONSEERROR
_SETROUTESTATERESPONSE.fields_by_name['status_code_500'].message_type = _RESPONSEERROR
_SETROUTESTATERESPONSE.oneofs_by_name['_status_code_200'].fields.append(
  _SETROUTESTATERESPONSE.fields_by_name['status_code_200'])
_SETROUTESTATERESPONSE.fields_by_name['status_code_200'].containing_oneof = _SETROUTESTATERESPONSE.oneofs_by_name['_status_code_200']
_SETROUTESTATERESPONSE.oneofs_by_name['_status_code_400'].fields.append(
  _SETROUTESTATERESPONSE.fields_by_name['status_code_400'])
_SETROUTESTATERESPONSE.fields_by_name['status_code_400'].containing_oneof = _SETROUTESTATERESPONSE.oneofs_by_name['_status_code_400']
_SETROUTESTATERESPONSE.oneofs_by_name['_status_code_500'].fields.append(
  _SETROUTESTATERESPONSE.fields_by_name['status_code_500'])
_SETROUTESTATERESPONSE.fields_by_name['status_code_500'].containing_oneof = _SETROUTESTATERESPONSE.oneofs_by_name['_status_code_500']
_SENDPINGREQUEST.fields_by_name['ping_request'].message_type = _PINGREQUEST
_SENDPINGRESPONSE.fields_by_name['status_code_200'].message_type = _PINGRESPONSE
_SENDPINGRESPONSE.fields_by_name['status_code_400'].message_type = _RESPONSEERROR
_SENDPINGRESPONSE.fields_by_name['status_code_500'].message_type = _RESPONSEERROR
_SENDPINGRESPONSE.oneofs_by_name['_status_code_200'].fields.append(
  _SENDPINGRESPONSE.fields_by_name['status_code_200'])
_SENDPINGRESPONSE.fields_by_name['status_code_200'].containing_oneof = _SENDPINGRESPONSE.oneofs_by_name['_status_code_200']
_SENDPINGRESPONSE.oneofs_by_name['_status_code_400'].fields.append(
  _SENDPINGRESPONSE.fields_by_name['status_code_400'])
_SENDPINGRESPONSE.fields_by_name['status_code_400'].containing_oneof = _SENDPINGRESPONSE.oneofs_by_name['_status_code_400']
_SENDPINGRESPONSE.oneofs_by_name['_status_code_500'].fields.append(
  _SENDPINGRESPONSE.fields_by_name['status_code_500'])
_SENDPINGRESPONSE.fields_by_name['status_code_500'].containing_oneof = _SENDPINGRESPONSE.oneofs_by_name['_status_code_500']
_SETPROTOCOLSTATEREQUEST.fields_by_name['protocol_state'].message_type = _PROTOCOLSTATE
_SETPROTOCOLSTATERESPONSE.fields_by_name['status_code_200'].message_type = _RESPONSEWARNING
_SETPROTOCOLSTATERESPONSE.fields_by_name['status_code_400'].message_type = _RESPONSEERROR
_SETPROTOCOLSTATERESPONSE.fields_by_name['status_code_500'].message_type = _RESPONSEERROR
_SETPROTOCOLSTATERESPONSE.oneofs_by_name['_status_code_200'].fields.append(
  _SETPROTOCOLSTATERESPONSE.fields_by_name['status_code_200'])
_SETPROTOCOLSTATERESPONSE.fields_by_name['status_code_200'].containing_oneof = _SETPROTOCOLSTATERESPONSE.oneofs_by_name['_status_code_200']
_SETPROTOCOLSTATERESPONSE.oneofs_by_name['_status_code_400'].fields.append(
  _SETPROTOCOLSTATERESPONSE.fields_by_name['status_code_400'])
_SETPROTOCOLSTATERESPONSE.fields_by_name['status_code_400'].containing_oneof = _SETPROTOCOLSTATERESPONSE.oneofs_by_name['_status_code_400']
_SETPROTOCOLSTATERESPONSE.oneofs_by_name['_status_code_500'].fields.append(
  _SETPROTOCOLSTATERESPONSE.fields_by_name['status_code_500'])
_SETPROTOCOLSTATERESPONSE.fields_by_name['status_code_500'].containing_oneof = _SETPROTOCOLSTATERESPONSE.oneofs_by_name['_status_code_500']
_GETMETRICSREQUEST.fields_by_name['metrics_request'].message_type = _METRICSREQUEST
_GETMETRICSRESPONSE.fields_by_name['status_code_200'].message_type = _METRICSRESPONSE
_GETMETRICSRESPONSE.fields_by_name['status_code_400'].message_type = _RESPONSEERROR
_GETMETRICSRESPONSE.fields_by_name['status_code_500'].message_type = _RESPONSEERROR
_GETMETRICSRESPONSE.oneofs_by_name['_status_code_200'].fields.append(
  _GETMETRICSRESPONSE.fields_by_name['status_code_200'])
_GETMETRICSRESPONSE.fields_by_name['status_code_200'].containing_oneof = _GETMETRICSRESPONSE.oneofs_by_name['_status_code_200']
_GETMETRICSRESPONSE.oneofs_by_name['_status_code_400'].fields.append(
  _GETMETRICSRESPONSE.fields_by_name['status_code_400'])
_GETMETRICSRESPONSE.fields_by_name['status_code_400'].containing_oneof = _GETMETRICSRESPONSE.oneofs_by_name['_status_code_400']
_GETMETRICSRESPONSE.oneofs_by_name['_status_code_500'].fields.append(
  _GETMETRICSRESPONSE.fields_by_name['status_code_500'])
_GETMETRICSRESPONSE.fields_by_name['status_code_500'].containing_oneof = _GETMETRICSRESPONSE.oneofs_by_name['_status_code_500']
_GETSTATESREQUEST.fields_by_name['states_request'].message_type = _STATESREQUEST
_GETSTATESRESPONSE.fields_by_name['status_code_200'].message_type = _STATESRESPONSE
_GETSTATESRESPONSE.fields_by_name['status_code_400'].message_type = _RESPONSEERROR
_GETSTATESRESPONSE.fields_by_name['status_code_500'].message_type = _RESPONSEERROR
_GETSTATESRESPONSE.oneofs_by_name['_status_code_200'].fields.append(
  _GETSTATESRESPONSE.fields_by_name['status_code_200'])
_GETSTATESRESPONSE.fields_by_name['status_code_200'].containing_oneof = _GETSTATESRESPONSE.oneofs_by_name['_status_code_200']
_GETSTATESRESPONSE.oneofs_by_name['_status_code_400'].fields.append(
  _GETSTATESRESPONSE.fields_by_name['status_code_400'])
_GETSTATESRESPONSE.fields_by_name['status_code_400'].containing_oneof = _GETSTATESRESPONSE.oneofs_by_name['_status_code_400']
_GETSTATESRESPONSE.oneofs_by_name['_status_code_500'].fields.append(
  _GETSTATESRESPONSE.fields_by_name['status_code_500'])
_GETSTATESRESPONSE.fields_by_name['status_code_500'].containing_oneof = _GETSTATESRESPONSE.oneofs_by_name['_status_code_500']
_GETCAPTUREREQUEST.fields_by_name['capture_request'].message_type = _CAPTUREREQUEST
_GETCAPTURERESPONSE.fields_by_name['status_code_400'].message_type = _RESPONSEERROR
_GETCAPTURERESPONSE.fields_by_name['status_code_500'].message_type = _RESPONSEERROR
_GETCAPTURERESPONSE.oneofs_by_name['_status_code_200'].fields.append(
  _GETCAPTURERESPONSE.fields_by_name['status_code_200'])
_GETCAPTURERESPONSE.fields_by_name['status_code_200'].containing_oneof = _GETCAPTURERESPONSE.oneofs_by_name['_status_code_200']
_GETCAPTURERESPONSE.oneofs_by_name['_status_code_400'].fields.append(
  _GETCAPTURERESPONSE.fields_by_name['status_code_400'])
_GETCAPTURERESPONSE.fields_by_name['status_code_400'].containing_oneof = _GETCAPTURERESPONSE.oneofs_by_name['_status_code_400']
_GETCAPTURERESPONSE.oneofs_by_name['_status_code_500'].fields.append(
  _GETCAPTURERESPONSE.fields_by_name['status_code_500'])
_GETCAPTURERESPONSE.fields_by_name['status_code_500'].containing_oneof = _GETCAPTURERESPONSE.oneofs_by_name['_status_code_500']
DESCRIPTOR.message_types_by_name['Config'] = _CONFIG
DESCRIPTOR.message_types_by_name['ConfigOptions'] = _CONFIGOPTIONS
DESCRIPTOR.message_types_by_name['Port'] = _PORT
DESCRIPTOR.message_types_by_name['PortOptions'] = _PORTOPTIONS
DESCRIPTOR.message_types_by_name['Lag'] = _LAG
DESCRIPTOR.message_types_by_name['LagPort'] = _LAGPORT
DESCRIPTOR.message_types_by_name['LagProtocol'] = _LAGPROTOCOL
DESCRIPTOR.message_types_by_name['LagStatic'] = _LAGSTATIC
DESCRIPTOR.message_types_by_name['LagLacp'] = _LAGLACP
DESCRIPTOR.message_types_by_name['DeviceEthernetBase'] = _DEVICEETHERNETBASE
DESCRIPTOR.message_types_by_name['DeviceEthernet'] = _DEVICEETHERNET
DESCRIPTOR.message_types_by_name['DeviceVlan'] = _DEVICEVLAN
DESCRIPTOR.message_types_by_name['DeviceIpv4'] = _DEVICEIPV4
DESCRIPTOR.message_types_by_name['DeviceIpv4Loopback'] = _DEVICEIPV4LOOPBACK
DESCRIPTOR.message_types_by_name['DeviceIpv6'] = _DEVICEIPV6
DESCRIPTOR.message_types_by_name['DeviceIpv6Loopback'] = _DEVICEIPV6LOOPBACK
DESCRIPTOR.message_types_by_name['Layer1'] = _LAYER1
DESCRIPTOR.message_types_by_name['Layer1AutoNegotiation'] = _LAYER1AUTONEGOTIATION
DESCRIPTOR.message_types_by_name['Layer1FlowControl'] = _LAYER1FLOWCONTROL
DESCRIPTOR.message_types_by_name['Layer1Ieee8023x'] = _LAYER1IEEE8023X
DESCRIPTOR.message_types_by_name['Layer1Ieee8021qbb'] = _LAYER1IEEE8021QBB
DESCRIPTOR.message_types_by_name['Capture'] = _CAPTURE
DESCRIPTOR.message_types_by_name['CaptureFilter'] = _CAPTUREFILTER
DESCRIPTOR.message_types_by_name['CaptureCustom'] = _CAPTURECUSTOM
DESCRIPTOR.message_types_by_name['CaptureField'] = _CAPTUREFIELD
DESCRIPTOR.message_types_by_name['CaptureEthernet'] = _CAPTUREETHERNET
DESCRIPTOR.message_types_by_name['CaptureVlan'] = _CAPTUREVLAN
DESCRIPTOR.message_types_by_name['CaptureIpv4'] = _CAPTUREIPV4
DESCRIPTOR.message_types_by_name['CaptureIpv6'] = _CAPTUREIPV6
DESCRIPTOR.message_types_by_name['Device'] = _DEVICE
DESCRIPTOR.message_types_by_name['DeviceIsisRouter'] = _DEVICEISISROUTER
DESCRIPTOR.message_types_by_name['DeviceIsisMultiInstance'] = _DEVICEISISMULTIINSTANCE
DESCRIPTOR.message_types_by_name['IsisInterface'] = _ISISINTERFACE
DESCRIPTOR.message_types_by_name['IsisInterfaceLevel'] = _ISISINTERFACELEVEL
DESCRIPTOR.message_types_by_name['IsisMT'] = _ISISMT
DESCRIPTOR.message_types_by_name['LinkStateTE'] = _LINKSTATETE
DESCRIPTOR.message_types_by_name['LinkStatepriorityBandwidths'] = _LINKSTATEPRIORITYBANDWIDTHS
DESCRIPTOR.message_types_by_name['IsisInterfaceAuthentication'] = _ISISINTERFACEAUTHENTICATION
DESCRIPTOR.message_types_by_name['IsisInterfaceAdvanced'] = _ISISINTERFACEADVANCED
DESCRIPTOR.message_types_by_name['IsisInterfaceLinkProtection'] = _ISISINTERFACELINKPROTECTION
DESCRIPTOR.message_types_by_name['IsisBasic'] = _ISISBASIC
DESCRIPTOR.message_types_by_name['IsisAdvanced'] = _ISISADVANCED
DESCRIPTOR.message_types_by_name['IsisAuthentication'] = _ISISAUTHENTICATION
DESCRIPTOR.message_types_by_name['IsisAuthenticationBase'] = _ISISAUTHENTICATIONBASE
DESCRIPTOR.message_types_by_name['IsisV4RouteRange'] = _ISISV4ROUTERANGE
DESCRIPTOR.message_types_by_name['V4RouteAddress'] = _V4ROUTEADDRESS
DESCRIPTOR.message_types_by_name['V6RouteAddress'] = _V6ROUTEADDRESS
DESCRIPTOR.message_types_by_name['IsisV6RouteRange'] = _ISISV6ROUTERANGE
DESCRIPTOR.message_types_by_name['DeviceBgpRouter'] = _DEVICEBGPROUTER
DESCRIPTOR.message_types_by_name['BgpV4Peer'] = _BGPV4PEER
DESCRIPTOR.message_types_by_name['BgpV4Interface'] = _BGPV4INTERFACE
DESCRIPTOR.message_types_by_name['BgpAdvanced'] = _BGPADVANCED
DESCRIPTOR.message_types_by_name['BgpCapability'] = _BGPCAPABILITY
DESCRIPTOR.message_types_by_name['BgpV4RouteRange'] = _BGPV4ROUTERANGE
DESCRIPTOR.message_types_by_name['BgpRouteAdvanced'] = _BGPROUTEADVANCED
DESCRIPTOR.message_types_by_name['BgpCommunity'] = _BGPCOMMUNITY
DESCRIPTOR.message_types_by_name['BgpAsPath'] = _BGPASPATH
DESCRIPTOR.message_types_by_name['BgpAsPathSegment'] = _BGPASPATHSEGMENT
DESCRIPTOR.message_types_by_name['BgpAddPath'] = _BGPADDPATH
DESCRIPTOR.message_types_by_name['BgpV6RouteRange'] = _BGPV6ROUTERANGE
DESCRIPTOR.message_types_by_name['BgpSrteV4Policy'] = _BGPSRTEV4POLICY
DESCRIPTOR.message_types_by_name['BgpExtCommunity'] = _BGPEXTCOMMUNITY
DESCRIPTOR.message_types_by_name['BgpSrteV4TunnelTlv'] = _BGPSRTEV4TUNNELTLV
DESCRIPTOR.message_types_by_name['BgpSrteRemoteEndpointSubTlv'] = _BGPSRTEREMOTEENDPOINTSUBTLV
DESCRIPTOR.message_types_by_name['BgpSrteColorSubTlv'] = _BGPSRTECOLORSUBTLV
DESCRIPTOR.message_types_by_name['BgpSrteBindingSubTlv'] = _BGPSRTEBINDINGSUBTLV
DESCRIPTOR.message_types_by_name['BgpSrtePreferenceSubTlv'] = _BGPSRTEPREFERENCESUBTLV
DESCRIPTOR.message_types_by_name['BgpSrtePolicyPrioritySubTlv'] = _BGPSRTEPOLICYPRIORITYSUBTLV
DESCRIPTOR.message_types_by_name['BgpSrtePolicyNameSubTlv'] = _BGPSRTEPOLICYNAMESUBTLV
DESCRIPTOR.message_types_by_name['BgpSrteExplicitNullLabelPolicySubTlv'] = _BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV
DESCRIPTOR.message_types_by_name['BgpSrteSegmentList'] = _BGPSRTESEGMENTLIST
DESCRIPTOR.message_types_by_name['BgpSrteSegment'] = _BGPSRTESEGMENT
DESCRIPTOR.message_types_by_name['BgpSrteSrMplsSid'] = _BGPSRTESRMPLSSID
DESCRIPTOR.message_types_by_name['BgpSrteSRv6SIDEndpointBehaviorAndStructure'] = _BGPSRTESRV6SIDENDPOINTBEHAVIORANDSTRUCTURE
DESCRIPTOR.message_types_by_name['BgpSrteSegmentATypeSubTlv'] = _BGPSRTESEGMENTATYPESUBTLV
DESCRIPTOR.message_types_by_name['BgpSrteSegmentBTypeSubTlv'] = _BGPSRTESEGMENTBTYPESUBTLV
DESCRIPTOR.message_types_by_name['BgpSrteSegmentCTypeSubTlv'] = _BGPSRTESEGMENTCTYPESUBTLV
DESCRIPTOR.message_types_by_name['BgpSrteSegmentDTypeSubTlv'] = _BGPSRTESEGMENTDTYPESUBTLV
DESCRIPTOR.message_types_by_name['BgpSrteSegmentETypeSubTlv'] = _BGPSRTESEGMENTETYPESUBTLV
DESCRIPTOR.message_types_by_name['BgpSrteSegmentFTypeSubTlv'] = _BGPSRTESEGMENTFTYPESUBTLV
DESCRIPTOR.message_types_by_name['BgpSrteSegmentGTypeSubTlv'] = _BGPSRTESEGMENTGTYPESUBTLV
DESCRIPTOR.message_types_by_name['BgpSrteSegmentHTypeSubTlv'] = _BGPSRTESEGMENTHTYPESUBTLV
DESCRIPTOR.message_types_by_name['BgpSrteSegmentITypeSubTlv'] = _BGPSRTESEGMENTITYPESUBTLV
DESCRIPTOR.message_types_by_name['BgpSrteSegmentJTypeSubTlv'] = _BGPSRTESEGMENTJTYPESUBTLV
DESCRIPTOR.message_types_by_name['BgpSrteSegmentKTypeSubTlv'] = _BGPSRTESEGMENTKTYPESUBTLV
DESCRIPTOR.message_types_by_name['BgpSrteV6Policy'] = _BGPSRTEV6POLICY
DESCRIPTOR.message_types_by_name['BgpSrteV6TunnelTlv'] = _BGPSRTEV6TUNNELTLV
DESCRIPTOR.message_types_by_name['BgpV6Peer'] = _BGPV6PEER
DESCRIPTOR.message_types_by_name['BgpV6Interface'] = _BGPV6INTERFACE
DESCRIPTOR.message_types_by_name['BgpV6SegmentRouting'] = _BGPV6SEGMENTROUTING
DESCRIPTOR.message_types_by_name['Flow'] = _FLOW
DESCRIPTOR.message_types_by_name['FlowTxRx'] = _FLOWTXRX
DESCRIPTOR.message_types_by_name['FlowPort'] = _FLOWPORT
DESCRIPTOR.message_types_by_name['FlowRouter'] = _FLOWROUTER
DESCRIPTOR.message_types_by_name['FlowHeader'] = _FLOWHEADER
DESCRIPTOR.message_types_by_name['FlowCustom'] = _FLOWCUSTOM
DESCRIPTOR.message_types_by_name['FlowEthernet'] = _FLOWETHERNET
DESCRIPTOR.message_types_by_name['FlowVlan'] = _FLOWVLAN
DESCRIPTOR.message_types_by_name['FlowVxlan'] = _FLOWVXLAN
DESCRIPTOR.message_types_by_name['FlowIpv4'] = _FLOWIPV4
DESCRIPTOR.message_types_by_name['FlowIpv4Priority'] = _FLOWIPV4PRIORITY
DESCRIPTOR.message_types_by_name['FlowIpv4Dscp'] = _FLOWIPV4DSCP
DESCRIPTOR.message_types_by_name['FlowIpv4Tos'] = _FLOWIPV4TOS
DESCRIPTOR.message_types_by_name['FlowIpv6'] = _FLOWIPV6
DESCRIPTOR.message_types_by_name['FlowPfcPause'] = _FLOWPFCPAUSE
DESCRIPTOR.message_types_by_name['FlowEthernetPause'] = _FLOWETHERNETPAUSE
DESCRIPTOR.message_types_by_name['FlowTcp'] = _FLOWTCP
DESCRIPTOR.message_types_by_name['FlowUdp'] = _FLOWUDP
DESCRIPTOR.message_types_by_name['FlowGre'] = _FLOWGRE
DESCRIPTOR.message_types_by_name['FlowGtpv1'] = _FLOWGTPV1
DESCRIPTOR.message_types_by_name['FlowGtpExtension'] = _FLOWGTPEXTENSION
DESCRIPTOR.message_types_by_name['FlowGtpv2'] = _FLOWGTPV2
DESCRIPTOR.message_types_by_name['FlowArp'] = _FLOWARP
DESCRIPTOR.message_types_by_name['FlowIcmp'] = _FLOWICMP
DESCRIPTOR.message_types_by_name['FlowIcmpEcho'] = _FLOWICMPECHO
DESCRIPTOR.message_types_by_name['FlowIcmpv6'] = _FLOWICMPV6
DESCRIPTOR.message_types_by_name['FlowIcmpv6Echo'] = _FLOWICMPV6ECHO
DESCRIPTOR.message_types_by_name['FlowPpp'] = _FLOWPPP
DESCRIPTOR.message_types_by_name['FlowIgmpv1'] = _FLOWIGMPV1
DESCRIPTOR.message_types_by_name['FlowSize'] = _FLOWSIZE
DESCRIPTOR.message_types_by_name['FlowSizeIncrement'] = _FLOWSIZEINCREMENT
DESCRIPTOR.message_types_by_name['FlowSizeRandom'] = _FLOWSIZERANDOM
DESCRIPTOR.message_types_by_name['FlowRate'] = _FLOWRATE
DESCRIPTOR.message_types_by_name['FlowDuration'] = _FLOWDURATION
DESCRIPTOR.message_types_by_name['FlowContinuous'] = _FLOWCONTINUOUS
DESCRIPTOR.message_types_by_name['FlowDelay'] = _FLOWDELAY
DESCRIPTOR.message_types_by_name['FlowFixedPackets'] = _FLOWFIXEDPACKETS
DESCRIPTOR.message_types_by_name['FlowFixedSeconds'] = _FLOWFIXEDSECONDS
DESCRIPTOR.message_types_by_name['FlowBurst'] = _FLOWBURST
DESCRIPTOR.message_types_by_name['FlowDurationInterBurstGap'] = _FLOWDURATIONINTERBURSTGAP
DESCRIPTOR.message_types_by_name['FlowMetrics'] = _FLOWMETRICS
DESCRIPTOR.message_types_by_name['FlowLatencyMetrics'] = _FLOWLATENCYMETRICS
DESCRIPTOR.message_types_by_name['Event'] = _EVENT
DESCRIPTOR.message_types_by_name['EventRxRateThreshold'] = _EVENTRXRATETHRESHOLD
DESCRIPTOR.message_types_by_name['EventLink'] = _EVENTLINK
DESCRIPTOR.message_types_by_name['EventRouteAdvertiseWithdraw'] = _EVENTROUTEADVERTISEWITHDRAW
DESCRIPTOR.message_types_by_name['EventRequest'] = _EVENTREQUEST
DESCRIPTOR.message_types_by_name['EventSubscription'] = _EVENTSUBSCRIPTION
DESCRIPTOR.message_types_by_name['ResponseError'] = _RESPONSEERROR
DESCRIPTOR.message_types_by_name['ResponseWarning'] = _RESPONSEWARNING
DESCRIPTOR.message_types_by_name['LinkState'] = _LINKSTATE
DESCRIPTOR.message_types_by_name['TransmitState'] = _TRANSMITSTATE
DESCRIPTOR.message_types_by_name['CaptureState'] = _CAPTURESTATE
DESCRIPTOR.message_types_by_name['FlowsUpdate'] = _FLOWSUPDATE
DESCRIPTOR.message_types_by_name['RouteState'] = _ROUTESTATE
DESCRIPTOR.message_types_by_name['PingRequest'] = _PINGREQUEST
DESCRIPTOR.message_types_by_name['ProtocolState'] = _PROTOCOLSTATE
DESCRIPTOR.message_types_by_name['Ping'] = _PING
DESCRIPTOR.message_types_by_name['PingIpv4'] = _PINGIPV4
DESCRIPTOR.message_types_by_name['PingIpv6'] = _PINGIPV6
DESCRIPTOR.message_types_by_name['PingResponse'] = _PINGRESPONSE
DESCRIPTOR.message_types_by_name['Response'] = _RESPONSE
DESCRIPTOR.message_types_by_name['MetricsRequest'] = _METRICSREQUEST
DESCRIPTOR.message_types_by_name['MetricsResponse'] = _METRICSRESPONSE
DESCRIPTOR.message_types_by_name['PortMetricsRequest'] = _PORTMETRICSREQUEST
DESCRIPTOR.message_types_by_name['PortMetric'] = _PORTMETRIC
DESCRIPTOR.message_types_by_name['FlowMetricsRequest'] = _FLOWMETRICSREQUEST
DESCRIPTOR.message_types_by_name['FlowMetricGroupRequest'] = _FLOWMETRICGROUPREQUEST
DESCRIPTOR.message_types_by_name['FlowMetric'] = _FLOWMETRIC
DESCRIPTOR.message_types_by_name['FlowMetricGroup'] = _FLOWMETRICGROUP
DESCRIPTOR.message_types_by_name['MetricTimestamp'] = _METRICTIMESTAMP
DESCRIPTOR.message_types_by_name['MetricLatency'] = _METRICLATENCY
DESCRIPTOR.message_types_by_name['Bgpv4MetricsRequest'] = _BGPV4METRICSREQUEST
DESCRIPTOR.message_types_by_name['Bgpv4Metric'] = _BGPV4METRIC
DESCRIPTOR.message_types_by_name['Bgpv6MetricsRequest'] = _BGPV6METRICSREQUEST
DESCRIPTOR.message_types_by_name['Bgpv6Metric'] = _BGPV6METRIC
DESCRIPTOR.message_types_by_name['IsisMetricsRequest'] = _ISISMETRICSREQUEST
DESCRIPTOR.message_types_by_name['IsisMetric'] = _ISISMETRIC
DESCRIPTOR.message_types_by_name['StatesRequest'] = _STATESREQUEST
DESCRIPTOR.message_types_by_name['StatesResponse'] = _STATESRESPONSE
DESCRIPTOR.message_types_by_name['Neighborsv4StatesRequest'] = _NEIGHBORSV4STATESREQUEST
DESCRIPTOR.message_types_by_name['Neighborsv4State'] = _NEIGHBORSV4STATE
DESCRIPTOR.message_types_by_name['Neighborsv6StatesRequest'] = _NEIGHBORSV6STATESREQUEST
DESCRIPTOR.message_types_by_name['Neighborsv6State'] = _NEIGHBORSV6STATE
DESCRIPTOR.message_types_by_name['CaptureRequest'] = _CAPTUREREQUEST
DESCRIPTOR.message_types_by_name['PatternFlowEthernetDstCounter'] = _PATTERNFLOWETHERNETDSTCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowEthernetDst'] = _PATTERNFLOWETHERNETDST
DESCRIPTOR.message_types_by_name['PatternFlowEthernetSrcCounter'] = _PATTERNFLOWETHERNETSRCCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowEthernetSrc'] = _PATTERNFLOWETHERNETSRC
DESCRIPTOR.message_types_by_name['PatternFlowEthernetEtherTypeCounter'] = _PATTERNFLOWETHERNETETHERTYPECOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowEthernetEtherType'] = _PATTERNFLOWETHERNETETHERTYPE
DESCRIPTOR.message_types_by_name['PatternFlowEthernetPfcQueueCounter'] = _PATTERNFLOWETHERNETPFCQUEUECOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowEthernetPfcQueue'] = _PATTERNFLOWETHERNETPFCQUEUE
DESCRIPTOR.message_types_by_name['PatternFlowVlanPriorityCounter'] = _PATTERNFLOWVLANPRIORITYCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowVlanPriority'] = _PATTERNFLOWVLANPRIORITY
DESCRIPTOR.message_types_by_name['PatternFlowVlanCfiCounter'] = _PATTERNFLOWVLANCFICOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowVlanCfi'] = _PATTERNFLOWVLANCFI
DESCRIPTOR.message_types_by_name['PatternFlowVlanIdCounter'] = _PATTERNFLOWVLANIDCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowVlanId'] = _PATTERNFLOWVLANID
DESCRIPTOR.message_types_by_name['PatternFlowVlanTpidCounter'] = _PATTERNFLOWVLANTPIDCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowVlanTpid'] = _PATTERNFLOWVLANTPID
DESCRIPTOR.message_types_by_name['PatternFlowVxlanFlagsCounter'] = _PATTERNFLOWVXLANFLAGSCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowVxlanFlags'] = _PATTERNFLOWVXLANFLAGS
DESCRIPTOR.message_types_by_name['PatternFlowVxlanReserved0Counter'] = _PATTERNFLOWVXLANRESERVED0COUNTER
DESCRIPTOR.message_types_by_name['PatternFlowVxlanReserved0'] = _PATTERNFLOWVXLANRESERVED0
DESCRIPTOR.message_types_by_name['PatternFlowVxlanVniCounter'] = _PATTERNFLOWVXLANVNICOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowVxlanVni'] = _PATTERNFLOWVXLANVNI
DESCRIPTOR.message_types_by_name['PatternFlowVxlanReserved1Counter'] = _PATTERNFLOWVXLANRESERVED1COUNTER
DESCRIPTOR.message_types_by_name['PatternFlowVxlanReserved1'] = _PATTERNFLOWVXLANRESERVED1
DESCRIPTOR.message_types_by_name['PatternFlowIpv4VersionCounter'] = _PATTERNFLOWIPV4VERSIONCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIpv4Version'] = _PATTERNFLOWIPV4VERSION
DESCRIPTOR.message_types_by_name['PatternFlowIpv4HeaderLengthCounter'] = _PATTERNFLOWIPV4HEADERLENGTHCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIpv4HeaderLength'] = _PATTERNFLOWIPV4HEADERLENGTH
DESCRIPTOR.message_types_by_name['PatternFlowIpv4TotalLengthCounter'] = _PATTERNFLOWIPV4TOTALLENGTHCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIpv4TotalLength'] = _PATTERNFLOWIPV4TOTALLENGTH
DESCRIPTOR.message_types_by_name['PatternFlowIpv4IdentificationCounter'] = _PATTERNFLOWIPV4IDENTIFICATIONCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIpv4Identification'] = _PATTERNFLOWIPV4IDENTIFICATION
DESCRIPTOR.message_types_by_name['PatternFlowIpv4ReservedCounter'] = _PATTERNFLOWIPV4RESERVEDCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIpv4Reserved'] = _PATTERNFLOWIPV4RESERVED
DESCRIPTOR.message_types_by_name['PatternFlowIpv4DontFragmentCounter'] = _PATTERNFLOWIPV4DONTFRAGMENTCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIpv4DontFragment'] = _PATTERNFLOWIPV4DONTFRAGMENT
DESCRIPTOR.message_types_by_name['PatternFlowIpv4MoreFragmentsCounter'] = _PATTERNFLOWIPV4MOREFRAGMENTSCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIpv4MoreFragments'] = _PATTERNFLOWIPV4MOREFRAGMENTS
DESCRIPTOR.message_types_by_name['PatternFlowIpv4FragmentOffsetCounter'] = _PATTERNFLOWIPV4FRAGMENTOFFSETCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIpv4FragmentOffset'] = _PATTERNFLOWIPV4FRAGMENTOFFSET
DESCRIPTOR.message_types_by_name['PatternFlowIpv4TimeToLiveCounter'] = _PATTERNFLOWIPV4TIMETOLIVECOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIpv4TimeToLive'] = _PATTERNFLOWIPV4TIMETOLIVE
DESCRIPTOR.message_types_by_name['PatternFlowIpv4ProtocolCounter'] = _PATTERNFLOWIPV4PROTOCOLCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIpv4Protocol'] = _PATTERNFLOWIPV4PROTOCOL
DESCRIPTOR.message_types_by_name['PatternFlowIpv4HeaderChecksum'] = _PATTERNFLOWIPV4HEADERCHECKSUM
DESCRIPTOR.message_types_by_name['PatternFlowIpv4SrcCounter'] = _PATTERNFLOWIPV4SRCCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIpv4Src'] = _PATTERNFLOWIPV4SRC
DESCRIPTOR.message_types_by_name['PatternFlowIpv4DstCounter'] = _PATTERNFLOWIPV4DSTCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIpv4Dst'] = _PATTERNFLOWIPV4DST
DESCRIPTOR.message_types_by_name['PatternFlowIpv4PriorityRawCounter'] = _PATTERNFLOWIPV4PRIORITYRAWCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIpv4PriorityRaw'] = _PATTERNFLOWIPV4PRIORITYRAW
DESCRIPTOR.message_types_by_name['PatternFlowIpv4DscpPhbCounter'] = _PATTERNFLOWIPV4DSCPPHBCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIpv4DscpPhb'] = _PATTERNFLOWIPV4DSCPPHB
DESCRIPTOR.message_types_by_name['PatternFlowIpv4DscpEcnCounter'] = _PATTERNFLOWIPV4DSCPECNCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIpv4DscpEcn'] = _PATTERNFLOWIPV4DSCPECN
DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosPrecedenceCounter'] = _PATTERNFLOWIPV4TOSPRECEDENCECOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosPrecedence'] = _PATTERNFLOWIPV4TOSPRECEDENCE
DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosDelayCounter'] = _PATTERNFLOWIPV4TOSDELAYCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosDelay'] = _PATTERNFLOWIPV4TOSDELAY
DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosThroughputCounter'] = _PATTERNFLOWIPV4TOSTHROUGHPUTCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosThroughput'] = _PATTERNFLOWIPV4TOSTHROUGHPUT
DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosReliabilityCounter'] = _PATTERNFLOWIPV4TOSRELIABILITYCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosReliability'] = _PATTERNFLOWIPV4TOSRELIABILITY
DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosMonetaryCounter'] = _PATTERNFLOWIPV4TOSMONETARYCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosMonetary'] = _PATTERNFLOWIPV4TOSMONETARY
DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosUnusedCounter'] = _PATTERNFLOWIPV4TOSUNUSEDCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosUnused'] = _PATTERNFLOWIPV4TOSUNUSED
DESCRIPTOR.message_types_by_name['PatternFlowIpv6VersionCounter'] = _PATTERNFLOWIPV6VERSIONCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIpv6Version'] = _PATTERNFLOWIPV6VERSION
DESCRIPTOR.message_types_by_name['PatternFlowIpv6TrafficClassCounter'] = _PATTERNFLOWIPV6TRAFFICCLASSCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIpv6TrafficClass'] = _PATTERNFLOWIPV6TRAFFICCLASS
DESCRIPTOR.message_types_by_name['PatternFlowIpv6FlowLabelCounter'] = _PATTERNFLOWIPV6FLOWLABELCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIpv6FlowLabel'] = _PATTERNFLOWIPV6FLOWLABEL
DESCRIPTOR.message_types_by_name['PatternFlowIpv6PayloadLengthCounter'] = _PATTERNFLOWIPV6PAYLOADLENGTHCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIpv6PayloadLength'] = _PATTERNFLOWIPV6PAYLOADLENGTH
DESCRIPTOR.message_types_by_name['PatternFlowIpv6NextHeaderCounter'] = _PATTERNFLOWIPV6NEXTHEADERCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIpv6NextHeader'] = _PATTERNFLOWIPV6NEXTHEADER
DESCRIPTOR.message_types_by_name['PatternFlowIpv6HopLimitCounter'] = _PATTERNFLOWIPV6HOPLIMITCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIpv6HopLimit'] = _PATTERNFLOWIPV6HOPLIMIT
DESCRIPTOR.message_types_by_name['PatternFlowIpv6SrcCounter'] = _PATTERNFLOWIPV6SRCCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIpv6Src'] = _PATTERNFLOWIPV6SRC
DESCRIPTOR.message_types_by_name['PatternFlowIpv6DstCounter'] = _PATTERNFLOWIPV6DSTCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIpv6Dst'] = _PATTERNFLOWIPV6DST
DESCRIPTOR.message_types_by_name['PatternFlowPfcPauseDstCounter'] = _PATTERNFLOWPFCPAUSEDSTCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowPfcPauseDst'] = _PATTERNFLOWPFCPAUSEDST
DESCRIPTOR.message_types_by_name['PatternFlowPfcPauseSrcCounter'] = _PATTERNFLOWPFCPAUSESRCCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowPfcPauseSrc'] = _PATTERNFLOWPFCPAUSESRC
DESCRIPTOR.message_types_by_name['PatternFlowPfcPauseEtherTypeCounter'] = _PATTERNFLOWPFCPAUSEETHERTYPECOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowPfcPauseEtherType'] = _PATTERNFLOWPFCPAUSEETHERTYPE
DESCRIPTOR.message_types_by_name['PatternFlowPfcPauseControlOpCodeCounter'] = _PATTERNFLOWPFCPAUSECONTROLOPCODECOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowPfcPauseControlOpCode'] = _PATTERNFLOWPFCPAUSECONTROLOPCODE
DESCRIPTOR.message_types_by_name['PatternFlowPfcPauseClassEnableVectorCounter'] = _PATTERNFLOWPFCPAUSECLASSENABLEVECTORCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowPfcPauseClassEnableVector'] = _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR
DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass0Counter'] = _PATTERNFLOWPFCPAUSEPAUSECLASS0COUNTER
DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass0'] = _PATTERNFLOWPFCPAUSEPAUSECLASS0
DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass1Counter'] = _PATTERNFLOWPFCPAUSEPAUSECLASS1COUNTER
DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass1'] = _PATTERNFLOWPFCPAUSEPAUSECLASS1
DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass2Counter'] = _PATTERNFLOWPFCPAUSEPAUSECLASS2COUNTER
DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass2'] = _PATTERNFLOWPFCPAUSEPAUSECLASS2
DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass3Counter'] = _PATTERNFLOWPFCPAUSEPAUSECLASS3COUNTER
DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass3'] = _PATTERNFLOWPFCPAUSEPAUSECLASS3
DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass4Counter'] = _PATTERNFLOWPFCPAUSEPAUSECLASS4COUNTER
DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass4'] = _PATTERNFLOWPFCPAUSEPAUSECLASS4
DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass5Counter'] = _PATTERNFLOWPFCPAUSEPAUSECLASS5COUNTER
DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass5'] = _PATTERNFLOWPFCPAUSEPAUSECLASS5
DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass6Counter'] = _PATTERNFLOWPFCPAUSEPAUSECLASS6COUNTER
DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass6'] = _PATTERNFLOWPFCPAUSEPAUSECLASS6
DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass7Counter'] = _PATTERNFLOWPFCPAUSEPAUSECLASS7COUNTER
DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass7'] = _PATTERNFLOWPFCPAUSEPAUSECLASS7
DESCRIPTOR.message_types_by_name['PatternFlowEthernetPauseDstCounter'] = _PATTERNFLOWETHERNETPAUSEDSTCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowEthernetPauseDst'] = _PATTERNFLOWETHERNETPAUSEDST
DESCRIPTOR.message_types_by_name['PatternFlowEthernetPauseSrcCounter'] = _PATTERNFLOWETHERNETPAUSESRCCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowEthernetPauseSrc'] = _PATTERNFLOWETHERNETPAUSESRC
DESCRIPTOR.message_types_by_name['PatternFlowEthernetPauseEtherTypeCounter'] = _PATTERNFLOWETHERNETPAUSEETHERTYPECOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowEthernetPauseEtherType'] = _PATTERNFLOWETHERNETPAUSEETHERTYPE
DESCRIPTOR.message_types_by_name['PatternFlowEthernetPauseControlOpCodeCounter'] = _PATTERNFLOWETHERNETPAUSECONTROLOPCODECOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowEthernetPauseControlOpCode'] = _PATTERNFLOWETHERNETPAUSECONTROLOPCODE
DESCRIPTOR.message_types_by_name['PatternFlowEthernetPauseTimeCounter'] = _PATTERNFLOWETHERNETPAUSETIMECOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowEthernetPauseTime'] = _PATTERNFLOWETHERNETPAUSETIME
DESCRIPTOR.message_types_by_name['PatternFlowTcpSrcPortCounter'] = _PATTERNFLOWTCPSRCPORTCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowTcpSrcPort'] = _PATTERNFLOWTCPSRCPORT
DESCRIPTOR.message_types_by_name['PatternFlowTcpDstPortCounter'] = _PATTERNFLOWTCPDSTPORTCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowTcpDstPort'] = _PATTERNFLOWTCPDSTPORT
DESCRIPTOR.message_types_by_name['PatternFlowTcpSeqNumCounter'] = _PATTERNFLOWTCPSEQNUMCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowTcpSeqNum'] = _PATTERNFLOWTCPSEQNUM
DESCRIPTOR.message_types_by_name['PatternFlowTcpAckNumCounter'] = _PATTERNFLOWTCPACKNUMCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowTcpAckNum'] = _PATTERNFLOWTCPACKNUM
DESCRIPTOR.message_types_by_name['PatternFlowTcpDataOffsetCounter'] = _PATTERNFLOWTCPDATAOFFSETCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowTcpDataOffset'] = _PATTERNFLOWTCPDATAOFFSET
DESCRIPTOR.message_types_by_name['PatternFlowTcpEcnNsCounter'] = _PATTERNFLOWTCPECNNSCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowTcpEcnNs'] = _PATTERNFLOWTCPECNNS
DESCRIPTOR.message_types_by_name['PatternFlowTcpEcnCwrCounter'] = _PATTERNFLOWTCPECNCWRCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowTcpEcnCwr'] = _PATTERNFLOWTCPECNCWR
DESCRIPTOR.message_types_by_name['PatternFlowTcpEcnEchoCounter'] = _PATTERNFLOWTCPECNECHOCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowTcpEcnEcho'] = _PATTERNFLOWTCPECNECHO
DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlUrgCounter'] = _PATTERNFLOWTCPCTLURGCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlUrg'] = _PATTERNFLOWTCPCTLURG
DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlAckCounter'] = _PATTERNFLOWTCPCTLACKCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlAck'] = _PATTERNFLOWTCPCTLACK
DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlPshCounter'] = _PATTERNFLOWTCPCTLPSHCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlPsh'] = _PATTERNFLOWTCPCTLPSH
DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlRstCounter'] = _PATTERNFLOWTCPCTLRSTCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlRst'] = _PATTERNFLOWTCPCTLRST
DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlSynCounter'] = _PATTERNFLOWTCPCTLSYNCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlSyn'] = _PATTERNFLOWTCPCTLSYN
DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlFinCounter'] = _PATTERNFLOWTCPCTLFINCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlFin'] = _PATTERNFLOWTCPCTLFIN
DESCRIPTOR.message_types_by_name['PatternFlowTcpWindowCounter'] = _PATTERNFLOWTCPWINDOWCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowTcpWindow'] = _PATTERNFLOWTCPWINDOW
DESCRIPTOR.message_types_by_name['PatternFlowUdpSrcPortCounter'] = _PATTERNFLOWUDPSRCPORTCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowUdpSrcPort'] = _PATTERNFLOWUDPSRCPORT
DESCRIPTOR.message_types_by_name['PatternFlowUdpDstPortCounter'] = _PATTERNFLOWUDPDSTPORTCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowUdpDstPort'] = _PATTERNFLOWUDPDSTPORT
DESCRIPTOR.message_types_by_name['PatternFlowUdpLengthCounter'] = _PATTERNFLOWUDPLENGTHCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowUdpLength'] = _PATTERNFLOWUDPLENGTH
DESCRIPTOR.message_types_by_name['PatternFlowUdpChecksum'] = _PATTERNFLOWUDPCHECKSUM
DESCRIPTOR.message_types_by_name['PatternFlowGreChecksumPresentCounter'] = _PATTERNFLOWGRECHECKSUMPRESENTCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowGreChecksumPresent'] = _PATTERNFLOWGRECHECKSUMPRESENT
DESCRIPTOR.message_types_by_name['PatternFlowGreReserved0Counter'] = _PATTERNFLOWGRERESERVED0COUNTER
DESCRIPTOR.message_types_by_name['PatternFlowGreReserved0'] = _PATTERNFLOWGRERESERVED0
DESCRIPTOR.message_types_by_name['PatternFlowGreVersionCounter'] = _PATTERNFLOWGREVERSIONCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowGreVersion'] = _PATTERNFLOWGREVERSION
DESCRIPTOR.message_types_by_name['PatternFlowGreProtocolCounter'] = _PATTERNFLOWGREPROTOCOLCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowGreProtocol'] = _PATTERNFLOWGREPROTOCOL
DESCRIPTOR.message_types_by_name['PatternFlowGreChecksum'] = _PATTERNFLOWGRECHECKSUM
DESCRIPTOR.message_types_by_name['PatternFlowGreReserved1Counter'] = _PATTERNFLOWGRERESERVED1COUNTER
DESCRIPTOR.message_types_by_name['PatternFlowGreReserved1'] = _PATTERNFLOWGRERESERVED1
DESCRIPTOR.message_types_by_name['PatternFlowGtpv1VersionCounter'] = _PATTERNFLOWGTPV1VERSIONCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowGtpv1Version'] = _PATTERNFLOWGTPV1VERSION
DESCRIPTOR.message_types_by_name['PatternFlowGtpv1ProtocolTypeCounter'] = _PATTERNFLOWGTPV1PROTOCOLTYPECOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowGtpv1ProtocolType'] = _PATTERNFLOWGTPV1PROTOCOLTYPE
DESCRIPTOR.message_types_by_name['PatternFlowGtpv1ReservedCounter'] = _PATTERNFLOWGTPV1RESERVEDCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowGtpv1Reserved'] = _PATTERNFLOWGTPV1RESERVED
DESCRIPTOR.message_types_by_name['PatternFlowGtpv1EFlagCounter'] = _PATTERNFLOWGTPV1EFLAGCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowGtpv1EFlag'] = _PATTERNFLOWGTPV1EFLAG
DESCRIPTOR.message_types_by_name['PatternFlowGtpv1SFlagCounter'] = _PATTERNFLOWGTPV1SFLAGCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowGtpv1SFlag'] = _PATTERNFLOWGTPV1SFLAG
DESCRIPTOR.message_types_by_name['PatternFlowGtpv1PnFlagCounter'] = _PATTERNFLOWGTPV1PNFLAGCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowGtpv1PnFlag'] = _PATTERNFLOWGTPV1PNFLAG
DESCRIPTOR.message_types_by_name['PatternFlowGtpv1MessageTypeCounter'] = _PATTERNFLOWGTPV1MESSAGETYPECOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowGtpv1MessageType'] = _PATTERNFLOWGTPV1MESSAGETYPE
DESCRIPTOR.message_types_by_name['PatternFlowGtpv1MessageLengthCounter'] = _PATTERNFLOWGTPV1MESSAGELENGTHCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowGtpv1MessageLength'] = _PATTERNFLOWGTPV1MESSAGELENGTH
DESCRIPTOR.message_types_by_name['PatternFlowGtpv1TeidCounter'] = _PATTERNFLOWGTPV1TEIDCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowGtpv1Teid'] = _PATTERNFLOWGTPV1TEID
DESCRIPTOR.message_types_by_name['PatternFlowGtpv1SquenceNumberCounter'] = _PATTERNFLOWGTPV1SQUENCENUMBERCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowGtpv1SquenceNumber'] = _PATTERNFLOWGTPV1SQUENCENUMBER
DESCRIPTOR.message_types_by_name['PatternFlowGtpv1NPduNumberCounter'] = _PATTERNFLOWGTPV1NPDUNUMBERCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowGtpv1NPduNumber'] = _PATTERNFLOWGTPV1NPDUNUMBER
DESCRIPTOR.message_types_by_name['PatternFlowGtpv1NextExtensionHeaderTypeCounter'] = _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPECOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowGtpv1NextExtensionHeaderType'] = _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE
DESCRIPTOR.message_types_by_name['PatternFlowGtpExtensionExtensionLengthCounter'] = _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowGtpExtensionExtensionLength'] = _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH
DESCRIPTOR.message_types_by_name['PatternFlowGtpExtensionContentsCounter'] = _PATTERNFLOWGTPEXTENSIONCONTENTSCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowGtpExtensionContents'] = _PATTERNFLOWGTPEXTENSIONCONTENTS
DESCRIPTOR.message_types_by_name['PatternFlowGtpExtensionNextExtensionHeaderCounter'] = _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowGtpExtensionNextExtensionHeader'] = _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER
DESCRIPTOR.message_types_by_name['PatternFlowGtpv2VersionCounter'] = _PATTERNFLOWGTPV2VERSIONCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowGtpv2Version'] = _PATTERNFLOWGTPV2VERSION
DESCRIPTOR.message_types_by_name['PatternFlowGtpv2PiggybackingFlagCounter'] = _PATTERNFLOWGTPV2PIGGYBACKINGFLAGCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowGtpv2PiggybackingFlag'] = _PATTERNFLOWGTPV2PIGGYBACKINGFLAG
DESCRIPTOR.message_types_by_name['PatternFlowGtpv2TeidFlagCounter'] = _PATTERNFLOWGTPV2TEIDFLAGCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowGtpv2TeidFlag'] = _PATTERNFLOWGTPV2TEIDFLAG
DESCRIPTOR.message_types_by_name['PatternFlowGtpv2Spare1Counter'] = _PATTERNFLOWGTPV2SPARE1COUNTER
DESCRIPTOR.message_types_by_name['PatternFlowGtpv2Spare1'] = _PATTERNFLOWGTPV2SPARE1
DESCRIPTOR.message_types_by_name['PatternFlowGtpv2MessageTypeCounter'] = _PATTERNFLOWGTPV2MESSAGETYPECOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowGtpv2MessageType'] = _PATTERNFLOWGTPV2MESSAGETYPE
DESCRIPTOR.message_types_by_name['PatternFlowGtpv2MessageLengthCounter'] = _PATTERNFLOWGTPV2MESSAGELENGTHCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowGtpv2MessageLength'] = _PATTERNFLOWGTPV2MESSAGELENGTH
DESCRIPTOR.message_types_by_name['PatternFlowGtpv2TeidCounter'] = _PATTERNFLOWGTPV2TEIDCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowGtpv2Teid'] = _PATTERNFLOWGTPV2TEID
DESCRIPTOR.message_types_by_name['PatternFlowGtpv2SequenceNumberCounter'] = _PATTERNFLOWGTPV2SEQUENCENUMBERCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowGtpv2SequenceNumber'] = _PATTERNFLOWGTPV2SEQUENCENUMBER
DESCRIPTOR.message_types_by_name['PatternFlowGtpv2Spare2Counter'] = _PATTERNFLOWGTPV2SPARE2COUNTER
DESCRIPTOR.message_types_by_name['PatternFlowGtpv2Spare2'] = _PATTERNFLOWGTPV2SPARE2
DESCRIPTOR.message_types_by_name['PatternFlowArpHardwareTypeCounter'] = _PATTERNFLOWARPHARDWARETYPECOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowArpHardwareType'] = _PATTERNFLOWARPHARDWARETYPE
DESCRIPTOR.message_types_by_name['PatternFlowArpProtocolTypeCounter'] = _PATTERNFLOWARPPROTOCOLTYPECOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowArpProtocolType'] = _PATTERNFLOWARPPROTOCOLTYPE
DESCRIPTOR.message_types_by_name['PatternFlowArpHardwareLengthCounter'] = _PATTERNFLOWARPHARDWARELENGTHCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowArpHardwareLength'] = _PATTERNFLOWARPHARDWARELENGTH
DESCRIPTOR.message_types_by_name['PatternFlowArpProtocolLengthCounter'] = _PATTERNFLOWARPPROTOCOLLENGTHCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowArpProtocolLength'] = _PATTERNFLOWARPPROTOCOLLENGTH
DESCRIPTOR.message_types_by_name['PatternFlowArpOperationCounter'] = _PATTERNFLOWARPOPERATIONCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowArpOperation'] = _PATTERNFLOWARPOPERATION
DESCRIPTOR.message_types_by_name['PatternFlowArpSenderHardwareAddrCounter'] = _PATTERNFLOWARPSENDERHARDWAREADDRCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowArpSenderHardwareAddr'] = _PATTERNFLOWARPSENDERHARDWAREADDR
DESCRIPTOR.message_types_by_name['PatternFlowArpSenderProtocolAddrCounter'] = _PATTERNFLOWARPSENDERPROTOCOLADDRCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowArpSenderProtocolAddr'] = _PATTERNFLOWARPSENDERPROTOCOLADDR
DESCRIPTOR.message_types_by_name['PatternFlowArpTargetHardwareAddrCounter'] = _PATTERNFLOWARPTARGETHARDWAREADDRCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowArpTargetHardwareAddr'] = _PATTERNFLOWARPTARGETHARDWAREADDR
DESCRIPTOR.message_types_by_name['PatternFlowArpTargetProtocolAddrCounter'] = _PATTERNFLOWARPTARGETPROTOCOLADDRCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowArpTargetProtocolAddr'] = _PATTERNFLOWARPTARGETPROTOCOLADDR
DESCRIPTOR.message_types_by_name['PatternFlowIcmpEchoTypeCounter'] = _PATTERNFLOWICMPECHOTYPECOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIcmpEchoType'] = _PATTERNFLOWICMPECHOTYPE
DESCRIPTOR.message_types_by_name['PatternFlowIcmpEchoCodeCounter'] = _PATTERNFLOWICMPECHOCODECOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIcmpEchoCode'] = _PATTERNFLOWICMPECHOCODE
DESCRIPTOR.message_types_by_name['PatternFlowIcmpEchoChecksum'] = _PATTERNFLOWICMPECHOCHECKSUM
DESCRIPTOR.message_types_by_name['PatternFlowIcmpEchoIdentifierCounter'] = _PATTERNFLOWICMPECHOIDENTIFIERCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIcmpEchoIdentifier'] = _PATTERNFLOWICMPECHOIDENTIFIER
DESCRIPTOR.message_types_by_name['PatternFlowIcmpEchoSequenceNumberCounter'] = _PATTERNFLOWICMPECHOSEQUENCENUMBERCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIcmpEchoSequenceNumber'] = _PATTERNFLOWICMPECHOSEQUENCENUMBER
DESCRIPTOR.message_types_by_name['PatternFlowIcmpCommonChecksum'] = _PATTERNFLOWICMPCOMMONCHECKSUM
DESCRIPTOR.message_types_by_name['PatternFlowIcmpNextFieldsIdentifierCounter'] = _PATTERNFLOWICMPNEXTFIELDSIDENTIFIERCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIcmpNextFieldsIdentifier'] = _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER
DESCRIPTOR.message_types_by_name['PatternFlowIcmpNextFieldsSequenceNumberCounter'] = _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIcmpNextFieldsSequenceNumber'] = _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER
DESCRIPTOR.message_types_by_name['PatternFlowIcmpv6EchoTypeCounter'] = _PATTERNFLOWICMPV6ECHOTYPECOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIcmpv6EchoType'] = _PATTERNFLOWICMPV6ECHOTYPE
DESCRIPTOR.message_types_by_name['PatternFlowIcmpv6EchoCodeCounter'] = _PATTERNFLOWICMPV6ECHOCODECOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIcmpv6EchoCode'] = _PATTERNFLOWICMPV6ECHOCODE
DESCRIPTOR.message_types_by_name['PatternFlowIcmpv6EchoIdentifierCounter'] = _PATTERNFLOWICMPV6ECHOIDENTIFIERCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIcmpv6EchoIdentifier'] = _PATTERNFLOWICMPV6ECHOIDENTIFIER
DESCRIPTOR.message_types_by_name['PatternFlowIcmpv6EchoSequenceNumberCounter'] = _PATTERNFLOWICMPV6ECHOSEQUENCENUMBERCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIcmpv6EchoSequenceNumber'] = _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER
DESCRIPTOR.message_types_by_name['PatternFlowIcmpv6EchoChecksum'] = _PATTERNFLOWICMPV6ECHOCHECKSUM
DESCRIPTOR.message_types_by_name['PatternFlowIcmpv6CommonChecksum'] = _PATTERNFLOWICMPV6COMMONCHECKSUM
DESCRIPTOR.message_types_by_name['PatternFlowPppAddressCounter'] = _PATTERNFLOWPPPADDRESSCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowPppAddress'] = _PATTERNFLOWPPPADDRESS
DESCRIPTOR.message_types_by_name['PatternFlowPppControlCounter'] = _PATTERNFLOWPPPCONTROLCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowPppControl'] = _PATTERNFLOWPPPCONTROL
DESCRIPTOR.message_types_by_name['PatternFlowPppProtocolTypeCounter'] = _PATTERNFLOWPPPPROTOCOLTYPECOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowPppProtocolType'] = _PATTERNFLOWPPPPROTOCOLTYPE
DESCRIPTOR.message_types_by_name['PatternFlowIgmpv1VersionCounter'] = _PATTERNFLOWIGMPV1VERSIONCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIgmpv1Version'] = _PATTERNFLOWIGMPV1VERSION
DESCRIPTOR.message_types_by_name['PatternFlowIgmpv1TypeCounter'] = _PATTERNFLOWIGMPV1TYPECOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIgmpv1Type'] = _PATTERNFLOWIGMPV1TYPE
DESCRIPTOR.message_types_by_name['PatternFlowIgmpv1UnusedCounter'] = _PATTERNFLOWIGMPV1UNUSEDCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIgmpv1Unused'] = _PATTERNFLOWIGMPV1UNUSED
DESCRIPTOR.message_types_by_name['PatternFlowIgmpv1Checksum'] = _PATTERNFLOWIGMPV1CHECKSUM
DESCRIPTOR.message_types_by_name['PatternFlowIgmpv1GroupAddressCounter'] = _PATTERNFLOWIGMPV1GROUPADDRESSCOUNTER
DESCRIPTOR.message_types_by_name['PatternFlowIgmpv1GroupAddress'] = _PATTERNFLOWIGMPV1GROUPADDRESS
DESCRIPTOR.message_types_by_name['Success'] = _SUCCESS
DESCRIPTOR.message_types_by_name['BadRequest'] = _BADREQUEST
DESCRIPTOR.message_types_by_name['InternalServerError'] = _INTERNALSERVERERROR
DESCRIPTOR.message_types_by_name['SetConfigRequest'] = _SETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['SetConfigResponse'] = _SETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['GetConfigResponse'] = _GETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetTransmitStateRequest'] = _SETTRANSMITSTATEREQUEST
DESCRIPTOR.message_types_by_name['SetTransmitStateResponse'] = _SETTRANSMITSTATERESPONSE
DESCRIPTOR.message_types_by_name['SetLinkStateRequest'] = _SETLINKSTATEREQUEST
DESCRIPTOR.message_types_by_name['SetLinkStateResponse'] = _SETLINKSTATERESPONSE
DESCRIPTOR.message_types_by_name['SetCaptureStateRequest'] = _SETCAPTURESTATEREQUEST
DESCRIPTOR.message_types_by_name['SetCaptureStateResponse'] = _SETCAPTURESTATERESPONSE
DESCRIPTOR.message_types_by_name['UpdateFlowsRequest'] = _UPDATEFLOWSREQUEST
DESCRIPTOR.message_types_by_name['UpdateFlowsResponse'] = _UPDATEFLOWSRESPONSE
DESCRIPTOR.message_types_by_name['SetRouteStateRequest'] = _SETROUTESTATEREQUEST
DESCRIPTOR.message_types_by_name['SetRouteStateResponse'] = _SETROUTESTATERESPONSE
DESCRIPTOR.message_types_by_name['SendPingRequest'] = _SENDPINGREQUEST
DESCRIPTOR.message_types_by_name['SendPingResponse'] = _SENDPINGRESPONSE
DESCRIPTOR.message_types_by_name['SetProtocolStateRequest'] = _SETPROTOCOLSTATEREQUEST
DESCRIPTOR.message_types_by_name['SetProtocolStateResponse'] = _SETPROTOCOLSTATERESPONSE
DESCRIPTOR.message_types_by_name['GetMetricsRequest'] = _GETMETRICSREQUEST
DESCRIPTOR.message_types_by_name['GetMetricsResponse'] = _GETMETRICSRESPONSE
DESCRIPTOR.message_types_by_name['GetStatesRequest'] = _GETSTATESREQUEST
DESCRIPTOR.message_types_by_name['GetStatesResponse'] = _GETSTATESRESPONSE
DESCRIPTOR.message_types_by_name['GetCaptureRequest'] = _GETCAPTUREREQUEST
DESCRIPTOR.message_types_by_name['GetCaptureResponse'] = _GETCAPTURERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Config = _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {
  'DESCRIPTOR' : _CONFIG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Config)
  })
_sym_db.RegisterMessage(Config)

ConfigOptions = _reflection.GeneratedProtocolMessageType('ConfigOptions', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGOPTIONS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.ConfigOptions)
  })
_sym_db.RegisterMessage(ConfigOptions)

Port = _reflection.GeneratedProtocolMessageType('Port', (_message.Message,), {
  'DESCRIPTOR' : _PORT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Port)
  })
_sym_db.RegisterMessage(Port)

PortOptions = _reflection.GeneratedProtocolMessageType('PortOptions', (_message.Message,), {
  'DESCRIPTOR' : _PORTOPTIONS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PortOptions)
  })
_sym_db.RegisterMessage(PortOptions)

Lag = _reflection.GeneratedProtocolMessageType('Lag', (_message.Message,), {
  'DESCRIPTOR' : _LAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Lag)
  })
_sym_db.RegisterMessage(Lag)

LagPort = _reflection.GeneratedProtocolMessageType('LagPort', (_message.Message,), {
  'DESCRIPTOR' : _LAGPORT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LagPort)
  })
_sym_db.RegisterMessage(LagPort)

LagProtocol = _reflection.GeneratedProtocolMessageType('LagProtocol', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _LAGPROTOCOL_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.LagProtocol.Choice)
    })
  ,
  'DESCRIPTOR' : _LAGPROTOCOL,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LagProtocol)
  })
_sym_db.RegisterMessage(LagProtocol)
_sym_db.RegisterMessage(LagProtocol.Choice)

LagStatic = _reflection.GeneratedProtocolMessageType('LagStatic', (_message.Message,), {
  'DESCRIPTOR' : _LAGSTATIC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LagStatic)
  })
_sym_db.RegisterMessage(LagStatic)

LagLacp = _reflection.GeneratedProtocolMessageType('LagLacp', (_message.Message,), {

  'ActorActivity' : _reflection.GeneratedProtocolMessageType('ActorActivity', (_message.Message,), {
    'DESCRIPTOR' : _LAGLACP_ACTORACTIVITY,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.LagLacp.ActorActivity)
    })
  ,
  'DESCRIPTOR' : _LAGLACP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LagLacp)
  })
_sym_db.RegisterMessage(LagLacp)
_sym_db.RegisterMessage(LagLacp.ActorActivity)

DeviceEthernetBase = _reflection.GeneratedProtocolMessageType('DeviceEthernetBase', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEETHERNETBASE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceEthernetBase)
  })
_sym_db.RegisterMessage(DeviceEthernetBase)

DeviceEthernet = _reflection.GeneratedProtocolMessageType('DeviceEthernet', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEETHERNET,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceEthernet)
  })
_sym_db.RegisterMessage(DeviceEthernet)

DeviceVlan = _reflection.GeneratedProtocolMessageType('DeviceVlan', (_message.Message,), {

  'Tpid' : _reflection.GeneratedProtocolMessageType('Tpid', (_message.Message,), {
    'DESCRIPTOR' : _DEVICEVLAN_TPID,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.DeviceVlan.Tpid)
    })
  ,
  'DESCRIPTOR' : _DEVICEVLAN,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceVlan)
  })
_sym_db.RegisterMessage(DeviceVlan)
_sym_db.RegisterMessage(DeviceVlan.Tpid)

DeviceIpv4 = _reflection.GeneratedProtocolMessageType('DeviceIpv4', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEIPV4,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceIpv4)
  })
_sym_db.RegisterMessage(DeviceIpv4)

DeviceIpv4Loopback = _reflection.GeneratedProtocolMessageType('DeviceIpv4Loopback', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEIPV4LOOPBACK,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceIpv4Loopback)
  })
_sym_db.RegisterMessage(DeviceIpv4Loopback)

DeviceIpv6 = _reflection.GeneratedProtocolMessageType('DeviceIpv6', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEIPV6,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceIpv6)
  })
_sym_db.RegisterMessage(DeviceIpv6)

DeviceIpv6Loopback = _reflection.GeneratedProtocolMessageType('DeviceIpv6Loopback', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEIPV6LOOPBACK,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceIpv6Loopback)
  })
_sym_db.RegisterMessage(DeviceIpv6Loopback)

Layer1 = _reflection.GeneratedProtocolMessageType('Layer1', (_message.Message,), {

  'Speed' : _reflection.GeneratedProtocolMessageType('Speed', (_message.Message,), {
    'DESCRIPTOR' : _LAYER1_SPEED,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.Layer1.Speed)
    })
  ,

  'Media' : _reflection.GeneratedProtocolMessageType('Media', (_message.Message,), {
    'DESCRIPTOR' : _LAYER1_MEDIA,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.Layer1.Media)
    })
  ,
  'DESCRIPTOR' : _LAYER1,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Layer1)
  })
_sym_db.RegisterMessage(Layer1)
_sym_db.RegisterMessage(Layer1.Speed)
_sym_db.RegisterMessage(Layer1.Media)

Layer1AutoNegotiation = _reflection.GeneratedProtocolMessageType('Layer1AutoNegotiation', (_message.Message,), {
  'DESCRIPTOR' : _LAYER1AUTONEGOTIATION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Layer1AutoNegotiation)
  })
_sym_db.RegisterMessage(Layer1AutoNegotiation)

Layer1FlowControl = _reflection.GeneratedProtocolMessageType('Layer1FlowControl', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _LAYER1FLOWCONTROL_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.Layer1FlowControl.Choice)
    })
  ,
  'DESCRIPTOR' : _LAYER1FLOWCONTROL,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Layer1FlowControl)
  })
_sym_db.RegisterMessage(Layer1FlowControl)
_sym_db.RegisterMessage(Layer1FlowControl.Choice)

Layer1Ieee8023x = _reflection.GeneratedProtocolMessageType('Layer1Ieee8023x', (_message.Message,), {
  'DESCRIPTOR' : _LAYER1IEEE8023X,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Layer1Ieee8023x)
  })
_sym_db.RegisterMessage(Layer1Ieee8023x)

Layer1Ieee8021qbb = _reflection.GeneratedProtocolMessageType('Layer1Ieee8021qbb', (_message.Message,), {
  'DESCRIPTOR' : _LAYER1IEEE8021QBB,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Layer1Ieee8021qbb)
  })
_sym_db.RegisterMessage(Layer1Ieee8021qbb)

Capture = _reflection.GeneratedProtocolMessageType('Capture', (_message.Message,), {

  'Format' : _reflection.GeneratedProtocolMessageType('Format', (_message.Message,), {
    'DESCRIPTOR' : _CAPTURE_FORMAT,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.Capture.Format)
    })
  ,
  'DESCRIPTOR' : _CAPTURE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Capture)
  })
_sym_db.RegisterMessage(Capture)
_sym_db.RegisterMessage(Capture.Format)

CaptureFilter = _reflection.GeneratedProtocolMessageType('CaptureFilter', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _CAPTUREFILTER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.CaptureFilter.Choice)
    })
  ,
  'DESCRIPTOR' : _CAPTUREFILTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.CaptureFilter)
  })
_sym_db.RegisterMessage(CaptureFilter)
_sym_db.RegisterMessage(CaptureFilter.Choice)

CaptureCustom = _reflection.GeneratedProtocolMessageType('CaptureCustom', (_message.Message,), {
  'DESCRIPTOR' : _CAPTURECUSTOM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.CaptureCustom)
  })
_sym_db.RegisterMessage(CaptureCustom)

CaptureField = _reflection.GeneratedProtocolMessageType('CaptureField', (_message.Message,), {
  'DESCRIPTOR' : _CAPTUREFIELD,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.CaptureField)
  })
_sym_db.RegisterMessage(CaptureField)

CaptureEthernet = _reflection.GeneratedProtocolMessageType('CaptureEthernet', (_message.Message,), {
  'DESCRIPTOR' : _CAPTUREETHERNET,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.CaptureEthernet)
  })
_sym_db.RegisterMessage(CaptureEthernet)

CaptureVlan = _reflection.GeneratedProtocolMessageType('CaptureVlan', (_message.Message,), {
  'DESCRIPTOR' : _CAPTUREVLAN,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.CaptureVlan)
  })
_sym_db.RegisterMessage(CaptureVlan)

CaptureIpv4 = _reflection.GeneratedProtocolMessageType('CaptureIpv4', (_message.Message,), {
  'DESCRIPTOR' : _CAPTUREIPV4,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.CaptureIpv4)
  })
_sym_db.RegisterMessage(CaptureIpv4)

CaptureIpv6 = _reflection.GeneratedProtocolMessageType('CaptureIpv6', (_message.Message,), {
  'DESCRIPTOR' : _CAPTUREIPV6,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.CaptureIpv6)
  })
_sym_db.RegisterMessage(CaptureIpv6)

Device = _reflection.GeneratedProtocolMessageType('Device', (_message.Message,), {
  'DESCRIPTOR' : _DEVICE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Device)
  })
_sym_db.RegisterMessage(Device)

DeviceIsisRouter = _reflection.GeneratedProtocolMessageType('DeviceIsisRouter', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEISISROUTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceIsisRouter)
  })
_sym_db.RegisterMessage(DeviceIsisRouter)

DeviceIsisMultiInstance = _reflection.GeneratedProtocolMessageType('DeviceIsisMultiInstance', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEISISMULTIINSTANCE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceIsisMultiInstance)
  })
_sym_db.RegisterMessage(DeviceIsisMultiInstance)

IsisInterface = _reflection.GeneratedProtocolMessageType('IsisInterface', (_message.Message,), {

  'NetworkType' : _reflection.GeneratedProtocolMessageType('NetworkType', (_message.Message,), {
    'DESCRIPTOR' : _ISISINTERFACE_NETWORKTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.IsisInterface.NetworkType)
    })
  ,

  'LevelType' : _reflection.GeneratedProtocolMessageType('LevelType', (_message.Message,), {
    'DESCRIPTOR' : _ISISINTERFACE_LEVELTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.IsisInterface.LevelType)
    })
  ,
  'DESCRIPTOR' : _ISISINTERFACE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisInterface)
  })
_sym_db.RegisterMessage(IsisInterface)
_sym_db.RegisterMessage(IsisInterface.NetworkType)
_sym_db.RegisterMessage(IsisInterface.LevelType)

IsisInterfaceLevel = _reflection.GeneratedProtocolMessageType('IsisInterfaceLevel', (_message.Message,), {
  'DESCRIPTOR' : _ISISINTERFACELEVEL,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisInterfaceLevel)
  })
_sym_db.RegisterMessage(IsisInterfaceLevel)

IsisMT = _reflection.GeneratedProtocolMessageType('IsisMT', (_message.Message,), {
  'DESCRIPTOR' : _ISISMT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisMT)
  })
_sym_db.RegisterMessage(IsisMT)

LinkStateTE = _reflection.GeneratedProtocolMessageType('LinkStateTE', (_message.Message,), {
  'DESCRIPTOR' : _LINKSTATETE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LinkStateTE)
  })
_sym_db.RegisterMessage(LinkStateTE)

LinkStatepriorityBandwidths = _reflection.GeneratedProtocolMessageType('LinkStatepriorityBandwidths', (_message.Message,), {
  'DESCRIPTOR' : _LINKSTATEPRIORITYBANDWIDTHS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LinkStatepriorityBandwidths)
  })
_sym_db.RegisterMessage(LinkStatepriorityBandwidths)

IsisInterfaceAuthentication = _reflection.GeneratedProtocolMessageType('IsisInterfaceAuthentication', (_message.Message,), {

  'AuthType' : _reflection.GeneratedProtocolMessageType('AuthType', (_message.Message,), {
    'DESCRIPTOR' : _ISISINTERFACEAUTHENTICATION_AUTHTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.IsisInterfaceAuthentication.AuthType)
    })
  ,
  'DESCRIPTOR' : _ISISINTERFACEAUTHENTICATION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisInterfaceAuthentication)
  })
_sym_db.RegisterMessage(IsisInterfaceAuthentication)
_sym_db.RegisterMessage(IsisInterfaceAuthentication.AuthType)

IsisInterfaceAdvanced = _reflection.GeneratedProtocolMessageType('IsisInterfaceAdvanced', (_message.Message,), {
  'DESCRIPTOR' : _ISISINTERFACEADVANCED,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisInterfaceAdvanced)
  })
_sym_db.RegisterMessage(IsisInterfaceAdvanced)

IsisInterfaceLinkProtection = _reflection.GeneratedProtocolMessageType('IsisInterfaceLinkProtection', (_message.Message,), {
  'DESCRIPTOR' : _ISISINTERFACELINKPROTECTION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisInterfaceLinkProtection)
  })
_sym_db.RegisterMessage(IsisInterfaceLinkProtection)

IsisBasic = _reflection.GeneratedProtocolMessageType('IsisBasic', (_message.Message,), {
  'DESCRIPTOR' : _ISISBASIC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisBasic)
  })
_sym_db.RegisterMessage(IsisBasic)

IsisAdvanced = _reflection.GeneratedProtocolMessageType('IsisAdvanced', (_message.Message,), {
  'DESCRIPTOR' : _ISISADVANCED,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisAdvanced)
  })
_sym_db.RegisterMessage(IsisAdvanced)

IsisAuthentication = _reflection.GeneratedProtocolMessageType('IsisAuthentication', (_message.Message,), {
  'DESCRIPTOR' : _ISISAUTHENTICATION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisAuthentication)
  })
_sym_db.RegisterMessage(IsisAuthentication)

IsisAuthenticationBase = _reflection.GeneratedProtocolMessageType('IsisAuthenticationBase', (_message.Message,), {

  'AuthType' : _reflection.GeneratedProtocolMessageType('AuthType', (_message.Message,), {
    'DESCRIPTOR' : _ISISAUTHENTICATIONBASE_AUTHTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.IsisAuthenticationBase.AuthType)
    })
  ,
  'DESCRIPTOR' : _ISISAUTHENTICATIONBASE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisAuthenticationBase)
  })
_sym_db.RegisterMessage(IsisAuthenticationBase)
_sym_db.RegisterMessage(IsisAuthenticationBase.AuthType)

IsisV4RouteRange = _reflection.GeneratedProtocolMessageType('IsisV4RouteRange', (_message.Message,), {

  'OriginType' : _reflection.GeneratedProtocolMessageType('OriginType', (_message.Message,), {
    'DESCRIPTOR' : _ISISV4ROUTERANGE_ORIGINTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.IsisV4RouteRange.OriginType)
    })
  ,

  'RedistributionType' : _reflection.GeneratedProtocolMessageType('RedistributionType', (_message.Message,), {
    'DESCRIPTOR' : _ISISV4ROUTERANGE_REDISTRIBUTIONTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.IsisV4RouteRange.RedistributionType)
    })
  ,
  'DESCRIPTOR' : _ISISV4ROUTERANGE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisV4RouteRange)
  })
_sym_db.RegisterMessage(IsisV4RouteRange)
_sym_db.RegisterMessage(IsisV4RouteRange.OriginType)
_sym_db.RegisterMessage(IsisV4RouteRange.RedistributionType)

V4RouteAddress = _reflection.GeneratedProtocolMessageType('V4RouteAddress', (_message.Message,), {
  'DESCRIPTOR' : _V4ROUTEADDRESS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.V4RouteAddress)
  })
_sym_db.RegisterMessage(V4RouteAddress)

V6RouteAddress = _reflection.GeneratedProtocolMessageType('V6RouteAddress', (_message.Message,), {
  'DESCRIPTOR' : _V6ROUTEADDRESS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.V6RouteAddress)
  })
_sym_db.RegisterMessage(V6RouteAddress)

IsisV6RouteRange = _reflection.GeneratedProtocolMessageType('IsisV6RouteRange', (_message.Message,), {

  'OriginType' : _reflection.GeneratedProtocolMessageType('OriginType', (_message.Message,), {
    'DESCRIPTOR' : _ISISV6ROUTERANGE_ORIGINTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.IsisV6RouteRange.OriginType)
    })
  ,

  'RedistributionType' : _reflection.GeneratedProtocolMessageType('RedistributionType', (_message.Message,), {
    'DESCRIPTOR' : _ISISV6ROUTERANGE_REDISTRIBUTIONTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.IsisV6RouteRange.RedistributionType)
    })
  ,
  'DESCRIPTOR' : _ISISV6ROUTERANGE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisV6RouteRange)
  })
_sym_db.RegisterMessage(IsisV6RouteRange)
_sym_db.RegisterMessage(IsisV6RouteRange.OriginType)
_sym_db.RegisterMessage(IsisV6RouteRange.RedistributionType)

DeviceBgpRouter = _reflection.GeneratedProtocolMessageType('DeviceBgpRouter', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEBGPROUTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceBgpRouter)
  })
_sym_db.RegisterMessage(DeviceBgpRouter)

BgpV4Peer = _reflection.GeneratedProtocolMessageType('BgpV4Peer', (_message.Message,), {

  'AsType' : _reflection.GeneratedProtocolMessageType('AsType', (_message.Message,), {
    'DESCRIPTOR' : _BGPV4PEER_ASTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpV4Peer.AsType)
    })
  ,

  'AsNumberWidth' : _reflection.GeneratedProtocolMessageType('AsNumberWidth', (_message.Message,), {
    'DESCRIPTOR' : _BGPV4PEER_ASNUMBERWIDTH,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpV4Peer.AsNumberWidth)
    })
  ,
  'DESCRIPTOR' : _BGPV4PEER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpV4Peer)
  })
_sym_db.RegisterMessage(BgpV4Peer)
_sym_db.RegisterMessage(BgpV4Peer.AsType)
_sym_db.RegisterMessage(BgpV4Peer.AsNumberWidth)

BgpV4Interface = _reflection.GeneratedProtocolMessageType('BgpV4Interface', (_message.Message,), {
  'DESCRIPTOR' : _BGPV4INTERFACE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpV4Interface)
  })
_sym_db.RegisterMessage(BgpV4Interface)

BgpAdvanced = _reflection.GeneratedProtocolMessageType('BgpAdvanced', (_message.Message,), {
  'DESCRIPTOR' : _BGPADVANCED,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpAdvanced)
  })
_sym_db.RegisterMessage(BgpAdvanced)

BgpCapability = _reflection.GeneratedProtocolMessageType('BgpCapability', (_message.Message,), {
  'DESCRIPTOR' : _BGPCAPABILITY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpCapability)
  })
_sym_db.RegisterMessage(BgpCapability)

BgpV4RouteRange = _reflection.GeneratedProtocolMessageType('BgpV4RouteRange', (_message.Message,), {

  'NextHopMode' : _reflection.GeneratedProtocolMessageType('NextHopMode', (_message.Message,), {
    'DESCRIPTOR' : _BGPV4ROUTERANGE_NEXTHOPMODE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpV4RouteRange.NextHopMode)
    })
  ,

  'NextHopAddressType' : _reflection.GeneratedProtocolMessageType('NextHopAddressType', (_message.Message,), {
    'DESCRIPTOR' : _BGPV4ROUTERANGE_NEXTHOPADDRESSTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpV4RouteRange.NextHopAddressType)
    })
  ,
  'DESCRIPTOR' : _BGPV4ROUTERANGE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpV4RouteRange)
  })
_sym_db.RegisterMessage(BgpV4RouteRange)
_sym_db.RegisterMessage(BgpV4RouteRange.NextHopMode)
_sym_db.RegisterMessage(BgpV4RouteRange.NextHopAddressType)

BgpRouteAdvanced = _reflection.GeneratedProtocolMessageType('BgpRouteAdvanced', (_message.Message,), {

  'Origin' : _reflection.GeneratedProtocolMessageType('Origin', (_message.Message,), {
    'DESCRIPTOR' : _BGPROUTEADVANCED_ORIGIN,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpRouteAdvanced.Origin)
    })
  ,
  'DESCRIPTOR' : _BGPROUTEADVANCED,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpRouteAdvanced)
  })
_sym_db.RegisterMessage(BgpRouteAdvanced)
_sym_db.RegisterMessage(BgpRouteAdvanced.Origin)

BgpCommunity = _reflection.GeneratedProtocolMessageType('BgpCommunity', (_message.Message,), {

  'Type' : _reflection.GeneratedProtocolMessageType('Type', (_message.Message,), {
    'DESCRIPTOR' : _BGPCOMMUNITY_TYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpCommunity.Type)
    })
  ,
  'DESCRIPTOR' : _BGPCOMMUNITY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpCommunity)
  })
_sym_db.RegisterMessage(BgpCommunity)
_sym_db.RegisterMessage(BgpCommunity.Type)

BgpAsPath = _reflection.GeneratedProtocolMessageType('BgpAsPath', (_message.Message,), {

  'AsSetMode' : _reflection.GeneratedProtocolMessageType('AsSetMode', (_message.Message,), {
    'DESCRIPTOR' : _BGPASPATH_ASSETMODE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpAsPath.AsSetMode)
    })
  ,
  'DESCRIPTOR' : _BGPASPATH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpAsPath)
  })
_sym_db.RegisterMessage(BgpAsPath)
_sym_db.RegisterMessage(BgpAsPath.AsSetMode)

BgpAsPathSegment = _reflection.GeneratedProtocolMessageType('BgpAsPathSegment', (_message.Message,), {

  'Type' : _reflection.GeneratedProtocolMessageType('Type', (_message.Message,), {
    'DESCRIPTOR' : _BGPASPATHSEGMENT_TYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpAsPathSegment.Type)
    })
  ,
  'DESCRIPTOR' : _BGPASPATHSEGMENT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpAsPathSegment)
  })
_sym_db.RegisterMessage(BgpAsPathSegment)
_sym_db.RegisterMessage(BgpAsPathSegment.Type)

BgpAddPath = _reflection.GeneratedProtocolMessageType('BgpAddPath', (_message.Message,), {
  'DESCRIPTOR' : _BGPADDPATH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpAddPath)
  })
_sym_db.RegisterMessage(BgpAddPath)

BgpV6RouteRange = _reflection.GeneratedProtocolMessageType('BgpV6RouteRange', (_message.Message,), {

  'NextHopMode' : _reflection.GeneratedProtocolMessageType('NextHopMode', (_message.Message,), {
    'DESCRIPTOR' : _BGPV6ROUTERANGE_NEXTHOPMODE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpV6RouteRange.NextHopMode)
    })
  ,

  'NextHopAddressType' : _reflection.GeneratedProtocolMessageType('NextHopAddressType', (_message.Message,), {
    'DESCRIPTOR' : _BGPV6ROUTERANGE_NEXTHOPADDRESSTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpV6RouteRange.NextHopAddressType)
    })
  ,
  'DESCRIPTOR' : _BGPV6ROUTERANGE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpV6RouteRange)
  })
_sym_db.RegisterMessage(BgpV6RouteRange)
_sym_db.RegisterMessage(BgpV6RouteRange.NextHopMode)
_sym_db.RegisterMessage(BgpV6RouteRange.NextHopAddressType)

BgpSrteV4Policy = _reflection.GeneratedProtocolMessageType('BgpSrteV4Policy', (_message.Message,), {

  'NextHopMode' : _reflection.GeneratedProtocolMessageType('NextHopMode', (_message.Message,), {
    'DESCRIPTOR' : _BGPSRTEV4POLICY_NEXTHOPMODE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpSrteV4Policy.NextHopMode)
    })
  ,

  'NextHopAddressType' : _reflection.GeneratedProtocolMessageType('NextHopAddressType', (_message.Message,), {
    'DESCRIPTOR' : _BGPSRTEV4POLICY_NEXTHOPADDRESSTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpSrteV4Policy.NextHopAddressType)
    })
  ,
  'DESCRIPTOR' : _BGPSRTEV4POLICY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteV4Policy)
  })
_sym_db.RegisterMessage(BgpSrteV4Policy)
_sym_db.RegisterMessage(BgpSrteV4Policy.NextHopMode)
_sym_db.RegisterMessage(BgpSrteV4Policy.NextHopAddressType)

BgpExtCommunity = _reflection.GeneratedProtocolMessageType('BgpExtCommunity', (_message.Message,), {

  'Type' : _reflection.GeneratedProtocolMessageType('Type', (_message.Message,), {
    'DESCRIPTOR' : _BGPEXTCOMMUNITY_TYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpExtCommunity.Type)
    })
  ,

  'Subtype' : _reflection.GeneratedProtocolMessageType('Subtype', (_message.Message,), {
    'DESCRIPTOR' : _BGPEXTCOMMUNITY_SUBTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpExtCommunity.Subtype)
    })
  ,
  'DESCRIPTOR' : _BGPEXTCOMMUNITY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpExtCommunity)
  })
_sym_db.RegisterMessage(BgpExtCommunity)
_sym_db.RegisterMessage(BgpExtCommunity.Type)
_sym_db.RegisterMessage(BgpExtCommunity.Subtype)

BgpSrteV4TunnelTlv = _reflection.GeneratedProtocolMessageType('BgpSrteV4TunnelTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTEV4TUNNELTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteV4TunnelTlv)
  })
_sym_db.RegisterMessage(BgpSrteV4TunnelTlv)

BgpSrteRemoteEndpointSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteRemoteEndpointSubTlv', (_message.Message,), {

  'AddressFamily' : _reflection.GeneratedProtocolMessageType('AddressFamily', (_message.Message,), {
    'DESCRIPTOR' : _BGPSRTEREMOTEENDPOINTSUBTLV_ADDRESSFAMILY,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpSrteRemoteEndpointSubTlv.AddressFamily)
    })
  ,
  'DESCRIPTOR' : _BGPSRTEREMOTEENDPOINTSUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteRemoteEndpointSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteRemoteEndpointSubTlv)
_sym_db.RegisterMessage(BgpSrteRemoteEndpointSubTlv.AddressFamily)

BgpSrteColorSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteColorSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTECOLORSUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteColorSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteColorSubTlv)

BgpSrteBindingSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteBindingSubTlv', (_message.Message,), {

  'BindingSidType' : _reflection.GeneratedProtocolMessageType('BindingSidType', (_message.Message,), {
    'DESCRIPTOR' : _BGPSRTEBINDINGSUBTLV_BINDINGSIDTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpSrteBindingSubTlv.BindingSidType)
    })
  ,
  'DESCRIPTOR' : _BGPSRTEBINDINGSUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteBindingSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteBindingSubTlv)
_sym_db.RegisterMessage(BgpSrteBindingSubTlv.BindingSidType)

BgpSrtePreferenceSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrtePreferenceSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTEPREFERENCESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrtePreferenceSubTlv)
  })
_sym_db.RegisterMessage(BgpSrtePreferenceSubTlv)

BgpSrtePolicyPrioritySubTlv = _reflection.GeneratedProtocolMessageType('BgpSrtePolicyPrioritySubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTEPOLICYPRIORITYSUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrtePolicyPrioritySubTlv)
  })
_sym_db.RegisterMessage(BgpSrtePolicyPrioritySubTlv)

BgpSrtePolicyNameSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrtePolicyNameSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTEPOLICYNAMESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrtePolicyNameSubTlv)
  })
_sym_db.RegisterMessage(BgpSrtePolicyNameSubTlv)

BgpSrteExplicitNullLabelPolicySubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteExplicitNullLabelPolicySubTlv', (_message.Message,), {

  'ExplicitNullLabelPolicy' : _reflection.GeneratedProtocolMessageType('ExplicitNullLabelPolicy', (_message.Message,), {
    'DESCRIPTOR' : _BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV_EXPLICITNULLLABELPOLICY,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpSrteExplicitNullLabelPolicySubTlv.ExplicitNullLabelPolicy)
    })
  ,
  'DESCRIPTOR' : _BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteExplicitNullLabelPolicySubTlv)
  })
_sym_db.RegisterMessage(BgpSrteExplicitNullLabelPolicySubTlv)
_sym_db.RegisterMessage(BgpSrteExplicitNullLabelPolicySubTlv.ExplicitNullLabelPolicy)

BgpSrteSegmentList = _reflection.GeneratedProtocolMessageType('BgpSrteSegmentList', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESEGMENTLIST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegmentList)
  })
_sym_db.RegisterMessage(BgpSrteSegmentList)

BgpSrteSegment = _reflection.GeneratedProtocolMessageType('BgpSrteSegment', (_message.Message,), {

  'SegmentType' : _reflection.GeneratedProtocolMessageType('SegmentType', (_message.Message,), {
    'DESCRIPTOR' : _BGPSRTESEGMENT_SEGMENTTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpSrteSegment.SegmentType)
    })
  ,
  'DESCRIPTOR' : _BGPSRTESEGMENT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegment)
  })
_sym_db.RegisterMessage(BgpSrteSegment)
_sym_db.RegisterMessage(BgpSrteSegment.SegmentType)

BgpSrteSrMplsSid = _reflection.GeneratedProtocolMessageType('BgpSrteSrMplsSid', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESRMPLSSID,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSrMplsSid)
  })
_sym_db.RegisterMessage(BgpSrteSrMplsSid)

BgpSrteSRv6SIDEndpointBehaviorAndStructure = _reflection.GeneratedProtocolMessageType('BgpSrteSRv6SIDEndpointBehaviorAndStructure', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESRV6SIDENDPOINTBEHAVIORANDSTRUCTURE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSRv6SIDEndpointBehaviorAndStructure)
  })
_sym_db.RegisterMessage(BgpSrteSRv6SIDEndpointBehaviorAndStructure)

BgpSrteSegmentATypeSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteSegmentATypeSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESEGMENTATYPESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegmentATypeSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteSegmentATypeSubTlv)

BgpSrteSegmentBTypeSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteSegmentBTypeSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESEGMENTBTYPESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegmentBTypeSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteSegmentBTypeSubTlv)

BgpSrteSegmentCTypeSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteSegmentCTypeSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESEGMENTCTYPESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegmentCTypeSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteSegmentCTypeSubTlv)

BgpSrteSegmentDTypeSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteSegmentDTypeSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESEGMENTDTYPESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegmentDTypeSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteSegmentDTypeSubTlv)

BgpSrteSegmentETypeSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteSegmentETypeSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESEGMENTETYPESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegmentETypeSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteSegmentETypeSubTlv)

BgpSrteSegmentFTypeSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteSegmentFTypeSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESEGMENTFTYPESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegmentFTypeSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteSegmentFTypeSubTlv)

BgpSrteSegmentGTypeSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteSegmentGTypeSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESEGMENTGTYPESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegmentGTypeSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteSegmentGTypeSubTlv)

BgpSrteSegmentHTypeSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteSegmentHTypeSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESEGMENTHTYPESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegmentHTypeSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteSegmentHTypeSubTlv)

BgpSrteSegmentITypeSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteSegmentITypeSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESEGMENTITYPESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegmentITypeSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteSegmentITypeSubTlv)

BgpSrteSegmentJTypeSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteSegmentJTypeSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESEGMENTJTYPESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegmentJTypeSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteSegmentJTypeSubTlv)

BgpSrteSegmentKTypeSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteSegmentKTypeSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESEGMENTKTYPESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegmentKTypeSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteSegmentKTypeSubTlv)

BgpSrteV6Policy = _reflection.GeneratedProtocolMessageType('BgpSrteV6Policy', (_message.Message,), {

  'NextHopMode' : _reflection.GeneratedProtocolMessageType('NextHopMode', (_message.Message,), {
    'DESCRIPTOR' : _BGPSRTEV6POLICY_NEXTHOPMODE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpSrteV6Policy.NextHopMode)
    })
  ,

  'NextHopAddressType' : _reflection.GeneratedProtocolMessageType('NextHopAddressType', (_message.Message,), {
    'DESCRIPTOR' : _BGPSRTEV6POLICY_NEXTHOPADDRESSTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpSrteV6Policy.NextHopAddressType)
    })
  ,
  'DESCRIPTOR' : _BGPSRTEV6POLICY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteV6Policy)
  })
_sym_db.RegisterMessage(BgpSrteV6Policy)
_sym_db.RegisterMessage(BgpSrteV6Policy.NextHopMode)
_sym_db.RegisterMessage(BgpSrteV6Policy.NextHopAddressType)

BgpSrteV6TunnelTlv = _reflection.GeneratedProtocolMessageType('BgpSrteV6TunnelTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTEV6TUNNELTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteV6TunnelTlv)
  })
_sym_db.RegisterMessage(BgpSrteV6TunnelTlv)

BgpV6Peer = _reflection.GeneratedProtocolMessageType('BgpV6Peer', (_message.Message,), {

  'AsType' : _reflection.GeneratedProtocolMessageType('AsType', (_message.Message,), {
    'DESCRIPTOR' : _BGPV6PEER_ASTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpV6Peer.AsType)
    })
  ,

  'AsNumberWidth' : _reflection.GeneratedProtocolMessageType('AsNumberWidth', (_message.Message,), {
    'DESCRIPTOR' : _BGPV6PEER_ASNUMBERWIDTH,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpV6Peer.AsNumberWidth)
    })
  ,
  'DESCRIPTOR' : _BGPV6PEER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpV6Peer)
  })
_sym_db.RegisterMessage(BgpV6Peer)
_sym_db.RegisterMessage(BgpV6Peer.AsType)
_sym_db.RegisterMessage(BgpV6Peer.AsNumberWidth)

BgpV6Interface = _reflection.GeneratedProtocolMessageType('BgpV6Interface', (_message.Message,), {
  'DESCRIPTOR' : _BGPV6INTERFACE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpV6Interface)
  })
_sym_db.RegisterMessage(BgpV6Interface)

BgpV6SegmentRouting = _reflection.GeneratedProtocolMessageType('BgpV6SegmentRouting', (_message.Message,), {
  'DESCRIPTOR' : _BGPV6SEGMENTROUTING,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpV6SegmentRouting)
  })
_sym_db.RegisterMessage(BgpV6SegmentRouting)

Flow = _reflection.GeneratedProtocolMessageType('Flow', (_message.Message,), {
  'DESCRIPTOR' : _FLOW,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Flow)
  })
_sym_db.RegisterMessage(Flow)

FlowTxRx = _reflection.GeneratedProtocolMessageType('FlowTxRx', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FLOWTXRX_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowTxRx.Choice)
    })
  ,
  'DESCRIPTOR' : _FLOWTXRX,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowTxRx)
  })
_sym_db.RegisterMessage(FlowTxRx)
_sym_db.RegisterMessage(FlowTxRx.Choice)

FlowPort = _reflection.GeneratedProtocolMessageType('FlowPort', (_message.Message,), {
  'DESCRIPTOR' : _FLOWPORT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowPort)
  })
_sym_db.RegisterMessage(FlowPort)

FlowRouter = _reflection.GeneratedProtocolMessageType('FlowRouter', (_message.Message,), {

  'Mode' : _reflection.GeneratedProtocolMessageType('Mode', (_message.Message,), {
    'DESCRIPTOR' : _FLOWROUTER_MODE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowRouter.Mode)
    })
  ,
  'DESCRIPTOR' : _FLOWROUTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowRouter)
  })
_sym_db.RegisterMessage(FlowRouter)
_sym_db.RegisterMessage(FlowRouter.Mode)

FlowHeader = _reflection.GeneratedProtocolMessageType('FlowHeader', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FLOWHEADER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowHeader.Choice)
    })
  ,
  'DESCRIPTOR' : _FLOWHEADER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowHeader)
  })
_sym_db.RegisterMessage(FlowHeader)
_sym_db.RegisterMessage(FlowHeader.Choice)

FlowCustom = _reflection.GeneratedProtocolMessageType('FlowCustom', (_message.Message,), {
  'DESCRIPTOR' : _FLOWCUSTOM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowCustom)
  })
_sym_db.RegisterMessage(FlowCustom)

FlowEthernet = _reflection.GeneratedProtocolMessageType('FlowEthernet', (_message.Message,), {
  'DESCRIPTOR' : _FLOWETHERNET,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowEthernet)
  })
_sym_db.RegisterMessage(FlowEthernet)

FlowVlan = _reflection.GeneratedProtocolMessageType('FlowVlan', (_message.Message,), {
  'DESCRIPTOR' : _FLOWVLAN,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowVlan)
  })
_sym_db.RegisterMessage(FlowVlan)

FlowVxlan = _reflection.GeneratedProtocolMessageType('FlowVxlan', (_message.Message,), {
  'DESCRIPTOR' : _FLOWVXLAN,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowVxlan)
  })
_sym_db.RegisterMessage(FlowVxlan)

FlowIpv4 = _reflection.GeneratedProtocolMessageType('FlowIpv4', (_message.Message,), {
  'DESCRIPTOR' : _FLOWIPV4,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowIpv4)
  })
_sym_db.RegisterMessage(FlowIpv4)

FlowIpv4Priority = _reflection.GeneratedProtocolMessageType('FlowIpv4Priority', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FLOWIPV4PRIORITY_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowIpv4Priority.Choice)
    })
  ,
  'DESCRIPTOR' : _FLOWIPV4PRIORITY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowIpv4Priority)
  })
_sym_db.RegisterMessage(FlowIpv4Priority)
_sym_db.RegisterMessage(FlowIpv4Priority.Choice)

FlowIpv4Dscp = _reflection.GeneratedProtocolMessageType('FlowIpv4Dscp', (_message.Message,), {
  'DESCRIPTOR' : _FLOWIPV4DSCP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowIpv4Dscp)
  })
_sym_db.RegisterMessage(FlowIpv4Dscp)

FlowIpv4Tos = _reflection.GeneratedProtocolMessageType('FlowIpv4Tos', (_message.Message,), {
  'DESCRIPTOR' : _FLOWIPV4TOS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowIpv4Tos)
  })
_sym_db.RegisterMessage(FlowIpv4Tos)

FlowIpv6 = _reflection.GeneratedProtocolMessageType('FlowIpv6', (_message.Message,), {
  'DESCRIPTOR' : _FLOWIPV6,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowIpv6)
  })
_sym_db.RegisterMessage(FlowIpv6)

FlowPfcPause = _reflection.GeneratedProtocolMessageType('FlowPfcPause', (_message.Message,), {
  'DESCRIPTOR' : _FLOWPFCPAUSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowPfcPause)
  })
_sym_db.RegisterMessage(FlowPfcPause)

FlowEthernetPause = _reflection.GeneratedProtocolMessageType('FlowEthernetPause', (_message.Message,), {
  'DESCRIPTOR' : _FLOWETHERNETPAUSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowEthernetPause)
  })
_sym_db.RegisterMessage(FlowEthernetPause)

FlowTcp = _reflection.GeneratedProtocolMessageType('FlowTcp', (_message.Message,), {
  'DESCRIPTOR' : _FLOWTCP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowTcp)
  })
_sym_db.RegisterMessage(FlowTcp)

FlowUdp = _reflection.GeneratedProtocolMessageType('FlowUdp', (_message.Message,), {
  'DESCRIPTOR' : _FLOWUDP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowUdp)
  })
_sym_db.RegisterMessage(FlowUdp)

FlowGre = _reflection.GeneratedProtocolMessageType('FlowGre', (_message.Message,), {
  'DESCRIPTOR' : _FLOWGRE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowGre)
  })
_sym_db.RegisterMessage(FlowGre)

FlowGtpv1 = _reflection.GeneratedProtocolMessageType('FlowGtpv1', (_message.Message,), {
  'DESCRIPTOR' : _FLOWGTPV1,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowGtpv1)
  })
_sym_db.RegisterMessage(FlowGtpv1)

FlowGtpExtension = _reflection.GeneratedProtocolMessageType('FlowGtpExtension', (_message.Message,), {
  'DESCRIPTOR' : _FLOWGTPEXTENSION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowGtpExtension)
  })
_sym_db.RegisterMessage(FlowGtpExtension)

FlowGtpv2 = _reflection.GeneratedProtocolMessageType('FlowGtpv2', (_message.Message,), {
  'DESCRIPTOR' : _FLOWGTPV2,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowGtpv2)
  })
_sym_db.RegisterMessage(FlowGtpv2)

FlowArp = _reflection.GeneratedProtocolMessageType('FlowArp', (_message.Message,), {
  'DESCRIPTOR' : _FLOWARP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowArp)
  })
_sym_db.RegisterMessage(FlowArp)

FlowIcmp = _reflection.GeneratedProtocolMessageType('FlowIcmp', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FLOWICMP_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowIcmp.Choice)
    })
  ,
  'DESCRIPTOR' : _FLOWICMP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowIcmp)
  })
_sym_db.RegisterMessage(FlowIcmp)
_sym_db.RegisterMessage(FlowIcmp.Choice)

FlowIcmpEcho = _reflection.GeneratedProtocolMessageType('FlowIcmpEcho', (_message.Message,), {
  'DESCRIPTOR' : _FLOWICMPECHO,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowIcmpEcho)
  })
_sym_db.RegisterMessage(FlowIcmpEcho)

FlowIcmpv6 = _reflection.GeneratedProtocolMessageType('FlowIcmpv6', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FLOWICMPV6_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowIcmpv6.Choice)
    })
  ,
  'DESCRIPTOR' : _FLOWICMPV6,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowIcmpv6)
  })
_sym_db.RegisterMessage(FlowIcmpv6)
_sym_db.RegisterMessage(FlowIcmpv6.Choice)

FlowIcmpv6Echo = _reflection.GeneratedProtocolMessageType('FlowIcmpv6Echo', (_message.Message,), {
  'DESCRIPTOR' : _FLOWICMPV6ECHO,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowIcmpv6Echo)
  })
_sym_db.RegisterMessage(FlowIcmpv6Echo)

FlowPpp = _reflection.GeneratedProtocolMessageType('FlowPpp', (_message.Message,), {
  'DESCRIPTOR' : _FLOWPPP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowPpp)
  })
_sym_db.RegisterMessage(FlowPpp)

FlowIgmpv1 = _reflection.GeneratedProtocolMessageType('FlowIgmpv1', (_message.Message,), {
  'DESCRIPTOR' : _FLOWIGMPV1,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowIgmpv1)
  })
_sym_db.RegisterMessage(FlowIgmpv1)

FlowSize = _reflection.GeneratedProtocolMessageType('FlowSize', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FLOWSIZE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowSize.Choice)
    })
  ,
  'DESCRIPTOR' : _FLOWSIZE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowSize)
  })
_sym_db.RegisterMessage(FlowSize)
_sym_db.RegisterMessage(FlowSize.Choice)

FlowSizeIncrement = _reflection.GeneratedProtocolMessageType('FlowSizeIncrement', (_message.Message,), {
  'DESCRIPTOR' : _FLOWSIZEINCREMENT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowSizeIncrement)
  })
_sym_db.RegisterMessage(FlowSizeIncrement)

FlowSizeRandom = _reflection.GeneratedProtocolMessageType('FlowSizeRandom', (_message.Message,), {
  'DESCRIPTOR' : _FLOWSIZERANDOM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowSizeRandom)
  })
_sym_db.RegisterMessage(FlowSizeRandom)

FlowRate = _reflection.GeneratedProtocolMessageType('FlowRate', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FLOWRATE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowRate.Choice)
    })
  ,
  'DESCRIPTOR' : _FLOWRATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowRate)
  })
_sym_db.RegisterMessage(FlowRate)
_sym_db.RegisterMessage(FlowRate.Choice)

FlowDuration = _reflection.GeneratedProtocolMessageType('FlowDuration', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FLOWDURATION_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowDuration.Choice)
    })
  ,
  'DESCRIPTOR' : _FLOWDURATION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowDuration)
  })
_sym_db.RegisterMessage(FlowDuration)
_sym_db.RegisterMessage(FlowDuration.Choice)

FlowContinuous = _reflection.GeneratedProtocolMessageType('FlowContinuous', (_message.Message,), {
  'DESCRIPTOR' : _FLOWCONTINUOUS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowContinuous)
  })
_sym_db.RegisterMessage(FlowContinuous)

FlowDelay = _reflection.GeneratedProtocolMessageType('FlowDelay', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FLOWDELAY_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowDelay.Choice)
    })
  ,
  'DESCRIPTOR' : _FLOWDELAY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowDelay)
  })
_sym_db.RegisterMessage(FlowDelay)
_sym_db.RegisterMessage(FlowDelay.Choice)

FlowFixedPackets = _reflection.GeneratedProtocolMessageType('FlowFixedPackets', (_message.Message,), {
  'DESCRIPTOR' : _FLOWFIXEDPACKETS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowFixedPackets)
  })
_sym_db.RegisterMessage(FlowFixedPackets)

FlowFixedSeconds = _reflection.GeneratedProtocolMessageType('FlowFixedSeconds', (_message.Message,), {
  'DESCRIPTOR' : _FLOWFIXEDSECONDS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowFixedSeconds)
  })
_sym_db.RegisterMessage(FlowFixedSeconds)

FlowBurst = _reflection.GeneratedProtocolMessageType('FlowBurst', (_message.Message,), {
  'DESCRIPTOR' : _FLOWBURST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowBurst)
  })
_sym_db.RegisterMessage(FlowBurst)

FlowDurationInterBurstGap = _reflection.GeneratedProtocolMessageType('FlowDurationInterBurstGap', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FLOWDURATIONINTERBURSTGAP_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowDurationInterBurstGap.Choice)
    })
  ,
  'DESCRIPTOR' : _FLOWDURATIONINTERBURSTGAP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowDurationInterBurstGap)
  })
_sym_db.RegisterMessage(FlowDurationInterBurstGap)
_sym_db.RegisterMessage(FlowDurationInterBurstGap.Choice)

FlowMetrics = _reflection.GeneratedProtocolMessageType('FlowMetrics', (_message.Message,), {
  'DESCRIPTOR' : _FLOWMETRICS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowMetrics)
  })
_sym_db.RegisterMessage(FlowMetrics)

FlowLatencyMetrics = _reflection.GeneratedProtocolMessageType('FlowLatencyMetrics', (_message.Message,), {

  'Mode' : _reflection.GeneratedProtocolMessageType('Mode', (_message.Message,), {
    'DESCRIPTOR' : _FLOWLATENCYMETRICS_MODE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowLatencyMetrics.Mode)
    })
  ,
  'DESCRIPTOR' : _FLOWLATENCYMETRICS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowLatencyMetrics)
  })
_sym_db.RegisterMessage(FlowLatencyMetrics)
_sym_db.RegisterMessage(FlowLatencyMetrics.Mode)

Event = _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), {
  'DESCRIPTOR' : _EVENT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Event)
  })
_sym_db.RegisterMessage(Event)

EventRxRateThreshold = _reflection.GeneratedProtocolMessageType('EventRxRateThreshold', (_message.Message,), {
  'DESCRIPTOR' : _EVENTRXRATETHRESHOLD,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.EventRxRateThreshold)
  })
_sym_db.RegisterMessage(EventRxRateThreshold)

EventLink = _reflection.GeneratedProtocolMessageType('EventLink', (_message.Message,), {
  'DESCRIPTOR' : _EVENTLINK,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.EventLink)
  })
_sym_db.RegisterMessage(EventLink)

EventRouteAdvertiseWithdraw = _reflection.GeneratedProtocolMessageType('EventRouteAdvertiseWithdraw', (_message.Message,), {
  'DESCRIPTOR' : _EVENTROUTEADVERTISEWITHDRAW,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.EventRouteAdvertiseWithdraw)
  })
_sym_db.RegisterMessage(EventRouteAdvertiseWithdraw)

EventRequest = _reflection.GeneratedProtocolMessageType('EventRequest', (_message.Message,), {

  'Type' : _reflection.GeneratedProtocolMessageType('Type', (_message.Message,), {
    'DESCRIPTOR' : _EVENTREQUEST_TYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.EventRequest.Type)
    })
  ,
  'DESCRIPTOR' : _EVENTREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.EventRequest)
  })
_sym_db.RegisterMessage(EventRequest)
_sym_db.RegisterMessage(EventRequest.Type)

EventSubscription = _reflection.GeneratedProtocolMessageType('EventSubscription', (_message.Message,), {
  'DESCRIPTOR' : _EVENTSUBSCRIPTION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.EventSubscription)
  })
_sym_db.RegisterMessage(EventSubscription)

ResponseError = _reflection.GeneratedProtocolMessageType('ResponseError', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEERROR,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.ResponseError)
  })
_sym_db.RegisterMessage(ResponseError)

ResponseWarning = _reflection.GeneratedProtocolMessageType('ResponseWarning', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEWARNING,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.ResponseWarning)
  })
_sym_db.RegisterMessage(ResponseWarning)

LinkState = _reflection.GeneratedProtocolMessageType('LinkState', (_message.Message,), {

  'State' : _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {
    'DESCRIPTOR' : _LINKSTATE_STATE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.LinkState.State)
    })
  ,
  'DESCRIPTOR' : _LINKSTATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LinkState)
  })
_sym_db.RegisterMessage(LinkState)
_sym_db.RegisterMessage(LinkState.State)

TransmitState = _reflection.GeneratedProtocolMessageType('TransmitState', (_message.Message,), {

  'State' : _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {
    'DESCRIPTOR' : _TRANSMITSTATE_STATE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.TransmitState.State)
    })
  ,
  'DESCRIPTOR' : _TRANSMITSTATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.TransmitState)
  })
_sym_db.RegisterMessage(TransmitState)
_sym_db.RegisterMessage(TransmitState.State)

CaptureState = _reflection.GeneratedProtocolMessageType('CaptureState', (_message.Message,), {

  'State' : _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {
    'DESCRIPTOR' : _CAPTURESTATE_STATE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.CaptureState.State)
    })
  ,
  'DESCRIPTOR' : _CAPTURESTATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.CaptureState)
  })
_sym_db.RegisterMessage(CaptureState)
_sym_db.RegisterMessage(CaptureState.State)

FlowsUpdate = _reflection.GeneratedProtocolMessageType('FlowsUpdate', (_message.Message,), {

  'PropertyNames' : _reflection.GeneratedProtocolMessageType('PropertyNames', (_message.Message,), {
    'DESCRIPTOR' : _FLOWSUPDATE_PROPERTYNAMES,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowsUpdate.PropertyNames)
    })
  ,
  'DESCRIPTOR' : _FLOWSUPDATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowsUpdate)
  })
_sym_db.RegisterMessage(FlowsUpdate)
_sym_db.RegisterMessage(FlowsUpdate.PropertyNames)

RouteState = _reflection.GeneratedProtocolMessageType('RouteState', (_message.Message,), {

  'State' : _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {
    'DESCRIPTOR' : _ROUTESTATE_STATE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.RouteState.State)
    })
  ,
  'DESCRIPTOR' : _ROUTESTATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.RouteState)
  })
_sym_db.RegisterMessage(RouteState)
_sym_db.RegisterMessage(RouteState.State)

PingRequest = _reflection.GeneratedProtocolMessageType('PingRequest', (_message.Message,), {
  'DESCRIPTOR' : _PINGREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PingRequest)
  })
_sym_db.RegisterMessage(PingRequest)

ProtocolState = _reflection.GeneratedProtocolMessageType('ProtocolState', (_message.Message,), {

  'State' : _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {
    'DESCRIPTOR' : _PROTOCOLSTATE_STATE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.ProtocolState.State)
    })
  ,
  'DESCRIPTOR' : _PROTOCOLSTATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.ProtocolState)
  })
_sym_db.RegisterMessage(ProtocolState)
_sym_db.RegisterMessage(ProtocolState.State)

Ping = _reflection.GeneratedProtocolMessageType('Ping', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PING_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.Ping.Choice)
    })
  ,
  'DESCRIPTOR' : _PING,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Ping)
  })
_sym_db.RegisterMessage(Ping)
_sym_db.RegisterMessage(Ping.Choice)

PingIpv4 = _reflection.GeneratedProtocolMessageType('PingIpv4', (_message.Message,), {
  'DESCRIPTOR' : _PINGIPV4,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PingIpv4)
  })
_sym_db.RegisterMessage(PingIpv4)

PingIpv6 = _reflection.GeneratedProtocolMessageType('PingIpv6', (_message.Message,), {
  'DESCRIPTOR' : _PINGIPV6,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PingIpv6)
  })
_sym_db.RegisterMessage(PingIpv6)

PingResponse = _reflection.GeneratedProtocolMessageType('PingResponse', (_message.Message,), {
  'DESCRIPTOR' : _PINGRESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PingResponse)
  })
_sym_db.RegisterMessage(PingResponse)

Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {

  'Result' : _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), {
    'DESCRIPTOR' : _RESPONSE_RESULT,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.Response.Result)
    })
  ,
  'DESCRIPTOR' : _RESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Response)
  })
_sym_db.RegisterMessage(Response)
_sym_db.RegisterMessage(Response.Result)

MetricsRequest = _reflection.GeneratedProtocolMessageType('MetricsRequest', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _METRICSREQUEST_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.MetricsRequest.Choice)
    })
  ,
  'DESCRIPTOR' : _METRICSREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.MetricsRequest)
  })
_sym_db.RegisterMessage(MetricsRequest)
_sym_db.RegisterMessage(MetricsRequest.Choice)

MetricsResponse = _reflection.GeneratedProtocolMessageType('MetricsResponse', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _METRICSRESPONSE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.MetricsResponse.Choice)
    })
  ,
  'DESCRIPTOR' : _METRICSRESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.MetricsResponse)
  })
_sym_db.RegisterMessage(MetricsResponse)
_sym_db.RegisterMessage(MetricsResponse.Choice)

PortMetricsRequest = _reflection.GeneratedProtocolMessageType('PortMetricsRequest', (_message.Message,), {

  'ColumnNames' : _reflection.GeneratedProtocolMessageType('ColumnNames', (_message.Message,), {
    'DESCRIPTOR' : _PORTMETRICSREQUEST_COLUMNNAMES,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PortMetricsRequest.ColumnNames)
    })
  ,
  'DESCRIPTOR' : _PORTMETRICSREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PortMetricsRequest)
  })
_sym_db.RegisterMessage(PortMetricsRequest)
_sym_db.RegisterMessage(PortMetricsRequest.ColumnNames)

PortMetric = _reflection.GeneratedProtocolMessageType('PortMetric', (_message.Message,), {

  'Link' : _reflection.GeneratedProtocolMessageType('Link', (_message.Message,), {
    'DESCRIPTOR' : _PORTMETRIC_LINK,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PortMetric.Link)
    })
  ,

  'Capture' : _reflection.GeneratedProtocolMessageType('Capture', (_message.Message,), {
    'DESCRIPTOR' : _PORTMETRIC_CAPTURE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PortMetric.Capture)
    })
  ,
  'DESCRIPTOR' : _PORTMETRIC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PortMetric)
  })
_sym_db.RegisterMessage(PortMetric)
_sym_db.RegisterMessage(PortMetric.Link)
_sym_db.RegisterMessage(PortMetric.Capture)

FlowMetricsRequest = _reflection.GeneratedProtocolMessageType('FlowMetricsRequest', (_message.Message,), {

  'MetricNames' : _reflection.GeneratedProtocolMessageType('MetricNames', (_message.Message,), {
    'DESCRIPTOR' : _FLOWMETRICSREQUEST_METRICNAMES,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowMetricsRequest.MetricNames)
    })
  ,
  'DESCRIPTOR' : _FLOWMETRICSREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowMetricsRequest)
  })
_sym_db.RegisterMessage(FlowMetricsRequest)
_sym_db.RegisterMessage(FlowMetricsRequest.MetricNames)

FlowMetricGroupRequest = _reflection.GeneratedProtocolMessageType('FlowMetricGroupRequest', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FLOWMETRICGROUPREQUEST_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowMetricGroupRequest.Choice)
    })
  ,
  'DESCRIPTOR' : _FLOWMETRICGROUPREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowMetricGroupRequest)
  })
_sym_db.RegisterMessage(FlowMetricGroupRequest)
_sym_db.RegisterMessage(FlowMetricGroupRequest.Choice)

FlowMetric = _reflection.GeneratedProtocolMessageType('FlowMetric', (_message.Message,), {

  'Transmit' : _reflection.GeneratedProtocolMessageType('Transmit', (_message.Message,), {
    'DESCRIPTOR' : _FLOWMETRIC_TRANSMIT,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowMetric.Transmit)
    })
  ,
  'DESCRIPTOR' : _FLOWMETRIC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowMetric)
  })
_sym_db.RegisterMessage(FlowMetric)
_sym_db.RegisterMessage(FlowMetric.Transmit)

FlowMetricGroup = _reflection.GeneratedProtocolMessageType('FlowMetricGroup', (_message.Message,), {
  'DESCRIPTOR' : _FLOWMETRICGROUP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowMetricGroup)
  })
_sym_db.RegisterMessage(FlowMetricGroup)

MetricTimestamp = _reflection.GeneratedProtocolMessageType('MetricTimestamp', (_message.Message,), {
  'DESCRIPTOR' : _METRICTIMESTAMP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.MetricTimestamp)
  })
_sym_db.RegisterMessage(MetricTimestamp)

MetricLatency = _reflection.GeneratedProtocolMessageType('MetricLatency', (_message.Message,), {
  'DESCRIPTOR' : _METRICLATENCY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.MetricLatency)
  })
_sym_db.RegisterMessage(MetricLatency)

Bgpv4MetricsRequest = _reflection.GeneratedProtocolMessageType('Bgpv4MetricsRequest', (_message.Message,), {

  'ColumnNames' : _reflection.GeneratedProtocolMessageType('ColumnNames', (_message.Message,), {
    'DESCRIPTOR' : _BGPV4METRICSREQUEST_COLUMNNAMES,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.Bgpv4MetricsRequest.ColumnNames)
    })
  ,
  'DESCRIPTOR' : _BGPV4METRICSREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Bgpv4MetricsRequest)
  })
_sym_db.RegisterMessage(Bgpv4MetricsRequest)
_sym_db.RegisterMessage(Bgpv4MetricsRequest.ColumnNames)

Bgpv4Metric = _reflection.GeneratedProtocolMessageType('Bgpv4Metric', (_message.Message,), {

  'SessionState' : _reflection.GeneratedProtocolMessageType('SessionState', (_message.Message,), {
    'DESCRIPTOR' : _BGPV4METRIC_SESSIONSTATE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.Bgpv4Metric.SessionState)
    })
  ,
  'DESCRIPTOR' : _BGPV4METRIC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Bgpv4Metric)
  })
_sym_db.RegisterMessage(Bgpv4Metric)
_sym_db.RegisterMessage(Bgpv4Metric.SessionState)

Bgpv6MetricsRequest = _reflection.GeneratedProtocolMessageType('Bgpv6MetricsRequest', (_message.Message,), {

  'ColumnNames' : _reflection.GeneratedProtocolMessageType('ColumnNames', (_message.Message,), {
    'DESCRIPTOR' : _BGPV6METRICSREQUEST_COLUMNNAMES,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.Bgpv6MetricsRequest.ColumnNames)
    })
  ,
  'DESCRIPTOR' : _BGPV6METRICSREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Bgpv6MetricsRequest)
  })
_sym_db.RegisterMessage(Bgpv6MetricsRequest)
_sym_db.RegisterMessage(Bgpv6MetricsRequest.ColumnNames)

Bgpv6Metric = _reflection.GeneratedProtocolMessageType('Bgpv6Metric', (_message.Message,), {

  'SessionState' : _reflection.GeneratedProtocolMessageType('SessionState', (_message.Message,), {
    'DESCRIPTOR' : _BGPV6METRIC_SESSIONSTATE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.Bgpv6Metric.SessionState)
    })
  ,
  'DESCRIPTOR' : _BGPV6METRIC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Bgpv6Metric)
  })
_sym_db.RegisterMessage(Bgpv6Metric)
_sym_db.RegisterMessage(Bgpv6Metric.SessionState)

IsisMetricsRequest = _reflection.GeneratedProtocolMessageType('IsisMetricsRequest', (_message.Message,), {

  'ColumnNames' : _reflection.GeneratedProtocolMessageType('ColumnNames', (_message.Message,), {
    'DESCRIPTOR' : _ISISMETRICSREQUEST_COLUMNNAMES,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.IsisMetricsRequest.ColumnNames)
    })
  ,
  'DESCRIPTOR' : _ISISMETRICSREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisMetricsRequest)
  })
_sym_db.RegisterMessage(IsisMetricsRequest)
_sym_db.RegisterMessage(IsisMetricsRequest.ColumnNames)

IsisMetric = _reflection.GeneratedProtocolMessageType('IsisMetric', (_message.Message,), {
  'DESCRIPTOR' : _ISISMETRIC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisMetric)
  })
_sym_db.RegisterMessage(IsisMetric)

StatesRequest = _reflection.GeneratedProtocolMessageType('StatesRequest', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _STATESREQUEST_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.StatesRequest.Choice)
    })
  ,
  'DESCRIPTOR' : _STATESREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.StatesRequest)
  })
_sym_db.RegisterMessage(StatesRequest)
_sym_db.RegisterMessage(StatesRequest.Choice)

StatesResponse = _reflection.GeneratedProtocolMessageType('StatesResponse', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _STATESRESPONSE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.StatesResponse.Choice)
    })
  ,
  'DESCRIPTOR' : _STATESRESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.StatesResponse)
  })
_sym_db.RegisterMessage(StatesResponse)
_sym_db.RegisterMessage(StatesResponse.Choice)

Neighborsv4StatesRequest = _reflection.GeneratedProtocolMessageType('Neighborsv4StatesRequest', (_message.Message,), {
  'DESCRIPTOR' : _NEIGHBORSV4STATESREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Neighborsv4StatesRequest)
  })
_sym_db.RegisterMessage(Neighborsv4StatesRequest)

Neighborsv4State = _reflection.GeneratedProtocolMessageType('Neighborsv4State', (_message.Message,), {
  'DESCRIPTOR' : _NEIGHBORSV4STATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Neighborsv4State)
  })
_sym_db.RegisterMessage(Neighborsv4State)

Neighborsv6StatesRequest = _reflection.GeneratedProtocolMessageType('Neighborsv6StatesRequest', (_message.Message,), {
  'DESCRIPTOR' : _NEIGHBORSV6STATESREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Neighborsv6StatesRequest)
  })
_sym_db.RegisterMessage(Neighborsv6StatesRequest)

Neighborsv6State = _reflection.GeneratedProtocolMessageType('Neighborsv6State', (_message.Message,), {
  'DESCRIPTOR' : _NEIGHBORSV6STATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Neighborsv6State)
  })
_sym_db.RegisterMessage(Neighborsv6State)

CaptureRequest = _reflection.GeneratedProtocolMessageType('CaptureRequest', (_message.Message,), {
  'DESCRIPTOR' : _CAPTUREREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.CaptureRequest)
  })
_sym_db.RegisterMessage(CaptureRequest)

PatternFlowEthernetDstCounter = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetDstCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWETHERNETDSTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetDstCounter)
  })
_sym_db.RegisterMessage(PatternFlowEthernetDstCounter)

PatternFlowEthernetDst = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetDst', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWETHERNETDST_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetDst.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWETHERNETDST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetDst)
  })
_sym_db.RegisterMessage(PatternFlowEthernetDst)
_sym_db.RegisterMessage(PatternFlowEthernetDst.Choice)

PatternFlowEthernetSrcCounter = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetSrcCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWETHERNETSRCCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetSrcCounter)
  })
_sym_db.RegisterMessage(PatternFlowEthernetSrcCounter)

PatternFlowEthernetSrc = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetSrc', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWETHERNETSRC_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetSrc.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWETHERNETSRC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetSrc)
  })
_sym_db.RegisterMessage(PatternFlowEthernetSrc)
_sym_db.RegisterMessage(PatternFlowEthernetSrc.Choice)

PatternFlowEthernetEtherTypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetEtherTypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWETHERNETETHERTYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetEtherTypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowEthernetEtherTypeCounter)

PatternFlowEthernetEtherType = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetEtherType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWETHERNETETHERTYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetEtherType.Choice)
    })
  ,

  'Auto' : _reflection.GeneratedProtocolMessageType('Auto', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWETHERNETETHERTYPE_AUTO,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetEtherType.Auto)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWETHERNETETHERTYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetEtherType)
  })
_sym_db.RegisterMessage(PatternFlowEthernetEtherType)
_sym_db.RegisterMessage(PatternFlowEthernetEtherType.Choice)
_sym_db.RegisterMessage(PatternFlowEthernetEtherType.Auto)

PatternFlowEthernetPfcQueueCounter = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPfcQueueCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPFCQUEUECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPfcQueueCounter)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPfcQueueCounter)

PatternFlowEthernetPfcQueue = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPfcQueue', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWETHERNETPFCQUEUE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPfcQueue.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPFCQUEUE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPfcQueue)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPfcQueue)
_sym_db.RegisterMessage(PatternFlowEthernetPfcQueue.Choice)

PatternFlowVlanPriorityCounter = _reflection.GeneratedProtocolMessageType('PatternFlowVlanPriorityCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWVLANPRIORITYCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanPriorityCounter)
  })
_sym_db.RegisterMessage(PatternFlowVlanPriorityCounter)

PatternFlowVlanPriority = _reflection.GeneratedProtocolMessageType('PatternFlowVlanPriority', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWVLANPRIORITY_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanPriority.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWVLANPRIORITY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanPriority)
  })
_sym_db.RegisterMessage(PatternFlowVlanPriority)
_sym_db.RegisterMessage(PatternFlowVlanPriority.Choice)

PatternFlowVlanCfiCounter = _reflection.GeneratedProtocolMessageType('PatternFlowVlanCfiCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWVLANCFICOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanCfiCounter)
  })
_sym_db.RegisterMessage(PatternFlowVlanCfiCounter)

PatternFlowVlanCfi = _reflection.GeneratedProtocolMessageType('PatternFlowVlanCfi', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWVLANCFI_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanCfi.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWVLANCFI,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanCfi)
  })
_sym_db.RegisterMessage(PatternFlowVlanCfi)
_sym_db.RegisterMessage(PatternFlowVlanCfi.Choice)

PatternFlowVlanIdCounter = _reflection.GeneratedProtocolMessageType('PatternFlowVlanIdCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWVLANIDCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanIdCounter)
  })
_sym_db.RegisterMessage(PatternFlowVlanIdCounter)

PatternFlowVlanId = _reflection.GeneratedProtocolMessageType('PatternFlowVlanId', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWVLANID_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanId.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWVLANID,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanId)
  })
_sym_db.RegisterMessage(PatternFlowVlanId)
_sym_db.RegisterMessage(PatternFlowVlanId.Choice)

PatternFlowVlanTpidCounter = _reflection.GeneratedProtocolMessageType('PatternFlowVlanTpidCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWVLANTPIDCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanTpidCounter)
  })
_sym_db.RegisterMessage(PatternFlowVlanTpidCounter)

PatternFlowVlanTpid = _reflection.GeneratedProtocolMessageType('PatternFlowVlanTpid', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWVLANTPID_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanTpid.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWVLANTPID,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanTpid)
  })
_sym_db.RegisterMessage(PatternFlowVlanTpid)
_sym_db.RegisterMessage(PatternFlowVlanTpid.Choice)

PatternFlowVxlanFlagsCounter = _reflection.GeneratedProtocolMessageType('PatternFlowVxlanFlagsCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWVXLANFLAGSCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanFlagsCounter)
  })
_sym_db.RegisterMessage(PatternFlowVxlanFlagsCounter)

PatternFlowVxlanFlags = _reflection.GeneratedProtocolMessageType('PatternFlowVxlanFlags', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWVXLANFLAGS_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanFlags.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWVXLANFLAGS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanFlags)
  })
_sym_db.RegisterMessage(PatternFlowVxlanFlags)
_sym_db.RegisterMessage(PatternFlowVxlanFlags.Choice)

PatternFlowVxlanReserved0Counter = _reflection.GeneratedProtocolMessageType('PatternFlowVxlanReserved0Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWVXLANRESERVED0COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanReserved0Counter)
  })
_sym_db.RegisterMessage(PatternFlowVxlanReserved0Counter)

PatternFlowVxlanReserved0 = _reflection.GeneratedProtocolMessageType('PatternFlowVxlanReserved0', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWVXLANRESERVED0_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanReserved0.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWVXLANRESERVED0,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanReserved0)
  })
_sym_db.RegisterMessage(PatternFlowVxlanReserved0)
_sym_db.RegisterMessage(PatternFlowVxlanReserved0.Choice)

PatternFlowVxlanVniCounter = _reflection.GeneratedProtocolMessageType('PatternFlowVxlanVniCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWVXLANVNICOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanVniCounter)
  })
_sym_db.RegisterMessage(PatternFlowVxlanVniCounter)

PatternFlowVxlanVni = _reflection.GeneratedProtocolMessageType('PatternFlowVxlanVni', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWVXLANVNI_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanVni.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWVXLANVNI,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanVni)
  })
_sym_db.RegisterMessage(PatternFlowVxlanVni)
_sym_db.RegisterMessage(PatternFlowVxlanVni.Choice)

PatternFlowVxlanReserved1Counter = _reflection.GeneratedProtocolMessageType('PatternFlowVxlanReserved1Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWVXLANRESERVED1COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanReserved1Counter)
  })
_sym_db.RegisterMessage(PatternFlowVxlanReserved1Counter)

PatternFlowVxlanReserved1 = _reflection.GeneratedProtocolMessageType('PatternFlowVxlanReserved1', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWVXLANRESERVED1_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanReserved1.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWVXLANRESERVED1,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanReserved1)
  })
_sym_db.RegisterMessage(PatternFlowVxlanReserved1)
_sym_db.RegisterMessage(PatternFlowVxlanReserved1.Choice)

PatternFlowIpv4VersionCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4VersionCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4VERSIONCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4VersionCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4VersionCounter)

PatternFlowIpv4Version = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4Version', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4VERSION_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Version.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4VERSION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Version)
  })
_sym_db.RegisterMessage(PatternFlowIpv4Version)
_sym_db.RegisterMessage(PatternFlowIpv4Version.Choice)

PatternFlowIpv4HeaderLengthCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4HeaderLengthCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4HEADERLENGTHCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4HeaderLengthCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4HeaderLengthCounter)

PatternFlowIpv4HeaderLength = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4HeaderLength', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4HEADERLENGTH_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4HeaderLength.Choice)
    })
  ,

  'Auto' : _reflection.GeneratedProtocolMessageType('Auto', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4HEADERLENGTH_AUTO,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4HeaderLength.Auto)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4HEADERLENGTH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4HeaderLength)
  })
_sym_db.RegisterMessage(PatternFlowIpv4HeaderLength)
_sym_db.RegisterMessage(PatternFlowIpv4HeaderLength.Choice)
_sym_db.RegisterMessage(PatternFlowIpv4HeaderLength.Auto)

PatternFlowIpv4TotalLengthCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TotalLengthCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOTALLENGTHCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TotalLengthCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TotalLengthCounter)

PatternFlowIpv4TotalLength = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TotalLength', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4TOTALLENGTH_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TotalLength.Choice)
    })
  ,

  'Auto' : _reflection.GeneratedProtocolMessageType('Auto', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4TOTALLENGTH_AUTO,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TotalLength.Auto)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOTALLENGTH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TotalLength)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TotalLength)
_sym_db.RegisterMessage(PatternFlowIpv4TotalLength.Choice)
_sym_db.RegisterMessage(PatternFlowIpv4TotalLength.Auto)

PatternFlowIpv4IdentificationCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4IdentificationCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4IDENTIFICATIONCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4IdentificationCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4IdentificationCounter)

PatternFlowIpv4Identification = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4Identification', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4IDENTIFICATION_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Identification.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4IDENTIFICATION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Identification)
  })
_sym_db.RegisterMessage(PatternFlowIpv4Identification)
_sym_db.RegisterMessage(PatternFlowIpv4Identification.Choice)

PatternFlowIpv4ReservedCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4ReservedCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4RESERVEDCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4ReservedCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4ReservedCounter)

PatternFlowIpv4Reserved = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4Reserved', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4RESERVED_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Reserved.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4RESERVED,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Reserved)
  })
_sym_db.RegisterMessage(PatternFlowIpv4Reserved)
_sym_db.RegisterMessage(PatternFlowIpv4Reserved.Choice)

PatternFlowIpv4DontFragmentCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4DontFragmentCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4DONTFRAGMENTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4DontFragmentCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4DontFragmentCounter)

PatternFlowIpv4DontFragment = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4DontFragment', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4DONTFRAGMENT_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4DontFragment.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4DONTFRAGMENT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4DontFragment)
  })
_sym_db.RegisterMessage(PatternFlowIpv4DontFragment)
_sym_db.RegisterMessage(PatternFlowIpv4DontFragment.Choice)

PatternFlowIpv4MoreFragmentsCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4MoreFragmentsCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4MOREFRAGMENTSCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4MoreFragmentsCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4MoreFragmentsCounter)

PatternFlowIpv4MoreFragments = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4MoreFragments', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4MOREFRAGMENTS_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4MoreFragments.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4MOREFRAGMENTS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4MoreFragments)
  })
_sym_db.RegisterMessage(PatternFlowIpv4MoreFragments)
_sym_db.RegisterMessage(PatternFlowIpv4MoreFragments.Choice)

PatternFlowIpv4FragmentOffsetCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4FragmentOffsetCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4FRAGMENTOFFSETCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4FragmentOffsetCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4FragmentOffsetCounter)

PatternFlowIpv4FragmentOffset = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4FragmentOffset', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4FRAGMENTOFFSET_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4FragmentOffset.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4FRAGMENTOFFSET,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4FragmentOffset)
  })
_sym_db.RegisterMessage(PatternFlowIpv4FragmentOffset)
_sym_db.RegisterMessage(PatternFlowIpv4FragmentOffset.Choice)

PatternFlowIpv4TimeToLiveCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TimeToLiveCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4TIMETOLIVECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TimeToLiveCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TimeToLiveCounter)

PatternFlowIpv4TimeToLive = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TimeToLive', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4TIMETOLIVE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TimeToLive.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4TIMETOLIVE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TimeToLive)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TimeToLive)
_sym_db.RegisterMessage(PatternFlowIpv4TimeToLive.Choice)

PatternFlowIpv4ProtocolCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4ProtocolCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4PROTOCOLCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4ProtocolCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4ProtocolCounter)

PatternFlowIpv4Protocol = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4Protocol', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4PROTOCOL_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Protocol.Choice)
    })
  ,

  'Auto' : _reflection.GeneratedProtocolMessageType('Auto', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4PROTOCOL_AUTO,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Protocol.Auto)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4PROTOCOL,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Protocol)
  })
_sym_db.RegisterMessage(PatternFlowIpv4Protocol)
_sym_db.RegisterMessage(PatternFlowIpv4Protocol.Choice)
_sym_db.RegisterMessage(PatternFlowIpv4Protocol.Auto)

PatternFlowIpv4HeaderChecksum = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4HeaderChecksum', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4HEADERCHECKSUM_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4HeaderChecksum.Choice)
    })
  ,

  'Generated' : _reflection.GeneratedProtocolMessageType('Generated', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4HEADERCHECKSUM_GENERATED,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4HeaderChecksum.Generated)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4HEADERCHECKSUM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4HeaderChecksum)
  })
_sym_db.RegisterMessage(PatternFlowIpv4HeaderChecksum)
_sym_db.RegisterMessage(PatternFlowIpv4HeaderChecksum.Choice)
_sym_db.RegisterMessage(PatternFlowIpv4HeaderChecksum.Generated)

PatternFlowIpv4SrcCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4SrcCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4SRCCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4SrcCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4SrcCounter)

PatternFlowIpv4Src = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4Src', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4SRC_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Src.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4SRC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Src)
  })
_sym_db.RegisterMessage(PatternFlowIpv4Src)
_sym_db.RegisterMessage(PatternFlowIpv4Src.Choice)

PatternFlowIpv4DstCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4DstCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4DSTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4DstCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4DstCounter)

PatternFlowIpv4Dst = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4Dst', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4DST_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Dst.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4DST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Dst)
  })
_sym_db.RegisterMessage(PatternFlowIpv4Dst)
_sym_db.RegisterMessage(PatternFlowIpv4Dst.Choice)

PatternFlowIpv4PriorityRawCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4PriorityRawCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4PRIORITYRAWCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4PriorityRawCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4PriorityRawCounter)

PatternFlowIpv4PriorityRaw = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4PriorityRaw', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4PRIORITYRAW_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4PriorityRaw.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4PRIORITYRAW,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4PriorityRaw)
  })
_sym_db.RegisterMessage(PatternFlowIpv4PriorityRaw)
_sym_db.RegisterMessage(PatternFlowIpv4PriorityRaw.Choice)

PatternFlowIpv4DscpPhbCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4DscpPhbCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4DSCPPHBCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4DscpPhbCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4DscpPhbCounter)

PatternFlowIpv4DscpPhb = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4DscpPhb', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4DSCPPHB_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4DscpPhb.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4DSCPPHB,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4DscpPhb)
  })
_sym_db.RegisterMessage(PatternFlowIpv4DscpPhb)
_sym_db.RegisterMessage(PatternFlowIpv4DscpPhb.Choice)

PatternFlowIpv4DscpEcnCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4DscpEcnCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4DSCPECNCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4DscpEcnCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4DscpEcnCounter)

PatternFlowIpv4DscpEcn = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4DscpEcn', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4DSCPECN_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4DscpEcn.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4DSCPECN,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4DscpEcn)
  })
_sym_db.RegisterMessage(PatternFlowIpv4DscpEcn)
_sym_db.RegisterMessage(PatternFlowIpv4DscpEcn.Choice)

PatternFlowIpv4TosPrecedenceCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosPrecedenceCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSPRECEDENCECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosPrecedenceCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosPrecedenceCounter)

PatternFlowIpv4TosPrecedence = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosPrecedence', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4TOSPRECEDENCE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosPrecedence.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSPRECEDENCE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosPrecedence)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosPrecedence)
_sym_db.RegisterMessage(PatternFlowIpv4TosPrecedence.Choice)

PatternFlowIpv4TosDelayCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosDelayCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSDELAYCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosDelayCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosDelayCounter)

PatternFlowIpv4TosDelay = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosDelay', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4TOSDELAY_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosDelay.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSDELAY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosDelay)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosDelay)
_sym_db.RegisterMessage(PatternFlowIpv4TosDelay.Choice)

PatternFlowIpv4TosThroughputCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosThroughputCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSTHROUGHPUTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosThroughputCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosThroughputCounter)

PatternFlowIpv4TosThroughput = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosThroughput', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4TOSTHROUGHPUT_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosThroughput.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSTHROUGHPUT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosThroughput)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosThroughput)
_sym_db.RegisterMessage(PatternFlowIpv4TosThroughput.Choice)

PatternFlowIpv4TosReliabilityCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosReliabilityCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSRELIABILITYCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosReliabilityCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosReliabilityCounter)

PatternFlowIpv4TosReliability = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosReliability', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4TOSRELIABILITY_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosReliability.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSRELIABILITY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosReliability)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosReliability)
_sym_db.RegisterMessage(PatternFlowIpv4TosReliability.Choice)

PatternFlowIpv4TosMonetaryCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosMonetaryCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSMONETARYCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosMonetaryCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosMonetaryCounter)

PatternFlowIpv4TosMonetary = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosMonetary', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4TOSMONETARY_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosMonetary.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSMONETARY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosMonetary)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosMonetary)
_sym_db.RegisterMessage(PatternFlowIpv4TosMonetary.Choice)

PatternFlowIpv4TosUnusedCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosUnusedCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSUNUSEDCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosUnusedCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosUnusedCounter)

PatternFlowIpv4TosUnused = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosUnused', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4TOSUNUSED_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosUnused.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSUNUSED,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosUnused)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosUnused)
_sym_db.RegisterMessage(PatternFlowIpv4TosUnused.Choice)

PatternFlowIpv6VersionCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6VersionCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV6VERSIONCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6VersionCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv6VersionCounter)

PatternFlowIpv6Version = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6Version', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV6VERSION_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6Version.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV6VERSION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6Version)
  })
_sym_db.RegisterMessage(PatternFlowIpv6Version)
_sym_db.RegisterMessage(PatternFlowIpv6Version.Choice)

PatternFlowIpv6TrafficClassCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6TrafficClassCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV6TRAFFICCLASSCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6TrafficClassCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv6TrafficClassCounter)

PatternFlowIpv6TrafficClass = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6TrafficClass', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV6TRAFFICCLASS_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6TrafficClass.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV6TRAFFICCLASS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6TrafficClass)
  })
_sym_db.RegisterMessage(PatternFlowIpv6TrafficClass)
_sym_db.RegisterMessage(PatternFlowIpv6TrafficClass.Choice)

PatternFlowIpv6FlowLabelCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6FlowLabelCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV6FLOWLABELCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6FlowLabelCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv6FlowLabelCounter)

PatternFlowIpv6FlowLabel = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6FlowLabel', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV6FLOWLABEL_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6FlowLabel.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV6FLOWLABEL,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6FlowLabel)
  })
_sym_db.RegisterMessage(PatternFlowIpv6FlowLabel)
_sym_db.RegisterMessage(PatternFlowIpv6FlowLabel.Choice)

PatternFlowIpv6PayloadLengthCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6PayloadLengthCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV6PAYLOADLENGTHCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6PayloadLengthCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv6PayloadLengthCounter)

PatternFlowIpv6PayloadLength = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6PayloadLength', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV6PAYLOADLENGTH_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6PayloadLength.Choice)
    })
  ,

  'Auto' : _reflection.GeneratedProtocolMessageType('Auto', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV6PAYLOADLENGTH_AUTO,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6PayloadLength.Auto)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV6PAYLOADLENGTH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6PayloadLength)
  })
_sym_db.RegisterMessage(PatternFlowIpv6PayloadLength)
_sym_db.RegisterMessage(PatternFlowIpv6PayloadLength.Choice)
_sym_db.RegisterMessage(PatternFlowIpv6PayloadLength.Auto)

PatternFlowIpv6NextHeaderCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6NextHeaderCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV6NEXTHEADERCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6NextHeaderCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv6NextHeaderCounter)

PatternFlowIpv6NextHeader = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6NextHeader', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV6NEXTHEADER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6NextHeader.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV6NEXTHEADER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6NextHeader)
  })
_sym_db.RegisterMessage(PatternFlowIpv6NextHeader)
_sym_db.RegisterMessage(PatternFlowIpv6NextHeader.Choice)

PatternFlowIpv6HopLimitCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6HopLimitCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV6HOPLIMITCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6HopLimitCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv6HopLimitCounter)

PatternFlowIpv6HopLimit = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6HopLimit', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV6HOPLIMIT_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6HopLimit.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV6HOPLIMIT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6HopLimit)
  })
_sym_db.RegisterMessage(PatternFlowIpv6HopLimit)
_sym_db.RegisterMessage(PatternFlowIpv6HopLimit.Choice)

PatternFlowIpv6SrcCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6SrcCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV6SRCCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6SrcCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv6SrcCounter)

PatternFlowIpv6Src = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6Src', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV6SRC_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6Src.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV6SRC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6Src)
  })
_sym_db.RegisterMessage(PatternFlowIpv6Src)
_sym_db.RegisterMessage(PatternFlowIpv6Src.Choice)

PatternFlowIpv6DstCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6DstCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV6DSTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6DstCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv6DstCounter)

PatternFlowIpv6Dst = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6Dst', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV6DST_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6Dst.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV6DST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6Dst)
  })
_sym_db.RegisterMessage(PatternFlowIpv6Dst)
_sym_db.RegisterMessage(PatternFlowIpv6Dst.Choice)

PatternFlowPfcPauseDstCounter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPauseDstCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEDSTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseDstCounter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPauseDstCounter)

PatternFlowPfcPauseDst = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPauseDst', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEDST_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseDst.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEDST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseDst)
  })
_sym_db.RegisterMessage(PatternFlowPfcPauseDst)
_sym_db.RegisterMessage(PatternFlowPfcPauseDst.Choice)

PatternFlowPfcPauseSrcCounter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPauseSrcCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSESRCCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseSrcCounter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPauseSrcCounter)

PatternFlowPfcPauseSrc = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPauseSrc', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSESRC_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseSrc.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSESRC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseSrc)
  })
_sym_db.RegisterMessage(PatternFlowPfcPauseSrc)
_sym_db.RegisterMessage(PatternFlowPfcPauseSrc.Choice)

PatternFlowPfcPauseEtherTypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPauseEtherTypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEETHERTYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseEtherTypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPauseEtherTypeCounter)

PatternFlowPfcPauseEtherType = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPauseEtherType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEETHERTYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseEtherType.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEETHERTYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseEtherType)
  })
_sym_db.RegisterMessage(PatternFlowPfcPauseEtherType)
_sym_db.RegisterMessage(PatternFlowPfcPauseEtherType.Choice)

PatternFlowPfcPauseControlOpCodeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPauseControlOpCodeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSECONTROLOPCODECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseControlOpCodeCounter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPauseControlOpCodeCounter)

PatternFlowPfcPauseControlOpCode = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPauseControlOpCode', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSECONTROLOPCODE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseControlOpCode.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSECONTROLOPCODE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseControlOpCode)
  })
_sym_db.RegisterMessage(PatternFlowPfcPauseControlOpCode)
_sym_db.RegisterMessage(PatternFlowPfcPauseControlOpCode.Choice)

PatternFlowPfcPauseClassEnableVectorCounter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPauseClassEnableVectorCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSECLASSENABLEVECTORCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseClassEnableVectorCounter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPauseClassEnableVectorCounter)

PatternFlowPfcPauseClassEnableVector = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPauseClassEnableVector', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseClassEnableVector.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseClassEnableVector)
  })
_sym_db.RegisterMessage(PatternFlowPfcPauseClassEnableVector)
_sym_db.RegisterMessage(PatternFlowPfcPauseClassEnableVector.Choice)

PatternFlowPfcPausePauseClass0Counter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass0Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS0COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass0Counter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass0Counter)

PatternFlowPfcPausePauseClass0 = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass0', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS0_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass0.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS0,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass0)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass0)
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass0.Choice)

PatternFlowPfcPausePauseClass1Counter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass1Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS1COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass1Counter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass1Counter)

PatternFlowPfcPausePauseClass1 = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass1', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS1_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass1.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS1,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass1)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass1)
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass1.Choice)

PatternFlowPfcPausePauseClass2Counter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass2Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS2COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass2Counter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass2Counter)

PatternFlowPfcPausePauseClass2 = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass2', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS2_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass2.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS2,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass2)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass2)
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass2.Choice)

PatternFlowPfcPausePauseClass3Counter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass3Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS3COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass3Counter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass3Counter)

PatternFlowPfcPausePauseClass3 = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass3', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS3_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass3.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS3,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass3)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass3)
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass3.Choice)

PatternFlowPfcPausePauseClass4Counter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass4Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS4COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass4Counter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass4Counter)

PatternFlowPfcPausePauseClass4 = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass4', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS4_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass4.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS4,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass4)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass4)
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass4.Choice)

PatternFlowPfcPausePauseClass5Counter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass5Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS5COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass5Counter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass5Counter)

PatternFlowPfcPausePauseClass5 = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass5', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS5_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass5.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS5,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass5)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass5)
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass5.Choice)

PatternFlowPfcPausePauseClass6Counter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass6Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS6COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass6Counter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass6Counter)

PatternFlowPfcPausePauseClass6 = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass6', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS6_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass6.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS6,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass6)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass6)
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass6.Choice)

PatternFlowPfcPausePauseClass7Counter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass7Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS7COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass7Counter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass7Counter)

PatternFlowPfcPausePauseClass7 = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass7', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS7_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass7.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS7,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass7)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass7)
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass7.Choice)

PatternFlowEthernetPauseDstCounter = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPauseDstCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSEDSTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseDstCounter)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPauseDstCounter)

PatternFlowEthernetPauseDst = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPauseDst', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSEDST_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseDst.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSEDST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseDst)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPauseDst)
_sym_db.RegisterMessage(PatternFlowEthernetPauseDst.Choice)

PatternFlowEthernetPauseSrcCounter = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPauseSrcCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSESRCCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseSrcCounter)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPauseSrcCounter)

PatternFlowEthernetPauseSrc = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPauseSrc', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSESRC_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseSrc.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSESRC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseSrc)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPauseSrc)
_sym_db.RegisterMessage(PatternFlowEthernetPauseSrc.Choice)

PatternFlowEthernetPauseEtherTypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPauseEtherTypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSEETHERTYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseEtherTypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPauseEtherTypeCounter)

PatternFlowEthernetPauseEtherType = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPauseEtherType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSEETHERTYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseEtherType.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSEETHERTYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseEtherType)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPauseEtherType)
_sym_db.RegisterMessage(PatternFlowEthernetPauseEtherType.Choice)

PatternFlowEthernetPauseControlOpCodeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPauseControlOpCodeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSECONTROLOPCODECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseControlOpCodeCounter)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPauseControlOpCodeCounter)

PatternFlowEthernetPauseControlOpCode = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPauseControlOpCode', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSECONTROLOPCODE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseControlOpCode.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSECONTROLOPCODE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseControlOpCode)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPauseControlOpCode)
_sym_db.RegisterMessage(PatternFlowEthernetPauseControlOpCode.Choice)

PatternFlowEthernetPauseTimeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPauseTimeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSETIMECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseTimeCounter)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPauseTimeCounter)

PatternFlowEthernetPauseTime = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPauseTime', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSETIME_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseTime.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSETIME,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseTime)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPauseTime)
_sym_db.RegisterMessage(PatternFlowEthernetPauseTime.Choice)

PatternFlowTcpSrcPortCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpSrcPortCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPSRCPORTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpSrcPortCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpSrcPortCounter)

PatternFlowTcpSrcPort = _reflection.GeneratedProtocolMessageType('PatternFlowTcpSrcPort', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPSRCPORT_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpSrcPort.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPSRCPORT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpSrcPort)
  })
_sym_db.RegisterMessage(PatternFlowTcpSrcPort)
_sym_db.RegisterMessage(PatternFlowTcpSrcPort.Choice)

PatternFlowTcpDstPortCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpDstPortCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPDSTPORTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpDstPortCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpDstPortCounter)

PatternFlowTcpDstPort = _reflection.GeneratedProtocolMessageType('PatternFlowTcpDstPort', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPDSTPORT_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpDstPort.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPDSTPORT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpDstPort)
  })
_sym_db.RegisterMessage(PatternFlowTcpDstPort)
_sym_db.RegisterMessage(PatternFlowTcpDstPort.Choice)

PatternFlowTcpSeqNumCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpSeqNumCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPSEQNUMCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpSeqNumCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpSeqNumCounter)

PatternFlowTcpSeqNum = _reflection.GeneratedProtocolMessageType('PatternFlowTcpSeqNum', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPSEQNUM_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpSeqNum.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPSEQNUM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpSeqNum)
  })
_sym_db.RegisterMessage(PatternFlowTcpSeqNum)
_sym_db.RegisterMessage(PatternFlowTcpSeqNum.Choice)

PatternFlowTcpAckNumCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpAckNumCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPACKNUMCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpAckNumCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpAckNumCounter)

PatternFlowTcpAckNum = _reflection.GeneratedProtocolMessageType('PatternFlowTcpAckNum', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPACKNUM_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpAckNum.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPACKNUM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpAckNum)
  })
_sym_db.RegisterMessage(PatternFlowTcpAckNum)
_sym_db.RegisterMessage(PatternFlowTcpAckNum.Choice)

PatternFlowTcpDataOffsetCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpDataOffsetCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPDATAOFFSETCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpDataOffsetCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpDataOffsetCounter)

PatternFlowTcpDataOffset = _reflection.GeneratedProtocolMessageType('PatternFlowTcpDataOffset', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPDATAOFFSET_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpDataOffset.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPDATAOFFSET,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpDataOffset)
  })
_sym_db.RegisterMessage(PatternFlowTcpDataOffset)
_sym_db.RegisterMessage(PatternFlowTcpDataOffset.Choice)

PatternFlowTcpEcnNsCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpEcnNsCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPECNNSCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpEcnNsCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpEcnNsCounter)

PatternFlowTcpEcnNs = _reflection.GeneratedProtocolMessageType('PatternFlowTcpEcnNs', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPECNNS_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpEcnNs.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPECNNS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpEcnNs)
  })
_sym_db.RegisterMessage(PatternFlowTcpEcnNs)
_sym_db.RegisterMessage(PatternFlowTcpEcnNs.Choice)

PatternFlowTcpEcnCwrCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpEcnCwrCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPECNCWRCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpEcnCwrCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpEcnCwrCounter)

PatternFlowTcpEcnCwr = _reflection.GeneratedProtocolMessageType('PatternFlowTcpEcnCwr', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPECNCWR_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpEcnCwr.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPECNCWR,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpEcnCwr)
  })
_sym_db.RegisterMessage(PatternFlowTcpEcnCwr)
_sym_db.RegisterMessage(PatternFlowTcpEcnCwr.Choice)

PatternFlowTcpEcnEchoCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpEcnEchoCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPECNECHOCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpEcnEchoCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpEcnEchoCounter)

PatternFlowTcpEcnEcho = _reflection.GeneratedProtocolMessageType('PatternFlowTcpEcnEcho', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPECNECHO_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpEcnEcho.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPECNECHO,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpEcnEcho)
  })
_sym_db.RegisterMessage(PatternFlowTcpEcnEcho)
_sym_db.RegisterMessage(PatternFlowTcpEcnEcho.Choice)

PatternFlowTcpCtlUrgCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlUrgCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLURGCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlUrgCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlUrgCounter)

PatternFlowTcpCtlUrg = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlUrg', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPCTLURG_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlUrg.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLURG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlUrg)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlUrg)
_sym_db.RegisterMessage(PatternFlowTcpCtlUrg.Choice)

PatternFlowTcpCtlAckCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlAckCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLACKCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlAckCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlAckCounter)

PatternFlowTcpCtlAck = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlAck', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPCTLACK_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlAck.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLACK,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlAck)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlAck)
_sym_db.RegisterMessage(PatternFlowTcpCtlAck.Choice)

PatternFlowTcpCtlPshCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlPshCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLPSHCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlPshCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlPshCounter)

PatternFlowTcpCtlPsh = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlPsh', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPCTLPSH_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlPsh.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLPSH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlPsh)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlPsh)
_sym_db.RegisterMessage(PatternFlowTcpCtlPsh.Choice)

PatternFlowTcpCtlRstCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlRstCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLRSTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlRstCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlRstCounter)

PatternFlowTcpCtlRst = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlRst', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPCTLRST_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlRst.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLRST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlRst)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlRst)
_sym_db.RegisterMessage(PatternFlowTcpCtlRst.Choice)

PatternFlowTcpCtlSynCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlSynCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLSYNCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlSynCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlSynCounter)

PatternFlowTcpCtlSyn = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlSyn', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPCTLSYN_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlSyn.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLSYN,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlSyn)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlSyn)
_sym_db.RegisterMessage(PatternFlowTcpCtlSyn.Choice)

PatternFlowTcpCtlFinCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlFinCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLFINCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlFinCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlFinCounter)

PatternFlowTcpCtlFin = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlFin', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPCTLFIN_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlFin.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLFIN,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlFin)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlFin)
_sym_db.RegisterMessage(PatternFlowTcpCtlFin.Choice)

PatternFlowTcpWindowCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpWindowCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPWINDOWCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpWindowCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpWindowCounter)

PatternFlowTcpWindow = _reflection.GeneratedProtocolMessageType('PatternFlowTcpWindow', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPWINDOW_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpWindow.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPWINDOW,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpWindow)
  })
_sym_db.RegisterMessage(PatternFlowTcpWindow)
_sym_db.RegisterMessage(PatternFlowTcpWindow.Choice)

PatternFlowUdpSrcPortCounter = _reflection.GeneratedProtocolMessageType('PatternFlowUdpSrcPortCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWUDPSRCPORTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpSrcPortCounter)
  })
_sym_db.RegisterMessage(PatternFlowUdpSrcPortCounter)

PatternFlowUdpSrcPort = _reflection.GeneratedProtocolMessageType('PatternFlowUdpSrcPort', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWUDPSRCPORT_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpSrcPort.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWUDPSRCPORT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpSrcPort)
  })
_sym_db.RegisterMessage(PatternFlowUdpSrcPort)
_sym_db.RegisterMessage(PatternFlowUdpSrcPort.Choice)

PatternFlowUdpDstPortCounter = _reflection.GeneratedProtocolMessageType('PatternFlowUdpDstPortCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWUDPDSTPORTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpDstPortCounter)
  })
_sym_db.RegisterMessage(PatternFlowUdpDstPortCounter)

PatternFlowUdpDstPort = _reflection.GeneratedProtocolMessageType('PatternFlowUdpDstPort', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWUDPDSTPORT_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpDstPort.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWUDPDSTPORT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpDstPort)
  })
_sym_db.RegisterMessage(PatternFlowUdpDstPort)
_sym_db.RegisterMessage(PatternFlowUdpDstPort.Choice)

PatternFlowUdpLengthCounter = _reflection.GeneratedProtocolMessageType('PatternFlowUdpLengthCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWUDPLENGTHCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpLengthCounter)
  })
_sym_db.RegisterMessage(PatternFlowUdpLengthCounter)

PatternFlowUdpLength = _reflection.GeneratedProtocolMessageType('PatternFlowUdpLength', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWUDPLENGTH_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpLength.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWUDPLENGTH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpLength)
  })
_sym_db.RegisterMessage(PatternFlowUdpLength)
_sym_db.RegisterMessage(PatternFlowUdpLength.Choice)

PatternFlowUdpChecksum = _reflection.GeneratedProtocolMessageType('PatternFlowUdpChecksum', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWUDPCHECKSUM_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpChecksum.Choice)
    })
  ,

  'Generated' : _reflection.GeneratedProtocolMessageType('Generated', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWUDPCHECKSUM_GENERATED,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpChecksum.Generated)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWUDPCHECKSUM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpChecksum)
  })
_sym_db.RegisterMessage(PatternFlowUdpChecksum)
_sym_db.RegisterMessage(PatternFlowUdpChecksum.Choice)
_sym_db.RegisterMessage(PatternFlowUdpChecksum.Generated)

PatternFlowGreChecksumPresentCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGreChecksumPresentCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGRECHECKSUMPRESENTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreChecksumPresentCounter)
  })
_sym_db.RegisterMessage(PatternFlowGreChecksumPresentCounter)

PatternFlowGreChecksumPresent = _reflection.GeneratedProtocolMessageType('PatternFlowGreChecksumPresent', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGRECHECKSUMPRESENT_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGreChecksumPresent.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGRECHECKSUMPRESENT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreChecksumPresent)
  })
_sym_db.RegisterMessage(PatternFlowGreChecksumPresent)
_sym_db.RegisterMessage(PatternFlowGreChecksumPresent.Choice)

PatternFlowGreReserved0Counter = _reflection.GeneratedProtocolMessageType('PatternFlowGreReserved0Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGRERESERVED0COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreReserved0Counter)
  })
_sym_db.RegisterMessage(PatternFlowGreReserved0Counter)

PatternFlowGreReserved0 = _reflection.GeneratedProtocolMessageType('PatternFlowGreReserved0', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGRERESERVED0_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGreReserved0.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGRERESERVED0,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreReserved0)
  })
_sym_db.RegisterMessage(PatternFlowGreReserved0)
_sym_db.RegisterMessage(PatternFlowGreReserved0.Choice)

PatternFlowGreVersionCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGreVersionCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGREVERSIONCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreVersionCounter)
  })
_sym_db.RegisterMessage(PatternFlowGreVersionCounter)

PatternFlowGreVersion = _reflection.GeneratedProtocolMessageType('PatternFlowGreVersion', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGREVERSION_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGreVersion.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGREVERSION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreVersion)
  })
_sym_db.RegisterMessage(PatternFlowGreVersion)
_sym_db.RegisterMessage(PatternFlowGreVersion.Choice)

PatternFlowGreProtocolCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGreProtocolCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGREPROTOCOLCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreProtocolCounter)
  })
_sym_db.RegisterMessage(PatternFlowGreProtocolCounter)

PatternFlowGreProtocol = _reflection.GeneratedProtocolMessageType('PatternFlowGreProtocol', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGREPROTOCOL_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGreProtocol.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGREPROTOCOL,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreProtocol)
  })
_sym_db.RegisterMessage(PatternFlowGreProtocol)
_sym_db.RegisterMessage(PatternFlowGreProtocol.Choice)

PatternFlowGreChecksum = _reflection.GeneratedProtocolMessageType('PatternFlowGreChecksum', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGRECHECKSUM_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGreChecksum.Choice)
    })
  ,

  'Generated' : _reflection.GeneratedProtocolMessageType('Generated', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGRECHECKSUM_GENERATED,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGreChecksum.Generated)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGRECHECKSUM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreChecksum)
  })
_sym_db.RegisterMessage(PatternFlowGreChecksum)
_sym_db.RegisterMessage(PatternFlowGreChecksum.Choice)
_sym_db.RegisterMessage(PatternFlowGreChecksum.Generated)

PatternFlowGreReserved1Counter = _reflection.GeneratedProtocolMessageType('PatternFlowGreReserved1Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGRERESERVED1COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreReserved1Counter)
  })
_sym_db.RegisterMessage(PatternFlowGreReserved1Counter)

PatternFlowGreReserved1 = _reflection.GeneratedProtocolMessageType('PatternFlowGreReserved1', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGRERESERVED1_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGreReserved1.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGRERESERVED1,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreReserved1)
  })
_sym_db.RegisterMessage(PatternFlowGreReserved1)
_sym_db.RegisterMessage(PatternFlowGreReserved1.Choice)

PatternFlowGtpv1VersionCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1VersionCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1VERSIONCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1VersionCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1VersionCounter)

PatternFlowGtpv1Version = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1Version', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV1VERSION_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1Version.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV1VERSION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1Version)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1Version)
_sym_db.RegisterMessage(PatternFlowGtpv1Version.Choice)

PatternFlowGtpv1ProtocolTypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1ProtocolTypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1PROTOCOLTYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1ProtocolTypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1ProtocolTypeCounter)

PatternFlowGtpv1ProtocolType = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1ProtocolType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV1PROTOCOLTYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1ProtocolType.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV1PROTOCOLTYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1ProtocolType)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1ProtocolType)
_sym_db.RegisterMessage(PatternFlowGtpv1ProtocolType.Choice)

PatternFlowGtpv1ReservedCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1ReservedCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1RESERVEDCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1ReservedCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1ReservedCounter)

PatternFlowGtpv1Reserved = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1Reserved', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV1RESERVED_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1Reserved.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV1RESERVED,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1Reserved)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1Reserved)
_sym_db.RegisterMessage(PatternFlowGtpv1Reserved.Choice)

PatternFlowGtpv1EFlagCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1EFlagCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1EFLAGCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1EFlagCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1EFlagCounter)

PatternFlowGtpv1EFlag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1EFlag', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV1EFLAG_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1EFlag.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV1EFLAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1EFlag)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1EFlag)
_sym_db.RegisterMessage(PatternFlowGtpv1EFlag.Choice)

PatternFlowGtpv1SFlagCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1SFlagCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1SFLAGCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1SFlagCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1SFlagCounter)

PatternFlowGtpv1SFlag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1SFlag', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV1SFLAG_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1SFlag.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV1SFLAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1SFlag)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1SFlag)
_sym_db.RegisterMessage(PatternFlowGtpv1SFlag.Choice)

PatternFlowGtpv1PnFlagCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1PnFlagCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1PNFLAGCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1PnFlagCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1PnFlagCounter)

PatternFlowGtpv1PnFlag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1PnFlag', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV1PNFLAG_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1PnFlag.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV1PNFLAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1PnFlag)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1PnFlag)
_sym_db.RegisterMessage(PatternFlowGtpv1PnFlag.Choice)

PatternFlowGtpv1MessageTypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1MessageTypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1MESSAGETYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1MessageTypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1MessageTypeCounter)

PatternFlowGtpv1MessageType = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1MessageType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV1MESSAGETYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1MessageType.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV1MESSAGETYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1MessageType)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1MessageType)
_sym_db.RegisterMessage(PatternFlowGtpv1MessageType.Choice)

PatternFlowGtpv1MessageLengthCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1MessageLengthCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1MESSAGELENGTHCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1MessageLengthCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1MessageLengthCounter)

PatternFlowGtpv1MessageLength = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1MessageLength', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV1MESSAGELENGTH_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1MessageLength.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV1MESSAGELENGTH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1MessageLength)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1MessageLength)
_sym_db.RegisterMessage(PatternFlowGtpv1MessageLength.Choice)

PatternFlowGtpv1TeidCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1TeidCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1TEIDCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1TeidCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1TeidCounter)

PatternFlowGtpv1Teid = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1Teid', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV1TEID_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1Teid.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV1TEID,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1Teid)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1Teid)
_sym_db.RegisterMessage(PatternFlowGtpv1Teid.Choice)

PatternFlowGtpv1SquenceNumberCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1SquenceNumberCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1SQUENCENUMBERCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1SquenceNumberCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1SquenceNumberCounter)

PatternFlowGtpv1SquenceNumber = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1SquenceNumber', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV1SQUENCENUMBER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1SquenceNumber.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV1SQUENCENUMBER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1SquenceNumber)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1SquenceNumber)
_sym_db.RegisterMessage(PatternFlowGtpv1SquenceNumber.Choice)

PatternFlowGtpv1NPduNumberCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1NPduNumberCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1NPDUNUMBERCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1NPduNumberCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1NPduNumberCounter)

PatternFlowGtpv1NPduNumber = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1NPduNumber', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV1NPDUNUMBER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1NPduNumber.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV1NPDUNUMBER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1NPduNumber)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1NPduNumber)
_sym_db.RegisterMessage(PatternFlowGtpv1NPduNumber.Choice)

PatternFlowGtpv1NextExtensionHeaderTypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1NextExtensionHeaderTypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1NextExtensionHeaderTypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1NextExtensionHeaderTypeCounter)

PatternFlowGtpv1NextExtensionHeaderType = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1NextExtensionHeaderType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1NextExtensionHeaderType.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1NextExtensionHeaderType)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1NextExtensionHeaderType)
_sym_db.RegisterMessage(PatternFlowGtpv1NextExtensionHeaderType.Choice)

PatternFlowGtpExtensionExtensionLengthCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpExtensionExtensionLengthCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpExtensionExtensionLengthCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpExtensionExtensionLengthCounter)

PatternFlowGtpExtensionExtensionLength = _reflection.GeneratedProtocolMessageType('PatternFlowGtpExtensionExtensionLength', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpExtensionExtensionLength.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpExtensionExtensionLength)
  })
_sym_db.RegisterMessage(PatternFlowGtpExtensionExtensionLength)
_sym_db.RegisterMessage(PatternFlowGtpExtensionExtensionLength.Choice)

PatternFlowGtpExtensionContentsCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpExtensionContentsCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPEXTENSIONCONTENTSCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpExtensionContentsCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpExtensionContentsCounter)

PatternFlowGtpExtensionContents = _reflection.GeneratedProtocolMessageType('PatternFlowGtpExtensionContents', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPEXTENSIONCONTENTS_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpExtensionContents.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPEXTENSIONCONTENTS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpExtensionContents)
  })
_sym_db.RegisterMessage(PatternFlowGtpExtensionContents)
_sym_db.RegisterMessage(PatternFlowGtpExtensionContents.Choice)

PatternFlowGtpExtensionNextExtensionHeaderCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpExtensionNextExtensionHeaderCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpExtensionNextExtensionHeaderCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpExtensionNextExtensionHeaderCounter)

PatternFlowGtpExtensionNextExtensionHeader = _reflection.GeneratedProtocolMessageType('PatternFlowGtpExtensionNextExtensionHeader', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpExtensionNextExtensionHeader.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpExtensionNextExtensionHeader)
  })
_sym_db.RegisterMessage(PatternFlowGtpExtensionNextExtensionHeader)
_sym_db.RegisterMessage(PatternFlowGtpExtensionNextExtensionHeader.Choice)

PatternFlowGtpv2VersionCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2VersionCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV2VERSIONCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2VersionCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2VersionCounter)

PatternFlowGtpv2Version = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2Version', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV2VERSION_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2Version.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV2VERSION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2Version)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2Version)
_sym_db.RegisterMessage(PatternFlowGtpv2Version.Choice)

PatternFlowGtpv2PiggybackingFlagCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2PiggybackingFlagCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV2PIGGYBACKINGFLAGCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2PiggybackingFlagCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2PiggybackingFlagCounter)

PatternFlowGtpv2PiggybackingFlag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2PiggybackingFlag', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV2PIGGYBACKINGFLAG_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2PiggybackingFlag.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV2PIGGYBACKINGFLAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2PiggybackingFlag)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2PiggybackingFlag)
_sym_db.RegisterMessage(PatternFlowGtpv2PiggybackingFlag.Choice)

PatternFlowGtpv2TeidFlagCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2TeidFlagCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV2TEIDFLAGCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2TeidFlagCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2TeidFlagCounter)

PatternFlowGtpv2TeidFlag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2TeidFlag', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV2TEIDFLAG_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2TeidFlag.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV2TEIDFLAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2TeidFlag)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2TeidFlag)
_sym_db.RegisterMessage(PatternFlowGtpv2TeidFlag.Choice)

PatternFlowGtpv2Spare1Counter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2Spare1Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV2SPARE1COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2Spare1Counter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2Spare1Counter)

PatternFlowGtpv2Spare1 = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2Spare1', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV2SPARE1_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2Spare1.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV2SPARE1,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2Spare1)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2Spare1)
_sym_db.RegisterMessage(PatternFlowGtpv2Spare1.Choice)

PatternFlowGtpv2MessageTypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2MessageTypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV2MESSAGETYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2MessageTypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2MessageTypeCounter)

PatternFlowGtpv2MessageType = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2MessageType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV2MESSAGETYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2MessageType.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV2MESSAGETYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2MessageType)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2MessageType)
_sym_db.RegisterMessage(PatternFlowGtpv2MessageType.Choice)

PatternFlowGtpv2MessageLengthCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2MessageLengthCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV2MESSAGELENGTHCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2MessageLengthCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2MessageLengthCounter)

PatternFlowGtpv2MessageLength = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2MessageLength', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV2MESSAGELENGTH_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2MessageLength.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV2MESSAGELENGTH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2MessageLength)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2MessageLength)
_sym_db.RegisterMessage(PatternFlowGtpv2MessageLength.Choice)

PatternFlowGtpv2TeidCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2TeidCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV2TEIDCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2TeidCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2TeidCounter)

PatternFlowGtpv2Teid = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2Teid', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV2TEID_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2Teid.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV2TEID,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2Teid)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2Teid)
_sym_db.RegisterMessage(PatternFlowGtpv2Teid.Choice)

PatternFlowGtpv2SequenceNumberCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2SequenceNumberCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV2SEQUENCENUMBERCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2SequenceNumberCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2SequenceNumberCounter)

PatternFlowGtpv2SequenceNumber = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2SequenceNumber', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV2SEQUENCENUMBER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2SequenceNumber.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV2SEQUENCENUMBER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2SequenceNumber)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2SequenceNumber)
_sym_db.RegisterMessage(PatternFlowGtpv2SequenceNumber.Choice)

PatternFlowGtpv2Spare2Counter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2Spare2Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV2SPARE2COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2Spare2Counter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2Spare2Counter)

PatternFlowGtpv2Spare2 = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2Spare2', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV2SPARE2_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2Spare2.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV2SPARE2,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2Spare2)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2Spare2)
_sym_db.RegisterMessage(PatternFlowGtpv2Spare2.Choice)

PatternFlowArpHardwareTypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowArpHardwareTypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWARPHARDWARETYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpHardwareTypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowArpHardwareTypeCounter)

PatternFlowArpHardwareType = _reflection.GeneratedProtocolMessageType('PatternFlowArpHardwareType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWARPHARDWARETYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowArpHardwareType.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWARPHARDWARETYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpHardwareType)
  })
_sym_db.RegisterMessage(PatternFlowArpHardwareType)
_sym_db.RegisterMessage(PatternFlowArpHardwareType.Choice)

PatternFlowArpProtocolTypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowArpProtocolTypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWARPPROTOCOLTYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpProtocolTypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowArpProtocolTypeCounter)

PatternFlowArpProtocolType = _reflection.GeneratedProtocolMessageType('PatternFlowArpProtocolType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWARPPROTOCOLTYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowArpProtocolType.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWARPPROTOCOLTYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpProtocolType)
  })
_sym_db.RegisterMessage(PatternFlowArpProtocolType)
_sym_db.RegisterMessage(PatternFlowArpProtocolType.Choice)

PatternFlowArpHardwareLengthCounter = _reflection.GeneratedProtocolMessageType('PatternFlowArpHardwareLengthCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWARPHARDWARELENGTHCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpHardwareLengthCounter)
  })
_sym_db.RegisterMessage(PatternFlowArpHardwareLengthCounter)

PatternFlowArpHardwareLength = _reflection.GeneratedProtocolMessageType('PatternFlowArpHardwareLength', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWARPHARDWARELENGTH_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowArpHardwareLength.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWARPHARDWARELENGTH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpHardwareLength)
  })
_sym_db.RegisterMessage(PatternFlowArpHardwareLength)
_sym_db.RegisterMessage(PatternFlowArpHardwareLength.Choice)

PatternFlowArpProtocolLengthCounter = _reflection.GeneratedProtocolMessageType('PatternFlowArpProtocolLengthCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWARPPROTOCOLLENGTHCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpProtocolLengthCounter)
  })
_sym_db.RegisterMessage(PatternFlowArpProtocolLengthCounter)

PatternFlowArpProtocolLength = _reflection.GeneratedProtocolMessageType('PatternFlowArpProtocolLength', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWARPPROTOCOLLENGTH_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowArpProtocolLength.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWARPPROTOCOLLENGTH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpProtocolLength)
  })
_sym_db.RegisterMessage(PatternFlowArpProtocolLength)
_sym_db.RegisterMessage(PatternFlowArpProtocolLength.Choice)

PatternFlowArpOperationCounter = _reflection.GeneratedProtocolMessageType('PatternFlowArpOperationCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWARPOPERATIONCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpOperationCounter)
  })
_sym_db.RegisterMessage(PatternFlowArpOperationCounter)

PatternFlowArpOperation = _reflection.GeneratedProtocolMessageType('PatternFlowArpOperation', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWARPOPERATION_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowArpOperation.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWARPOPERATION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpOperation)
  })
_sym_db.RegisterMessage(PatternFlowArpOperation)
_sym_db.RegisterMessage(PatternFlowArpOperation.Choice)

PatternFlowArpSenderHardwareAddrCounter = _reflection.GeneratedProtocolMessageType('PatternFlowArpSenderHardwareAddrCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWARPSENDERHARDWAREADDRCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpSenderHardwareAddrCounter)
  })
_sym_db.RegisterMessage(PatternFlowArpSenderHardwareAddrCounter)

PatternFlowArpSenderHardwareAddr = _reflection.GeneratedProtocolMessageType('PatternFlowArpSenderHardwareAddr', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWARPSENDERHARDWAREADDR_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowArpSenderHardwareAddr.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWARPSENDERHARDWAREADDR,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpSenderHardwareAddr)
  })
_sym_db.RegisterMessage(PatternFlowArpSenderHardwareAddr)
_sym_db.RegisterMessage(PatternFlowArpSenderHardwareAddr.Choice)

PatternFlowArpSenderProtocolAddrCounter = _reflection.GeneratedProtocolMessageType('PatternFlowArpSenderProtocolAddrCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWARPSENDERPROTOCOLADDRCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpSenderProtocolAddrCounter)
  })
_sym_db.RegisterMessage(PatternFlowArpSenderProtocolAddrCounter)

PatternFlowArpSenderProtocolAddr = _reflection.GeneratedProtocolMessageType('PatternFlowArpSenderProtocolAddr', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWARPSENDERPROTOCOLADDR_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowArpSenderProtocolAddr.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWARPSENDERPROTOCOLADDR,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpSenderProtocolAddr)
  })
_sym_db.RegisterMessage(PatternFlowArpSenderProtocolAddr)
_sym_db.RegisterMessage(PatternFlowArpSenderProtocolAddr.Choice)

PatternFlowArpTargetHardwareAddrCounter = _reflection.GeneratedProtocolMessageType('PatternFlowArpTargetHardwareAddrCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWARPTARGETHARDWAREADDRCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpTargetHardwareAddrCounter)
  })
_sym_db.RegisterMessage(PatternFlowArpTargetHardwareAddrCounter)

PatternFlowArpTargetHardwareAddr = _reflection.GeneratedProtocolMessageType('PatternFlowArpTargetHardwareAddr', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWARPTARGETHARDWAREADDR_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowArpTargetHardwareAddr.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWARPTARGETHARDWAREADDR,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpTargetHardwareAddr)
  })
_sym_db.RegisterMessage(PatternFlowArpTargetHardwareAddr)
_sym_db.RegisterMessage(PatternFlowArpTargetHardwareAddr.Choice)

PatternFlowArpTargetProtocolAddrCounter = _reflection.GeneratedProtocolMessageType('PatternFlowArpTargetProtocolAddrCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWARPTARGETPROTOCOLADDRCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpTargetProtocolAddrCounter)
  })
_sym_db.RegisterMessage(PatternFlowArpTargetProtocolAddrCounter)

PatternFlowArpTargetProtocolAddr = _reflection.GeneratedProtocolMessageType('PatternFlowArpTargetProtocolAddr', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWARPTARGETPROTOCOLADDR_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowArpTargetProtocolAddr.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWARPTARGETPROTOCOLADDR,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpTargetProtocolAddr)
  })
_sym_db.RegisterMessage(PatternFlowArpTargetProtocolAddr)
_sym_db.RegisterMessage(PatternFlowArpTargetProtocolAddr.Choice)

PatternFlowIcmpEchoTypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpEchoTypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPECHOTYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoTypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowIcmpEchoTypeCounter)

PatternFlowIcmpEchoType = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpEchoType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPECHOTYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoType.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPECHOTYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoType)
  })
_sym_db.RegisterMessage(PatternFlowIcmpEchoType)
_sym_db.RegisterMessage(PatternFlowIcmpEchoType.Choice)

PatternFlowIcmpEchoCodeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpEchoCodeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPECHOCODECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoCodeCounter)
  })
_sym_db.RegisterMessage(PatternFlowIcmpEchoCodeCounter)

PatternFlowIcmpEchoCode = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpEchoCode', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPECHOCODE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoCode.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPECHOCODE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoCode)
  })
_sym_db.RegisterMessage(PatternFlowIcmpEchoCode)
_sym_db.RegisterMessage(PatternFlowIcmpEchoCode.Choice)

PatternFlowIcmpEchoChecksum = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpEchoChecksum', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPECHOCHECKSUM_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoChecksum.Choice)
    })
  ,

  'Generated' : _reflection.GeneratedProtocolMessageType('Generated', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPECHOCHECKSUM_GENERATED,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoChecksum.Generated)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPECHOCHECKSUM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoChecksum)
  })
_sym_db.RegisterMessage(PatternFlowIcmpEchoChecksum)
_sym_db.RegisterMessage(PatternFlowIcmpEchoChecksum.Choice)
_sym_db.RegisterMessage(PatternFlowIcmpEchoChecksum.Generated)

PatternFlowIcmpEchoIdentifierCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpEchoIdentifierCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPECHOIDENTIFIERCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoIdentifierCounter)
  })
_sym_db.RegisterMessage(PatternFlowIcmpEchoIdentifierCounter)

PatternFlowIcmpEchoIdentifier = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpEchoIdentifier', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPECHOIDENTIFIER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoIdentifier.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPECHOIDENTIFIER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoIdentifier)
  })
_sym_db.RegisterMessage(PatternFlowIcmpEchoIdentifier)
_sym_db.RegisterMessage(PatternFlowIcmpEchoIdentifier.Choice)

PatternFlowIcmpEchoSequenceNumberCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpEchoSequenceNumberCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPECHOSEQUENCENUMBERCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoSequenceNumberCounter)
  })
_sym_db.RegisterMessage(PatternFlowIcmpEchoSequenceNumberCounter)

PatternFlowIcmpEchoSequenceNumber = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpEchoSequenceNumber', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPECHOSEQUENCENUMBER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoSequenceNumber.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPECHOSEQUENCENUMBER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoSequenceNumber)
  })
_sym_db.RegisterMessage(PatternFlowIcmpEchoSequenceNumber)
_sym_db.RegisterMessage(PatternFlowIcmpEchoSequenceNumber.Choice)

PatternFlowIcmpCommonChecksum = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpCommonChecksum', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPCOMMONCHECKSUM_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpCommonChecksum.Choice)
    })
  ,

  'Generated' : _reflection.GeneratedProtocolMessageType('Generated', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPCOMMONCHECKSUM_GENERATED,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpCommonChecksum.Generated)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPCOMMONCHECKSUM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpCommonChecksum)
  })
_sym_db.RegisterMessage(PatternFlowIcmpCommonChecksum)
_sym_db.RegisterMessage(PatternFlowIcmpCommonChecksum.Choice)
_sym_db.RegisterMessage(PatternFlowIcmpCommonChecksum.Generated)

PatternFlowIcmpNextFieldsIdentifierCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpNextFieldsIdentifierCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPNEXTFIELDSIDENTIFIERCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpNextFieldsIdentifierCounter)
  })
_sym_db.RegisterMessage(PatternFlowIcmpNextFieldsIdentifierCounter)

PatternFlowIcmpNextFieldsIdentifier = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpNextFieldsIdentifier', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpNextFieldsIdentifier.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpNextFieldsIdentifier)
  })
_sym_db.RegisterMessage(PatternFlowIcmpNextFieldsIdentifier)
_sym_db.RegisterMessage(PatternFlowIcmpNextFieldsIdentifier.Choice)

PatternFlowIcmpNextFieldsSequenceNumberCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpNextFieldsSequenceNumberCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpNextFieldsSequenceNumberCounter)
  })
_sym_db.RegisterMessage(PatternFlowIcmpNextFieldsSequenceNumberCounter)

PatternFlowIcmpNextFieldsSequenceNumber = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpNextFieldsSequenceNumber', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpNextFieldsSequenceNumber.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpNextFieldsSequenceNumber)
  })
_sym_db.RegisterMessage(PatternFlowIcmpNextFieldsSequenceNumber)
_sym_db.RegisterMessage(PatternFlowIcmpNextFieldsSequenceNumber.Choice)

PatternFlowIcmpv6EchoTypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpv6EchoTypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOTYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoTypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoTypeCounter)

PatternFlowIcmpv6EchoType = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpv6EchoType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOTYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoType.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOTYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoType)
  })
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoType)
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoType.Choice)

PatternFlowIcmpv6EchoCodeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpv6EchoCodeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOCODECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoCodeCounter)
  })
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoCodeCounter)

PatternFlowIcmpv6EchoCode = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpv6EchoCode', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOCODE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoCode.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOCODE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoCode)
  })
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoCode)
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoCode.Choice)

PatternFlowIcmpv6EchoIdentifierCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpv6EchoIdentifierCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOIDENTIFIERCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoIdentifierCounter)
  })
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoIdentifierCounter)

PatternFlowIcmpv6EchoIdentifier = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpv6EchoIdentifier', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOIDENTIFIER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoIdentifier.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOIDENTIFIER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoIdentifier)
  })
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoIdentifier)
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoIdentifier.Choice)

PatternFlowIcmpv6EchoSequenceNumberCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpv6EchoSequenceNumberCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOSEQUENCENUMBERCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoSequenceNumberCounter)
  })
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoSequenceNumberCounter)

PatternFlowIcmpv6EchoSequenceNumber = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpv6EchoSequenceNumber', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoSequenceNumber.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoSequenceNumber)
  })
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoSequenceNumber)
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoSequenceNumber.Choice)

PatternFlowIcmpv6EchoChecksum = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpv6EchoChecksum', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOCHECKSUM_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoChecksum.Choice)
    })
  ,

  'Generated' : _reflection.GeneratedProtocolMessageType('Generated', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOCHECKSUM_GENERATED,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoChecksum.Generated)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOCHECKSUM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoChecksum)
  })
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoChecksum)
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoChecksum.Choice)
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoChecksum.Generated)

PatternFlowIcmpv6CommonChecksum = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpv6CommonChecksum', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPV6COMMONCHECKSUM_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6CommonChecksum.Choice)
    })
  ,

  'Generated' : _reflection.GeneratedProtocolMessageType('Generated', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPV6COMMONCHECKSUM_GENERATED,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6CommonChecksum.Generated)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPV6COMMONCHECKSUM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6CommonChecksum)
  })
_sym_db.RegisterMessage(PatternFlowIcmpv6CommonChecksum)
_sym_db.RegisterMessage(PatternFlowIcmpv6CommonChecksum.Choice)
_sym_db.RegisterMessage(PatternFlowIcmpv6CommonChecksum.Generated)

PatternFlowPppAddressCounter = _reflection.GeneratedProtocolMessageType('PatternFlowPppAddressCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPPPADDRESSCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPppAddressCounter)
  })
_sym_db.RegisterMessage(PatternFlowPppAddressCounter)

PatternFlowPppAddress = _reflection.GeneratedProtocolMessageType('PatternFlowPppAddress', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPPPADDRESS_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPppAddress.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPPPADDRESS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPppAddress)
  })
_sym_db.RegisterMessage(PatternFlowPppAddress)
_sym_db.RegisterMessage(PatternFlowPppAddress.Choice)

PatternFlowPppControlCounter = _reflection.GeneratedProtocolMessageType('PatternFlowPppControlCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPPPCONTROLCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPppControlCounter)
  })
_sym_db.RegisterMessage(PatternFlowPppControlCounter)

PatternFlowPppControl = _reflection.GeneratedProtocolMessageType('PatternFlowPppControl', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPPPCONTROL_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPppControl.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPPPCONTROL,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPppControl)
  })
_sym_db.RegisterMessage(PatternFlowPppControl)
_sym_db.RegisterMessage(PatternFlowPppControl.Choice)

PatternFlowPppProtocolTypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowPppProtocolTypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPPPPROTOCOLTYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPppProtocolTypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowPppProtocolTypeCounter)

PatternFlowPppProtocolType = _reflection.GeneratedProtocolMessageType('PatternFlowPppProtocolType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPPPPROTOCOLTYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPppProtocolType.Choice)
    })
  ,

  'Auto' : _reflection.GeneratedProtocolMessageType('Auto', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPPPPROTOCOLTYPE_AUTO,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPppProtocolType.Auto)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPPPPROTOCOLTYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPppProtocolType)
  })
_sym_db.RegisterMessage(PatternFlowPppProtocolType)
_sym_db.RegisterMessage(PatternFlowPppProtocolType.Choice)
_sym_db.RegisterMessage(PatternFlowPppProtocolType.Auto)

PatternFlowIgmpv1VersionCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIgmpv1VersionCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIGMPV1VERSIONCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1VersionCounter)
  })
_sym_db.RegisterMessage(PatternFlowIgmpv1VersionCounter)

PatternFlowIgmpv1Version = _reflection.GeneratedProtocolMessageType('PatternFlowIgmpv1Version', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIGMPV1VERSION_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1Version.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIGMPV1VERSION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1Version)
  })
_sym_db.RegisterMessage(PatternFlowIgmpv1Version)
_sym_db.RegisterMessage(PatternFlowIgmpv1Version.Choice)

PatternFlowIgmpv1TypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIgmpv1TypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIGMPV1TYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1TypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowIgmpv1TypeCounter)

PatternFlowIgmpv1Type = _reflection.GeneratedProtocolMessageType('PatternFlowIgmpv1Type', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIGMPV1TYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1Type.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIGMPV1TYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1Type)
  })
_sym_db.RegisterMessage(PatternFlowIgmpv1Type)
_sym_db.RegisterMessage(PatternFlowIgmpv1Type.Choice)

PatternFlowIgmpv1UnusedCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIgmpv1UnusedCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIGMPV1UNUSEDCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1UnusedCounter)
  })
_sym_db.RegisterMessage(PatternFlowIgmpv1UnusedCounter)

PatternFlowIgmpv1Unused = _reflection.GeneratedProtocolMessageType('PatternFlowIgmpv1Unused', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIGMPV1UNUSED_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1Unused.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIGMPV1UNUSED,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1Unused)
  })
_sym_db.RegisterMessage(PatternFlowIgmpv1Unused)
_sym_db.RegisterMessage(PatternFlowIgmpv1Unused.Choice)

PatternFlowIgmpv1Checksum = _reflection.GeneratedProtocolMessageType('PatternFlowIgmpv1Checksum', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIGMPV1CHECKSUM_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1Checksum.Choice)
    })
  ,

  'Generated' : _reflection.GeneratedProtocolMessageType('Generated', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIGMPV1CHECKSUM_GENERATED,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1Checksum.Generated)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIGMPV1CHECKSUM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1Checksum)
  })
_sym_db.RegisterMessage(PatternFlowIgmpv1Checksum)
_sym_db.RegisterMessage(PatternFlowIgmpv1Checksum.Choice)
_sym_db.RegisterMessage(PatternFlowIgmpv1Checksum.Generated)

PatternFlowIgmpv1GroupAddressCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIgmpv1GroupAddressCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIGMPV1GROUPADDRESSCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1GroupAddressCounter)
  })
_sym_db.RegisterMessage(PatternFlowIgmpv1GroupAddressCounter)

PatternFlowIgmpv1GroupAddress = _reflection.GeneratedProtocolMessageType('PatternFlowIgmpv1GroupAddress', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIGMPV1GROUPADDRESS_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1GroupAddress.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIGMPV1GROUPADDRESS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1GroupAddress)
  })
_sym_db.RegisterMessage(PatternFlowIgmpv1GroupAddress)
_sym_db.RegisterMessage(PatternFlowIgmpv1GroupAddress.Choice)

Success = _reflection.GeneratedProtocolMessageType('Success', (_message.Message,), {
  'DESCRIPTOR' : _SUCCESS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Success)
  })
_sym_db.RegisterMessage(Success)

BadRequest = _reflection.GeneratedProtocolMessageType('BadRequest', (_message.Message,), {
  'DESCRIPTOR' : _BADREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BadRequest)
  })
_sym_db.RegisterMessage(BadRequest)

InternalServerError = _reflection.GeneratedProtocolMessageType('InternalServerError', (_message.Message,), {
  'DESCRIPTOR' : _INTERNALSERVERERROR,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.InternalServerError)
  })
_sym_db.RegisterMessage(InternalServerError)

SetConfigRequest = _reflection.GeneratedProtocolMessageType('SetConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETCONFIGREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetConfigRequest)
  })
_sym_db.RegisterMessage(SetConfigRequest)

SetConfigResponse = _reflection.GeneratedProtocolMessageType('SetConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETCONFIGRESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetConfigResponse)
  })
_sym_db.RegisterMessage(SetConfigResponse)

GetConfigResponse = _reflection.GeneratedProtocolMessageType('GetConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGRESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.GetConfigResponse)
  })
_sym_db.RegisterMessage(GetConfigResponse)

SetTransmitStateRequest = _reflection.GeneratedProtocolMessageType('SetTransmitStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETTRANSMITSTATEREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetTransmitStateRequest)
  })
_sym_db.RegisterMessage(SetTransmitStateRequest)

SetTransmitStateResponse = _reflection.GeneratedProtocolMessageType('SetTransmitStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETTRANSMITSTATERESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetTransmitStateResponse)
  })
_sym_db.RegisterMessage(SetTransmitStateResponse)

SetLinkStateRequest = _reflection.GeneratedProtocolMessageType('SetLinkStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETLINKSTATEREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetLinkStateRequest)
  })
_sym_db.RegisterMessage(SetLinkStateRequest)

SetLinkStateResponse = _reflection.GeneratedProtocolMessageType('SetLinkStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETLINKSTATERESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetLinkStateResponse)
  })
_sym_db.RegisterMessage(SetLinkStateResponse)

SetCaptureStateRequest = _reflection.GeneratedProtocolMessageType('SetCaptureStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETCAPTURESTATEREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetCaptureStateRequest)
  })
_sym_db.RegisterMessage(SetCaptureStateRequest)

SetCaptureStateResponse = _reflection.GeneratedProtocolMessageType('SetCaptureStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETCAPTURESTATERESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetCaptureStateResponse)
  })
_sym_db.RegisterMessage(SetCaptureStateResponse)

UpdateFlowsRequest = _reflection.GeneratedProtocolMessageType('UpdateFlowsRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFLOWSREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.UpdateFlowsRequest)
  })
_sym_db.RegisterMessage(UpdateFlowsRequest)

UpdateFlowsResponse = _reflection.GeneratedProtocolMessageType('UpdateFlowsResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFLOWSRESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.UpdateFlowsResponse)
  })
_sym_db.RegisterMessage(UpdateFlowsResponse)

SetRouteStateRequest = _reflection.GeneratedProtocolMessageType('SetRouteStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETROUTESTATEREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetRouteStateRequest)
  })
_sym_db.RegisterMessage(SetRouteStateRequest)

SetRouteStateResponse = _reflection.GeneratedProtocolMessageType('SetRouteStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETROUTESTATERESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetRouteStateResponse)
  })
_sym_db.RegisterMessage(SetRouteStateResponse)

SendPingRequest = _reflection.GeneratedProtocolMessageType('SendPingRequest', (_message.Message,), {
  'DESCRIPTOR' : _SENDPINGREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SendPingRequest)
  })
_sym_db.RegisterMessage(SendPingRequest)

SendPingResponse = _reflection.GeneratedProtocolMessageType('SendPingResponse', (_message.Message,), {
  'DESCRIPTOR' : _SENDPINGRESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SendPingResponse)
  })
_sym_db.RegisterMessage(SendPingResponse)

SetProtocolStateRequest = _reflection.GeneratedProtocolMessageType('SetProtocolStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETPROTOCOLSTATEREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetProtocolStateRequest)
  })
_sym_db.RegisterMessage(SetProtocolStateRequest)

SetProtocolStateResponse = _reflection.GeneratedProtocolMessageType('SetProtocolStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETPROTOCOLSTATERESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetProtocolStateResponse)
  })
_sym_db.RegisterMessage(SetProtocolStateResponse)

GetMetricsRequest = _reflection.GeneratedProtocolMessageType('GetMetricsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMETRICSREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.GetMetricsRequest)
  })
_sym_db.RegisterMessage(GetMetricsRequest)

GetMetricsResponse = _reflection.GeneratedProtocolMessageType('GetMetricsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMETRICSRESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.GetMetricsResponse)
  })
_sym_db.RegisterMessage(GetMetricsResponse)

GetStatesRequest = _reflection.GeneratedProtocolMessageType('GetStatesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTATESREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.GetStatesRequest)
  })
_sym_db.RegisterMessage(GetStatesRequest)

GetStatesResponse = _reflection.GeneratedProtocolMessageType('GetStatesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSTATESRESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.GetStatesResponse)
  })
_sym_db.RegisterMessage(GetStatesResponse)

GetCaptureRequest = _reflection.GeneratedProtocolMessageType('GetCaptureRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCAPTUREREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.GetCaptureRequest)
  })
_sym_db.RegisterMessage(GetCaptureRequest)

GetCaptureResponse = _reflection.GeneratedProtocolMessageType('GetCaptureResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCAPTURERESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.GetCaptureResponse)
  })
_sym_db.RegisterMessage(GetCaptureResponse)



_OPENAPI = _descriptor.ServiceDescriptor(
  name='Openapi',
  full_name='otg.Openapi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=137183,
  serialized_end=138003,
  methods=[
  _descriptor.MethodDescriptor(
    name='SetConfig',
    full_name='otg.Openapi.SetConfig',
    index=0,
    containing_service=None,
    input_type=_SETCONFIGREQUEST,
    output_type=_SETCONFIGRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetConfig',
    full_name='otg.Openapi.GetConfig',
    index=1,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_GETCONFIGRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetTransmitState',
    full_name='otg.Openapi.SetTransmitState',
    index=2,
    containing_service=None,
    input_type=_SETTRANSMITSTATEREQUEST,
    output_type=_SETTRANSMITSTATERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetLinkState',
    full_name='otg.Openapi.SetLinkState',
    index=3,
    containing_service=None,
    input_type=_SETLINKSTATEREQUEST,
    output_type=_SETLINKSTATERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetCaptureState',
    full_name='otg.Openapi.SetCaptureState',
    index=4,
    containing_service=None,
    input_type=_SETCAPTURESTATEREQUEST,
    output_type=_SETCAPTURESTATERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFlows',
    full_name='otg.Openapi.UpdateFlows',
    index=5,
    containing_service=None,
    input_type=_UPDATEFLOWSREQUEST,
    output_type=_UPDATEFLOWSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetRouteState',
    full_name='otg.Openapi.SetRouteState',
    index=6,
    containing_service=None,
    input_type=_SETROUTESTATEREQUEST,
    output_type=_SETROUTESTATERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendPing',
    full_name='otg.Openapi.SendPing',
    index=7,
    containing_service=None,
    input_type=_SENDPINGREQUEST,
    output_type=_SENDPINGRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetProtocolState',
    full_name='otg.Openapi.SetProtocolState',
    index=8,
    containing_service=None,
    input_type=_SETPROTOCOLSTATEREQUEST,
    output_type=_SETPROTOCOLSTATERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetMetrics',
    full_name='otg.Openapi.GetMetrics',
    index=9,
    containing_service=None,
    input_type=_GETMETRICSREQUEST,
    output_type=_GETMETRICSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetStates',
    full_name='otg.Openapi.GetStates',
    index=10,
    containing_service=None,
    input_type=_GETSTATESREQUEST,
    output_type=_GETSTATESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCapture',
    full_name='otg.Openapi.GetCapture',
    index=11,
    containing_service=None,
    input_type=_GETCAPTUREREQUEST,
    output_type=_GETCAPTURERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_OPENAPI)

DESCRIPTOR.services_by_name['Openapi'] = _OPENAPI

# @@protoc_insertion_point(module_scope)
